package androidx.activity;

import androidx.fragment.app.FragmentManager;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleEventObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.LifecycleRegistry;
import java.util.ArrayDeque;
import java.util.Iterator;

public final class OnBackPressedDispatcher {
    public final Runnable mFallbackOnBackPressed;
    public final ArrayDeque<FragmentManager.AnonymousClass1> mOnBackPressedCallbacks = new ArrayDeque<>();

    public class LifecycleOnBackPressedCancellable implements LifecycleEventObserver, Cancellable {
        public Cancellable mCurrentCancellable;
        public final Lifecycle mLifecycle;
        public final FragmentManager.AnonymousClass1 mOnBackPressedCallback;

        public LifecycleOnBackPressedCancellable(Lifecycle lifecycle, FragmentManager.AnonymousClass1 r3) {
            this.mLifecycle = lifecycle;
            this.mOnBackPressedCallback = r3;
            lifecycle.addObserver(this);
        }

        @Override // androidx.activity.Cancellable
        public void cancel() {
            LifecycleRegistry lifecycleRegistry = (LifecycleRegistry) this.mLifecycle;
            lifecycleRegistry.enforceMainThreadIfNeeded("removeObserver");
            lifecycleRegistry.mObserverMap.remove(this);
            this.mOnBackPressedCallback.mCancellables.remove(this);
            Cancellable cancellable = this.mCurrentCancellable;
            if (cancellable != null) {
                cancellable.cancel();
                this.mCurrentCancellable = null;
            }
        }

        @Override // androidx.lifecycle.LifecycleEventObserver
        public void onStateChanged(LifecycleOwner lifecycleOwner, Lifecycle.Event event) {
            if (event == Lifecycle.Event.ON_START) {
                OnBackPressedDispatcher onBackPressedDispatcher = OnBackPressedDispatcher.this;
                FragmentManager.AnonymousClass1 r3 = this.mOnBackPressedCallback;
                onBackPressedDispatcher.mOnBackPressedCallbacks.add(r3);
                OnBackPressedCancellable onBackPressedCancellable = new OnBackPressedCancellable(r3);
                r3.mCancellables.add(onBackPressedCancellable);
                this.mCurrentCancellable = onBackPressedCancellable;
            } else if (event == Lifecycle.Event.ON_STOP) {
                Cancellable cancellable = this.mCurrentCancellable;
                if (cancellable != null) {
                    cancellable.cancel();
                }
            } else if (event == Lifecycle.Event.ON_DESTROY) {
                cancel();
            }
        }
    }

    public class OnBackPressedCancellable implements Cancellable {
        public final FragmentManager.AnonymousClass1 mOnBackPressedCallback;

        public OnBackPressedCancellable(FragmentManager.AnonymousClass1 r2) {
            this.mOnBackPressedCallback = r2;
        }

        @Override // androidx.activity.Cancellable
        public void cancel() {
            OnBackPressedDispatcher.this.mOnBackPressedCallbacks.remove(this.mOnBackPressedCallback);
            this.mOnBackPressedCallback.mCancellables.remove(this);
        }
    }

    public OnBackPressedDispatcher(Runnable runnable) {
        this.mFallbackOnBackPressed = runnable;
    }

    public void onBackPressed() {
        Iterator<FragmentManager.AnonymousClass1> descendingIterator = this.mOnBackPressedCallbacks.descendingIterator();
        while (descendingIterator.hasNext()) {
            FragmentManager.AnonymousClass1 next = descendingIterator.next();
            if (next.mEnabled) {
                FragmentManager fragmentManager = FragmentManager.this;
                fragmentManager.execPendingActions(true);
                if (fragmentManager.mOnBackPressedCallback.mEnabled) {
                    fragmentManager.popBackStackImmediate();
                    return;
                } else {
                    fragmentManager.mOnBackPressedDispatcher.onBackPressed();
                    return;
                }
            }
        }
        Runnable runnable = this.mFallbackOnBackPressed;
        if (runnable != null) {
            runnable.run();
        }
    }
}
