package androidx.appcompat.app;

import android.content.Context;
import android.content.DialogInterface;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.TypedValue;
import android.view.ContextThemeWrapper;
import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;
import androidx.appcompat.R$attr;
import androidx.appcompat.R$id;
import androidx.appcompat.app.AlertController;
import androidx.appcompat.widget.LinearLayoutCompat;
import androidx.core.view.ViewCompat;
import androidx.core.widget.NestedScrollView;
import com.tencent.mm.opensdk.modelmsg.WXMediaMessage;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;
import org.xbill.DNS.KEYRecord;

public class AlertDialog extends AppCompatDialog implements DialogInterface {
    public final AlertController mAlert = new AlertController(getContext(), this, getWindow());

    public class Builder {
        public final AlertController.AlertParams P;
        public final int mTheme;

        public Builder(Context context) {
            int resolveDialogTheme = AlertDialog.resolveDialogTheme(context, 0);
            this.P = new AlertController.AlertParams(new ContextThemeWrapper(context, AlertDialog.resolveDialogTheme(context, resolveDialogTheme)));
            this.mTheme = resolveDialogTheme;
        }

        public AlertDialog create() {
            int i;
            AlertDialog alertDialog = new AlertDialog(this.P.mContext, this.mTheme);
            AlertController.AlertParams alertParams = this.P;
            AlertController alertController = alertDialog.mAlert;
            View view = alertParams.mCustomTitleView;
            if (view != null) {
                alertController.mCustomTitleView = view;
            } else {
                CharSequence charSequence = alertParams.mTitle;
                if (charSequence != null) {
                    alertController.mTitle = charSequence;
                    TextView textView = alertController.mTitleView;
                    if (textView != null) {
                        textView.setText(charSequence);
                    }
                }
                Drawable drawable = alertParams.mIcon;
                if (drawable != null) {
                    alertController.mIcon = drawable;
                    alertController.mIconId = 0;
                    ImageView imageView = alertController.mIconView;
                    if (imageView != null) {
                        imageView.setVisibility(0);
                        alertController.mIconView.setImageDrawable(drawable);
                    }
                }
            }
            CharSequence charSequence2 = alertParams.mMessage;
            if (charSequence2 != null) {
                alertController.mMessage = charSequence2;
                TextView textView2 = alertController.mMessageView;
                if (textView2 != null) {
                    textView2.setText(charSequence2);
                }
            }
            CharSequence charSequence3 = alertParams.mPositiveButtonText;
            if (charSequence3 != null) {
                alertController.setButton(-1, charSequence3, alertParams.mPositiveButtonListener, null, null);
            }
            CharSequence charSequence4 = alertParams.mNegativeButtonText;
            if (charSequence4 != null) {
                alertController.setButton(-2, charSequence4, alertParams.mNegativeButtonListener, null, null);
            }
            if (alertParams.mAdapter != null) {
                AlertController.RecycleListView recycleListView = (AlertController.RecycleListView) alertParams.mInflater.inflate(alertController.mListLayout, (ViewGroup) null);
                if (alertParams.mIsSingleChoice) {
                    i = alertController.mSingleChoiceItemLayout;
                } else {
                    i = alertController.mListItemLayout;
                }
                ListAdapter listAdapter = alertParams.mAdapter;
                if (listAdapter == null) {
                    listAdapter = new AlertController.CheckedItemAdapter(alertParams.mContext, i, 16908308, null);
                }
                alertController.mAdapter = listAdapter;
                alertController.mCheckedItem = alertParams.mCheckedItem;
                if (alertParams.mOnClickListener != null) {
                    recycleListView.setOnItemClickListener(
                    /*  JADX ERROR: Method code generation error
                        jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0098: INVOKE  
                          (r2v6 'recycleListView' androidx.appcompat.app.AlertController$RecycleListView)
                          (wrap: androidx.appcompat.app.AlertController$AlertParams$3 : 0x0095: CONSTRUCTOR  (r5v5 androidx.appcompat.app.AlertController$AlertParams$3) = 
                          (r1v2 'alertParams' androidx.appcompat.app.AlertController$AlertParams)
                          (r8v0 'alertController' androidx.appcompat.app.AlertController)
                         call: androidx.appcompat.app.AlertController.AlertParams.3.<init>(androidx.appcompat.app.AlertController$AlertParams, androidx.appcompat.app.AlertController):void type: CONSTRUCTOR)
                         type: VIRTUAL call: android.widget.ListView.setOnItemClickListener(android.widget.AdapterView$OnItemClickListener):void in method: androidx.appcompat.app.AlertDialog.Builder.create():androidx.appcompat.app.AlertDialog, file: classes.dex
                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                        	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                        	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                        	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                        	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                        	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                        	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                        	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                        	at java.util.ArrayList.forEach(ArrayList.java:1259)
                        	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                        	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                        Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0095: CONSTRUCTOR  (r5v5 androidx.appcompat.app.AlertController$AlertParams$3) = 
                          (r1v2 'alertParams' androidx.appcompat.app.AlertController$AlertParams)
                          (r8v0 'alertController' androidx.appcompat.app.AlertController)
                         call: androidx.appcompat.app.AlertController.AlertParams.3.<init>(androidx.appcompat.app.AlertController$AlertParams, androidx.appcompat.app.AlertController):void type: CONSTRUCTOR in method: androidx.appcompat.app.AlertDialog.Builder.create():androidx.appcompat.app.AlertDialog, file: classes.dex
                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                        	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                        	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                        	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                        	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                        	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                        	... 24 more
                        Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.appcompat.app.AlertController, state: GENERATED_AND_UNLOADED
                        	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                        	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                        	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                        	... 30 more
                        */
                    /*
                    // Method dump skipped, instructions count: 206
                    */
                    throw new UnsupportedOperationException("Method not decompiled: androidx.appcompat.app.AlertDialog.Builder.create():androidx.appcompat.app.AlertDialog");
                }
            }

            public AlertDialog(Context context, int i) {
                super(context, resolveDialogTheme(context, i));
            }

            public static int resolveDialogTheme(Context context, int i) {
                if (((i >>> 24) & KEYRecord.PROTOCOL_ANY) >= 1) {
                    return i;
                }
                TypedValue typedValue = new TypedValue();
                context.getTheme().resolveAttribute(R$attr.alertDialogTheme, typedValue, true);
                return typedValue.resourceId;
            }

            @Override // androidx.appcompat.app.AppCompatDialog
            public void onCreate(Bundle bundle) {
                int i;
                boolean z;
                View view;
                ListAdapter listAdapter;
                View view2;
                View view3;
                View findViewById;
                super.onCreate(bundle);
                AlertController alertController = this.mAlert;
                if (alertController.mButtonPanelSideLayout == 0) {
                    i = alertController.mAlertDialogLayout;
                } else {
                    i = alertController.mAlertDialogLayout;
                }
                alertController.mDialog.setContentView(i);
                View findViewById2 = alertController.mWindow.findViewById(R$id.parentPanel);
                int i2 = R$id.topPanel;
                View findViewById3 = findViewById2.findViewById(i2);
                int i3 = R$id.contentPanel;
                View findViewById4 = findViewById2.findViewById(i3);
                int i4 = R$id.buttonPanel;
                View findViewById5 = findViewById2.findViewById(i4);
                ViewGroup viewGroup = (ViewGroup) findViewById2.findViewById(R$id.customPanel);
                View view4 = alertController.mView;
                int i5 = 0;
                if (view4 == null) {
                    view4 = alertController.mViewLayoutResId != 0 ? LayoutInflater.from(alertController.mContext).inflate(alertController.mViewLayoutResId, viewGroup, false) : null;
                }
                boolean z2 = view4 != null;
                if (!z2 || !AlertController.canTextInput(view4)) {
                    alertController.mWindow.setFlags(WXMediaMessage.MINI_PROGRAM__THUMB_LENGHT, WXMediaMessage.MINI_PROGRAM__THUMB_LENGHT);
                }
                if (z2) {
                    FrameLayout frameLayout = (FrameLayout) alertController.mWindow.findViewById(R$id.custom);
                    frameLayout.addView(view4, new ViewGroup.LayoutParams(-1, -1));
                    if (alertController.mViewSpacingSpecified) {
                        frameLayout.setPadding(alertController.mViewSpacingLeft, alertController.mViewSpacingTop, alertController.mViewSpacingRight, alertController.mViewSpacingBottom);
                    }
                    if (alertController.mListView != null) {
                        ((LinearLayout.LayoutParams) ((LinearLayoutCompat.LayoutParams) viewGroup.getLayoutParams())).weight = 0.0f;
                    }
                } else {
                    viewGroup.setVisibility(8);
                }
                View findViewById6 = viewGroup.findViewById(i2);
                View findViewById7 = viewGroup.findViewById(i3);
                View findViewById8 = viewGroup.findViewById(i4);
                ViewGroup resolvePanel = alertController.resolvePanel(findViewById6, findViewById3);
                ViewGroup resolvePanel2 = alertController.resolvePanel(findViewById7, findViewById4);
                ViewGroup resolvePanel3 = alertController.resolvePanel(findViewById8, findViewById5);
                NestedScrollView nestedScrollView = (NestedScrollView) alertController.mWindow.findViewById(R$id.scrollView);
                alertController.mScrollView = nestedScrollView;
                nestedScrollView.setFocusable(false);
                alertController.mScrollView.setNestedScrollingEnabled(false);
                TextView textView = (TextView) resolvePanel2.findViewById(16908299);
                alertController.mMessageView = textView;
                if (textView != null) {
                    CharSequence charSequence = alertController.mMessage;
                    if (charSequence != null) {
                        textView.setText(charSequence);
                    } else {
                        textView.setVisibility(8);
                        alertController.mScrollView.removeView(alertController.mMessageView);
                        if (alertController.mListView != null) {
                            ViewGroup viewGroup2 = (ViewGroup) alertController.mScrollView.getParent();
                            int indexOfChild = viewGroup2.indexOfChild(alertController.mScrollView);
                            viewGroup2.removeViewAt(indexOfChild);
                            viewGroup2.addView(alertController.mListView, indexOfChild, new ViewGroup.LayoutParams(-1, -1));
                        } else {
                            resolvePanel2.setVisibility(8);
                        }
                    }
                }
                Button button = (Button) resolvePanel3.findViewById(16908313);
                alertController.mButtonPositive = button;
                button.setOnClickListener(alertController.mButtonHandler);
                if (!TextUtils.isEmpty(alertController.mButtonPositiveText) || alertController.mButtonPositiveIcon != null) {
                    alertController.mButtonPositive.setText(alertController.mButtonPositiveText);
                    Drawable drawable = alertController.mButtonPositiveIcon;
                    if (drawable != null) {
                        int i6 = alertController.mButtonIconDimen;
                        drawable.setBounds(0, 0, i6, i6);
                        alertController.mButtonPositive.setCompoundDrawables(alertController.mButtonPositiveIcon, null, null, null);
                    }
                    alertController.mButtonPositive.setVisibility(0);
                    z = true;
                } else {
                    alertController.mButtonPositive.setVisibility(8);
                    z = false;
                }
                Button button2 = (Button) resolvePanel3.findViewById(16908314);
                alertController.mButtonNegative = button2;
                button2.setOnClickListener(alertController.mButtonHandler);
                if (!TextUtils.isEmpty(alertController.mButtonNegativeText) || alertController.mButtonNegativeIcon != null) {
                    alertController.mButtonNegative.setText(alertController.mButtonNegativeText);
                    Drawable drawable2 = alertController.mButtonNegativeIcon;
                    if (drawable2 != null) {
                        int i7 = alertController.mButtonIconDimen;
                        drawable2.setBounds(0, 0, i7, i7);
                        alertController.mButtonNegative.setCompoundDrawables(alertController.mButtonNegativeIcon, null, null, null);
                    }
                    alertController.mButtonNegative.setVisibility(0);
                    z |= true;
                } else {
                    alertController.mButtonNegative.setVisibility(8);
                }
                Button button3 = (Button) resolvePanel3.findViewById(16908315);
                alertController.mButtonNeutral = button3;
                button3.setOnClickListener(alertController.mButtonHandler);
                if (!TextUtils.isEmpty(alertController.mButtonNeutralText) || alertController.mButtonNeutralIcon != null) {
                    alertController.mButtonNeutral.setText(alertController.mButtonNeutralText);
                    Drawable drawable3 = alertController.mButtonNeutralIcon;
                    if (drawable3 != null) {
                        int i8 = alertController.mButtonIconDimen;
                        drawable3.setBounds(0, 0, i8, i8);
                        view = null;
                        alertController.mButtonNeutral.setCompoundDrawables(alertController.mButtonNeutralIcon, null, null, null);
                    } else {
                        view = null;
                    }
                    alertController.mButtonNeutral.setVisibility(0);
                    z |= true;
                } else {
                    alertController.mButtonNeutral.setVisibility(8);
                    view = null;
                }
                Context context = alertController.mContext;
                TypedValue typedValue = new TypedValue();
                context.getTheme().resolveAttribute(R$attr.alertDialogCenterButtons, typedValue, true);
                if (typedValue.data != 0) {
                    if (z) {
                        alertController.centerButton(alertController.mButtonPositive);
                    } else if (z) {
                        alertController.centerButton(alertController.mButtonNegative);
                    } else if (z) {
                        alertController.centerButton(alertController.mButtonNeutral);
                    }
                }
                if (!(z)) {
                    resolvePanel3.setVisibility(8);
                }
                if (alertController.mCustomTitleView != null) {
                    resolvePanel.addView(alertController.mCustomTitleView, 0, new ViewGroup.LayoutParams(-1, -2));
                    alertController.mWindow.findViewById(R$id.title_template).setVisibility(8);
                } else {
                    alertController.mIconView = (ImageView) alertController.mWindow.findViewById(16908294);
                    if (!(!TextUtils.isEmpty(alertController.mTitle)) || !alertController.mShowTitle) {
                        alertController.mWindow.findViewById(R$id.title_template).setVisibility(8);
                        alertController.mIconView.setVisibility(8);
                        resolvePanel.setVisibility(8);
                    } else {
                        TextView textView2 = (TextView) alertController.mWindow.findViewById(R$id.alertTitle);
                        alertController.mTitleView = textView2;
                        textView2.setText(alertController.mTitle);
                        int i9 = alertController.mIconId;
                        if (i9 != 0) {
                            alertController.mIconView.setImageResource(i9);
                        } else {
                            Drawable drawable4 = alertController.mIcon;
                            if (drawable4 != null) {
                                alertController.mIconView.setImageDrawable(drawable4);
                            } else {
                                alertController.mTitleView.setPadding(alertController.mIconView.getPaddingLeft(), alertController.mIconView.getPaddingTop(), alertController.mIconView.getPaddingRight(), alertController.mIconView.getPaddingBottom());
                                alertController.mIconView.setVisibility(8);
                            }
                        }
                    }
                }
                boolean z3 = viewGroup.getVisibility() != 8;
                int i10 = (resolvePanel == null || resolvePanel.getVisibility() == 8) ? 0 : 1;
                boolean z4 = resolvePanel3.getVisibility() != 8;
                if (!z4 && (findViewById = resolvePanel2.findViewById(R$id.textSpacerNoButtons)) != null) {
                    findViewById.setVisibility(0);
                }
                if (i10 != 0) {
                    NestedScrollView nestedScrollView2 = alertController.mScrollView;
                    if (nestedScrollView2 != null) {
                        nestedScrollView2.setClipToPadding(true);
                    }
                    if (alertController.mMessage == null && alertController.mListView == null) {
                        view3 = view;
                    } else {
                        view3 = resolvePanel.findViewById(R$id.titleDividerNoCustom);
                    }
                    if (view3 != null) {
                        view3.setVisibility(0);
                    }
                } else {
                    View findViewById9 = resolvePanel2.findViewById(R$id.textSpacerNoTitle);
                    if (findViewById9 != null) {
                        findViewById9.setVisibility(0);
                    }
                }
                ListView listView = alertController.mListView;
                if (listView instanceof AlertController.RecycleListView) {
                    AlertController.RecycleListView recycleListView = (AlertController.RecycleListView) listView;
                    Objects.requireNonNull(recycleListView);
                    if (!z4 || i10 == 0) {
                        recycleListView.setPadding(recycleListView.getPaddingLeft(), i10 != 0 ? recycleListView.getPaddingTop() : recycleListView.mPaddingTopNoTitle, recycleListView.getPaddingRight(), z4 ? recycleListView.getPaddingBottom() : recycleListView.mPaddingBottomNoButtons);
                    }
                }
                if (!z3) {
                    View view5 = alertController.mListView;
                    if (view5 == null) {
                        view5 = alertController.mScrollView;
                    }
                    if (view5 != null) {
                        if (z4) {
                            i5 = 2;
                        }
                        int i11 = i10 | i5;
                        View findViewById10 = alertController.mWindow.findViewById(R$id.scrollIndicatorUp);
                        View findViewById11 = alertController.mWindow.findViewById(R$id.scrollIndicatorDown);
                        int i12 = Build.VERSION.SDK_INT;
                        if (i12 >= 23) {
                            AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                            if (i12 >= 23) {
                                view5.setScrollIndicators(i11, 3);
                            }
                            if (findViewById10 != null) {
                                resolvePanel2.removeView(findViewById10);
                            }
                            if (findViewById11 != null) {
                                resolvePanel2.removeView(findViewById11);
                            }
                        } else {
                            if (findViewById10 != null && (i11 & 1) == 0) {
                                resolvePanel2.removeView(findViewById10);
                                findViewById10 = view;
                            }
                            if (findViewById11 == null || (i11 & 2) != 0) {
                                view2 = findViewById11;
                            } else {
                                resolvePanel2.removeView(findViewById11);
                                view2 = view;
                            }
                            if (!(findViewById10 == null && view2 == null)) {
                                if (alertController.mMessage != null) {
                                    alertController.mScrollView.setOnScrollChangeListener(
                                    /*  JADX ERROR: Method code generation error
                                        jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x037e: INVOKE  
                                          (wrap: androidx.core.widget.NestedScrollView : 0x0377: IGET  (r2v13 androidx.core.widget.NestedScrollView) = (r1v0 'alertController' androidx.appcompat.app.AlertController) androidx.appcompat.app.AlertController.mScrollView androidx.core.widget.NestedScrollView)
                                          (wrap: androidx.appcompat.app.AlertController$2 : 0x037b: CONSTRUCTOR  (r3v13 androidx.appcompat.app.AlertController$2) = 
                                          (r1v0 'alertController' androidx.appcompat.app.AlertController)
                                          (r6v21 'findViewById10' android.view.View)
                                          (r10v3 'view2' android.view.View)
                                         call: androidx.appcompat.app.AlertController.2.<init>(androidx.appcompat.app.AlertController, android.view.View, android.view.View):void type: CONSTRUCTOR)
                                         type: VIRTUAL call: androidx.core.widget.NestedScrollView.setOnScrollChangeListener(androidx.core.widget.NestedScrollView$OnScrollChangeListener):void in method: androidx.appcompat.app.AlertDialog.onCreate(android.os.Bundle):void, file: classes.dex
                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                                        	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:157)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                        	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                                        	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                                        	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                                        	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                                        	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                                        	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                                        	at java.util.ArrayList.forEach(ArrayList.java:1259)
                                        	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                                        	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                                        Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x037b: CONSTRUCTOR  (r3v13 androidx.appcompat.app.AlertController$2) = 
                                          (r1v0 'alertController' androidx.appcompat.app.AlertController)
                                          (r6v21 'findViewById10' android.view.View)
                                          (r10v3 'view2' android.view.View)
                                         call: androidx.appcompat.app.AlertController.2.<init>(androidx.appcompat.app.AlertController, android.view.View, android.view.View):void type: CONSTRUCTOR in method: androidx.appcompat.app.AlertDialog.onCreate(android.os.Bundle):void, file: classes.dex
                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                        	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                                        	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                                        	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                                        	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                                        	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                                        	... 39 more
                                        Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.appcompat.app.AlertController, state: GENERATED_AND_UNLOADED
                                        	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                                        	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                                        	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                                        	... 45 more
                                        */
                                    /*
                                    // Method dump skipped, instructions count: 965
                                    */
                                    throw new UnsupportedOperationException("Method not decompiled: androidx.appcompat.app.AlertDialog.onCreate(android.os.Bundle):void");
                                }

                                public boolean onKeyDown(int i, KeyEvent keyEvent) {
                                    NestedScrollView nestedScrollView = this.mAlert.mScrollView;
                                    if (nestedScrollView != null && nestedScrollView.executeKeyEvent(keyEvent)) {
                                        return true;
                                    }
                                    return super.onKeyDown(i, keyEvent);
                                }

                                public boolean onKeyUp(int i, KeyEvent keyEvent) {
                                    NestedScrollView nestedScrollView = this.mAlert.mScrollView;
                                    if (nestedScrollView != null && nestedScrollView.executeKeyEvent(keyEvent)) {
                                        return true;
                                    }
                                    return super.onKeyUp(i, keyEvent);
                                }

                                @Override // android.app.Dialog, androidx.appcompat.app.AppCompatDialog
                                public void setTitle(CharSequence charSequence) {
                                    super.setTitle(charSequence);
                                    AlertController alertController = this.mAlert;
                                    alertController.mTitle = charSequence;
                                    TextView textView = alertController.mTitleView;
                                    if (textView != null) {
                                        textView.setText(charSequence);
                                    }
                                }
                            }
