package androidx.appcompat.widget;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.PorterDuff;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.LocaleList;
import android.text.TextUtils;
import android.text.method.PasswordTransformationMethod;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputConnection;
import android.widget.TextView;
import androidx.appcompat.R$styleable;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.appcompat.content.res.AppCompatResources;
import androidx.core.content.res.ResourcesCompat$FontCallback;
import androidx.core.view.ViewCompat;
import androidx.core.view.inputmethod.EditorInfoCompat;
import androidx.core.widget.AutoSizeableTextView;
import androidx.core.widget.TintableCompoundDrawablesView;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.lang.ref.WeakReference;
import java.util.Arrays;
import java.util.Locale;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public class AppCompatTextHelper {
    public boolean mAsyncFontPending;
    public final AppCompatTextViewAutoSizeHelper mAutoSizeTextHelper;
    public TintInfo mDrawableBottomTint;
    public TintInfo mDrawableEndTint;
    public TintInfo mDrawableLeftTint;
    public TintInfo mDrawableRightTint;
    public TintInfo mDrawableStartTint;
    public TintInfo mDrawableTint;
    public TintInfo mDrawableTopTint;
    public Typeface mFontTypeface;
    public int mFontWeight = -1;
    public int mStyle = 0;
    public final TextView mView;

    public AppCompatTextHelper(TextView textView) {
        this.mView = textView;
        this.mAutoSizeTextHelper = new AppCompatTextViewAutoSizeHelper(textView);
    }

    public static TintInfo createTintInfo(Context context, AppCompatDrawableManager appCompatDrawableManager, int i) {
        ColorStateList tintList = appCompatDrawableManager.getTintList(context, i);
        if (tintList == null) {
            return null;
        }
        TintInfo tintInfo = new TintInfo();
        tintInfo.mHasTintList = true;
        tintInfo.mTintList = tintList;
        return tintInfo;
    }

    public final void applyCompoundDrawableTint(Drawable drawable, TintInfo tintInfo) {
        if (drawable != null && tintInfo != null) {
            AppCompatDrawableManager.tintDrawable(drawable, tintInfo, this.mView.getDrawableState());
        }
    }

    public void applyCompoundDrawablesTints() {
        if (!(this.mDrawableLeftTint == null && this.mDrawableTopTint == null && this.mDrawableRightTint == null && this.mDrawableBottomTint == null)) {
            Drawable[] compoundDrawables = this.mView.getCompoundDrawables();
            applyCompoundDrawableTint(compoundDrawables[0], this.mDrawableLeftTint);
            applyCompoundDrawableTint(compoundDrawables[1], this.mDrawableTopTint);
            applyCompoundDrawableTint(compoundDrawables[2], this.mDrawableRightTint);
            applyCompoundDrawableTint(compoundDrawables[3], this.mDrawableBottomTint);
        }
        if (this.mDrawableStartTint != null || this.mDrawableEndTint != null) {
            Drawable[] compoundDrawablesRelative = this.mView.getCompoundDrawablesRelative();
            applyCompoundDrawableTint(compoundDrawablesRelative[0], this.mDrawableStartTint);
            applyCompoundDrawableTint(compoundDrawablesRelative[2], this.mDrawableEndTint);
        }
    }

    public boolean isAutoSizeEnabled() {
        AppCompatTextViewAutoSizeHelper appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
        return appCompatTextViewAutoSizeHelper.supportsAutoSizeText() && appCompatTextViewAutoSizeHelper.mAutoSizeTextType != 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:102:0x01f0  */
    /* JADX WARNING: Removed duplicated region for block: B:105:0x01f9  */
    /* JADX WARNING: Removed duplicated region for block: B:111:0x023e  */
    /* JADX WARNING: Removed duplicated region for block: B:114:0x024f  */
    /* JADX WARNING: Removed duplicated region for block: B:115:0x0254  */
    /* JADX WARNING: Removed duplicated region for block: B:118:0x025e  */
    /* JADX WARNING: Removed duplicated region for block: B:119:0x0263  */
    /* JADX WARNING: Removed duplicated region for block: B:122:0x026d  */
    /* JADX WARNING: Removed duplicated region for block: B:123:0x0272  */
    /* JADX WARNING: Removed duplicated region for block: B:130:0x0293  */
    /* JADX WARNING: Removed duplicated region for block: B:137:0x02b6  */
    /* JADX WARNING: Removed duplicated region for block: B:152:0x02ea  */
    /* JADX WARNING: Removed duplicated region for block: B:155:0x02f1  */
    /* JADX WARNING: Removed duplicated region for block: B:165:0x033b  */
    /* JADX WARNING: Removed duplicated region for block: B:166:0x0342  */
    /* JADX WARNING: Removed duplicated region for block: B:169:0x034d  */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x0352  */
    /* JADX WARNING: Removed duplicated region for block: B:173:0x035b  */
    /* JADX WARNING: Removed duplicated region for block: B:174:0x0360  */
    /* JADX WARNING: Removed duplicated region for block: B:177:0x0369  */
    /* JADX WARNING: Removed duplicated region for block: B:178:0x036e  */
    /* JADX WARNING: Removed duplicated region for block: B:181:0x0377  */
    /* JADX WARNING: Removed duplicated region for block: B:182:0x037c  */
    /* JADX WARNING: Removed duplicated region for block: B:185:0x0385  */
    /* JADX WARNING: Removed duplicated region for block: B:186:0x038a  */
    /* JADX WARNING: Removed duplicated region for block: B:189:0x038e A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:217:0x03eb  */
    /* JADX WARNING: Removed duplicated region for block: B:219:0x03f2  */
    /* JADX WARNING: Removed duplicated region for block: B:221:0x03f8  */
    /* JADX WARNING: Removed duplicated region for block: B:223:0x03fd  */
    /* JADX WARNING: Removed duplicated region for block: B:227:0x040a  */
    /* JADX WARNING: Removed duplicated region for block: B:242:0x0440  */
    /* JADX WARNING: Removed duplicated region for block: B:250:0x0478  */
    /* JADX WARNING: Removed duplicated region for block: B:252:0x047f  */
    /* JADX WARNING: Removed duplicated region for block: B:254:0x0486  */
    /* JADX WARNING: Removed duplicated region for block: B:257:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x00d3  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x00fe  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x0109  */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x010e  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x0111  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x0152  */
    /* JADX WARNING: Removed duplicated region for block: B:70:0x017e  */
    /* JADX WARNING: Removed duplicated region for block: B:71:0x0183  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x0189  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x0199  */
    /* JADX WARNING: Removed duplicated region for block: B:87:0x01bc  */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x01c3  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x01ca  */
    /* JADX WARNING: Removed duplicated region for block: B:97:0x01dc  */
    @SuppressLint({"NewApi"})
    public void loadFromAttributes(AttributeSet attributeSet, int i) {
        boolean z;
        ColorStateList colorStateList;
        ColorStateList colorStateList2;
        ColorStateList colorStateList3;
        boolean z2;
        String str;
        String str2;
        String str3;
        int i2;
        String string;
        AppCompatDrawableManager appCompatDrawableManager;
        Typeface typeface;
        int i3;
        AppCompatTextViewAutoSizeHelper appCompatTextViewAutoSizeHelper;
        TypedArray obtainStyledAttributes;
        int i4;
        TypedArray obtainStyledAttributes2;
        int resourceId;
        AppCompatDrawableManager appCompatDrawableManager2;
        Drawable drawable;
        Drawable drawable2;
        Drawable drawable3;
        Drawable drawable4;
        Drawable drawable5;
        int i5;
        int i6;
        int dimensionPixelSize;
        int dimensionPixelSize2;
        int dimensionPixelSize3;
        ColorStateList colorStateList4;
        int resourceId2;
        int resourceId3;
        int length;
        Context context = this.mView.getContext();
        AppCompatDrawableManager appCompatDrawableManager3 = AppCompatDrawableManager.get();
        int[] iArr = R$styleable.AppCompatTextHelper;
        TintTypedArray obtainStyledAttributes3 = TintTypedArray.obtainStyledAttributes(context, attributeSet, iArr, i, 0);
        TextView textView = this.mView;
        ViewCompat.saveAttributeDataForStyleable(textView, textView.getContext(), iArr, attributeSet, obtainStyledAttributes3.mWrapped, i, 0);
        int resourceId4 = obtainStyledAttributes3.getResourceId(R$styleable.AppCompatTextHelper_android_textAppearance, -1);
        int i7 = R$styleable.AppCompatTextHelper_android_drawableLeft;
        if (obtainStyledAttributes3.hasValue(i7)) {
            this.mDrawableLeftTint = createTintInfo(context, appCompatDrawableManager3, obtainStyledAttributes3.getResourceId(i7, 0));
        }
        int i8 = R$styleable.AppCompatTextHelper_android_drawableTop;
        if (obtainStyledAttributes3.hasValue(i8)) {
            this.mDrawableTopTint = createTintInfo(context, appCompatDrawableManager3, obtainStyledAttributes3.getResourceId(i8, 0));
        }
        int i9 = R$styleable.AppCompatTextHelper_android_drawableRight;
        if (obtainStyledAttributes3.hasValue(i9)) {
            this.mDrawableRightTint = createTintInfo(context, appCompatDrawableManager3, obtainStyledAttributes3.getResourceId(i9, 0));
        }
        int i10 = R$styleable.AppCompatTextHelper_android_drawableBottom;
        if (obtainStyledAttributes3.hasValue(i10)) {
            this.mDrawableBottomTint = createTintInfo(context, appCompatDrawableManager3, obtainStyledAttributes3.getResourceId(i10, 0));
        }
        int i11 = Build.VERSION.SDK_INT;
        int i12 = R$styleable.AppCompatTextHelper_android_drawableStart;
        if (obtainStyledAttributes3.hasValue(i12)) {
            this.mDrawableStartTint = createTintInfo(context, appCompatDrawableManager3, obtainStyledAttributes3.getResourceId(i12, 0));
        }
        int i13 = R$styleable.AppCompatTextHelper_android_drawableEnd;
        if (obtainStyledAttributes3.hasValue(i13)) {
            this.mDrawableEndTint = createTintInfo(context, appCompatDrawableManager3, obtainStyledAttributes3.getResourceId(i13, 0));
        }
        obtainStyledAttributes3.mWrapped.recycle();
        boolean z3 = this.mView.getTransformationMethod() instanceof PasswordTransformationMethod;
        if (resourceId4 != -1) {
            TypedArray obtainStyledAttributes4 = context.obtainStyledAttributes(resourceId4, R$styleable.TextAppearance);
            TintTypedArray tintTypedArray = new TintTypedArray(context, obtainStyledAttributes4);
            if (!z3) {
                int i14 = R$styleable.TextAppearance_textAllCaps;
                if (tintTypedArray.hasValue(i14)) {
                    z2 = tintTypedArray.getBoolean(i14, false);
                    z = true;
                    updateTypefaceAndStyle(context, tintTypedArray);
                    if (i11 >= 23) {
                        int i15 = R$styleable.TextAppearance_android_textColor;
                        colorStateList = tintTypedArray.hasValue(i15) ? tintTypedArray.getColorStateList(i15) : null;
                        int i16 = R$styleable.TextAppearance_android_textColorHint;
                        colorStateList3 = tintTypedArray.hasValue(i16) ? tintTypedArray.getColorStateList(i16) : null;
                        int i17 = R$styleable.TextAppearance_android_textColorLink;
                        colorStateList2 = tintTypedArray.hasValue(i17) ? tintTypedArray.getColorStateList(i17) : null;
                    } else {
                        colorStateList3 = null;
                        colorStateList2 = null;
                        colorStateList = null;
                    }
                    int i18 = R$styleable.TextAppearance_textLocale;
                    str2 = !tintTypedArray.hasValue(i18) ? tintTypedArray.getString(i18) : null;
                    if (i11 >= 26) {
                        int i19 = R$styleable.TextAppearance_fontVariationSettings;
                        if (tintTypedArray.hasValue(i19)) {
                            str = tintTypedArray.getString(i19);
                            obtainStyledAttributes4.recycle();
                        }
                    }
                    str = null;
                    obtainStyledAttributes4.recycle();
                }
            }
            z2 = false;
            z = false;
            updateTypefaceAndStyle(context, tintTypedArray);
            if (i11 >= 23) {
            }
            int i182 = R$styleable.TextAppearance_textLocale;
            if (!tintTypedArray.hasValue(i182)) {
            }
            if (i11 >= 26) {
            }
            str = null;
            obtainStyledAttributes4.recycle();
        } else {
            str2 = null;
            str = null;
            z2 = false;
            colorStateList3 = null;
            colorStateList2 = null;
            colorStateList = null;
            z = false;
        }
        TypedArray obtainStyledAttributes5 = context.obtainStyledAttributes(attributeSet, R$styleable.TextAppearance, i, 0);
        TintTypedArray tintTypedArray2 = new TintTypedArray(context, obtainStyledAttributes5);
        if (!z3) {
            int i20 = R$styleable.TextAppearance_textAllCaps;
            if (tintTypedArray2.hasValue(i20)) {
                str3 = str2;
                z2 = tintTypedArray2.getBoolean(i20, false);
                i2 = 23;
                z = true;
                if (i11 < i2) {
                    int i21 = R$styleable.TextAppearance_android_textColor;
                    if (tintTypedArray2.hasValue(i21)) {
                        colorStateList = tintTypedArray2.getColorStateList(i21);
                    }
                    int i22 = R$styleable.TextAppearance_android_textColorHint;
                    if (tintTypedArray2.hasValue(i22)) {
                        colorStateList3 = tintTypedArray2.getColorStateList(i22);
                    }
                    int i23 = R$styleable.TextAppearance_android_textColorLink;
                    if (tintTypedArray2.hasValue(i23)) {
                        colorStateList2 = tintTypedArray2.getColorStateList(i23);
                    }
                }
                int i24 = R$styleable.TextAppearance_textLocale;
                string = !tintTypedArray2.hasValue(i24) ? tintTypedArray2.getString(i24) : str3;
                if (i11 >= 26) {
                    int i25 = R$styleable.TextAppearance_fontVariationSettings;
                    if (tintTypedArray2.hasValue(i25)) {
                        str = tintTypedArray2.getString(i25);
                    }
                }
                if (i11 >= 28) {
                    int i26 = R$styleable.TextAppearance_android_textSize;
                    if (tintTypedArray2.hasValue(i26)) {
                        appCompatDrawableManager = appCompatDrawableManager3;
                        if (tintTypedArray2.getDimensionPixelSize(i26, -1) == 0) {
                            this.mView.setTextSize(0, 0.0f);
                        }
                        updateTypefaceAndStyle(context, tintTypedArray2);
                        obtainStyledAttributes5.recycle();
                        if (colorStateList != null) {
                            this.mView.setTextColor(colorStateList);
                        }
                        if (colorStateList3 != null) {
                            this.mView.setHintTextColor(colorStateList3);
                        }
                        if (colorStateList2 != null) {
                            this.mView.setLinkTextColor(colorStateList2);
                        }
                        if (!z3 && z) {
                            this.mView.setAllCaps(z2);
                        }
                        typeface = this.mFontTypeface;
                        if (typeface != null) {
                            if (this.mFontWeight == -1) {
                                this.mView.setTypeface(typeface, this.mStyle);
                            } else {
                                this.mView.setTypeface(typeface);
                            }
                        }
                        if (str != null) {
                            this.mView.setFontVariationSettings(str);
                        }
                        if (string != null) {
                            if (i11 >= 24) {
                                this.mView.setTextLocales(LocaleList.forLanguageTags(string));
                            } else {
                                i3 = 0;
                                this.mView.setTextLocale(Locale.forLanguageTag(string.substring(0, string.indexOf(44))));
                                appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
                                Context context2 = appCompatTextViewAutoSizeHelper.mContext;
                                int[] iArr2 = R$styleable.AppCompatTextView;
                                obtainStyledAttributes = context2.obtainStyledAttributes(attributeSet, iArr2, i, i3);
                                TextView textView2 = appCompatTextViewAutoSizeHelper.mTextView;
                                ViewCompat.saveAttributeDataForStyleable(textView2, textView2.getContext(), iArr2, attributeSet, obtainStyledAttributes, i, 0);
                                i4 = R$styleable.AppCompatTextView_autoSizeTextType;
                                if (obtainStyledAttributes.hasValue(i4)) {
                                    appCompatTextViewAutoSizeHelper.mAutoSizeTextType = obtainStyledAttributes.getInt(i4, 0);
                                }
                                int i27 = R$styleable.AppCompatTextView_autoSizeStepGranularity;
                                float dimension = !obtainStyledAttributes.hasValue(i27) ? obtainStyledAttributes.getDimension(i27, -1.0f) : -1.0f;
                                int i28 = R$styleable.AppCompatTextView_autoSizeMinTextSize;
                                float dimension2 = !obtainStyledAttributes.hasValue(i28) ? obtainStyledAttributes.getDimension(i28, -1.0f) : -1.0f;
                                int i29 = R$styleable.AppCompatTextView_autoSizeMaxTextSize;
                                float dimension3 = !obtainStyledAttributes.hasValue(i29) ? obtainStyledAttributes.getDimension(i29, -1.0f) : -1.0f;
                                int i30 = R$styleable.AppCompatTextView_autoSizePresetSizes;
                                if (obtainStyledAttributes.hasValue(i30) && (resourceId3 = obtainStyledAttributes.getResourceId(i30, 0)) > 0) {
                                    TypedArray obtainTypedArray = obtainStyledAttributes.getResources().obtainTypedArray(resourceId3);
                                    length = obtainTypedArray.length();
                                    int[] iArr3 = new int[length];
                                    if (length > 0) {
                                        for (int i31 = 0; i31 < length; i31++) {
                                            iArr3[i31] = obtainTypedArray.getDimensionPixelSize(i31, -1);
                                        }
                                        appCompatTextViewAutoSizeHelper.mAutoSizeTextSizesInPx = appCompatTextViewAutoSizeHelper.cleanupAutoSizePresetSizes(iArr3);
                                        appCompatTextViewAutoSizeHelper.setupAutoSizeUniformPresetSizesConfiguration();
                                    }
                                    obtainTypedArray.recycle();
                                }
                                obtainStyledAttributes.recycle();
                                if (appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
                                    appCompatTextViewAutoSizeHelper.mAutoSizeTextType = 0;
                                } else if (appCompatTextViewAutoSizeHelper.mAutoSizeTextType == 1) {
                                    if (!appCompatTextViewAutoSizeHelper.mHasPresetAutoSizeValues) {
                                        DisplayMetrics displayMetrics = appCompatTextViewAutoSizeHelper.mContext.getResources().getDisplayMetrics();
                                        if (dimension2 == -1.0f) {
                                            dimension2 = TypedValue.applyDimension(2, 12.0f, displayMetrics);
                                        }
                                        if (dimension3 == -1.0f) {
                                            dimension3 = TypedValue.applyDimension(2, 112.0f, displayMetrics);
                                        }
                                        if (dimension == -1.0f) {
                                            dimension = 1.0f;
                                        }
                                        appCompatTextViewAutoSizeHelper.validateAndSetAutoSizeTextTypeUniformConfiguration(dimension2, dimension3, dimension);
                                    }
                                    appCompatTextViewAutoSizeHelper.setupAutoSizeText();
                                }
                                if (AutoSizeableTextView.PLATFORM_SUPPORTS_AUTOSIZE) {
                                    AppCompatTextViewAutoSizeHelper appCompatTextViewAutoSizeHelper2 = this.mAutoSizeTextHelper;
                                    if (appCompatTextViewAutoSizeHelper2.mAutoSizeTextType != 0) {
                                        int[] iArr4 = appCompatTextViewAutoSizeHelper2.mAutoSizeTextSizesInPx;
                                        if (iArr4.length > 0) {
                                            if (((float) this.mView.getAutoSizeStepGranularity()) != -1.0f) {
                                                this.mView.setAutoSizeTextTypeUniformWithConfiguration(Math.round(this.mAutoSizeTextHelper.mAutoSizeMinTextSizeInPx), Math.round(this.mAutoSizeTextHelper.mAutoSizeMaxTextSizeInPx), Math.round(this.mAutoSizeTextHelper.mAutoSizeStepGranularityInPx), 0);
                                            } else {
                                                this.mView.setAutoSizeTextTypeUniformWithPresetSizes(iArr4, 0);
                                            }
                                        }
                                    }
                                }
                                obtainStyledAttributes2 = context.obtainStyledAttributes(attributeSet, R$styleable.AppCompatTextView);
                                resourceId = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableLeftCompat, -1);
                                if (resourceId == -1) {
                                    appCompatDrawableManager2 = appCompatDrawableManager;
                                    drawable = appCompatDrawableManager2.getDrawable(context, resourceId);
                                } else {
                                    appCompatDrawableManager2 = appCompatDrawableManager;
                                    drawable = null;
                                }
                                int resourceId5 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableTopCompat, -1);
                                drawable2 = resourceId5 == -1 ? appCompatDrawableManager2.getDrawable(context, resourceId5) : null;
                                int resourceId6 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableRightCompat, -1);
                                Drawable drawable6 = resourceId6 == -1 ? appCompatDrawableManager2.getDrawable(context, resourceId6) : null;
                                int resourceId7 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableBottomCompat, -1);
                                drawable3 = resourceId7 == -1 ? appCompatDrawableManager2.getDrawable(context, resourceId7) : null;
                                int resourceId8 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableStartCompat, -1);
                                drawable4 = resourceId8 == -1 ? appCompatDrawableManager2.getDrawable(context, resourceId8) : null;
                                int resourceId9 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableEndCompat, -1);
                                drawable5 = resourceId9 == -1 ? appCompatDrawableManager2.getDrawable(context, resourceId9) : null;
                                if (drawable4 == null || drawable5 != null) {
                                    Drawable[] compoundDrawablesRelative = this.mView.getCompoundDrawablesRelative();
                                    TextView textView3 = this.mView;
                                    if (drawable4 == null) {
                                        drawable4 = compoundDrawablesRelative[0];
                                    }
                                    if (drawable2 == null) {
                                        drawable2 = compoundDrawablesRelative[1];
                                    }
                                    if (drawable5 == null) {
                                        drawable5 = compoundDrawablesRelative[2];
                                    }
                                    if (drawable3 == null) {
                                        drawable3 = compoundDrawablesRelative[3];
                                    }
                                    textView3.setCompoundDrawablesRelativeWithIntrinsicBounds(drawable4, drawable2, drawable5, drawable3);
                                } else if (!(drawable == null && drawable2 == null && drawable6 == null && drawable3 == null)) {
                                    Drawable[] compoundDrawablesRelative2 = this.mView.getCompoundDrawablesRelative();
                                    if (compoundDrawablesRelative2[0] == null && compoundDrawablesRelative2[2] == null) {
                                        Drawable[] compoundDrawables = this.mView.getCompoundDrawables();
                                        TextView textView4 = this.mView;
                                        if (drawable == null) {
                                            drawable = compoundDrawables[0];
                                        }
                                        if (drawable2 == null) {
                                            drawable2 = compoundDrawables[1];
                                        }
                                        if (drawable6 == null) {
                                            drawable6 = compoundDrawables[2];
                                        }
                                        if (drawable3 == null) {
                                            drawable3 = compoundDrawables[3];
                                        }
                                        textView4.setCompoundDrawablesWithIntrinsicBounds(drawable, drawable2, drawable6, drawable3);
                                    } else {
                                        TextView textView5 = this.mView;
                                        Drawable drawable7 = compoundDrawablesRelative2[0];
                                        if (drawable2 == null) {
                                            drawable2 = compoundDrawablesRelative2[1];
                                        }
                                        Drawable drawable8 = compoundDrawablesRelative2[2];
                                        if (drawable3 == null) {
                                            drawable3 = compoundDrawablesRelative2[3];
                                        }
                                        textView5.setCompoundDrawablesRelativeWithIntrinsicBounds(drawable7, drawable2, drawable8, drawable3);
                                    }
                                }
                                i5 = R$styleable.AppCompatTextView_drawableTint;
                                if (obtainStyledAttributes2.hasValue(i5)) {
                                    if (!obtainStyledAttributes2.hasValue(i5) || (resourceId2 = obtainStyledAttributes2.getResourceId(i5, 0)) == 0 || (colorStateList4 = AppCompatResources.getColorStateList(context, resourceId2)) == null) {
                                        colorStateList4 = obtainStyledAttributes2.getColorStateList(i5);
                                    }
                                    TextView textView6 = this.mView;
                                    Objects.requireNonNull(textView6);
                                    if (Build.VERSION.SDK_INT >= 24) {
                                        textView6.setCompoundDrawableTintList(colorStateList4);
                                    } else if (textView6 instanceof TintableCompoundDrawablesView) {
                                        ((TintableCompoundDrawablesView) textView6).setSupportCompoundDrawablesTintList(colorStateList4);
                                    }
                                }
                                i6 = R$styleable.AppCompatTextView_drawableTintMode;
                                if (obtainStyledAttributes2.hasValue(i6)) {
                                    PorterDuff.Mode parseTintMode = DrawableUtils.parseTintMode(obtainStyledAttributes2.getInt(i6, -1), null);
                                    TextView textView7 = this.mView;
                                    Objects.requireNonNull(textView7);
                                    if (Build.VERSION.SDK_INT >= 24) {
                                        textView7.setCompoundDrawableTintMode(parseTintMode);
                                    } else if (textView7 instanceof TintableCompoundDrawablesView) {
                                        ((TintableCompoundDrawablesView) textView7).setSupportCompoundDrawablesTintMode(parseTintMode);
                                    }
                                }
                                dimensionPixelSize = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_firstBaselineToTopHeight, -1);
                                dimensionPixelSize2 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lastBaselineToBottomHeight, -1);
                                dimensionPixelSize3 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lineHeight, -1);
                                obtainStyledAttributes2.recycle();
                                if (dimensionPixelSize != -1) {
                                    AppCompatDelegateImpl.Api17Impl.setFirstBaselineToTopHeight(this.mView, dimensionPixelSize);
                                }
                                if (dimensionPixelSize2 != -1) {
                                    AppCompatDelegateImpl.Api17Impl.setLastBaselineToBottomHeight(this.mView, dimensionPixelSize2);
                                }
                                if (dimensionPixelSize3 == -1) {
                                    AppCompatDelegateImpl.Api17Impl.setLineHeight(this.mView, dimensionPixelSize3);
                                    return;
                                }
                                return;
                            }
                        }
                        i3 = 0;
                        appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
                        Context context22 = appCompatTextViewAutoSizeHelper.mContext;
                        int[] iArr22 = R$styleable.AppCompatTextView;
                        obtainStyledAttributes = context22.obtainStyledAttributes(attributeSet, iArr22, i, i3);
                        TextView textView22 = appCompatTextViewAutoSizeHelper.mTextView;
                        ViewCompat.saveAttributeDataForStyleable(textView22, textView22.getContext(), iArr22, attributeSet, obtainStyledAttributes, i, 0);
                        i4 = R$styleable.AppCompatTextView_autoSizeTextType;
                        if (obtainStyledAttributes.hasValue(i4)) {
                        }
                        int i272 = R$styleable.AppCompatTextView_autoSizeStepGranularity;
                        if (!obtainStyledAttributes.hasValue(i272)) {
                        }
                        int i282 = R$styleable.AppCompatTextView_autoSizeMinTextSize;
                        if (!obtainStyledAttributes.hasValue(i282)) {
                        }
                        int i292 = R$styleable.AppCompatTextView_autoSizeMaxTextSize;
                        if (!obtainStyledAttributes.hasValue(i292)) {
                        }
                        int i302 = R$styleable.AppCompatTextView_autoSizePresetSizes;
                        TypedArray obtainTypedArray2 = obtainStyledAttributes.getResources().obtainTypedArray(resourceId3);
                        length = obtainTypedArray2.length();
                        int[] iArr32 = new int[length];
                        if (length > 0) {
                        }
                        obtainTypedArray2.recycle();
                        obtainStyledAttributes.recycle();
                        if (appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
                        }
                        if (AutoSizeableTextView.PLATFORM_SUPPORTS_AUTOSIZE) {
                        }
                        obtainStyledAttributes2 = context.obtainStyledAttributes(attributeSet, R$styleable.AppCompatTextView);
                        resourceId = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableLeftCompat, -1);
                        if (resourceId == -1) {
                        }
                        int resourceId52 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableTopCompat, -1);
                        if (resourceId52 == -1) {
                        }
                        int resourceId62 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableRightCompat, -1);
                        if (resourceId62 == -1) {
                        }
                        int resourceId72 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableBottomCompat, -1);
                        if (resourceId72 == -1) {
                        }
                        int resourceId82 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableStartCompat, -1);
                        if (resourceId82 == -1) {
                        }
                        int resourceId92 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableEndCompat, -1);
                        if (resourceId92 == -1) {
                        }
                        if (drawable4 == null) {
                        }
                        Drawable[] compoundDrawablesRelative3 = this.mView.getCompoundDrawablesRelative();
                        TextView textView32 = this.mView;
                        if (drawable4 == null) {
                        }
                        if (drawable2 == null) {
                        }
                        if (drawable5 == null) {
                        }
                        if (drawable3 == null) {
                        }
                        textView32.setCompoundDrawablesRelativeWithIntrinsicBounds(drawable4, drawable2, drawable5, drawable3);
                        i5 = R$styleable.AppCompatTextView_drawableTint;
                        if (obtainStyledAttributes2.hasValue(i5)) {
                        }
                        i6 = R$styleable.AppCompatTextView_drawableTintMode;
                        if (obtainStyledAttributes2.hasValue(i6)) {
                        }
                        dimensionPixelSize = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_firstBaselineToTopHeight, -1);
                        dimensionPixelSize2 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lastBaselineToBottomHeight, -1);
                        dimensionPixelSize3 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lineHeight, -1);
                        obtainStyledAttributes2.recycle();
                        if (dimensionPixelSize != -1) {
                        }
                        if (dimensionPixelSize2 != -1) {
                        }
                        if (dimensionPixelSize3 == -1) {
                        }
                    }
                }
                appCompatDrawableManager = appCompatDrawableManager3;
                updateTypefaceAndStyle(context, tintTypedArray2);
                obtainStyledAttributes5.recycle();
                if (colorStateList != null) {
                }
                if (colorStateList3 != null) {
                }
                if (colorStateList2 != null) {
                }
                this.mView.setAllCaps(z2);
                typeface = this.mFontTypeface;
                if (typeface != null) {
                }
                if (str != null) {
                }
                if (string != null) {
                }
                i3 = 0;
                appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
                Context context222 = appCompatTextViewAutoSizeHelper.mContext;
                int[] iArr222 = R$styleable.AppCompatTextView;
                obtainStyledAttributes = context222.obtainStyledAttributes(attributeSet, iArr222, i, i3);
                TextView textView222 = appCompatTextViewAutoSizeHelper.mTextView;
                ViewCompat.saveAttributeDataForStyleable(textView222, textView222.getContext(), iArr222, attributeSet, obtainStyledAttributes, i, 0);
                i4 = R$styleable.AppCompatTextView_autoSizeTextType;
                if (obtainStyledAttributes.hasValue(i4)) {
                }
                int i2722 = R$styleable.AppCompatTextView_autoSizeStepGranularity;
                if (!obtainStyledAttributes.hasValue(i2722)) {
                }
                int i2822 = R$styleable.AppCompatTextView_autoSizeMinTextSize;
                if (!obtainStyledAttributes.hasValue(i2822)) {
                }
                int i2922 = R$styleable.AppCompatTextView_autoSizeMaxTextSize;
                if (!obtainStyledAttributes.hasValue(i2922)) {
                }
                int i3022 = R$styleable.AppCompatTextView_autoSizePresetSizes;
                TypedArray obtainTypedArray22 = obtainStyledAttributes.getResources().obtainTypedArray(resourceId3);
                length = obtainTypedArray22.length();
                int[] iArr322 = new int[length];
                if (length > 0) {
                }
                obtainTypedArray22.recycle();
                obtainStyledAttributes.recycle();
                if (appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
                }
                if (AutoSizeableTextView.PLATFORM_SUPPORTS_AUTOSIZE) {
                }
                obtainStyledAttributes2 = context.obtainStyledAttributes(attributeSet, R$styleable.AppCompatTextView);
                resourceId = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableLeftCompat, -1);
                if (resourceId == -1) {
                }
                int resourceId522 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableTopCompat, -1);
                if (resourceId522 == -1) {
                }
                int resourceId622 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableRightCompat, -1);
                if (resourceId622 == -1) {
                }
                int resourceId722 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableBottomCompat, -1);
                if (resourceId722 == -1) {
                }
                int resourceId822 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableStartCompat, -1);
                if (resourceId822 == -1) {
                }
                int resourceId922 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableEndCompat, -1);
                if (resourceId922 == -1) {
                }
                if (drawable4 == null) {
                }
                Drawable[] compoundDrawablesRelative32 = this.mView.getCompoundDrawablesRelative();
                TextView textView322 = this.mView;
                if (drawable4 == null) {
                }
                if (drawable2 == null) {
                }
                if (drawable5 == null) {
                }
                if (drawable3 == null) {
                }
                textView322.setCompoundDrawablesRelativeWithIntrinsicBounds(drawable4, drawable2, drawable5, drawable3);
                i5 = R$styleable.AppCompatTextView_drawableTint;
                if (obtainStyledAttributes2.hasValue(i5)) {
                }
                i6 = R$styleable.AppCompatTextView_drawableTintMode;
                if (obtainStyledAttributes2.hasValue(i6)) {
                }
                dimensionPixelSize = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_firstBaselineToTopHeight, -1);
                dimensionPixelSize2 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lastBaselineToBottomHeight, -1);
                dimensionPixelSize3 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lineHeight, -1);
                obtainStyledAttributes2.recycle();
                if (dimensionPixelSize != -1) {
                }
                if (dimensionPixelSize2 != -1) {
                }
                if (dimensionPixelSize3 == -1) {
                }
            }
        }
        str3 = str2;
        i2 = 23;
        if (i11 < i2) {
        }
        int i242 = R$styleable.TextAppearance_textLocale;
        if (!tintTypedArray2.hasValue(i242)) {
        }
        if (i11 >= 26) {
        }
        if (i11 >= 28) {
        }
        appCompatDrawableManager = appCompatDrawableManager3;
        updateTypefaceAndStyle(context, tintTypedArray2);
        obtainStyledAttributes5.recycle();
        if (colorStateList != null) {
        }
        if (colorStateList3 != null) {
        }
        if (colorStateList2 != null) {
        }
        this.mView.setAllCaps(z2);
        typeface = this.mFontTypeface;
        if (typeface != null) {
        }
        if (str != null) {
        }
        if (string != null) {
        }
        i3 = 0;
        appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
        Context context2222 = appCompatTextViewAutoSizeHelper.mContext;
        int[] iArr2222 = R$styleable.AppCompatTextView;
        obtainStyledAttributes = context2222.obtainStyledAttributes(attributeSet, iArr2222, i, i3);
        TextView textView2222 = appCompatTextViewAutoSizeHelper.mTextView;
        ViewCompat.saveAttributeDataForStyleable(textView2222, textView2222.getContext(), iArr2222, attributeSet, obtainStyledAttributes, i, 0);
        i4 = R$styleable.AppCompatTextView_autoSizeTextType;
        if (obtainStyledAttributes.hasValue(i4)) {
        }
        int i27222 = R$styleable.AppCompatTextView_autoSizeStepGranularity;
        if (!obtainStyledAttributes.hasValue(i27222)) {
        }
        int i28222 = R$styleable.AppCompatTextView_autoSizeMinTextSize;
        if (!obtainStyledAttributes.hasValue(i28222)) {
        }
        int i29222 = R$styleable.AppCompatTextView_autoSizeMaxTextSize;
        if (!obtainStyledAttributes.hasValue(i29222)) {
        }
        int i30222 = R$styleable.AppCompatTextView_autoSizePresetSizes;
        TypedArray obtainTypedArray222 = obtainStyledAttributes.getResources().obtainTypedArray(resourceId3);
        length = obtainTypedArray222.length();
        int[] iArr3222 = new int[length];
        if (length > 0) {
        }
        obtainTypedArray222.recycle();
        obtainStyledAttributes.recycle();
        if (appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
        }
        if (AutoSizeableTextView.PLATFORM_SUPPORTS_AUTOSIZE) {
        }
        obtainStyledAttributes2 = context.obtainStyledAttributes(attributeSet, R$styleable.AppCompatTextView);
        resourceId = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableLeftCompat, -1);
        if (resourceId == -1) {
        }
        int resourceId5222 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableTopCompat, -1);
        if (resourceId5222 == -1) {
        }
        int resourceId6222 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableRightCompat, -1);
        if (resourceId6222 == -1) {
        }
        int resourceId7222 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableBottomCompat, -1);
        if (resourceId7222 == -1) {
        }
        int resourceId8222 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableStartCompat, -1);
        if (resourceId8222 == -1) {
        }
        int resourceId9222 = obtainStyledAttributes2.getResourceId(R$styleable.AppCompatTextView_drawableEndCompat, -1);
        if (resourceId9222 == -1) {
        }
        if (drawable4 == null) {
        }
        Drawable[] compoundDrawablesRelative322 = this.mView.getCompoundDrawablesRelative();
        TextView textView3222 = this.mView;
        if (drawable4 == null) {
        }
        if (drawable2 == null) {
        }
        if (drawable5 == null) {
        }
        if (drawable3 == null) {
        }
        textView3222.setCompoundDrawablesRelativeWithIntrinsicBounds(drawable4, drawable2, drawable5, drawable3);
        i5 = R$styleable.AppCompatTextView_drawableTint;
        if (obtainStyledAttributes2.hasValue(i5)) {
        }
        i6 = R$styleable.AppCompatTextView_drawableTintMode;
        if (obtainStyledAttributes2.hasValue(i6)) {
        }
        dimensionPixelSize = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_firstBaselineToTopHeight, -1);
        dimensionPixelSize2 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lastBaselineToBottomHeight, -1);
        dimensionPixelSize3 = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.AppCompatTextView_lineHeight, -1);
        obtainStyledAttributes2.recycle();
        if (dimensionPixelSize != -1) {
        }
        if (dimensionPixelSize2 != -1) {
        }
        if (dimensionPixelSize3 == -1) {
        }
    }

    public void onSetTextAppearance(Context context, int i) {
        String string;
        ColorStateList colorStateList;
        ColorStateList colorStateList2;
        ColorStateList colorStateList3;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(i, R$styleable.TextAppearance);
        TintTypedArray tintTypedArray = new TintTypedArray(context, obtainStyledAttributes);
        int i2 = R$styleable.TextAppearance_textAllCaps;
        if (tintTypedArray.hasValue(i2)) {
            this.mView.setAllCaps(tintTypedArray.getBoolean(i2, false));
        }
        int i3 = Build.VERSION.SDK_INT;
        if (i3 < 23) {
            int i4 = R$styleable.TextAppearance_android_textColor;
            if (tintTypedArray.hasValue(i4) && (colorStateList3 = tintTypedArray.getColorStateList(i4)) != null) {
                this.mView.setTextColor(colorStateList3);
            }
            int i5 = R$styleable.TextAppearance_android_textColorLink;
            if (tintTypedArray.hasValue(i5) && (colorStateList2 = tintTypedArray.getColorStateList(i5)) != null) {
                this.mView.setLinkTextColor(colorStateList2);
            }
            int i6 = R$styleable.TextAppearance_android_textColorHint;
            if (tintTypedArray.hasValue(i6) && (colorStateList = tintTypedArray.getColorStateList(i6)) != null) {
                this.mView.setHintTextColor(colorStateList);
            }
        }
        int i7 = R$styleable.TextAppearance_android_textSize;
        if (tintTypedArray.hasValue(i7) && tintTypedArray.getDimensionPixelSize(i7, -1) == 0) {
            this.mView.setTextSize(0, 0.0f);
        }
        updateTypefaceAndStyle(context, tintTypedArray);
        if (i3 >= 26) {
            int i8 = R$styleable.TextAppearance_fontVariationSettings;
            if (tintTypedArray.hasValue(i8) && (string = tintTypedArray.getString(i8)) != null) {
                this.mView.setFontVariationSettings(string);
            }
        }
        obtainStyledAttributes.recycle();
        Typeface typeface = this.mFontTypeface;
        if (typeface != null) {
            this.mView.setTypeface(typeface, this.mStyle);
        }
    }

    public void populateSurroundingTextIfNeeded(TextView textView, InputConnection inputConnection, EditorInfo editorInfo) {
        CharSequence charSequence;
        int i = Build.VERSION.SDK_INT;
        if (i < 30 && inputConnection != null) {
            CharSequence text = textView.getText();
            if (i >= 30) {
                editorInfo.setInitialSurroundingSubText(text, 0);
                return;
            }
            Objects.requireNonNull(text);
            if (i >= 30) {
                editorInfo.setInitialSurroundingSubText(text, 0);
                return;
            }
            int i2 = editorInfo.initialSelStart;
            int i3 = editorInfo.initialSelEnd;
            int i4 = i2 > i3 ? i3 + 0 : i2 + 0;
            int i5 = i2 > i3 ? i2 - 0 : i3 + 0;
            int length = text.length();
            if (i4 < 0 || i5 > length) {
                EditorInfoCompat.setSurroundingText(editorInfo, null, 0, 0);
                return;
            }
            int i6 = editorInfo.inputType & 4095;
            if (i6 == 129 || i6 == 225 || i6 == 18) {
                EditorInfoCompat.setSurroundingText(editorInfo, null, 0, 0);
            } else if (length <= 2048) {
                EditorInfoCompat.setSurroundingText(editorInfo, text, i4, i5);
            } else {
                int i7 = i5 - i4;
                int i8 = i7 > 1024 ? 0 : i7;
                int i9 = 2048 - i8;
                int min = Math.min(text.length() - i5, i9 - Math.min(i4, (int) (((double) i9) * 0.8d)));
                int min2 = Math.min(i4, i9 - min);
                int i10 = i4 - min2;
                if (EditorInfoCompat.isCutOnSurrogate(text, i10, 0)) {
                    i10++;
                    min2--;
                }
                if (EditorInfoCompat.isCutOnSurrogate(text, (i5 + min) - 1, 1)) {
                    min--;
                }
                int i11 = min2 + i8 + min;
                if (i8 != i7) {
                    charSequence = TextUtils.concat(text.subSequence(i10, i10 + min2), text.subSequence(i5, min + i5));
                } else {
                    charSequence = text.subSequence(i10, i11 + i10);
                }
                int i12 = min2 + 0;
                EditorInfoCompat.setSurroundingText(editorInfo, charSequence, i12, i8 + i12);
            }
        }
    }

    public void setAutoSizeTextTypeUniformWithConfiguration(int i, int i2, int i3, int i4) {
        AppCompatTextViewAutoSizeHelper appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
        if (appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
            DisplayMetrics displayMetrics = appCompatTextViewAutoSizeHelper.mContext.getResources().getDisplayMetrics();
            appCompatTextViewAutoSizeHelper.validateAndSetAutoSizeTextTypeUniformConfiguration(TypedValue.applyDimension(i4, (float) i, displayMetrics), TypedValue.applyDimension(i4, (float) i2, displayMetrics), TypedValue.applyDimension(i4, (float) i3, displayMetrics));
            if (appCompatTextViewAutoSizeHelper.setupAutoSizeText()) {
                appCompatTextViewAutoSizeHelper.autoSizeText();
            }
        }
    }

    public void setAutoSizeTextTypeUniformWithPresetSizes(int[] iArr, int i) {
        AppCompatTextViewAutoSizeHelper appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
        if (appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
            int length = iArr.length;
            if (length > 0) {
                int[] iArr2 = new int[length];
                if (i == 0) {
                    iArr2 = Arrays.copyOf(iArr, length);
                } else {
                    DisplayMetrics displayMetrics = appCompatTextViewAutoSizeHelper.mContext.getResources().getDisplayMetrics();
                    for (int i2 = 0; i2 < length; i2++) {
                        iArr2[i2] = Math.round(TypedValue.applyDimension(i, (float) iArr[i2], displayMetrics));
                    }
                }
                appCompatTextViewAutoSizeHelper.mAutoSizeTextSizesInPx = appCompatTextViewAutoSizeHelper.cleanupAutoSizePresetSizes(iArr2);
                if (!appCompatTextViewAutoSizeHelper.setupAutoSizeUniformPresetSizesConfiguration()) {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("None of the preset sizes is valid: ");
                    outline25.append(Arrays.toString(iArr));
                    throw new IllegalArgumentException(outline25.toString());
                }
            } else {
                appCompatTextViewAutoSizeHelper.mHasPresetAutoSizeValues = false;
            }
            if (appCompatTextViewAutoSizeHelper.setupAutoSizeText()) {
                appCompatTextViewAutoSizeHelper.autoSizeText();
            }
        }
    }

    public void setAutoSizeTextTypeWithDefaults(int i) {
        AppCompatTextViewAutoSizeHelper appCompatTextViewAutoSizeHelper = this.mAutoSizeTextHelper;
        if (!appCompatTextViewAutoSizeHelper.supportsAutoSizeText()) {
            return;
        }
        if (i == 0) {
            appCompatTextViewAutoSizeHelper.mAutoSizeTextType = 0;
            appCompatTextViewAutoSizeHelper.mAutoSizeMinTextSizeInPx = -1.0f;
            appCompatTextViewAutoSizeHelper.mAutoSizeMaxTextSizeInPx = -1.0f;
            appCompatTextViewAutoSizeHelper.mAutoSizeStepGranularityInPx = -1.0f;
            appCompatTextViewAutoSizeHelper.mAutoSizeTextSizesInPx = new int[0];
            appCompatTextViewAutoSizeHelper.mNeedsAutoSizeText = false;
        } else if (i == 1) {
            DisplayMetrics displayMetrics = appCompatTextViewAutoSizeHelper.mContext.getResources().getDisplayMetrics();
            appCompatTextViewAutoSizeHelper.validateAndSetAutoSizeTextTypeUniformConfiguration(TypedValue.applyDimension(2, 12.0f, displayMetrics), TypedValue.applyDimension(2, 112.0f, displayMetrics), 1.0f);
            if (appCompatTextViewAutoSizeHelper.setupAutoSizeText()) {
                appCompatTextViewAutoSizeHelper.autoSizeText();
            }
        } else {
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline11("Unknown auto-size text type: ", i));
        }
    }

    public void setCompoundDrawableTintList(ColorStateList colorStateList) {
        if (this.mDrawableTint == null) {
            this.mDrawableTint = new TintInfo();
        }
        TintInfo tintInfo = this.mDrawableTint;
        tintInfo.mTintList = colorStateList;
        tintInfo.mHasTintList = colorStateList != null;
        this.mDrawableLeftTint = tintInfo;
        this.mDrawableTopTint = tintInfo;
        this.mDrawableRightTint = tintInfo;
        this.mDrawableBottomTint = tintInfo;
        this.mDrawableStartTint = tintInfo;
        this.mDrawableEndTint = tintInfo;
    }

    public void setCompoundDrawableTintMode(PorterDuff.Mode mode) {
        if (this.mDrawableTint == null) {
            this.mDrawableTint = new TintInfo();
        }
        TintInfo tintInfo = this.mDrawableTint;
        tintInfo.mTintMode = mode;
        tintInfo.mHasTintMode = mode != null;
        this.mDrawableLeftTint = tintInfo;
        this.mDrawableTopTint = tintInfo;
        this.mDrawableRightTint = tintInfo;
        this.mDrawableBottomTint = tintInfo;
        this.mDrawableStartTint = tintInfo;
        this.mDrawableEndTint = tintInfo;
    }

    public final void updateTypefaceAndStyle(Context context, TintTypedArray tintTypedArray) {
        String string;
        this.mStyle = tintTypedArray.getInt(R$styleable.TextAppearance_android_textStyle, this.mStyle);
        int i = Build.VERSION.SDK_INT;
        boolean z = false;
        if (i >= 28) {
            int i2 = tintTypedArray.getInt(R$styleable.TextAppearance_android_textFontWeight, -1);
            this.mFontWeight = i2;
            if (i2 != -1) {
                this.mStyle = (this.mStyle & 2) | 0;
            }
        }
        int i3 = R$styleable.TextAppearance_android_fontFamily;
        if (tintTypedArray.hasValue(i3) || tintTypedArray.hasValue(R$styleable.TextAppearance_fontFamily)) {
            this.mFontTypeface = null;
            int i4 = R$styleable.TextAppearance_fontFamily;
            if (tintTypedArray.hasValue(i4)) {
                i3 = i4;
            }
            final int i5 = this.mFontWeight;
            final int i6 = this.mStyle;
            if (!context.isRestricted()) {
                final WeakReference weakReference = new WeakReference(this.mView);
                try {
                    Typeface font = tintTypedArray.getFont(i3, this.mStyle, new ResourcesCompat$FontCallback() {
                        /* class androidx.appcompat.widget.AppCompatTextHelper.AnonymousClass1 */

                        @Override // androidx.core.content.res.ResourcesCompat$FontCallback
                        public void onFontRetrievalFailed(int i) {
                        }

                        @Override // androidx.core.content.res.ResourcesCompat$FontCallback
                        public void onFontRetrieved(Typeface typeface) {
                            int i;
                            if (Build.VERSION.SDK_INT >= 28 && (i = i5) != -1) {
                                typeface = Typeface.create(typeface, i, (i6 & 2) != 0);
                            }
                            AppCompatTextHelper appCompatTextHelper = AppCompatTextHelper.this;
                            WeakReference weakReference = weakReference;
                            if (appCompatTextHelper.mAsyncFontPending) {
                                appCompatTextHelper.mFontTypeface = typeface;
                                TextView textView = (TextView) weakReference.get();
                                if (textView != null) {
                                    AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                                    if (textView.isAttachedToWindow()) {
                                        textView.post(new Runnable(appCompatTextHelper, textView, typeface, appCompatTextHelper.mStyle) {
                                            /* class androidx.appcompat.widget.AppCompatTextHelper.AnonymousClass2 */
                                            public final /* synthetic */ int val$style;
                                            public final /* synthetic */ TextView val$textView;
                                            public final /* synthetic */ Typeface val$typeface;

                                            {
                                                this.val$textView = r2;
                                                this.val$typeface = r3;
                                                this.val$style = r4;
                                            }

                                            public void run() {
                                                this.val$textView.setTypeface(this.val$typeface, this.val$style);
                                            }
                                        });
                                    } else {
                                        textView.setTypeface(typeface, appCompatTextHelper.mStyle);
                                    }
                                }
                            }
                        }
                    });
                    if (font != null) {
                        if (i < 28 || this.mFontWeight == -1) {
                            this.mFontTypeface = font;
                        } else {
                            this.mFontTypeface = Typeface.create(Typeface.create(font, 0), this.mFontWeight, (this.mStyle & 2) != 0);
                        }
                    }
                    this.mAsyncFontPending = this.mFontTypeface == null;
                } catch (Resources.NotFoundException | UnsupportedOperationException unused) {
                }
            }
            if (this.mFontTypeface == null && (string = tintTypedArray.getString(i3)) != null) {
                if (Build.VERSION.SDK_INT < 28 || this.mFontWeight == -1) {
                    this.mFontTypeface = Typeface.create(string, this.mStyle);
                    return;
                }
                Typeface create = Typeface.create(string, 0);
                int i7 = this.mFontWeight;
                if ((this.mStyle & 2) != 0) {
                    z = true;
                }
                this.mFontTypeface = Typeface.create(create, i7, z);
                return;
            }
            return;
        }
        int i8 = R$styleable.TextAppearance_android_typeface;
        if (tintTypedArray.hasValue(i8)) {
            this.mAsyncFontPending = false;
            int i9 = tintTypedArray.getInt(i8, 1);
            if (i9 == 1) {
                this.mFontTypeface = Typeface.SANS_SERIF;
            } else if (i9 == 2) {
                this.mFontTypeface = Typeface.SERIF;
            } else if (i9 == 3) {
                this.mFontTypeface = Typeface.MONOSPACE;
            }
        }
    }
}
