package androidx.appcompat.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.Gravity;
import android.view.View;
import android.view.ViewGroup;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityNodeInfo;
import android.widget.LinearLayout;
import androidx.appcompat.R$styleable;
import androidx.appcompat.content.res.AppCompatResources;
import androidx.core.view.ViewCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.concurrent.atomic.AtomicInteger;

public class LinearLayoutCompat extends ViewGroup {
    public boolean mBaselineAligned;
    public int mBaselineAlignedChildIndex;
    public int mBaselineChildTop;
    public Drawable mDivider;
    public int mDividerHeight;
    public int mDividerPadding;
    public int mDividerWidth;
    public int mGravity;
    public int[] mMaxAscent;
    public int[] mMaxDescent;
    public int mOrientation;
    public int mShowDividers;
    public int mTotalLength;
    public boolean mUseLargestChild;
    public float mWeightSum;

    public static class LayoutParams extends LinearLayout.LayoutParams {
        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        public LayoutParams(int i, int i2) {
            super(i, i2);
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }
    }

    public LinearLayoutCompat(Context context) {
        this(context, null);
    }

    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof LayoutParams;
    }

    public void drawHorizontalDivider(Canvas canvas, int i) {
        this.mDivider.setBounds(getPaddingLeft() + this.mDividerPadding, i, (getWidth() - getPaddingRight()) - this.mDividerPadding, this.mDividerHeight + i);
        this.mDivider.draw(canvas);
    }

    public void drawVerticalDivider(Canvas canvas, int i) {
        this.mDivider.setBounds(i, getPaddingTop() + this.mDividerPadding, this.mDividerWidth + i, (getHeight() - getPaddingBottom()) - this.mDividerPadding);
        this.mDivider.draw(canvas);
    }

    public int getBaseline() {
        int i;
        if (this.mBaselineAlignedChildIndex < 0) {
            return super.getBaseline();
        }
        int childCount = getChildCount();
        int i2 = this.mBaselineAlignedChildIndex;
        if (childCount > i2) {
            View childAt = getChildAt(i2);
            int baseline = childAt.getBaseline();
            if (baseline != -1) {
                int i3 = this.mBaselineChildTop;
                if (this.mOrientation == 1 && (i = this.mGravity & 112) != 48) {
                    if (i == 16) {
                        i3 += ((((getBottom() - getTop()) - getPaddingTop()) - getPaddingBottom()) - this.mTotalLength) / 2;
                    } else if (i == 80) {
                        i3 = ((getBottom() - getTop()) - getPaddingBottom()) - this.mTotalLength;
                    }
                }
                return i3 + ((LinearLayout.LayoutParams) ((LayoutParams) childAt.getLayoutParams())).topMargin + baseline;
            } else if (this.mBaselineAlignedChildIndex == 0) {
                return -1;
            } else {
                throw new RuntimeException("mBaselineAlignedChildIndex of LinearLayout points to a View that doesn't know how to get its baseline.");
            }
        } else {
            throw new RuntimeException("mBaselineAlignedChildIndex of LinearLayout set to an index that is out of bounds.");
        }
    }

    public int getBaselineAlignedChildIndex() {
        return this.mBaselineAlignedChildIndex;
    }

    public int getChildrenSkipCount() {
        return 0;
    }

    public Drawable getDividerDrawable() {
        return this.mDivider;
    }

    public int getDividerPadding() {
        return this.mDividerPadding;
    }

    public int getDividerWidth() {
        return this.mDividerWidth;
    }

    public int getGravity() {
        return this.mGravity;
    }

    public int getLocationOffset() {
        return 0;
    }

    public int getNextLocationOffset() {
        return 0;
    }

    public int getOrientation() {
        return this.mOrientation;
    }

    public int getShowDividers() {
        return this.mShowDividers;
    }

    public int getVirtualChildCount() {
        return getChildCount();
    }

    public float getWeightSum() {
        return this.mWeightSum;
    }

    public boolean hasDividerBeforeChildAt(int i) {
        if (i == 0) {
            return (this.mShowDividers & 1) != 0;
        }
        if (i == getChildCount()) {
            if ((this.mShowDividers & 4) != 0) {
                return true;
            }
            return false;
        } else if ((this.mShowDividers & 2) == 0) {
            return false;
        } else {
            for (int i2 = i - 1; i2 >= 0; i2--) {
                if (getChildAt(i2).getVisibility() != 8) {
                    return true;
                }
            }
            return false;
        }
    }

    public void measureChildBeforeLayout(View view, int i, int i2, int i3, int i4) {
        measureChildWithMargins(view, i, i2, i3, i4);
    }

    public int measureNullChild() {
        return 0;
    }

    public void onDraw(Canvas canvas) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        if (this.mDivider != null) {
            int i6 = 0;
            if (this.mOrientation == 1) {
                int virtualChildCount = getVirtualChildCount();
                while (i6 < virtualChildCount) {
                    View childAt = getChildAt(i6);
                    if (!(childAt == null || childAt.getVisibility() == 8 || !hasDividerBeforeChildAt(i6))) {
                        drawHorizontalDivider(canvas, (childAt.getTop() - ((LinearLayout.LayoutParams) ((LayoutParams) childAt.getLayoutParams())).topMargin) - this.mDividerHeight);
                    }
                    i6++;
                }
                if (hasDividerBeforeChildAt(virtualChildCount)) {
                    View childAt2 = getChildAt(virtualChildCount - 1);
                    if (childAt2 == null) {
                        i5 = (getHeight() - getPaddingBottom()) - this.mDividerHeight;
                    } else {
                        i5 = childAt2.getBottom() + ((LinearLayout.LayoutParams) ((LayoutParams) childAt2.getLayoutParams())).bottomMargin;
                    }
                    drawHorizontalDivider(canvas, i5);
                    return;
                }
                return;
            }
            int virtualChildCount2 = getVirtualChildCount();
            boolean isLayoutRtl = ViewUtils.isLayoutRtl(this);
            while (i6 < virtualChildCount2) {
                View childAt3 = getChildAt(i6);
                if (!(childAt3 == null || childAt3.getVisibility() == 8 || !hasDividerBeforeChildAt(i6))) {
                    LayoutParams layoutParams = (LayoutParams) childAt3.getLayoutParams();
                    if (isLayoutRtl) {
                        i4 = childAt3.getRight() + ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                    } else {
                        i4 = (childAt3.getLeft() - ((LinearLayout.LayoutParams) layoutParams).leftMargin) - this.mDividerWidth;
                    }
                    drawVerticalDivider(canvas, i4);
                }
                i6++;
            }
            if (hasDividerBeforeChildAt(virtualChildCount2)) {
                View childAt4 = getChildAt(virtualChildCount2 - 1);
                if (childAt4 != null) {
                    LayoutParams layoutParams2 = (LayoutParams) childAt4.getLayoutParams();
                    if (isLayoutRtl) {
                        i3 = childAt4.getLeft() - ((LinearLayout.LayoutParams) layoutParams2).leftMargin;
                        i2 = this.mDividerWidth;
                    } else {
                        i = childAt4.getRight() + ((LinearLayout.LayoutParams) layoutParams2).rightMargin;
                        drawVerticalDivider(canvas, i);
                    }
                } else if (isLayoutRtl) {
                    i = getPaddingLeft();
                    drawVerticalDivider(canvas, i);
                } else {
                    i3 = getWidth() - getPaddingRight();
                    i2 = this.mDividerWidth;
                }
                i = i3 - i2;
                drawVerticalDivider(canvas, i);
            }
        }
    }

    public void onInitializeAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        super.onInitializeAccessibilityEvent(accessibilityEvent);
        accessibilityEvent.setClassName("androidx.appcompat.widget.LinearLayoutCompat");
    }

    public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo accessibilityNodeInfo) {
        super.onInitializeAccessibilityNodeInfo(accessibilityNodeInfo);
        accessibilityNodeInfo.setClassName("androidx.appcompat.widget.LinearLayoutCompat");
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x009f  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0169  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x0173  */
    /* JADX WARNING: Removed duplicated region for block: B:71:0x019e  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x01b0  */
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        boolean z2;
        int i13;
        int i14;
        int i15;
        int i16;
        int i17;
        int i18;
        int i19;
        int i20;
        int i21;
        int i22 = 8;
        int i23 = 5;
        if (this.mOrientation == 1) {
            int paddingLeft = getPaddingLeft();
            int i24 = i3 - i;
            int paddingRight = i24 - getPaddingRight();
            int paddingRight2 = (i24 - paddingLeft) - getPaddingRight();
            int virtualChildCount = getVirtualChildCount();
            int i25 = this.mGravity;
            int i26 = i25 & 112;
            int i27 = 8388615 & i25;
            if (i26 == 16) {
                i17 = getPaddingTop() + (((i4 - i2) - this.mTotalLength) / 2);
            } else if (i26 != 80) {
                i17 = getPaddingTop();
            } else {
                i17 = ((getPaddingTop() + i4) - i2) - this.mTotalLength;
            }
            int i28 = 0;
            while (i28 < virtualChildCount) {
                View childAt = getChildAt(i28);
                if (childAt == null) {
                    i18 = measureNullChild() + i17;
                } else if (childAt.getVisibility() != i22) {
                    int measuredWidth = childAt.getMeasuredWidth();
                    int measuredHeight = childAt.getMeasuredHeight();
                    LayoutParams layoutParams = (LayoutParams) childAt.getLayoutParams();
                    int i29 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                    if (i29 < 0) {
                        i29 = i27;
                    }
                    AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                    int absoluteGravity = Gravity.getAbsoluteGravity(i29, getLayoutDirection()) & 7;
                    if (absoluteGravity == 1) {
                        i21 = ((paddingRight2 - measuredWidth) / 2) + paddingLeft + ((LinearLayout.LayoutParams) layoutParams).leftMargin;
                        i20 = ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                    } else if (absoluteGravity != i23) {
                        i19 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + paddingLeft;
                        if (hasDividerBeforeChildAt(i28)) {
                            i17 += this.mDividerHeight;
                        }
                        int i30 = i17 + ((LinearLayout.LayoutParams) layoutParams).topMargin;
                        int locationOffset = getLocationOffset() + i30;
                        childAt.layout(i19, locationOffset, measuredWidth + i19, measuredHeight + locationOffset);
                        i18 = getNextLocationOffset() + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + i30;
                        i28 = getChildrenSkipCount() + i28;
                    } else {
                        i21 = paddingRight - measuredWidth;
                        i20 = ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                    }
                    i19 = i21 - i20;
                    if (hasDividerBeforeChildAt(i28)) {
                    }
                    int i302 = i17 + ((LinearLayout.LayoutParams) layoutParams).topMargin;
                    int locationOffset2 = getLocationOffset() + i302;
                    childAt.layout(i19, locationOffset2, measuredWidth + i19, measuredHeight + locationOffset2);
                    i18 = getNextLocationOffset() + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + i302;
                    i28 = getChildrenSkipCount() + i28;
                } else {
                    i28++;
                    i22 = 8;
                    i23 = 5;
                }
                i17 = i18;
                i28++;
                i22 = 8;
                i23 = 5;
            }
            return;
        }
        boolean isLayoutRtl = ViewUtils.isLayoutRtl(this);
        int paddingTop = getPaddingTop();
        int i31 = i4 - i2;
        int paddingBottom = i31 - getPaddingBottom();
        int paddingBottom2 = (i31 - paddingTop) - getPaddingBottom();
        int virtualChildCount2 = getVirtualChildCount();
        int i32 = this.mGravity;
        int i33 = 8388615 & i32;
        int i34 = i32 & 112;
        boolean z3 = this.mBaselineAligned;
        int[] iArr = this.mMaxAscent;
        int[] iArr2 = this.mMaxDescent;
        AtomicInteger atomicInteger2 = ViewCompat.sNextGeneratedId;
        int absoluteGravity2 = Gravity.getAbsoluteGravity(i33, getLayoutDirection());
        if (absoluteGravity2 == 1) {
            i5 = getPaddingLeft() + (((i3 - i) - this.mTotalLength) / 2);
        } else if (absoluteGravity2 != 5) {
            i5 = getPaddingLeft();
        } else {
            i5 = ((getPaddingLeft() + i3) - i) - this.mTotalLength;
        }
        if (isLayoutRtl) {
            i8 = virtualChildCount2 - 1;
            i7 = 0;
            i6 = -1;
        } else {
            i7 = 0;
            i6 = 1;
            i8 = 0;
        }
        while (i7 < virtualChildCount2) {
            int i35 = (i6 * i7) + i8;
            View childAt2 = getChildAt(i35);
            if (childAt2 == null) {
                i5 += measureNullChild();
                i12 = i8;
            } else {
                i12 = i8;
                if (childAt2.getVisibility() != 8) {
                    int measuredWidth2 = childAt2.getMeasuredWidth();
                    int measuredHeight2 = childAt2.getMeasuredHeight();
                    i10 = virtualChildCount2;
                    LayoutParams layoutParams2 = (LayoutParams) childAt2.getLayoutParams();
                    if (z3) {
                        i9 = i34;
                        z2 = z3;
                        if (((LinearLayout.LayoutParams) layoutParams2).height != -1) {
                            i13 = childAt2.getBaseline();
                            i14 = ((LinearLayout.LayoutParams) layoutParams2).gravity;
                            if (i14 < 0) {
                                i14 = i9;
                            }
                            i15 = i14 & 112;
                            i11 = i6;
                            if (i15 != 16) {
                                i16 = ((((paddingBottom2 - measuredHeight2) / 2) + paddingTop) + ((LinearLayout.LayoutParams) layoutParams2).topMargin) - ((LinearLayout.LayoutParams) layoutParams2).bottomMargin;
                            } else if (i15 == 48) {
                                int i36 = ((LinearLayout.LayoutParams) layoutParams2).topMargin + paddingTop;
                                i16 = i13 != -1 ? (iArr[1] - i13) + i36 : i36;
                            } else if (i15 != 80) {
                                i16 = paddingTop;
                            } else {
                                i16 = (paddingBottom - measuredHeight2) - ((LinearLayout.LayoutParams) layoutParams2).bottomMargin;
                                if (i13 != -1) {
                                    i16 -= iArr2[2] - (childAt2.getMeasuredHeight() - i13);
                                }
                            }
                            if (hasDividerBeforeChildAt(i35)) {
                                i5 += this.mDividerWidth;
                            }
                            int i37 = i5 + ((LinearLayout.LayoutParams) layoutParams2).leftMargin;
                            int locationOffset3 = getLocationOffset() + i37;
                            childAt2.layout(locationOffset3, i16, measuredWidth2 + locationOffset3, measuredHeight2 + i16);
                            int i38 = measuredWidth2 + ((LinearLayout.LayoutParams) layoutParams2).rightMargin;
                            i7 += getChildrenSkipCount();
                            i5 = getNextLocationOffset() + i38 + i37;
                            i7++;
                            i8 = i12;
                            i6 = i11;
                            virtualChildCount2 = i10;
                            i34 = i9;
                            z3 = z2;
                        }
                    } else {
                        i9 = i34;
                        z2 = z3;
                    }
                    i13 = -1;
                    i14 = ((LinearLayout.LayoutParams) layoutParams2).gravity;
                    if (i14 < 0) {
                    }
                    i15 = i14 & 112;
                    i11 = i6;
                    if (i15 != 16) {
                    }
                    if (hasDividerBeforeChildAt(i35)) {
                    }
                    int i372 = i5 + ((LinearLayout.LayoutParams) layoutParams2).leftMargin;
                    int locationOffset32 = getLocationOffset() + i372;
                    childAt2.layout(locationOffset32, i16, measuredWidth2 + locationOffset32, measuredHeight2 + i16);
                    int i382 = measuredWidth2 + ((LinearLayout.LayoutParams) layoutParams2).rightMargin;
                    i7 += getChildrenSkipCount();
                    i5 = getNextLocationOffset() + i382 + i372;
                    i7++;
                    i8 = i12;
                    i6 = i11;
                    virtualChildCount2 = i10;
                    i34 = i9;
                    z3 = z2;
                }
            }
            i10 = virtualChildCount2;
            i9 = i34;
            z2 = z3;
            i11 = i6;
            i7++;
            i8 = i12;
            i6 = i11;
            virtualChildCount2 = i10;
            i34 = i9;
            z3 = z2;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:142:0x0310  */
    /* JADX WARNING: Removed duplicated region for block: B:208:0x04b9  */
    /* JADX WARNING: Removed duplicated region for block: B:209:0x04be  */
    /* JADX WARNING: Removed duplicated region for block: B:212:0x04e6  */
    /* JADX WARNING: Removed duplicated region for block: B:213:0x04eb  */
    /* JADX WARNING: Removed duplicated region for block: B:216:0x04f3  */
    /* JADX WARNING: Removed duplicated region for block: B:217:0x0504  */
    /* JADX WARNING: Removed duplicated region for block: B:219:0x051b  */
    /* JADX WARNING: Removed duplicated region for block: B:243:0x0588  */
    /* JADX WARNING: Removed duplicated region for block: B:246:0x0593  */
    /* JADX WARNING: Removed duplicated region for block: B:274:0x062e  */
    /* JADX WARNING: Removed duplicated region for block: B:308:0x06f8  */
    /* JADX WARNING: Removed duplicated region for block: B:311:0x0715  */
    /* JADX WARNING: Removed duplicated region for block: B:378:0x08ca  */
    /* JADX WARNING: Removed duplicated region for block: B:428:? A[RETURN, SYNTHETIC] */
    public void onMeasure(int i, int i2) {
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        float f;
        int i8;
        char c;
        int i9;
        int i10;
        int i11;
        float f2;
        int i12;
        int i13;
        boolean z;
        int baseline;
        int i14;
        int i15;
        char c2;
        boolean z2;
        boolean z3;
        int i16;
        int i17;
        int i18;
        int i19;
        int i20;
        boolean z4;
        LayoutParams layoutParams;
        int i21;
        boolean z5;
        int i22;
        int i23;
        int baseline2;
        int i24;
        float f3;
        int i25;
        int i26;
        int i27;
        int i28;
        boolean z6;
        int i29;
        int i30;
        int i31;
        int i32;
        int i33;
        int i34;
        int i35;
        LayoutParams layoutParams2;
        boolean z7;
        boolean z8;
        int i36;
        int i37;
        int i38 = this.mOrientation;
        int i39 = -2;
        int i40 = LinearLayoutManager.INVALID_OFFSET;
        int i41 = 8;
        float f4 = 0.0f;
        int i42 = 1073741824;
        if (i38 == 1) {
            this.mTotalLength = 0;
            int virtualChildCount = getVirtualChildCount();
            int mode = View.MeasureSpec.getMode(i);
            int mode2 = View.MeasureSpec.getMode(i2);
            int i43 = this.mBaselineAlignedChildIndex;
            boolean z9 = this.mUseLargestChild;
            int i44 = 0;
            int i45 = 0;
            int i46 = 0;
            int i47 = 0;
            int i48 = 0;
            float f5 = 0.0f;
            boolean z10 = false;
            int i49 = 0;
            boolean z11 = true;
            boolean z12 = false;
            while (i44 < virtualChildCount) {
                View childAt = getChildAt(i44);
                if (childAt == null) {
                    this.mTotalLength = measureNullChild() + this.mTotalLength;
                } else if (childAt.getVisibility() == i41) {
                    i44 += getChildrenSkipCount();
                } else {
                    if (hasDividerBeforeChildAt(i44)) {
                        this.mTotalLength += this.mDividerHeight;
                    }
                    LayoutParams layoutParams3 = (LayoutParams) childAt.getLayoutParams();
                    float f6 = ((LinearLayout.LayoutParams) layoutParams3).weight;
                    f5 += f6;
                    if (mode2 == i42 && ((LinearLayout.LayoutParams) layoutParams3).height == 0 && f6 > f4) {
                        int i50 = this.mTotalLength;
                        this.mTotalLength = Math.max(i50, ((LinearLayout.LayoutParams) layoutParams3).topMargin + i50 + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin);
                        i32 = i43;
                        i31 = mode2;
                        i35 = mode;
                        i30 = virtualChildCount;
                        layoutParams2 = layoutParams3;
                        z7 = true;
                    } else {
                        if (((LinearLayout.LayoutParams) layoutParams3).height != 0 || f6 <= f4) {
                            i36 = LinearLayoutManager.INVALID_OFFSET;
                        } else {
                            ((LinearLayout.LayoutParams) layoutParams3).height = i39;
                            i36 = 0;
                        }
                        if (f5 == f4) {
                            i37 = this.mTotalLength;
                            i32 = i43;
                        } else {
                            i32 = i43;
                            i37 = 0;
                        }
                        i31 = mode2;
                        i35 = mode;
                        i30 = virtualChildCount;
                        layoutParams2 = layoutParams3;
                        measureChildBeforeLayout(childAt, i, 0, i2, i37);
                        if (i36 != i40) {
                            ((LinearLayout.LayoutParams) layoutParams2).height = i36;
                        }
                        int measuredHeight = childAt.getMeasuredHeight();
                        int i51 = this.mTotalLength;
                        this.mTotalLength = Math.max(i51, getNextLocationOffset() + i51 + measuredHeight + ((LinearLayout.LayoutParams) layoutParams2).topMargin + ((LinearLayout.LayoutParams) layoutParams2).bottomMargin);
                        if (z9) {
                            i46 = Math.max(measuredHeight, i46);
                        }
                        z7 = z10;
                    }
                    if (i32 >= 0 && i32 == i44 + 1) {
                        this.mBaselineChildTop = this.mTotalLength;
                    }
                    if (i44 >= i32 || ((LinearLayout.LayoutParams) layoutParams2).weight <= 0.0f) {
                        i34 = i35;
                        if (i34 == 1073741824 || ((LinearLayout.LayoutParams) layoutParams2).width != -1) {
                            z8 = false;
                        } else {
                            z8 = true;
                            z12 = true;
                        }
                        int i52 = ((LinearLayout.LayoutParams) layoutParams2).leftMargin + ((LinearLayout.LayoutParams) layoutParams2).rightMargin;
                        int measuredWidth = childAt.getMeasuredWidth() + i52;
                        i33 = Math.max(i48, measuredWidth);
                        int combineMeasuredStates = View.combineMeasuredStates(i49, childAt.getMeasuredState());
                        boolean z13 = z11 && ((LinearLayout.LayoutParams) layoutParams2).width == -1;
                        if (((LinearLayout.LayoutParams) layoutParams2).weight > 0.0f) {
                            if (!z8) {
                                i52 = measuredWidth;
                            }
                            i45 = Math.max(i45, i52);
                        } else {
                            if (!z8) {
                                i52 = measuredWidth;
                            }
                            i47 = Math.max(i47, i52);
                            i45 = i45;
                        }
                        i44 += getChildrenSkipCount();
                        z10 = z7;
                        z11 = z13;
                        i49 = combineMeasuredStates;
                        i44++;
                        mode = i34;
                        i48 = i33;
                        i43 = i32;
                        mode2 = i31;
                        virtualChildCount = i30;
                        i39 = -2;
                        i40 = LinearLayoutManager.INVALID_OFFSET;
                        i41 = 8;
                        f4 = 0.0f;
                        i42 = 1073741824;
                    } else {
                        throw new RuntimeException("A child of LinearLayout with index less than mBaselineAlignedChildIndex has weight > 0, which won't work.  Either remove the weight, or don't set mBaselineAlignedChildIndex.");
                    }
                }
                i32 = i43;
                i31 = mode2;
                i34 = mode;
                i30 = virtualChildCount;
                i33 = i48;
                i44++;
                mode = i34;
                i48 = i33;
                i43 = i32;
                mode2 = i31;
                virtualChildCount = i30;
                i39 = -2;
                i40 = LinearLayoutManager.INVALID_OFFSET;
                i41 = 8;
                f4 = 0.0f;
                i42 = 1073741824;
            }
            int i53 = i47;
            int i54 = i48;
            int i55 = i49;
            if (this.mTotalLength > 0 && hasDividerBeforeChildAt(virtualChildCount)) {
                this.mTotalLength += this.mDividerHeight;
            }
            int i56 = mode2;
            if (z9 && (i56 == Integer.MIN_VALUE || i56 == 0)) {
                this.mTotalLength = 0;
                int i57 = 0;
                while (i57 < virtualChildCount) {
                    View childAt2 = getChildAt(i57);
                    if (childAt2 == null) {
                        this.mTotalLength = measureNullChild() + this.mTotalLength;
                    } else if (childAt2.getVisibility() == 8) {
                        i57 += getChildrenSkipCount();
                    } else {
                        LayoutParams layoutParams4 = (LayoutParams) childAt2.getLayoutParams();
                        int i58 = this.mTotalLength;
                        this.mTotalLength = Math.max(i58, getNextLocationOffset() + i58 + i46 + ((LinearLayout.LayoutParams) layoutParams4).topMargin + ((LinearLayout.LayoutParams) layoutParams4).bottomMargin);
                    }
                    i57++;
                }
            }
            int paddingBottom = getPaddingBottom() + getPaddingTop() + this.mTotalLength;
            this.mTotalLength = paddingBottom;
            int resolveSizeAndState = View.resolveSizeAndState(Math.max(paddingBottom, getSuggestedMinimumHeight()), i2, 0);
            int i59 = (16777215 & resolveSizeAndState) - this.mTotalLength;
            if (z10 || (i59 != 0 && f5 > 0.0f)) {
                float f7 = this.mWeightSum;
                if (f7 > 0.0f) {
                    f5 = f7;
                }
                this.mTotalLength = 0;
                int i60 = 0;
                while (i60 < virtualChildCount) {
                    View childAt3 = getChildAt(i60);
                    if (childAt3.getVisibility() == 8) {
                        i26 = i56;
                    } else {
                        LayoutParams layoutParams5 = (LayoutParams) childAt3.getLayoutParams();
                        float f8 = ((LinearLayout.LayoutParams) layoutParams5).weight;
                        if (f8 > 0.0f) {
                            int i61 = (int) ((((float) i59) * f8) / f5);
                            f5 -= f8;
                            int i62 = i59 - i61;
                            int childMeasureSpec = ViewGroup.getChildMeasureSpec(i, getPaddingRight() + getPaddingLeft() + ((LinearLayout.LayoutParams) layoutParams5).leftMargin + ((LinearLayout.LayoutParams) layoutParams5).rightMargin, ((LinearLayout.LayoutParams) layoutParams5).width);
                            if (((LinearLayout.LayoutParams) layoutParams5).height == 0) {
                                i29 = 1073741824;
                                if (i56 == 1073741824) {
                                    if (i61 <= 0) {
                                        i61 = 0;
                                    }
                                    childAt3.measure(childMeasureSpec, View.MeasureSpec.makeMeasureSpec(i61, 1073741824));
                                    i55 = View.combineMeasuredStates(i55, childAt3.getMeasuredState() & -256);
                                    i59 = i62;
                                }
                            } else {
                                i29 = 1073741824;
                            }
                            int measuredHeight2 = childAt3.getMeasuredHeight() + i61;
                            if (measuredHeight2 < 0) {
                                measuredHeight2 = 0;
                            }
                            childAt3.measure(childMeasureSpec, View.MeasureSpec.makeMeasureSpec(measuredHeight2, i29));
                            i55 = View.combineMeasuredStates(i55, childAt3.getMeasuredState() & -256);
                            i59 = i62;
                        }
                        int i63 = ((LinearLayout.LayoutParams) layoutParams5).leftMargin + ((LinearLayout.LayoutParams) layoutParams5).rightMargin;
                        int measuredWidth2 = childAt3.getMeasuredWidth() + i63;
                        i54 = Math.max(i54, measuredWidth2);
                        i26 = i56;
                        if (mode != 1073741824) {
                            i27 = i59;
                            i28 = -1;
                            if (((LinearLayout.LayoutParams) layoutParams5).width == -1) {
                                z6 = true;
                                if (!z6) {
                                    i63 = measuredWidth2;
                                }
                                i53 = Math.max(i53, i63);
                                boolean z14 = !z11 && ((LinearLayout.LayoutParams) layoutParams5).width == i28;
                                int i64 = this.mTotalLength;
                                this.mTotalLength = Math.max(i64, getNextLocationOffset() + childAt3.getMeasuredHeight() + i64 + ((LinearLayout.LayoutParams) layoutParams5).topMargin + ((LinearLayout.LayoutParams) layoutParams5).bottomMargin);
                                z11 = z14;
                                i59 = i27;
                            }
                        } else {
                            i27 = i59;
                            i28 = -1;
                        }
                        z6 = false;
                        if (!z6) {
                        }
                        i53 = Math.max(i53, i63);
                        if (!z11) {
                        }
                        int i642 = this.mTotalLength;
                        this.mTotalLength = Math.max(i642, getNextLocationOffset() + childAt3.getMeasuredHeight() + i642 + ((LinearLayout.LayoutParams) layoutParams5).topMargin + ((LinearLayout.LayoutParams) layoutParams5).bottomMargin);
                        z11 = z14;
                        i59 = i27;
                    }
                    i60++;
                    i56 = i26;
                }
                this.mTotalLength = getPaddingBottom() + getPaddingTop() + this.mTotalLength;
            } else {
                i53 = Math.max(i53, i45);
                if (z9 && i56 != 1073741824) {
                    for (int i65 = 0; i65 < virtualChildCount; i65++) {
                        View childAt4 = getChildAt(i65);
                        if (!(childAt4 == null || childAt4.getVisibility() == 8 || ((LinearLayout.LayoutParams) ((LayoutParams) childAt4.getLayoutParams())).weight <= 0.0f)) {
                            childAt4.measure(View.MeasureSpec.makeMeasureSpec(childAt4.getMeasuredWidth(), 1073741824), View.MeasureSpec.makeMeasureSpec(i46, 1073741824));
                        }
                    }
                }
            }
            if (z11 || mode == 1073741824) {
                i53 = i54;
            }
            setMeasuredDimension(View.resolveSizeAndState(Math.max(getPaddingRight() + getPaddingLeft() + i53, getSuggestedMinimumWidth()), i, i55), resolveSizeAndState);
            if (z12) {
                int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(getMeasuredWidth(), 1073741824);
                for (int i66 = 0; i66 < virtualChildCount; i66++) {
                    View childAt5 = getChildAt(i66);
                    if (childAt5.getVisibility() != 8) {
                        LayoutParams layoutParams6 = (LayoutParams) childAt5.getLayoutParams();
                        if (((LinearLayout.LayoutParams) layoutParams6).width == -1) {
                            int i67 = ((LinearLayout.LayoutParams) layoutParams6).height;
                            ((LinearLayout.LayoutParams) layoutParams6).height = childAt5.getMeasuredHeight();
                            measureChildWithMargins(childAt5, makeMeasureSpec, 0, i2, 0);
                            ((LinearLayout.LayoutParams) layoutParams6).height = i67;
                        }
                    }
                }
                return;
            }
            return;
        }
        this.mTotalLength = 0;
        int virtualChildCount2 = getVirtualChildCount();
        int mode3 = View.MeasureSpec.getMode(i);
        int mode4 = View.MeasureSpec.getMode(i2);
        if (this.mMaxAscent == null || this.mMaxDescent == null) {
            this.mMaxAscent = new int[4];
            this.mMaxDescent = new int[4];
        }
        int[] iArr = this.mMaxAscent;
        int[] iArr2 = this.mMaxDescent;
        iArr[3] = -1;
        iArr[2] = -1;
        iArr[1] = -1;
        iArr[0] = -1;
        iArr2[3] = -1;
        iArr2[2] = -1;
        iArr2[1] = -1;
        iArr2[0] = -1;
        boolean z15 = this.mBaselineAligned;
        boolean z16 = this.mUseLargestChild;
        boolean z17 = mode3 == 1073741824;
        int i68 = 0;
        float f9 = 0.0f;
        int i69 = 0;
        int i70 = 0;
        int i71 = 0;
        int i72 = 0;
        int i73 = 0;
        boolean z18 = false;
        boolean z19 = true;
        boolean z20 = false;
        while (i70 < virtualChildCount2) {
            View childAt6 = getChildAt(i70);
            if (childAt6 == null) {
                this.mTotalLength = measureNullChild() + this.mTotalLength;
                i17 = i68;
                i16 = i69;
            } else {
                i17 = i68;
                i16 = i69;
                if (childAt6.getVisibility() == 8) {
                    i70 += getChildrenSkipCount();
                } else {
                    if (hasDividerBeforeChildAt(i70)) {
                        this.mTotalLength += this.mDividerWidth;
                    }
                    LayoutParams layoutParams7 = (LayoutParams) childAt6.getLayoutParams();
                    float f10 = ((LinearLayout.LayoutParams) layoutParams7).weight;
                    float f11 = f9 + f10;
                    if (mode3 == 1073741824 && ((LinearLayout.LayoutParams) layoutParams7).width == 0 && f10 > 0.0f) {
                        if (z17) {
                            i25 = i70;
                            this.mTotalLength = ((LinearLayout.LayoutParams) layoutParams7).leftMargin + ((LinearLayout.LayoutParams) layoutParams7).rightMargin + this.mTotalLength;
                        } else {
                            i25 = i70;
                            int i74 = this.mTotalLength;
                            this.mTotalLength = Math.max(i74, ((LinearLayout.LayoutParams) layoutParams7).leftMargin + i74 + ((LinearLayout.LayoutParams) layoutParams7).rightMargin);
                        }
                        if (z15) {
                            int makeMeasureSpec2 = View.MeasureSpec.makeMeasureSpec(0, 0);
                            childAt6.measure(makeMeasureSpec2, makeMeasureSpec2);
                            layoutParams = layoutParams7;
                            i19 = i17;
                            i18 = i16;
                            i20 = i25;
                            z3 = z16;
                            z2 = z15;
                        } else {
                            layoutParams = layoutParams7;
                            i19 = i17;
                            i18 = i16;
                            i20 = i25;
                            i21 = 1073741824;
                            z3 = z16;
                            z2 = z15;
                            z4 = true;
                            if (mode4 == i21 && ((LinearLayout.LayoutParams) layoutParams).height == -1) {
                                z5 = true;
                                z20 = true;
                            } else {
                                z5 = false;
                            }
                            i22 = ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                            int measuredHeight3 = childAt6.getMeasuredHeight() + i22;
                            int combineMeasuredStates2 = View.combineMeasuredStates(i72, childAt6.getMeasuredState());
                            if (z2 || (baseline2 = childAt6.getBaseline()) == -1) {
                                i23 = i22;
                            } else {
                                int i75 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                                if (i75 < 0) {
                                    i75 = this.mGravity;
                                }
                                int i76 = (((i75 & 112) >> 4) & -2) >> 1;
                                i23 = i22;
                                iArr[i76] = Math.max(iArr[i76], baseline2);
                                iArr2[i76] = Math.max(iArr2[i76], measuredHeight3 - baseline2);
                            }
                            int max = Math.max(i73, measuredHeight3);
                            boolean z21 = !z19 && ((LinearLayout.LayoutParams) layoutParams).height == -1;
                            if (((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                                if (z5) {
                                    measuredHeight3 = i23;
                                }
                                i68 = Math.max(i19, measuredHeight3);
                            } else {
                                if (z5) {
                                    measuredHeight3 = i23;
                                }
                                i18 = Math.max(i18, measuredHeight3);
                                i68 = i19;
                            }
                            i70 = getChildrenSkipCount() + i20;
                            i73 = max;
                            i72 = combineMeasuredStates2;
                            z18 = z4;
                            z19 = z21;
                            f9 = f11;
                            i69 = i18;
                            i70++;
                            z16 = z3;
                            z15 = z2;
                        }
                    } else {
                        if (((LinearLayout.LayoutParams) layoutParams7).width == 0) {
                            f3 = 0.0f;
                            if (f10 > 0.0f) {
                                ((LinearLayout.LayoutParams) layoutParams7).width = -2;
                                i24 = 0;
                                i19 = i17;
                                i18 = i16;
                                i20 = i70;
                                z3 = z16;
                                z2 = z15;
                                measureChildBeforeLayout(childAt6, i, f11 != f3 ? this.mTotalLength : 0, i2, 0);
                                if (i24 == Integer.MIN_VALUE) {
                                    layoutParams = layoutParams7;
                                    ((LinearLayout.LayoutParams) layoutParams).width = i24;
                                } else {
                                    layoutParams = layoutParams7;
                                }
                                int measuredWidth3 = childAt6.getMeasuredWidth();
                                if (!z17) {
                                    this.mTotalLength = getNextLocationOffset() + ((LinearLayout.LayoutParams) layoutParams).leftMargin + measuredWidth3 + ((LinearLayout.LayoutParams) layoutParams).rightMargin + this.mTotalLength;
                                } else {
                                    int i77 = this.mTotalLength;
                                    this.mTotalLength = Math.max(i77, getNextLocationOffset() + i77 + measuredWidth3 + ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin);
                                }
                                if (z3) {
                                    i71 = Math.max(measuredWidth3, i71);
                                }
                            }
                        } else {
                            f3 = 0.0f;
                        }
                        i24 = LinearLayoutManager.INVALID_OFFSET;
                        i19 = i17;
                        i18 = i16;
                        i20 = i70;
                        z3 = z16;
                        z2 = z15;
                        measureChildBeforeLayout(childAt6, i, f11 != f3 ? this.mTotalLength : 0, i2, 0);
                        if (i24 == Integer.MIN_VALUE) {
                        }
                        int measuredWidth32 = childAt6.getMeasuredWidth();
                        if (!z17) {
                        }
                        if (z3) {
                        }
                    }
                    z4 = z18;
                    i21 = 1073741824;
                    if (mode4 == i21) {
                    }
                    z5 = false;
                    i22 = ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                    int measuredHeight32 = childAt6.getMeasuredHeight() + i22;
                    int combineMeasuredStates22 = View.combineMeasuredStates(i72, childAt6.getMeasuredState());
                    if (z2) {
                    }
                    i23 = i22;
                    int max2 = Math.max(i73, measuredHeight32);
                    if (!z19) {
                    }
                    if (((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                    }
                    i70 = getChildrenSkipCount() + i20;
                    i73 = max2;
                    i72 = combineMeasuredStates22;
                    z18 = z4;
                    z19 = z21;
                    f9 = f11;
                    i69 = i18;
                    i70++;
                    z16 = z3;
                    z15 = z2;
                }
            }
            z2 = z15;
            i68 = i17;
            i69 = i16;
            z3 = z16;
            i70++;
            z16 = z3;
            z15 = z2;
        }
        int i78 = i69;
        if (this.mTotalLength > 0 && hasDividerBeforeChildAt(virtualChildCount2)) {
            this.mTotalLength += this.mDividerWidth;
        }
        if (iArr[1] == -1 && iArr[0] == -1 && iArr[2] == -1) {
            c2 = 3;
            if (iArr[3] == -1) {
                i3 = i72;
                if (z16 && (mode3 == Integer.MIN_VALUE || mode3 == 0)) {
                    this.mTotalLength = 0;
                    i15 = 0;
                    while (i15 < virtualChildCount2) {
                        View childAt7 = getChildAt(i15);
                        if (childAt7 == null) {
                            this.mTotalLength = measureNullChild() + this.mTotalLength;
                        } else if (childAt7.getVisibility() == 8) {
                            i15 += getChildrenSkipCount();
                        } else {
                            LayoutParams layoutParams8 = (LayoutParams) childAt7.getLayoutParams();
                            if (z17) {
                                this.mTotalLength = getNextLocationOffset() + ((LinearLayout.LayoutParams) layoutParams8).leftMargin + i71 + ((LinearLayout.LayoutParams) layoutParams8).rightMargin + this.mTotalLength;
                            } else {
                                int i79 = this.mTotalLength;
                                this.mTotalLength = Math.max(i79, getNextLocationOffset() + i79 + i71 + ((LinearLayout.LayoutParams) layoutParams8).leftMargin + ((LinearLayout.LayoutParams) layoutParams8).rightMargin);
                            }
                        }
                        i15++;
                    }
                }
                int paddingRight = getPaddingRight() + getPaddingLeft() + this.mTotalLength;
                this.mTotalLength = paddingRight;
                int resolveSizeAndState2 = View.resolveSizeAndState(Math.max(paddingRight, getSuggestedMinimumWidth()), i, 0);
                i4 = (16777215 & resolveSizeAndState2) - this.mTotalLength;
                if (!z18 || (i4 != 0 && f9 > 0.0f)) {
                    f = this.mWeightSum;
                    if (f > 0.0f) {
                        f9 = f;
                    }
                    iArr[3] = -1;
                    iArr[2] = -1;
                    iArr[1] = -1;
                    iArr[0] = -1;
                    iArr2[3] = -1;
                    iArr2[2] = -1;
                    iArr2[1] = -1;
                    iArr2[0] = -1;
                    this.mTotalLength = 0;
                    int i80 = i4;
                    i6 = i3;
                    int i81 = -1;
                    i8 = 0;
                    while (i8 < virtualChildCount2) {
                        View childAt8 = getChildAt(i8);
                        if (childAt8 == null || childAt8.getVisibility() == 8) {
                            i10 = i80;
                            i9 = virtualChildCount2;
                        } else {
                            LayoutParams layoutParams9 = (LayoutParams) childAt8.getLayoutParams();
                            float f12 = ((LinearLayout.LayoutParams) layoutParams9).weight;
                            if (f12 > 0.0f) {
                                i9 = virtualChildCount2;
                                int i82 = (int) ((((float) i80) * f12) / f9);
                                float f13 = f9 - f12;
                                int i83 = i80 - i82;
                                int childMeasureSpec2 = ViewGroup.getChildMeasureSpec(i2, getPaddingBottom() + getPaddingTop() + ((LinearLayout.LayoutParams) layoutParams9).topMargin + ((LinearLayout.LayoutParams) layoutParams9).bottomMargin, ((LinearLayout.LayoutParams) layoutParams9).height);
                                if (((LinearLayout.LayoutParams) layoutParams9).width == 0) {
                                    i14 = 1073741824;
                                    if (mode3 == 1073741824) {
                                        if (i82 <= 0) {
                                            i82 = 0;
                                        }
                                        childAt8.measure(View.MeasureSpec.makeMeasureSpec(i82, 1073741824), childMeasureSpec2);
                                        i6 = View.combineMeasuredStates(i6, childAt8.getMeasuredState() & -16777216);
                                        f9 = f13;
                                        i11 = i83;
                                    }
                                } else {
                                    i14 = 1073741824;
                                }
                                int measuredWidth4 = childAt8.getMeasuredWidth() + i82;
                                if (measuredWidth4 < 0) {
                                    measuredWidth4 = 0;
                                }
                                childAt8.measure(View.MeasureSpec.makeMeasureSpec(measuredWidth4, i14), childMeasureSpec2);
                                i6 = View.combineMeasuredStates(i6, childAt8.getMeasuredState() & -16777216);
                                f9 = f13;
                                i11 = i83;
                            } else {
                                i11 = i80;
                                i9 = virtualChildCount2;
                            }
                            if (z17) {
                                f2 = f9;
                                this.mTotalLength = getNextLocationOffset() + childAt8.getMeasuredWidth() + ((LinearLayout.LayoutParams) layoutParams9).leftMargin + ((LinearLayout.LayoutParams) layoutParams9).rightMargin + this.mTotalLength;
                                i12 = i11;
                            } else {
                                f2 = f9;
                                int i84 = this.mTotalLength;
                                i12 = i11;
                                this.mTotalLength = Math.max(i84, getNextLocationOffset() + childAt8.getMeasuredWidth() + i84 + ((LinearLayout.LayoutParams) layoutParams9).leftMargin + ((LinearLayout.LayoutParams) layoutParams9).rightMargin);
                            }
                            boolean z22 = mode4 != 1073741824 && ((LinearLayout.LayoutParams) layoutParams9).height == -1;
                            int i85 = ((LinearLayout.LayoutParams) layoutParams9).topMargin + ((LinearLayout.LayoutParams) layoutParams9).bottomMargin;
                            int measuredHeight4 = childAt8.getMeasuredHeight() + i85;
                            i81 = Math.max(i81, measuredHeight4);
                            if (!z22) {
                                i85 = measuredHeight4;
                            }
                            i78 = Math.max(i78, i85);
                            if (z19) {
                                i13 = -1;
                                if (((LinearLayout.LayoutParams) layoutParams9).height == -1) {
                                    z = true;
                                    if (!z15 && (baseline = childAt8.getBaseline()) != i13) {
                                        int i86 = ((LinearLayout.LayoutParams) layoutParams9).gravity;
                                        if (i86 < 0) {
                                            i86 = this.mGravity;
                                        }
                                        int i87 = (((i86 & 112) >> 4) & -2) >> 1;
                                        iArr[i87] = Math.max(iArr[i87], baseline);
                                        iArr2[i87] = Math.max(iArr2[i87], measuredHeight4 - baseline);
                                    }
                                    z19 = z;
                                    i10 = i12;
                                    f9 = f2;
                                }
                            } else {
                                i13 = -1;
                            }
                            z = false;
                            if (!z15) {
                            }
                            z19 = z;
                            i10 = i12;
                            f9 = f2;
                        }
                        i8++;
                        i80 = i10;
                        virtualChildCount2 = i9;
                    }
                    i7 = i2;
                    i5 = virtualChildCount2;
                    this.mTotalLength = getPaddingRight() + getPaddingLeft() + this.mTotalLength;
                    if (iArr[1] != -1 && iArr[0] == -1 && iArr[2] == -1) {
                        c = 3;
                        if (iArr[3] == -1) {
                            i73 = i81;
                        }
                    } else {
                        c = 3;
                    }
                    i73 = Math.max(i81, Math.max(iArr2[c], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))) + Math.max(iArr[c], Math.max(iArr[0], Math.max(iArr[1], iArr[2]))));
                    if (z19 || mode4 == 1073741824) {
                        i78 = i73;
                    }
                    setMeasuredDimension((-16777216 & i6) | resolveSizeAndState2, View.resolveSizeAndState(Math.max(getPaddingBottom() + getPaddingTop() + i78, getSuggestedMinimumHeight()), i7, i6 << 16));
                    if (z20) {
                        int makeMeasureSpec3 = View.MeasureSpec.makeMeasureSpec(getMeasuredHeight(), 1073741824);
                        for (int i88 = 0; i88 < i5; i88++) {
                            View childAt9 = getChildAt(i88);
                            if (childAt9.getVisibility() != 8) {
                                LayoutParams layoutParams10 = (LayoutParams) childAt9.getLayoutParams();
                                if (((LinearLayout.LayoutParams) layoutParams10).height == -1) {
                                    int i89 = ((LinearLayout.LayoutParams) layoutParams10).width;
                                    ((LinearLayout.LayoutParams) layoutParams10).width = childAt9.getMeasuredWidth();
                                    measureChildWithMargins(childAt9, i, 0, makeMeasureSpec3, 0);
                                    ((LinearLayout.LayoutParams) layoutParams10).width = i89;
                                }
                            }
                        }
                        return;
                    }
                    return;
                }
                i78 = Math.max(i78, i68);
                if (z16 && mode3 != 1073741824) {
                    for (int i90 = 0; i90 < virtualChildCount2; i90++) {
                        View childAt10 = getChildAt(i90);
                        if (!(childAt10 == null || childAt10.getVisibility() == 8 || ((LinearLayout.LayoutParams) ((LayoutParams) childAt10.getLayoutParams())).weight <= 0.0f)) {
                            childAt10.measure(View.MeasureSpec.makeMeasureSpec(i71, 1073741824), View.MeasureSpec.makeMeasureSpec(childAt10.getMeasuredHeight(), 1073741824));
                        }
                    }
                }
                i7 = i2;
                i5 = virtualChildCount2;
                i6 = i3;
                i78 = i73;
                setMeasuredDimension((-16777216 & i6) | resolveSizeAndState2, View.resolveSizeAndState(Math.max(getPaddingBottom() + getPaddingTop() + i78, getSuggestedMinimumHeight()), i7, i6 << 16));
                if (z20) {
                }
            }
        } else {
            c2 = 3;
        }
        i3 = i72;
        i73 = Math.max(i73, Math.max(iArr2[3], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))) + Math.max(iArr[c2], Math.max(iArr[0], Math.max(iArr[1], iArr[2]))));
        this.mTotalLength = 0;
        i15 = 0;
        while (i15 < virtualChildCount2) {
        }
        int paddingRight2 = getPaddingRight() + getPaddingLeft() + this.mTotalLength;
        this.mTotalLength = paddingRight2;
        int resolveSizeAndState22 = View.resolveSizeAndState(Math.max(paddingRight2, getSuggestedMinimumWidth()), i, 0);
        i4 = (16777215 & resolveSizeAndState22) - this.mTotalLength;
        if (!z18) {
        }
        f = this.mWeightSum;
        if (f > 0.0f) {
        }
        iArr[3] = -1;
        iArr[2] = -1;
        iArr[1] = -1;
        iArr[0] = -1;
        iArr2[3] = -1;
        iArr2[2] = -1;
        iArr2[1] = -1;
        iArr2[0] = -1;
        this.mTotalLength = 0;
        int i802 = i4;
        i6 = i3;
        int i812 = -1;
        i8 = 0;
        while (i8 < virtualChildCount2) {
        }
        i7 = i2;
        i5 = virtualChildCount2;
        this.mTotalLength = getPaddingRight() + getPaddingLeft() + this.mTotalLength;
        if (iArr[1] != -1) {
        }
        c = 3;
        i73 = Math.max(i812, Math.max(iArr2[c], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))) + Math.max(iArr[c], Math.max(iArr[0], Math.max(iArr[1], iArr[2]))));
        i78 = i73;
        setMeasuredDimension((-16777216 & i6) | resolveSizeAndState22, View.resolveSizeAndState(Math.max(getPaddingBottom() + getPaddingTop() + i78, getSuggestedMinimumHeight()), i7, i6 << 16));
        if (z20) {
        }
    }

    public void setBaselineAligned(boolean z) {
        this.mBaselineAligned = z;
    }

    public void setBaselineAlignedChildIndex(int i) {
        if (i < 0 || i >= getChildCount()) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("base aligned child index out of range (0, ");
            outline25.append(getChildCount());
            outline25.append(")");
            throw new IllegalArgumentException(outline25.toString());
        }
        this.mBaselineAlignedChildIndex = i;
    }

    public void setDividerDrawable(Drawable drawable) {
        if (drawable != this.mDivider) {
            this.mDivider = drawable;
            boolean z = false;
            if (drawable != null) {
                this.mDividerWidth = drawable.getIntrinsicWidth();
                this.mDividerHeight = drawable.getIntrinsicHeight();
            } else {
                this.mDividerWidth = 0;
                this.mDividerHeight = 0;
            }
            if (drawable == null) {
                z = true;
            }
            setWillNotDraw(z);
            requestLayout();
        }
    }

    public void setDividerPadding(int i) {
        this.mDividerPadding = i;
    }

    public void setGravity(int i) {
        if (this.mGravity != i) {
            if ((8388615 & i) == 0) {
                i |= 8388611;
            }
            if ((i & 112) == 0) {
                i |= 48;
            }
            this.mGravity = i;
            requestLayout();
        }
    }

    public void setHorizontalGravity(int i) {
        int i2 = i & 8388615;
        int i3 = this.mGravity;
        if ((8388615 & i3) != i2) {
            this.mGravity = i2 | (-8388616 & i3);
            requestLayout();
        }
    }

    public void setMeasureWithLargestChildEnabled(boolean z) {
        this.mUseLargestChild = z;
    }

    public void setOrientation(int i) {
        if (this.mOrientation != i) {
            this.mOrientation = i;
            requestLayout();
        }
    }

    public void setShowDividers(int i) {
        if (i != this.mShowDividers) {
            requestLayout();
        }
        this.mShowDividers = i;
    }

    public void setVerticalGravity(int i) {
        int i2 = i & 112;
        int i3 = this.mGravity;
        if ((i3 & 112) != i2) {
            this.mGravity = i2 | (i3 & -113);
            requestLayout();
        }
    }

    public void setWeightSum(float f) {
        this.mWeightSum = Math.max(0.0f, f);
    }

    public boolean shouldDelayChildPressedState() {
        return false;
    }

    public LinearLayoutCompat(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public LayoutParams generateDefaultLayoutParams() {
        int i = this.mOrientation;
        if (i == 0) {
            return new LayoutParams(-2, -2);
        }
        if (i == 1) {
            return new LayoutParams(-1, -2);
        }
        return null;
    }

    public LinearLayoutCompat(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        Drawable drawable;
        int resourceId;
        this.mBaselineAligned = true;
        this.mBaselineAlignedChildIndex = -1;
        this.mBaselineChildTop = 0;
        this.mGravity = 8388659;
        int[] iArr = R$styleable.LinearLayoutCompat;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, iArr, i, 0);
        ViewCompat.saveAttributeDataForStyleable(this, context, iArr, attributeSet, obtainStyledAttributes, i, 0);
        int i2 = obtainStyledAttributes.getInt(R$styleable.LinearLayoutCompat_android_orientation, -1);
        if (i2 >= 0) {
            setOrientation(i2);
        }
        int i3 = obtainStyledAttributes.getInt(R$styleable.LinearLayoutCompat_android_gravity, -1);
        if (i3 >= 0) {
            setGravity(i3);
        }
        boolean z = obtainStyledAttributes.getBoolean(R$styleable.LinearLayoutCompat_android_baselineAligned, true);
        if (!z) {
            setBaselineAligned(z);
        }
        this.mWeightSum = obtainStyledAttributes.getFloat(R$styleable.LinearLayoutCompat_android_weightSum, -1.0f);
        this.mBaselineAlignedChildIndex = obtainStyledAttributes.getInt(R$styleable.LinearLayoutCompat_android_baselineAlignedChildIndex, -1);
        this.mUseLargestChild = obtainStyledAttributes.getBoolean(R$styleable.LinearLayoutCompat_measureWithLargestChild, false);
        int i4 = R$styleable.LinearLayoutCompat_divider;
        if (!obtainStyledAttributes.hasValue(i4) || (resourceId = obtainStyledAttributes.getResourceId(i4, 0)) == 0) {
            drawable = obtainStyledAttributes.getDrawable(i4);
        } else {
            drawable = AppCompatResources.getDrawable(context, resourceId);
        }
        setDividerDrawable(drawable);
        this.mShowDividers = obtainStyledAttributes.getInt(R$styleable.LinearLayoutCompat_showDividers, 0);
        this.mDividerPadding = obtainStyledAttributes.getDimensionPixelSize(R$styleable.LinearLayoutCompat_dividerPadding, 0);
        obtainStyledAttributes.recycle();
    }

    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }

    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return new LayoutParams(layoutParams);
    }
}
