package androidx.constraintlayout.core.motion.utils;

public class SpringStopEngine implements StopEngine {
    public int mBoundaryMode = 0;
    public double mDamping = 0.5d;
    public float mLastTime;
    public float mMass;
    public float mPos;
    public double mStiffness;
    public float mStopThreshold;
    public double mTargetPos;
    public float mV;

    @Override // androidx.constraintlayout.core.motion.utils.StopEngine
    public float getInterpolation(float f) {
        SpringStopEngine springStopEngine = this;
        double d = (double) (f - springStopEngine.mLastTime);
        double d2 = springStopEngine.mStiffness;
        double d3 = springStopEngine.mDamping;
        int sqrt = (int) ((9.0d / ((Math.sqrt(d2 / ((double) springStopEngine.mMass)) * d) * 4.0d)) + 1.0d);
        double d4 = d / ((double) sqrt);
        int i = 0;
        while (i < sqrt) {
            double d5 = (double) springStopEngine.mPos;
            double d6 = springStopEngine.mTargetPos;
            double d7 = (double) springStopEngine.mV;
            double d8 = (double) springStopEngine.mMass;
            double d9 = ((((((-d2) * (d5 - d6)) - (d7 * d3)) / d8) * d4) / 2.0d) + d7;
            double d10 = ((((-((((d4 * d9) / 2.0d) + d5) - d6)) * d2) - (d9 * d3)) / d8) * d4;
            float f2 = (float) (d7 + d10);
            this.mV = f2;
            float f3 = (float) ((((d10 / 2.0d) + d7) * d4) + d5);
            this.mPos = f3;
            int i2 = this.mBoundaryMode;
            if (i2 > 0) {
                if (f3 < 0.0f && (i2 & 1) == 1) {
                    this.mPos = -f3;
                    this.mV = -f2;
                }
                float f4 = this.mPos;
                if (f4 > 1.0f && (i2 & 2) == 2) {
                    this.mPos = 2.0f - f4;
                    this.mV = -this.mV;
                }
            }
            sqrt = sqrt;
            i++;
            springStopEngine = this;
        }
        springStopEngine.mLastTime = f;
        return springStopEngine.mPos;
    }

    @Override // androidx.constraintlayout.core.motion.utils.StopEngine
    public float getVelocity() {
        return 0.0f;
    }

    @Override // androidx.constraintlayout.core.motion.utils.StopEngine
    public boolean isStopped() {
        double d = ((double) this.mPos) - this.mTargetPos;
        double d2 = this.mStiffness;
        double d3 = (double) this.mV;
        return Math.sqrt((((d2 * d) * d) + ((d3 * d3) * ((double) this.mMass))) / d2) <= ((double) this.mStopThreshold);
    }
}
