package androidx.constraintlayout.core.widgets;

import androidx.constraintlayout.core.ArrayRow;
import androidx.constraintlayout.core.Cache;
import androidx.constraintlayout.core.LinearSystem;
import androidx.constraintlayout.core.SolverVariable;
import androidx.constraintlayout.core.widgets.ConstraintAnchor;
import androidx.constraintlayout.core.widgets.analyzer.ChainRun;
import androidx.constraintlayout.core.widgets.analyzer.DependencyNode;
import androidx.constraintlayout.core.widgets.analyzer.HorizontalWidgetRun;
import androidx.constraintlayout.core.widgets.analyzer.VerticalWidgetRun;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Objects;

public class ConstraintWidget {
    public boolean hasBaseline;
    public ChainRun horizontalChainRun;
    public int horizontalGroup;
    public HorizontalWidgetRun horizontalRun = null;
    public boolean horizontalSolvingPass;
    public boolean inPlaceholder;
    public boolean[] isTerminalWidget = {true, true};
    public ArrayList<ConstraintAnchor> mAnchors;
    public ConstraintAnchor mBaseline;
    public int mBaselineDistance;
    public ConstraintAnchor mBottom;
    public boolean mBottomHasCentered;
    public ConstraintAnchor mCenter;
    public ConstraintAnchor mCenterX;
    public ConstraintAnchor mCenterY;
    public float mCircleConstraintAngle;
    public Object mCompanionWidget;
    public int mContainerItemSkip;
    public String mDebugName;
    public float mDimensionRatio;
    public int mDimensionRatioSide;
    public int mDistToBottom;
    public int mDistToLeft;
    public int mDistToRight;
    public int mDistToTop;
    public int mHeight;
    public int mHeightOverride = -1;
    public float mHorizontalBiasPercent;
    public boolean mHorizontalChainFixedPosition;
    public int mHorizontalChainStyle;
    public ConstraintWidget mHorizontalNextWidget;
    public int mHorizontalResolution;
    public boolean mHorizontalWrapVisited;
    public boolean mInVirtualLayout;
    public boolean mIsHeightWrapContent;
    public boolean[] mIsInBarrier;
    public boolean mIsWidthWrapContent;
    public int mLastHorizontalMeasureSpec;
    public int mLastVerticalMeasureSpec;
    public ConstraintAnchor mLeft;
    public boolean mLeftHasCentered;
    public ConstraintAnchor[] mListAnchors;
    public DimensionBehaviour[] mListDimensionBehaviors;
    public ConstraintWidget[] mListNextMatchConstraintsWidget;
    public int mMatchConstraintDefaultHeight;
    public int mMatchConstraintDefaultWidth;
    public int mMatchConstraintMaxHeight;
    public int mMatchConstraintMaxWidth;
    public int mMatchConstraintMinHeight;
    public int mMatchConstraintMinWidth;
    public float mMatchConstraintPercentHeight;
    public float mMatchConstraintPercentWidth;
    public int[] mMaxDimension;
    public boolean mMeasureRequested = true;
    public int mMinHeight;
    public int mMinWidth;
    public ConstraintWidget[] mNextChainWidget;
    public int mOffsetX;
    public int mOffsetY;
    public ConstraintWidget mParent;
    public int mRelX;
    public int mRelY;
    public float mResolvedDimensionRatio;
    public int mResolvedDimensionRatioSide;
    public int[] mResolvedMatchConstraintDefault;
    public ConstraintAnchor mRight;
    public boolean mRightHasCentered;
    public ConstraintAnchor mTop;
    public boolean mTopHasCentered;
    public String mType;
    public float mVerticalBiasPercent;
    public boolean mVerticalChainFixedPosition;
    public int mVerticalChainStyle;
    public ConstraintWidget mVerticalNextWidget;
    public int mVerticalResolution;
    public boolean mVerticalWrapVisited;
    public int mVisibility;
    public float[] mWeight;
    public int mWidth;
    public int mWidthOverride = -1;
    public int mWrapBehaviorInParent;
    public int mX;
    public int mY;
    public boolean measured = false;
    public boolean resolvedHorizontal;
    public boolean resolvedVertical;
    public ChainRun verticalChainRun;
    public int verticalGroup;
    public VerticalWidgetRun verticalRun = null;
    public boolean verticalSolvingPass;

    public enum DimensionBehaviour {
        FIXED,
        WRAP_CONTENT,
        MATCH_CONSTRAINT,
        MATCH_PARENT
    }

    public ConstraintWidget() {
        new HashMap();
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
        this.horizontalSolvingPass = false;
        this.verticalSolvingPass = false;
        this.mHorizontalResolution = -1;
        this.mVerticalResolution = -1;
        this.mWrapBehaviorInParent = 0;
        this.mMatchConstraintDefaultWidth = 0;
        this.mMatchConstraintDefaultHeight = 0;
        this.mResolvedMatchConstraintDefault = new int[2];
        this.mMatchConstraintMinWidth = 0;
        this.mMatchConstraintMaxWidth = 0;
        this.mMatchConstraintPercentWidth = 1.0f;
        this.mMatchConstraintMinHeight = 0;
        this.mMatchConstraintMaxHeight = 0;
        this.mMatchConstraintPercentHeight = 1.0f;
        this.mResolvedDimensionRatioSide = -1;
        this.mResolvedDimensionRatio = 1.0f;
        this.mMaxDimension = new int[]{Integer.MAX_VALUE, Integer.MAX_VALUE};
        this.mCircleConstraintAngle = 0.0f;
        this.hasBaseline = false;
        this.mInVirtualLayout = false;
        this.mLastHorizontalMeasureSpec = 0;
        this.mLastVerticalMeasureSpec = 0;
        ConstraintAnchor constraintAnchor = new ConstraintAnchor(this, ConstraintAnchor.Type.LEFT);
        this.mLeft = constraintAnchor;
        ConstraintAnchor constraintAnchor2 = new ConstraintAnchor(this, ConstraintAnchor.Type.TOP);
        this.mTop = constraintAnchor2;
        ConstraintAnchor constraintAnchor3 = new ConstraintAnchor(this, ConstraintAnchor.Type.RIGHT);
        this.mRight = constraintAnchor3;
        ConstraintAnchor constraintAnchor4 = new ConstraintAnchor(this, ConstraintAnchor.Type.BOTTOM);
        this.mBottom = constraintAnchor4;
        ConstraintAnchor constraintAnchor5 = new ConstraintAnchor(this, ConstraintAnchor.Type.BASELINE);
        this.mBaseline = constraintAnchor5;
        this.mCenterX = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_X);
        this.mCenterY = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER_Y);
        ConstraintAnchor constraintAnchor6 = new ConstraintAnchor(this, ConstraintAnchor.Type.CENTER);
        this.mCenter = constraintAnchor6;
        this.mListAnchors = new ConstraintAnchor[]{constraintAnchor, constraintAnchor3, constraintAnchor2, constraintAnchor4, constraintAnchor5, constraintAnchor6};
        this.mAnchors = new ArrayList<>();
        this.mIsInBarrier = new boolean[2];
        DimensionBehaviour dimensionBehaviour = DimensionBehaviour.FIXED;
        this.mListDimensionBehaviors = new DimensionBehaviour[]{dimensionBehaviour, dimensionBehaviour};
        this.mParent = null;
        this.mWidth = 0;
        this.mHeight = 0;
        this.mDimensionRatio = 0.0f;
        this.mDimensionRatioSide = -1;
        this.mX = 0;
        this.mY = 0;
        this.mRelX = 0;
        this.mRelY = 0;
        this.mOffsetX = 0;
        this.mOffsetY = 0;
        this.mBaselineDistance = 0;
        this.mHorizontalBiasPercent = 0.5f;
        this.mVerticalBiasPercent = 0.5f;
        this.mContainerItemSkip = 0;
        this.mVisibility = 0;
        this.mDebugName = null;
        this.mType = null;
        this.mHorizontalChainStyle = 0;
        this.mVerticalChainStyle = 0;
        this.mWeight = new float[]{-1.0f, -1.0f};
        this.mListNextMatchConstraintsWidget = new ConstraintWidget[]{null, null};
        this.mNextChainWidget = new ConstraintWidget[]{null, null};
        this.mHorizontalNextWidget = null;
        this.mVerticalNextWidget = null;
        this.horizontalGroup = -1;
        this.verticalGroup = -1;
        this.mAnchors.add(this.mLeft);
        this.mAnchors.add(this.mTop);
        this.mAnchors.add(this.mRight);
        this.mAnchors.add(this.mBottom);
        this.mAnchors.add(this.mCenterX);
        this.mAnchors.add(this.mCenterY);
        this.mAnchors.add(this.mCenter);
        this.mAnchors.add(this.mBaseline);
    }

    public void addChildrenToSolverByDependency(ConstraintWidgetContainer constraintWidgetContainer, LinearSystem linearSystem, HashSet<ConstraintWidget> hashSet, int i, boolean z) {
        if (z) {
            if (hashSet.contains(this)) {
                Optimizer.checkMatchParent(constraintWidgetContainer, linearSystem, this);
                hashSet.remove(this);
                addToSolver(linearSystem, constraintWidgetContainer.optimizeFor(64));
            } else {
                return;
            }
        }
        if (i == 0) {
            HashSet<ConstraintAnchor> hashSet2 = this.mLeft.mDependents;
            if (hashSet2 != null) {
                Iterator<ConstraintAnchor> it = hashSet2.iterator();
                while (it.hasNext()) {
                    it.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i, true);
                }
            }
            HashSet<ConstraintAnchor> hashSet3 = this.mRight.mDependents;
            if (hashSet3 != null) {
                Iterator<ConstraintAnchor> it2 = hashSet3.iterator();
                while (it2.hasNext()) {
                    it2.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i, true);
                }
                return;
            }
            return;
        }
        HashSet<ConstraintAnchor> hashSet4 = this.mTop.mDependents;
        if (hashSet4 != null) {
            Iterator<ConstraintAnchor> it3 = hashSet4.iterator();
            while (it3.hasNext()) {
                it3.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i, true);
            }
        }
        HashSet<ConstraintAnchor> hashSet5 = this.mBottom.mDependents;
        if (hashSet5 != null) {
            Iterator<ConstraintAnchor> it4 = hashSet5.iterator();
            while (it4.hasNext()) {
                it4.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i, true);
            }
        }
        HashSet<ConstraintAnchor> hashSet6 = this.mBaseline.mDependents;
        if (hashSet6 != null) {
            Iterator<ConstraintAnchor> it5 = hashSet6.iterator();
            while (it5.hasNext()) {
                it5.next().mOwner.addChildrenToSolverByDependency(constraintWidgetContainer, linearSystem, hashSet, i, true);
            }
        }
    }

    public boolean addFirst() {
        return (this instanceof VirtualLayout) || (this instanceof Guideline);
    }

    /* JADX WARNING: Removed duplicated region for block: B:235:0x0386  */
    /* JADX WARNING: Removed duplicated region for block: B:239:0x0390  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0063  */
    /* JADX WARNING: Removed duplicated region for block: B:242:0x0395  */
    /* JADX WARNING: Removed duplicated region for block: B:249:0x03aa  */
    /* JADX WARNING: Removed duplicated region for block: B:254:0x03b3  */
    /* JADX WARNING: Removed duplicated region for block: B:267:0x03e5  */
    /* JADX WARNING: Removed duplicated region for block: B:290:0x04b2  */
    /* JADX WARNING: Removed duplicated region for block: B:307:0x0516  */
    /* JADX WARNING: Removed duplicated region for block: B:311:0x052a  */
    /* JADX WARNING: Removed duplicated region for block: B:312:0x052c  */
    /* JADX WARNING: Removed duplicated region for block: B:314:0x052f  */
    /* JADX WARNING: Removed duplicated region for block: B:349:0x05c2  */
    /* JADX WARNING: Removed duplicated region for block: B:350:0x05c5  */
    /* JADX WARNING: Removed duplicated region for block: B:354:0x060b  */
    /* JADX WARNING: Removed duplicated region for block: B:358:0x0636  */
    /* JADX WARNING: Removed duplicated region for block: B:361:0x0640  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x0097  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00ba  */
    public void addToSolver(LinearSystem linearSystem, boolean z) {
        boolean z2;
        boolean z3;
        boolean z4;
        boolean z5;
        boolean z6;
        int i;
        int i2;
        boolean z7;
        int i3;
        SolverVariable solverVariable;
        char c;
        boolean z8;
        int i4;
        boolean z9;
        DimensionBehaviour dimensionBehaviour;
        SolverVariable solverVariable2;
        SolverVariable solverVariable3;
        SolverVariable solverVariable4;
        DimensionBehaviour dimensionBehaviour2;
        SolverVariable solverVariable5;
        SolverVariable solverVariable6;
        ConstraintWidget constraintWidget;
        LinearSystem linearSystem2;
        SolverVariable solverVariable7;
        SolverVariable solverVariable8;
        char c2;
        int i5;
        boolean z10;
        int i6;
        SolverVariable solverVariable9;
        SolverVariable solverVariable10;
        SolverVariable solverVariable11;
        ConstraintWidget constraintWidget2;
        boolean z11;
        HorizontalWidgetRun horizontalWidgetRun;
        int i7;
        boolean z12;
        boolean z13;
        HorizontalWidgetRun horizontalWidgetRun2;
        VerticalWidgetRun verticalWidgetRun;
        ConstraintWidget constraintWidget3;
        ConstraintWidget constraintWidget4;
        boolean z14;
        SolverVariable createObjectVariable = linearSystem.createObjectVariable(this.mLeft);
        SolverVariable createObjectVariable2 = linearSystem.createObjectVariable(this.mRight);
        SolverVariable createObjectVariable3 = linearSystem.createObjectVariable(this.mTop);
        SolverVariable createObjectVariable4 = linearSystem.createObjectVariable(this.mBottom);
        SolverVariable createObjectVariable5 = linearSystem.createObjectVariable(this.mBaseline);
        ConstraintWidget constraintWidget5 = this.mParent;
        if (constraintWidget5 != null) {
            boolean z15 = constraintWidget5 != null && constraintWidget5.mListDimensionBehaviors[0] == DimensionBehaviour.WRAP_CONTENT;
            boolean z16 = constraintWidget5 != null && constraintWidget5.mListDimensionBehaviors[1] == DimensionBehaviour.WRAP_CONTENT;
            int i8 = this.mWrapBehaviorInParent;
            if (i8 == 1) {
                z2 = z15;
                z3 = false;
            } else if (i8 == 2) {
                z3 = z16;
                z2 = false;
            } else if (i8 != 3) {
                z3 = z16;
                z2 = z15;
            }
            if (this.mVisibility == 8) {
                int size = this.mAnchors.size();
                int i9 = 0;
                while (true) {
                    if (i9 >= size) {
                        z14 = false;
                        break;
                    } else if (this.mAnchors.get(i9).hasDependents()) {
                        z14 = true;
                        break;
                    } else {
                        i9++;
                    }
                }
                if (!z14) {
                    boolean[] zArr = this.mIsInBarrier;
                    if (!zArr[0] && !zArr[1]) {
                        return;
                    }
                }
            }
            z4 = this.resolvedHorizontal;
            if (z4 || this.resolvedVertical) {
                if (z4) {
                    linearSystem.addEquality(createObjectVariable, this.mX);
                    linearSystem.addEquality(createObjectVariable2, this.mX + this.mWidth);
                    if (z2 && (constraintWidget4 = this.mParent) != null) {
                        ConstraintWidgetContainer constraintWidgetContainer = (ConstraintWidgetContainer) constraintWidget4;
                        constraintWidgetContainer.addHorizontalWrapMinVariable(this.mLeft);
                        constraintWidgetContainer.addHorizontalWrapMaxVariable(this.mRight);
                    }
                }
                if (this.resolvedVertical) {
                    linearSystem.addEquality(createObjectVariable3, this.mY);
                    linearSystem.addEquality(createObjectVariable4, this.mY + this.mHeight);
                    if (this.mBaseline.hasDependents()) {
                        linearSystem.addEquality(createObjectVariable5, this.mY + this.mBaselineDistance);
                    }
                    if (z3 && (constraintWidget3 = this.mParent) != null) {
                        ConstraintWidgetContainer constraintWidgetContainer2 = (ConstraintWidgetContainer) constraintWidget3;
                        constraintWidgetContainer2.addVerticalWrapMinVariable(this.mTop);
                        constraintWidgetContainer2.addVerticalWrapMaxVariable(this.mBottom);
                    }
                }
                if (this.resolvedHorizontal && this.resolvedVertical) {
                    this.resolvedHorizontal = false;
                    this.resolvedVertical = false;
                }
            }
            if (!(!z || (horizontalWidgetRun2 = this.horizontalRun) == null || (verticalWidgetRun = this.verticalRun) == null)) {
                DependencyNode dependencyNode = horizontalWidgetRun2.start;
                if (dependencyNode.resolved && horizontalWidgetRun2.end.resolved && verticalWidgetRun.start.resolved && verticalWidgetRun.end.resolved) {
                    linearSystem.addEquality(createObjectVariable, dependencyNode.value);
                    linearSystem.addEquality(createObjectVariable2, this.horizontalRun.end.value);
                    linearSystem.addEquality(createObjectVariable3, this.verticalRun.start.value);
                    linearSystem.addEquality(createObjectVariable4, this.verticalRun.end.value);
                    linearSystem.addEquality(createObjectVariable5, this.verticalRun.baseline.value);
                    if (this.mParent != null) {
                        if (z2 && this.isTerminalWidget[0] && !isInHorizontalChain()) {
                            linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mRight), createObjectVariable2, 0, 8);
                        }
                        if (z3 && this.isTerminalWidget[1] && !isInVerticalChain()) {
                            linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mBottom), createObjectVariable4, 0, 8);
                        }
                    }
                    this.resolvedHorizontal = false;
                    this.resolvedVertical = false;
                    return;
                }
            }
            if (this.mParent != null) {
                if (isChainHead(0)) {
                    ((ConstraintWidgetContainer) this.mParent).addChain(this, 0);
                    z12 = true;
                } else {
                    z12 = isInHorizontalChain();
                }
                if (isChainHead(1)) {
                    ((ConstraintWidgetContainer) this.mParent).addChain(this, 1);
                    z13 = true;
                } else {
                    z13 = isInVerticalChain();
                }
                if (!z12 && z2 && this.mVisibility != 8 && this.mLeft.mTarget == null && this.mRight.mTarget == null) {
                    linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mRight), createObjectVariable2, 0, 1);
                }
                if (!z13 && z3 && this.mVisibility != 8 && this.mTop.mTarget == null && this.mBottom.mTarget == null && this.mBaseline == null) {
                    linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mBottom), createObjectVariable4, 0, 1);
                }
                z5 = z12;
                z6 = z13;
            } else {
                z6 = false;
                z5 = false;
            }
            int i10 = this.mWidth;
            int i11 = this.mMinWidth;
            if (i10 >= i11) {
                i11 = i10;
            }
            int i12 = this.mHeight;
            int i13 = this.mMinHeight;
            if (i12 >= i13) {
                i13 = i12;
            }
            DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
            DimensionBehaviour dimensionBehaviour3 = dimensionBehaviourArr[0];
            int i14 = i11;
            DimensionBehaviour dimensionBehaviour4 = DimensionBehaviour.MATCH_CONSTRAINT;
            boolean z17 = dimensionBehaviour3 != dimensionBehaviour4;
            boolean z18 = dimensionBehaviourArr[1] != dimensionBehaviour4;
            int i15 = this.mDimensionRatioSide;
            this.mResolvedDimensionRatioSide = i15;
            float f = this.mDimensionRatio;
            this.mResolvedDimensionRatio = f;
            int i16 = this.mMatchConstraintDefaultWidth;
            int i17 = this.mMatchConstraintDefaultHeight;
            if (f > 0.0f) {
                solverVariable = createObjectVariable3;
                if (this.mVisibility != 8) {
                    if (dimensionBehaviourArr[0] == dimensionBehaviour4 && i16 == 0) {
                        i16 = 3;
                    }
                    if (dimensionBehaviourArr[1] == dimensionBehaviour4 && i17 == 0) {
                        i17 = 3;
                    }
                    if (dimensionBehaviourArr[0] == dimensionBehaviour4 && dimensionBehaviourArr[1] == dimensionBehaviour4 && i16 == 3 && i17 == 3) {
                        if (i15 == -1) {
                            if (z17 && !z18) {
                                this.mResolvedDimensionRatioSide = 0;
                            } else if (!z17 && z18) {
                                this.mResolvedDimensionRatioSide = 1;
                                if (i15 == -1) {
                                    this.mResolvedDimensionRatio = 1.0f / f;
                                }
                            }
                        }
                        if (this.mResolvedDimensionRatioSide == 0 && (!this.mTop.isConnected() || !this.mBottom.isConnected())) {
                            this.mResolvedDimensionRatioSide = 1;
                        } else if (this.mResolvedDimensionRatioSide == 1 && (!this.mLeft.isConnected() || !this.mRight.isConnected())) {
                            this.mResolvedDimensionRatioSide = 0;
                        }
                        if (this.mResolvedDimensionRatioSide == -1 && (!this.mTop.isConnected() || !this.mBottom.isConnected() || !this.mLeft.isConnected() || !this.mRight.isConnected())) {
                            if (this.mTop.isConnected() && this.mBottom.isConnected()) {
                                this.mResolvedDimensionRatioSide = 0;
                            } else if (this.mLeft.isConnected() && this.mRight.isConnected()) {
                                this.mResolvedDimensionRatio = 1.0f / this.mResolvedDimensionRatio;
                                this.mResolvedDimensionRatioSide = 1;
                            }
                        }
                        if (this.mResolvedDimensionRatioSide == -1) {
                            int i18 = this.mMatchConstraintMinWidth;
                            if (i18 > 0 && this.mMatchConstraintMinHeight == 0) {
                                this.mResolvedDimensionRatioSide = 0;
                            } else if (i18 == 0 && this.mMatchConstraintMinHeight > 0) {
                                this.mResolvedDimensionRatio = 1.0f / this.mResolvedDimensionRatio;
                                this.mResolvedDimensionRatioSide = 1;
                            }
                        }
                    } else if (dimensionBehaviourArr[0] == dimensionBehaviour4 && i16 == 3) {
                        this.mResolvedDimensionRatioSide = 0;
                        i14 = (int) (f * ((float) i12));
                        if (dimensionBehaviourArr[1] != dimensionBehaviour4) {
                            i2 = i17;
                            i3 = i13;
                            c = 0;
                            z7 = false;
                            i = 4;
                            int[] iArr = this.mResolvedMatchConstraintDefault;
                            iArr[c] = i;
                            iArr[1] = i2;
                            if (!z7) {
                            }
                            z8 = false;
                            if (!z7) {
                            }
                            DimensionBehaviour dimensionBehaviour5 = this.mListDimensionBehaviors[0];
                            DimensionBehaviour dimensionBehaviour6 = DimensionBehaviour.WRAP_CONTENT;
                            if (dimensionBehaviour5 != dimensionBehaviour6) {
                            }
                            if (z9) {
                            }
                            boolean z19 = !this.mCenter.isConnected();
                            boolean[] zArr2 = this.mIsInBarrier;
                            boolean z20 = zArr2[0];
                            boolean z21 = zArr2[1];
                            DependencyNode dependencyNode2 = horizontalWidgetRun.start;
                            if (z) {
                            }
                            dimensionBehaviour2 = dimensionBehaviour4;
                            dimensionBehaviour = dimensionBehaviour6;
                            solverVariable5 = createObjectVariable;
                            solverVariable4 = createObjectVariable5;
                            solverVariable3 = createObjectVariable4;
                            solverVariable2 = solverVariable;
                            solverVariable6 = createObjectVariable2;
                            if (!z) {
                            }
                            z10 = true;
                            if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                            }
                            solverVariable11 = solverVariable8;
                            solverVariable10 = solverVariable7;
                            if (z7) {
                            }
                            if (constraintWidget2.mCenter.isConnected()) {
                            }
                            this.resolvedHorizontal = false;
                            this.resolvedVertical = false;
                            return;
                        }
                        i = i16;
                        i2 = i17;
                        i3 = i13;
                        c = 0;
                        z7 = true;
                        int[] iArr2 = this.mResolvedMatchConstraintDefault;
                        iArr2[c] = i;
                        iArr2[1] = i2;
                        if (!z7) {
                        }
                        z8 = false;
                        if (!z7) {
                        }
                        DimensionBehaviour dimensionBehaviour52 = this.mListDimensionBehaviors[0];
                        DimensionBehaviour dimensionBehaviour62 = DimensionBehaviour.WRAP_CONTENT;
                        if (dimensionBehaviour52 != dimensionBehaviour62) {
                        }
                        if (z9) {
                        }
                        boolean z192 = !this.mCenter.isConnected();
                        boolean[] zArr22 = this.mIsInBarrier;
                        boolean z202 = zArr22[0];
                        boolean z212 = zArr22[1];
                        DependencyNode dependencyNode22 = horizontalWidgetRun.start;
                        if (z) {
                        }
                        dimensionBehaviour2 = dimensionBehaviour4;
                        dimensionBehaviour = dimensionBehaviour62;
                        solverVariable5 = createObjectVariable;
                        solverVariable4 = createObjectVariable5;
                        solverVariable3 = createObjectVariable4;
                        solverVariable2 = solverVariable;
                        solverVariable6 = createObjectVariable2;
                        if (!z) {
                        }
                        z10 = true;
                        if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                        }
                        solverVariable11 = solverVariable8;
                        solverVariable10 = solverVariable7;
                        if (z7) {
                        }
                        if (constraintWidget2.mCenter.isConnected()) {
                        }
                        this.resolvedHorizontal = false;
                        this.resolvedVertical = false;
                        return;
                    } else if (dimensionBehaviourArr[1] == dimensionBehaviour4 && i17 == 3) {
                        this.mResolvedDimensionRatioSide = 1;
                        if (i15 == -1) {
                            this.mResolvedDimensionRatio = 1.0f / f;
                        }
                        c = 0;
                        i3 = (int) (this.mResolvedDimensionRatio * ((float) i10));
                        i = i16;
                        if (dimensionBehaviourArr[0] != dimensionBehaviour4) {
                            z7 = false;
                            i2 = 4;
                            int[] iArr22 = this.mResolvedMatchConstraintDefault;
                            iArr22[c] = i;
                            iArr22[1] = i2;
                            if (!z7) {
                                int i19 = this.mResolvedDimensionRatioSide;
                                i4 = -1;
                                if (i19 == 0 || i19 == -1) {
                                    z8 = true;
                                    boolean z22 = !z7 && ((i7 = this.mResolvedDimensionRatioSide) == 1 || i7 == i4);
                                    DimensionBehaviour dimensionBehaviour522 = this.mListDimensionBehaviors[0];
                                    DimensionBehaviour dimensionBehaviour622 = DimensionBehaviour.WRAP_CONTENT;
                                    z9 = dimensionBehaviour522 != dimensionBehaviour622 && (this instanceof ConstraintWidgetContainer);
                                    if (z9) {
                                        i14 = 0;
                                    }
                                    boolean z1922 = !this.mCenter.isConnected();
                                    boolean[] zArr222 = this.mIsInBarrier;
                                    boolean z2022 = zArr222[0];
                                    boolean z2122 = zArr222[1];
                                    if (this.mHorizontalResolution != 2 && !this.resolvedHorizontal) {
                                        if (z && (horizontalWidgetRun = this.horizontalRun) != null) {
                                            DependencyNode dependencyNode222 = horizontalWidgetRun.start;
                                            if (dependencyNode222.resolved && horizontalWidgetRun.end.resolved) {
                                                if (z) {
                                                    linearSystem.addEquality(createObjectVariable, dependencyNode222.value);
                                                    linearSystem.addEquality(createObjectVariable2, this.horizontalRun.end.value);
                                                    if (this.mParent != null && z2 && this.isTerminalWidget[0] && !isInHorizontalChain()) {
                                                        linearSystem.addGreaterThan(linearSystem.createObjectVariable(this.mParent.mRight), createObjectVariable2, 0, 8);
                                                    }
                                                }
                                            }
                                        }
                                        ConstraintWidget constraintWidget6 = this.mParent;
                                        SolverVariable createObjectVariable6 = constraintWidget6 != null ? linearSystem.createObjectVariable(constraintWidget6.mRight) : null;
                                        ConstraintWidget constraintWidget7 = this.mParent;
                                        SolverVariable createObjectVariable7 = constraintWidget7 != null ? linearSystem.createObjectVariable(constraintWidget7.mLeft) : null;
                                        boolean z23 = this.isTerminalWidget[0];
                                        DimensionBehaviour[] dimensionBehaviourArr2 = this.mListDimensionBehaviors;
                                        dimensionBehaviour2 = dimensionBehaviour4;
                                        solverVariable4 = createObjectVariable5;
                                        solverVariable3 = createObjectVariable4;
                                        dimensionBehaviour = dimensionBehaviour622;
                                        solverVariable2 = solverVariable;
                                        solverVariable6 = createObjectVariable2;
                                        solverVariable5 = createObjectVariable;
                                        applyConstraints(linearSystem, true, z2, z3, z23, createObjectVariable7, createObjectVariable6, dimensionBehaviourArr2[0], z9, this.mLeft, this.mRight, this.mX, i14, this.mMinWidth, this.mMaxDimension[0], this.mHorizontalBiasPercent, z8, dimensionBehaviourArr2[1] == dimensionBehaviour4, z5, z6, z2022, i, i2, this.mMatchConstraintMinWidth, this.mMatchConstraintMaxWidth, this.mMatchConstraintPercentWidth, z1922);
                                        if (!z) {
                                            constraintWidget = this;
                                            VerticalWidgetRun verticalWidgetRun2 = constraintWidget.verticalRun;
                                            if (verticalWidgetRun2 != null) {
                                                DependencyNode dependencyNode3 = verticalWidgetRun2.start;
                                                if (dependencyNode3.resolved && verticalWidgetRun2.end.resolved) {
                                                    linearSystem2 = linearSystem;
                                                    solverVariable7 = solverVariable2;
                                                    linearSystem2.addEquality(solverVariable7, dependencyNode3.value);
                                                    solverVariable8 = solverVariable3;
                                                    linearSystem2.addEquality(solverVariable8, constraintWidget.verticalRun.end.value);
                                                    solverVariable9 = solverVariable4;
                                                    linearSystem2.addEquality(solverVariable9, constraintWidget.verticalRun.baseline.value);
                                                    ConstraintWidget constraintWidget8 = constraintWidget.mParent;
                                                    if (constraintWidget8 == null || z6 || !z3) {
                                                        i6 = 8;
                                                        i5 = 0;
                                                        c2 = 1;
                                                    } else {
                                                        c2 = 1;
                                                        if (constraintWidget.isTerminalWidget[1]) {
                                                            i6 = 8;
                                                            i5 = 0;
                                                            linearSystem2.addGreaterThan(linearSystem2.createObjectVariable(constraintWidget8.mBottom), solverVariable8, 0, 8);
                                                        } else {
                                                            i6 = 8;
                                                            i5 = 0;
                                                        }
                                                    }
                                                    z10 = false;
                                                    if ((constraintWidget.mVerticalResolution == 2 ? false : z10) || constraintWidget.resolvedVertical) {
                                                        solverVariable11 = solverVariable8;
                                                        solverVariable10 = solverVariable7;
                                                    } else {
                                                        boolean z24 = constraintWidget.mListDimensionBehaviors[c2] == dimensionBehaviour && (constraintWidget instanceof ConstraintWidgetContainer);
                                                        if (z24) {
                                                            i3 = 0;
                                                        }
                                                        ConstraintWidget constraintWidget9 = constraintWidget.mParent;
                                                        SolverVariable createObjectVariable8 = constraintWidget9 != null ? linearSystem2.createObjectVariable(constraintWidget9.mBottom) : null;
                                                        ConstraintWidget constraintWidget10 = constraintWidget.mParent;
                                                        SolverVariable createObjectVariable9 = constraintWidget10 != null ? linearSystem2.createObjectVariable(constraintWidget10.mTop) : null;
                                                        int i20 = constraintWidget.mBaselineDistance;
                                                        if (i20 > 0 || constraintWidget.mVisibility == i6) {
                                                            ConstraintAnchor constraintAnchor = constraintWidget.mBaseline;
                                                            if (constraintAnchor.mTarget != null) {
                                                                linearSystem2.addEquality(solverVariable9, solverVariable7, i20, i6);
                                                                linearSystem2.addEquality(solverVariable9, linearSystem2.createObjectVariable(constraintWidget.mBaseline.mTarget), constraintWidget.mBaseline.getMargin(), i6);
                                                                if (z3) {
                                                                    linearSystem2.addGreaterThan(createObjectVariable8, linearSystem2.createObjectVariable(constraintWidget.mBottom), i5, 5);
                                                                }
                                                                z11 = false;
                                                                boolean z25 = constraintWidget.isTerminalWidget[c2];
                                                                DimensionBehaviour[] dimensionBehaviourArr3 = constraintWidget.mListDimensionBehaviors;
                                                                solverVariable11 = solverVariable8;
                                                                solverVariable10 = solverVariable7;
                                                                applyConstraints(linearSystem, false, z3, z2, z25, createObjectVariable9, createObjectVariable8, dimensionBehaviourArr3[c2], z24, constraintWidget.mTop, constraintWidget.mBottom, constraintWidget.mY, i3, constraintWidget.mMinHeight, constraintWidget.mMaxDimension[c2], constraintWidget.mVerticalBiasPercent, z22, dimensionBehaviourArr3[0] != dimensionBehaviour2, z6, z5, z2122, i2, i, constraintWidget.mMatchConstraintMinHeight, constraintWidget.mMatchConstraintMaxHeight, constraintWidget.mMatchConstraintPercentHeight, z11);
                                                            } else if (constraintWidget.mVisibility == i6) {
                                                                linearSystem2.addEquality(solverVariable9, solverVariable7, constraintAnchor.getMargin(), i6);
                                                            } else {
                                                                linearSystem2.addEquality(solverVariable9, solverVariable7, i20, i6);
                                                            }
                                                        }
                                                        z11 = z1922;
                                                        boolean z252 = constraintWidget.isTerminalWidget[c2];
                                                        DimensionBehaviour[] dimensionBehaviourArr32 = constraintWidget.mListDimensionBehaviors;
                                                        solverVariable11 = solverVariable8;
                                                        solverVariable10 = solverVariable7;
                                                        applyConstraints(linearSystem, false, z3, z2, z252, createObjectVariable9, createObjectVariable8, dimensionBehaviourArr32[c2], z24, constraintWidget.mTop, constraintWidget.mBottom, constraintWidget.mY, i3, constraintWidget.mMinHeight, constraintWidget.mMaxDimension[c2], constraintWidget.mVerticalBiasPercent, z22, dimensionBehaviourArr32[0] != dimensionBehaviour2, z6, z5, z2122, i2, i, constraintWidget.mMatchConstraintMinHeight, constraintWidget.mMatchConstraintMaxHeight, constraintWidget.mMatchConstraintPercentHeight, z11);
                                                    }
                                                    if (z7) {
                                                        constraintWidget2 = this;
                                                        if (constraintWidget2.mResolvedDimensionRatioSide == 1) {
                                                            linearSystem.addRatio(solverVariable11, solverVariable10, solverVariable6, solverVariable5, constraintWidget2.mResolvedDimensionRatio, 8);
                                                        } else {
                                                            linearSystem.addRatio(solverVariable6, solverVariable5, solverVariable11, solverVariable10, constraintWidget2.mResolvedDimensionRatio, 8);
                                                        }
                                                    } else {
                                                        constraintWidget2 = this;
                                                    }
                                                    if (constraintWidget2.mCenter.isConnected()) {
                                                        ConstraintWidget constraintWidget11 = constraintWidget2.mCenter.mTarget.mOwner;
                                                        int margin = constraintWidget2.mCenter.getMargin();
                                                        ConstraintAnchor.Type type = ConstraintAnchor.Type.LEFT;
                                                        SolverVariable createObjectVariable10 = linearSystem.createObjectVariable(constraintWidget2.getAnchor(type));
                                                        ConstraintAnchor.Type type2 = ConstraintAnchor.Type.TOP;
                                                        SolverVariable createObjectVariable11 = linearSystem.createObjectVariable(constraintWidget2.getAnchor(type2));
                                                        ConstraintAnchor.Type type3 = ConstraintAnchor.Type.RIGHT;
                                                        SolverVariable createObjectVariable12 = linearSystem.createObjectVariable(constraintWidget2.getAnchor(type3));
                                                        ConstraintAnchor.Type type4 = ConstraintAnchor.Type.BOTTOM;
                                                        SolverVariable createObjectVariable13 = linearSystem.createObjectVariable(constraintWidget2.getAnchor(type4));
                                                        SolverVariable createObjectVariable14 = linearSystem.createObjectVariable(constraintWidget11.getAnchor(type));
                                                        SolverVariable createObjectVariable15 = linearSystem.createObjectVariable(constraintWidget11.getAnchor(type2));
                                                        SolverVariable createObjectVariable16 = linearSystem.createObjectVariable(constraintWidget11.getAnchor(type3));
                                                        SolverVariable createObjectVariable17 = linearSystem.createObjectVariable(constraintWidget11.getAnchor(type4));
                                                        ArrayRow createRow = linearSystem.createRow();
                                                        double radians = (double) ((float) Math.toRadians((double) (constraintWidget2.mCircleConstraintAngle + 90.0f)));
                                                        double d = (double) margin;
                                                        createRow.createRowWithAngle(createObjectVariable11, createObjectVariable13, createObjectVariable15, createObjectVariable17, (float) (Math.sin(radians) * d));
                                                        linearSystem.addConstraint(createRow);
                                                        ArrayRow createRow2 = linearSystem.createRow();
                                                        createRow2.createRowWithAngle(createObjectVariable10, createObjectVariable12, createObjectVariable14, createObjectVariable16, (float) (Math.cos(radians) * d));
                                                        linearSystem.addConstraint(createRow2);
                                                    }
                                                    this.resolvedHorizontal = false;
                                                    this.resolvedVertical = false;
                                                    return;
                                                }
                                            }
                                            linearSystem2 = linearSystem;
                                            solverVariable9 = solverVariable4;
                                            solverVariable8 = solverVariable3;
                                            solverVariable7 = solverVariable2;
                                            i6 = 8;
                                            i5 = 0;
                                            c2 = 1;
                                        } else {
                                            i6 = 8;
                                            i5 = 0;
                                            c2 = 1;
                                            constraintWidget = this;
                                            linearSystem2 = linearSystem;
                                            solverVariable9 = solverVariable4;
                                            solverVariable8 = solverVariable3;
                                            solverVariable7 = solverVariable2;
                                        }
                                        z10 = true;
                                        if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                                        }
                                        solverVariable11 = solverVariable8;
                                        solverVariable10 = solverVariable7;
                                        if (z7) {
                                        }
                                        if (constraintWidget2.mCenter.isConnected()) {
                                        }
                                        this.resolvedHorizontal = false;
                                        this.resolvedVertical = false;
                                        return;
                                    }
                                    dimensionBehaviour2 = dimensionBehaviour4;
                                    dimensionBehaviour = dimensionBehaviour622;
                                    solverVariable5 = createObjectVariable;
                                    solverVariable4 = createObjectVariable5;
                                    solverVariable3 = createObjectVariable4;
                                    solverVariable2 = solverVariable;
                                    solverVariable6 = createObjectVariable2;
                                    if (!z) {
                                    }
                                    z10 = true;
                                    if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                                    }
                                    solverVariable11 = solverVariable8;
                                    solverVariable10 = solverVariable7;
                                    if (z7) {
                                    }
                                    if (constraintWidget2.mCenter.isConnected()) {
                                    }
                                    this.resolvedHorizontal = false;
                                    this.resolvedVertical = false;
                                    return;
                                }
                            } else {
                                i4 = -1;
                            }
                            z8 = false;
                            if (!z7) {
                            }
                            DimensionBehaviour dimensionBehaviour5222 = this.mListDimensionBehaviors[0];
                            DimensionBehaviour dimensionBehaviour6222 = DimensionBehaviour.WRAP_CONTENT;
                            if (dimensionBehaviour5222 != dimensionBehaviour6222) {
                            }
                            if (z9) {
                            }
                            boolean z19222 = !this.mCenter.isConnected();
                            boolean[] zArr2222 = this.mIsInBarrier;
                            boolean z20222 = zArr2222[0];
                            boolean z21222 = zArr2222[1];
                            DependencyNode dependencyNode2222 = horizontalWidgetRun.start;
                            if (z) {
                            }
                            dimensionBehaviour2 = dimensionBehaviour4;
                            dimensionBehaviour = dimensionBehaviour6222;
                            solverVariable5 = createObjectVariable;
                            solverVariable4 = createObjectVariable5;
                            solverVariable3 = createObjectVariable4;
                            solverVariable2 = solverVariable;
                            solverVariable6 = createObjectVariable2;
                            if (!z) {
                            }
                            z10 = true;
                            if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                            }
                            solverVariable11 = solverVariable8;
                            solverVariable10 = solverVariable7;
                            if (z7) {
                            }
                            if (constraintWidget2.mCenter.isConnected()) {
                            }
                            this.resolvedHorizontal = false;
                            this.resolvedVertical = false;
                            return;
                        }
                        i2 = i17;
                        z7 = true;
                        int[] iArr222 = this.mResolvedMatchConstraintDefault;
                        iArr222[c] = i;
                        iArr222[1] = i2;
                        if (!z7) {
                        }
                        z8 = false;
                        if (!z7) {
                        }
                        DimensionBehaviour dimensionBehaviour52222 = this.mListDimensionBehaviors[0];
                        DimensionBehaviour dimensionBehaviour62222 = DimensionBehaviour.WRAP_CONTENT;
                        if (dimensionBehaviour52222 != dimensionBehaviour62222) {
                        }
                        if (z9) {
                        }
                        boolean z192222 = !this.mCenter.isConnected();
                        boolean[] zArr22222 = this.mIsInBarrier;
                        boolean z202222 = zArr22222[0];
                        boolean z212222 = zArr22222[1];
                        DependencyNode dependencyNode22222 = horizontalWidgetRun.start;
                        if (z) {
                        }
                        dimensionBehaviour2 = dimensionBehaviour4;
                        dimensionBehaviour = dimensionBehaviour62222;
                        solverVariable5 = createObjectVariable;
                        solverVariable4 = createObjectVariable5;
                        solverVariable3 = createObjectVariable4;
                        solverVariable2 = solverVariable;
                        solverVariable6 = createObjectVariable2;
                        if (!z) {
                        }
                        z10 = true;
                        if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                        }
                        solverVariable11 = solverVariable8;
                        solverVariable10 = solverVariable7;
                        if (z7) {
                        }
                        if (constraintWidget2.mCenter.isConnected()) {
                        }
                        this.resolvedHorizontal = false;
                        this.resolvedVertical = false;
                        return;
                    }
                    c = 0;
                    i = i16;
                    i2 = i17;
                    i3 = i13;
                    z7 = true;
                    int[] iArr2222 = this.mResolvedMatchConstraintDefault;
                    iArr2222[c] = i;
                    iArr2222[1] = i2;
                    if (!z7) {
                    }
                    z8 = false;
                    if (!z7) {
                    }
                    DimensionBehaviour dimensionBehaviour522222 = this.mListDimensionBehaviors[0];
                    DimensionBehaviour dimensionBehaviour622222 = DimensionBehaviour.WRAP_CONTENT;
                    if (dimensionBehaviour522222 != dimensionBehaviour622222) {
                    }
                    if (z9) {
                    }
                    boolean z1922222 = !this.mCenter.isConnected();
                    boolean[] zArr222222 = this.mIsInBarrier;
                    boolean z2022222 = zArr222222[0];
                    boolean z2122222 = zArr222222[1];
                    DependencyNode dependencyNode222222 = horizontalWidgetRun.start;
                    if (z) {
                    }
                    dimensionBehaviour2 = dimensionBehaviour4;
                    dimensionBehaviour = dimensionBehaviour622222;
                    solverVariable5 = createObjectVariable;
                    solverVariable4 = createObjectVariable5;
                    solverVariable3 = createObjectVariable4;
                    solverVariable2 = solverVariable;
                    solverVariable6 = createObjectVariable2;
                    if (!z) {
                    }
                    z10 = true;
                    if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
                    }
                    solverVariable11 = solverVariable8;
                    solverVariable10 = solverVariable7;
                    if (z7) {
                    }
                    if (constraintWidget2.mCenter.isConnected()) {
                    }
                    this.resolvedHorizontal = false;
                    this.resolvedVertical = false;
                    return;
                }
            } else {
                solverVariable = createObjectVariable3;
            }
            c = 0;
            i = i16;
            i2 = i17;
            i3 = i13;
            z7 = false;
            int[] iArr22222 = this.mResolvedMatchConstraintDefault;
            iArr22222[c] = i;
            iArr22222[1] = i2;
            if (!z7) {
            }
            z8 = false;
            if (!z7) {
            }
            DimensionBehaviour dimensionBehaviour5222222 = this.mListDimensionBehaviors[0];
            DimensionBehaviour dimensionBehaviour6222222 = DimensionBehaviour.WRAP_CONTENT;
            if (dimensionBehaviour5222222 != dimensionBehaviour6222222) {
            }
            if (z9) {
            }
            boolean z19222222 = !this.mCenter.isConnected();
            boolean[] zArr2222222 = this.mIsInBarrier;
            boolean z20222222 = zArr2222222[0];
            boolean z21222222 = zArr2222222[1];
            DependencyNode dependencyNode2222222 = horizontalWidgetRun.start;
            if (z) {
            }
            dimensionBehaviour2 = dimensionBehaviour4;
            dimensionBehaviour = dimensionBehaviour6222222;
            solverVariable5 = createObjectVariable;
            solverVariable4 = createObjectVariable5;
            solverVariable3 = createObjectVariable4;
            solverVariable2 = solverVariable;
            solverVariable6 = createObjectVariable2;
            if (!z) {
            }
            z10 = true;
            if (constraintWidget.mVerticalResolution == 2 ? false : z10) {
            }
            solverVariable11 = solverVariable8;
            solverVariable10 = solverVariable7;
            if (z7) {
            }
            if (constraintWidget2.mCenter.isConnected()) {
            }
            this.resolvedHorizontal = false;
            this.resolvedVertical = false;
            return;
        }
        z3 = false;
        z2 = false;
        if (this.mVisibility == 8) {
        }
        z4 = this.resolvedHorizontal;
        if (z4) {
        }
        if (this.resolvedVertical) {
        }
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
    }

    public boolean allowedInBarrier() {
        return this.mVisibility != 8;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:247:0x03e5, code lost:
        if ((r3 instanceof androidx.constraintlayout.core.widgets.Barrier) != false) goto L_0x03ea;
     */
    /* JADX WARNING: Removed duplicated region for block: B:109:0x01bb A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:181:0x02b7  */
    /* JADX WARNING: Removed duplicated region for block: B:182:0x02bb  */
    /* JADX WARNING: Removed duplicated region for block: B:221:0x0362 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:226:0x0371  */
    /* JADX WARNING: Removed duplicated region for block: B:234:0x03b6  */
    /* JADX WARNING: Removed duplicated region for block: B:237:0x03cc  */
    /* JADX WARNING: Removed duplicated region for block: B:241:0x03d5  */
    /* JADX WARNING: Removed duplicated region for block: B:253:0x0406  */
    /* JADX WARNING: Removed duplicated region for block: B:255:0x040e A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:266:0x0428  */
    /* JADX WARNING: Removed duplicated region for block: B:296:0x0471  */
    /* JADX WARNING: Removed duplicated region for block: B:304:0x0485 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0081  */
    /* JADX WARNING: Removed duplicated region for block: B:316:0x04a1 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0084  */
    /* JADX WARNING: Removed duplicated region for block: B:325:0x04c6 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x0089  */
    /* JADX WARNING: Removed duplicated region for block: B:351:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:355:? A[ADDED_TO_REGION, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00a7  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00c6  */
    public final void applyConstraints(LinearSystem linearSystem, boolean z, boolean z2, boolean z3, boolean z4, SolverVariable solverVariable, SolverVariable solverVariable2, DimensionBehaviour dimensionBehaviour, boolean z5, ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, int i, int i2, int i3, int i4, float f, boolean z6, boolean z7, boolean z8, boolean z9, boolean z10, int i5, int i6, int i7, int i8, float f2, boolean z11) {
        int i9;
        SolverVariable solverVariable3;
        int i10;
        boolean z12;
        int i11;
        int i12;
        boolean z13;
        int i13;
        boolean z14;
        int i14;
        boolean z15;
        SolverVariable solverVariable4;
        SolverVariable solverVariable5;
        SolverVariable solverVariable6;
        int i15;
        int i16;
        ConstraintAnchor constraintAnchor3;
        DimensionBehaviour[] dimensionBehaviourArr;
        DimensionBehaviour dimensionBehaviour2;
        boolean z16;
        int i17;
        int i18;
        SolverVariable solverVariable7;
        boolean z17;
        boolean z18;
        boolean z19;
        int i19;
        int i20;
        int i21;
        SolverVariable solverVariable8;
        boolean z20;
        boolean z21;
        SolverVariable solverVariable9;
        ConstraintWidget constraintWidget;
        ConstraintWidget constraintWidget2;
        ConstraintWidget constraintWidget3;
        int i22;
        boolean z22;
        SolverVariable solverVariable10;
        ConstraintWidget constraintWidget4;
        ConstraintWidget constraintWidget5;
        int i23;
        int i24;
        ConstraintWidget constraintWidget6;
        int i25;
        int i26;
        int i27;
        int i28;
        int i29;
        boolean z23;
        int i30;
        int i31;
        SolverVariable solverVariable11;
        int i32;
        int i33;
        int i34;
        int i35;
        int i36;
        boolean z24;
        int i37;
        int i38;
        boolean z25;
        boolean z26;
        boolean z27;
        int i39;
        int i40;
        int i41;
        int i42;
        int i43;
        SolverVariable solverVariable12;
        SolverVariable solverVariable13;
        int i44 = i8;
        SolverVariable createObjectVariable = linearSystem.createObjectVariable(constraintAnchor);
        SolverVariable createObjectVariable2 = linearSystem.createObjectVariable(constraintAnchor2);
        SolverVariable createObjectVariable3 = linearSystem.createObjectVariable(constraintAnchor.mTarget);
        SolverVariable createObjectVariable4 = linearSystem.createObjectVariable(constraintAnchor2.mTarget);
        boolean isConnected = constraintAnchor.isConnected();
        boolean isConnected2 = constraintAnchor2.isConnected();
        boolean isConnected3 = this.mCenter.isConnected();
        if (isConnected2) {
            i9 = (isConnected ? 1 : 0) + 1;
        } else {
            i9 = isConnected ? 1 : 0;
        }
        if (isConnected3) {
            i9++;
        }
        if (z6) {
            solverVariable3 = createObjectVariable4;
            i10 = 3;
        } else {
            i10 = i5;
            solverVariable3 = createObjectVariable4;
        }
        int ordinal = dimensionBehaviour.ordinal();
        if (ordinal != 0 && ordinal != 1 && ordinal == 2) {
            if (i10 != 4) {
                z12 = true;
                i11 = this.mWidthOverride;
                if (i11 != -1 && z) {
                    this.mWidthOverride = -1;
                    i2 = i11;
                    z12 = false;
                }
                i12 = this.mHeightOverride;
                if (i12 != -1 || z) {
                    i12 = i2;
                } else {
                    this.mHeightOverride = -1;
                    z12 = false;
                }
                if (this.mVisibility != 8) {
                    i13 = 0;
                    z13 = false;
                } else {
                    z13 = z12;
                    i13 = i12;
                }
                if (z11) {
                    if (!isConnected && !isConnected2 && !isConnected3) {
                        linearSystem.addEquality(createObjectVariable, i);
                    } else if (isConnected && !isConnected2) {
                        linearSystem.addEquality(createObjectVariable, createObjectVariable3, constraintAnchor.getMargin(), 8);
                        if (!z13) {
                            if (z5) {
                                linearSystem.addEquality(createObjectVariable2, createObjectVariable, 0, 3);
                                if (i3 > 0) {
                                    linearSystem.addGreaterThan(createObjectVariable2, createObjectVariable, i3, 8);
                                }
                                if (i4 < Integer.MAX_VALUE) {
                                    linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i4, 8);
                                }
                            } else {
                                linearSystem.addEquality(createObjectVariable2, createObjectVariable, i13, 8);
                            }
                            i41 = i7;
                        } else if (i9 == 2 || z6 || !(i10 == 1 || i10 == 0)) {
                            i41 = i7 == -2 ? i13 : i7;
                            i16 = i44 == -2 ? i13 : i44;
                            if (i13 > 0 && i10 != 1) {
                                i13 = 0;
                            }
                            if (i41 > 0) {
                                linearSystem.addGreaterThan(createObjectVariable2, createObjectVariable, i41, 8);
                                i13 = Math.max(i13, i41);
                            }
                            if (i16 > 0) {
                                if (!z2 || i10 != 1) {
                                    i42 = 8;
                                    linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i16, 8);
                                } else {
                                    i42 = 8;
                                }
                                i13 = Math.min(i13, i16);
                            } else {
                                i42 = 8;
                            }
                            if (i10 == 1) {
                                if (z2) {
                                    linearSystem.addEquality(createObjectVariable2, createObjectVariable, i13, i42);
                                } else if (z8) {
                                    linearSystem.addEquality(createObjectVariable2, createObjectVariable, i13, 5);
                                    linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i13, i42);
                                } else {
                                    linearSystem.addEquality(createObjectVariable2, createObjectVariable, i13, 5);
                                    linearSystem.addLowerThan(createObjectVariable2, createObjectVariable, i13, i42);
                                }
                                i44 = i16;
                            } else {
                                if (i10 == 2) {
                                    ConstraintAnchor.Type type = constraintAnchor.mType;
                                    ConstraintAnchor.Type type2 = ConstraintAnchor.Type.TOP;
                                    if (type == type2 || type == ConstraintAnchor.Type.BOTTOM) {
                                        solverVariable13 = linearSystem.createObjectVariable(this.mParent.getAnchor(type2));
                                        solverVariable12 = linearSystem.createObjectVariable(this.mParent.getAnchor(ConstraintAnchor.Type.BOTTOM));
                                    } else {
                                        solverVariable13 = linearSystem.createObjectVariable(this.mParent.getAnchor(ConstraintAnchor.Type.LEFT));
                                        solverVariable12 = linearSystem.createObjectVariable(this.mParent.getAnchor(ConstraintAnchor.Type.RIGHT));
                                    }
                                    ArrayRow createRow = linearSystem.createRow();
                                    i43 = i41;
                                    i15 = i9;
                                    boolean z28 = z13;
                                    solverVariable5 = solverVariable3;
                                    solverVariable4 = createObjectVariable3;
                                    solverVariable6 = createObjectVariable2;
                                    createRow.createRowDimensionRatio(createObjectVariable2, createObjectVariable, solverVariable12, solverVariable13, f2);
                                    linearSystem.addConstraint(createRow);
                                    if (z2) {
                                        z28 = false;
                                    }
                                    z15 = z4;
                                    i16 = i16;
                                    z14 = z28;
                                } else {
                                    i43 = i41;
                                    i15 = i9;
                                    solverVariable4 = createObjectVariable3;
                                    solverVariable6 = createObjectVariable2;
                                    solverVariable5 = solverVariable3;
                                    z14 = z13;
                                    z15 = true;
                                }
                                i14 = i43;
                                if (!z11 && !z8) {
                                    if (isConnected || isConnected2 || isConnected3) {
                                        if (isConnected && !isConnected2) {
                                            i18 = (!z2 || !(constraintAnchor.mTarget.mOwner instanceof Barrier)) ? 5 : 8;
                                            z16 = z2;
                                            i17 = 0;
                                            if (!z16) {
                                            }
                                        } else if (isConnected || !isConnected2) {
                                            if (isConnected && isConnected2) {
                                                ConstraintWidget constraintWidget7 = constraintAnchor.mTarget.mOwner;
                                                ConstraintWidget constraintWidget8 = constraintAnchor2.mTarget.mOwner;
                                                ConstraintWidget constraintWidget9 = this.mParent;
                                                if (z14) {
                                                    if (i10 == 0) {
                                                        if (i16 != 0 || i14 != 0) {
                                                            i40 = 5;
                                                            i39 = 5;
                                                            z27 = true;
                                                            z26 = false;
                                                            z25 = true;
                                                        } else if (!solverVariable4.isFinalValue || !solverVariable5.isFinalValue) {
                                                            i40 = 8;
                                                            i39 = 8;
                                                            z27 = false;
                                                            z26 = true;
                                                            z25 = false;
                                                        } else {
                                                            linearSystem.addEquality(createObjectVariable, solverVariable4, constraintAnchor.getMargin(), 8);
                                                            linearSystem.addEquality(solverVariable6, solverVariable5, -constraintAnchor2.getMargin(), 8);
                                                            return;
                                                        }
                                                        if ((constraintWidget7 instanceof Barrier) || (constraintWidget8 instanceof Barrier)) {
                                                            i40 = 4;
                                                        }
                                                        solverVariable8 = solverVariable2;
                                                        i20 = i40;
                                                        i19 = i39;
                                                        z17 = z26;
                                                        z18 = z25;
                                                        z19 = z27;
                                                        i21 = 6;
                                                        if (z18 || solverVariable4 != solverVariable5 || constraintWidget7 == constraintWidget9) {
                                                            z20 = z18;
                                                            z21 = true;
                                                        } else {
                                                            z21 = false;
                                                            z20 = false;
                                                        }
                                                        if (!z19) {
                                                            if (z14 || z7 || z9 || solverVariable4 != solverVariable || solverVariable5 != solverVariable8) {
                                                                i28 = i19;
                                                                i29 = i21;
                                                                z16 = z2;
                                                            } else {
                                                                z16 = false;
                                                                i29 = 8;
                                                                i28 = 8;
                                                                z21 = false;
                                                            }
                                                            i22 = 8;
                                                            constraintWidget3 = constraintWidget9;
                                                            constraintWidget2 = constraintWidget8;
                                                            constraintWidget = constraintWidget7;
                                                            solverVariable9 = createObjectVariable;
                                                            linearSystem.addCentering(createObjectVariable, solverVariable4, constraintAnchor.getMargin(), f, solverVariable5, solverVariable6, constraintAnchor2.getMargin(), i29);
                                                            i19 = i28;
                                                        } else {
                                                            constraintWidget3 = constraintWidget9;
                                                            constraintWidget2 = constraintWidget8;
                                                            constraintWidget = constraintWidget7;
                                                            solverVariable9 = createObjectVariable;
                                                            i22 = 8;
                                                            z16 = z2;
                                                        }
                                                        z22 = z21;
                                                        if (this.mVisibility == i22 || constraintAnchor2.hasDependents()) {
                                                            if (!z20) {
                                                                if (!z16 || solverVariable4 == solverVariable5 || z14) {
                                                                    constraintWidget4 = constraintWidget2;
                                                                    constraintWidget5 = constraintWidget;
                                                                } else {
                                                                    constraintWidget5 = constraintWidget;
                                                                    if (!(constraintWidget5 instanceof Barrier)) {
                                                                        constraintWidget4 = constraintWidget2;
                                                                    } else {
                                                                        constraintWidget4 = constraintWidget2;
                                                                    }
                                                                    i27 = 6;
                                                                    solverVariable10 = solverVariable9;
                                                                    linearSystem.addGreaterThan(solverVariable10, solverVariable4, constraintAnchor.getMargin(), i27);
                                                                    linearSystem.addLowerThan(solverVariable6, solverVariable5, -constraintAnchor2.getMargin(), i27);
                                                                    i19 = i27;
                                                                }
                                                                i27 = i19;
                                                                solverVariable10 = solverVariable9;
                                                                linearSystem.addGreaterThan(solverVariable10, solverVariable4, constraintAnchor.getMargin(), i27);
                                                                linearSystem.addLowerThan(solverVariable6, solverVariable5, -constraintAnchor2.getMargin(), i27);
                                                                i19 = i27;
                                                            } else {
                                                                constraintWidget4 = constraintWidget2;
                                                                constraintWidget5 = constraintWidget;
                                                                solverVariable10 = solverVariable9;
                                                            }
                                                            if (z16 || !z10 || (constraintWidget5 instanceof Barrier) || (constraintWidget4 instanceof Barrier)) {
                                                                constraintWidget6 = constraintWidget3;
                                                            } else {
                                                                constraintWidget6 = constraintWidget3;
                                                                if (constraintWidget4 != constraintWidget6) {
                                                                    z22 = true;
                                                                    i24 = 6;
                                                                    i23 = 6;
                                                                    if (z22) {
                                                                        if (!z17 || (z9 && !z3)) {
                                                                            i26 = i24;
                                                                        } else {
                                                                            int i45 = (constraintWidget5 == constraintWidget6 || constraintWidget4 == constraintWidget6) ? 6 : i24;
                                                                            if ((constraintWidget5 instanceof Guideline) || (constraintWidget4 instanceof Guideline)) {
                                                                                i45 = 5;
                                                                            }
                                                                            if ((constraintWidget5 instanceof Barrier) || (constraintWidget4 instanceof Barrier)) {
                                                                                i45 = 5;
                                                                            }
                                                                            if (z9) {
                                                                                i45 = 5;
                                                                            }
                                                                            i26 = Math.max(i45, i24);
                                                                        }
                                                                        if (z16) {
                                                                            i26 = Math.min(i23, i26);
                                                                            if (z6 && !z9 && (constraintWidget5 == constraintWidget6 || constraintWidget4 == constraintWidget6)) {
                                                                                i26 = 4;
                                                                            }
                                                                        }
                                                                        linearSystem.addEquality(solverVariable10, solverVariable4, constraintAnchor.getMargin(), i26);
                                                                        linearSystem.addEquality(solverVariable6, solverVariable5, -constraintAnchor2.getMargin(), i26);
                                                                    }
                                                                    if (z16) {
                                                                        int margin = solverVariable == solverVariable4 ? constraintAnchor.getMargin() : 0;
                                                                        if (solverVariable4 != solverVariable) {
                                                                            i25 = 5;
                                                                            linearSystem.addGreaterThan(solverVariable10, solverVariable, margin, 5);
                                                                            if (z16 || !z14 || i3 != 0 || i14 != 0) {
                                                                                i17 = 0;
                                                                                i18 = 5;
                                                                                if (!z16 && z15) {
                                                                                    if (constraintAnchor2.mTarget != null) {
                                                                                        solverVariable7 = solverVariable2;
                                                                                        i17 = constraintAnchor2.getMargin();
                                                                                    } else {
                                                                                        solverVariable7 = solverVariable2;
                                                                                    }
                                                                                    if (solverVariable5 != solverVariable7) {
                                                                                        linearSystem.addGreaterThan(solverVariable7, solverVariable6, i17, i18);
                                                                                        return;
                                                                                    }
                                                                                    return;
                                                                                }
                                                                                return;
                                                                            }
                                                                            if (!z14 || i10 != 3) {
                                                                                i17 = 0;
                                                                                linearSystem.addGreaterThan(solverVariable6, solverVariable10, 0, i25);
                                                                            } else {
                                                                                i17 = 0;
                                                                                linearSystem.addGreaterThan(solverVariable6, solverVariable10, 0, i22);
                                                                            }
                                                                            i18 = 5;
                                                                            if (!z16) {
                                                                                return;
                                                                            }
                                                                            return;
                                                                        }
                                                                    }
                                                                    i25 = 5;
                                                                    if (z16) {
                                                                    }
                                                                    i17 = 0;
                                                                    i18 = 5;
                                                                    if (!z16) {
                                                                    }
                                                                }
                                                            }
                                                            i24 = i20;
                                                            i23 = i19;
                                                            if (z22) {
                                                            }
                                                            if (z16) {
                                                            }
                                                            i25 = 5;
                                                            if (z16) {
                                                            }
                                                            i17 = 0;
                                                            i18 = 5;
                                                            if (!z16) {
                                                            }
                                                        } else {
                                                            return;
                                                        }
                                                    } else if (i10 == 2) {
                                                        if ((constraintWidget7 instanceof Barrier) || (constraintWidget8 instanceof Barrier)) {
                                                            solverVariable8 = solverVariable2;
                                                        } else {
                                                            solverVariable8 = solverVariable2;
                                                            i31 = 5;
                                                            i20 = i31;
                                                            i30 = 5;
                                                            z23 = true;
                                                            z19 = true;
                                                            z18 = z23;
                                                            z17 = false;
                                                            i19 = i30;
                                                            i21 = 6;
                                                            if (z18) {
                                                            }
                                                            z20 = z18;
                                                            z21 = true;
                                                            if (!z19) {
                                                            }
                                                            z22 = z21;
                                                            if (this.mVisibility == i22) {
                                                            }
                                                            if (!z20) {
                                                            }
                                                            if (z16) {
                                                            }
                                                            constraintWidget6 = constraintWidget3;
                                                            i24 = i20;
                                                            i23 = i19;
                                                            if (z22) {
                                                            }
                                                            if (z16) {
                                                            }
                                                            i25 = 5;
                                                            if (z16) {
                                                            }
                                                            i17 = 0;
                                                            i18 = 5;
                                                            if (!z16) {
                                                            }
                                                        }
                                                    } else if (i10 == 1) {
                                                        solverVariable8 = solverVariable2;
                                                        i30 = 8;
                                                        i20 = 4;
                                                        z23 = true;
                                                        z19 = true;
                                                        z18 = z23;
                                                        z17 = false;
                                                        i19 = i30;
                                                        i21 = 6;
                                                        if (z18) {
                                                        }
                                                        z20 = z18;
                                                        z21 = true;
                                                        if (!z19) {
                                                        }
                                                        z22 = z21;
                                                        if (this.mVisibility == i22) {
                                                        }
                                                        if (!z20) {
                                                        }
                                                        if (z16) {
                                                        }
                                                        constraintWidget6 = constraintWidget3;
                                                        i24 = i20;
                                                        i23 = i19;
                                                        if (z22) {
                                                        }
                                                        if (z16) {
                                                        }
                                                        i25 = 5;
                                                        if (z16) {
                                                        }
                                                        i17 = 0;
                                                        i18 = 5;
                                                        if (!z16) {
                                                        }
                                                    } else if (i10 == 3) {
                                                        if (this.mResolvedDimensionRatioSide == -1) {
                                                            i35 = z9 ? z2 ? 5 : 4 : 8;
                                                            i34 = 5;
                                                            i33 = 8;
                                                        } else if (z6) {
                                                            if (i6 != 2) {
                                                                if (i6 != 1) {
                                                                    z24 = false;
                                                                    if (z24) {
                                                                        i38 = 5;
                                                                        i37 = 8;
                                                                    } else {
                                                                        i38 = 4;
                                                                        i37 = 5;
                                                                    }
                                                                    i20 = i38;
                                                                    i19 = i37;
                                                                    i21 = 6;
                                                                    z19 = true;
                                                                    z18 = true;
                                                                    z17 = true;
                                                                    solverVariable8 = solverVariable2;
                                                                    if (z18) {
                                                                    }
                                                                    z20 = z18;
                                                                    z21 = true;
                                                                    if (!z19) {
                                                                    }
                                                                    z22 = z21;
                                                                    if (this.mVisibility == i22) {
                                                                    }
                                                                    if (!z20) {
                                                                    }
                                                                    if (z16) {
                                                                    }
                                                                    constraintWidget6 = constraintWidget3;
                                                                    i24 = i20;
                                                                    i23 = i19;
                                                                    if (z22) {
                                                                    }
                                                                    if (z16) {
                                                                    }
                                                                    i25 = 5;
                                                                    if (z16) {
                                                                    }
                                                                    i17 = 0;
                                                                    i18 = 5;
                                                                    if (!z16) {
                                                                    }
                                                                }
                                                            }
                                                            z24 = true;
                                                            if (z24) {
                                                            }
                                                            i20 = i38;
                                                            i19 = i37;
                                                            i21 = 6;
                                                            z19 = true;
                                                            z18 = true;
                                                            z17 = true;
                                                            solverVariable8 = solverVariable2;
                                                            if (z18) {
                                                            }
                                                            z20 = z18;
                                                            z21 = true;
                                                            if (!z19) {
                                                            }
                                                            z22 = z21;
                                                            if (this.mVisibility == i22) {
                                                            }
                                                            if (!z20) {
                                                            }
                                                            if (z16) {
                                                            }
                                                            constraintWidget6 = constraintWidget3;
                                                            i24 = i20;
                                                            i23 = i19;
                                                            if (z22) {
                                                            }
                                                            if (z16) {
                                                            }
                                                            i25 = 5;
                                                            if (z16) {
                                                            }
                                                            i17 = 0;
                                                            i18 = 5;
                                                            if (!z16) {
                                                            }
                                                        } else {
                                                            if (i16 > 0) {
                                                                i36 = 5;
                                                            } else if (i16 != 0 || i14 != 0) {
                                                                i36 = 4;
                                                            } else if (!z9) {
                                                                i36 = 8;
                                                            } else {
                                                                i33 = (constraintWidget7 == constraintWidget9 || constraintWidget8 == constraintWidget9) ? 5 : 4;
                                                                i35 = 6;
                                                                i34 = 4;
                                                            }
                                                            i34 = i36;
                                                            i35 = 6;
                                                            i33 = 5;
                                                        }
                                                        i21 = i35;
                                                        i20 = i34;
                                                        i19 = i33;
                                                        z19 = true;
                                                        z18 = true;
                                                        z17 = true;
                                                        solverVariable8 = solverVariable2;
                                                        if (z18) {
                                                        }
                                                        z20 = z18;
                                                        z21 = true;
                                                        if (!z19) {
                                                        }
                                                        z22 = z21;
                                                        if (this.mVisibility == i22) {
                                                        }
                                                        if (!z20) {
                                                        }
                                                        if (z16) {
                                                        }
                                                        constraintWidget6 = constraintWidget3;
                                                        i24 = i20;
                                                        i23 = i19;
                                                        if (z22) {
                                                        }
                                                        if (z16) {
                                                        }
                                                        i25 = 5;
                                                        if (z16) {
                                                        }
                                                        i17 = 0;
                                                        i18 = 5;
                                                        if (!z16) {
                                                        }
                                                    } else {
                                                        solverVariable8 = solverVariable2;
                                                        i30 = 5;
                                                        i20 = 4;
                                                        z23 = false;
                                                        z19 = false;
                                                        z18 = z23;
                                                        z17 = false;
                                                        i19 = i30;
                                                        i21 = 6;
                                                        if (z18) {
                                                        }
                                                        z20 = z18;
                                                        z21 = true;
                                                        if (!z19) {
                                                        }
                                                        z22 = z21;
                                                        if (this.mVisibility == i22) {
                                                        }
                                                        if (!z20) {
                                                        }
                                                        if (z16) {
                                                        }
                                                        constraintWidget6 = constraintWidget3;
                                                        i24 = i20;
                                                        i23 = i19;
                                                        if (z22) {
                                                        }
                                                        if (z16) {
                                                        }
                                                        i25 = 5;
                                                        if (z16) {
                                                        }
                                                        i17 = 0;
                                                        i18 = 5;
                                                        if (!z16) {
                                                        }
                                                    }
                                                } else if (!solverVariable4.isFinalValue || !solverVariable5.isFinalValue) {
                                                    solverVariable8 = solverVariable2;
                                                } else {
                                                    linearSystem.addCentering(createObjectVariable, solverVariable4, constraintAnchor.getMargin(), f, solverVariable5, solverVariable6, constraintAnchor2.getMargin(), 8);
                                                    if (z2 && z15) {
                                                        if (constraintAnchor2.mTarget != null) {
                                                            i32 = constraintAnchor2.getMargin();
                                                            solverVariable11 = solverVariable2;
                                                        } else {
                                                            solverVariable11 = solverVariable2;
                                                            i32 = 0;
                                                        }
                                                        if (solverVariable5 != solverVariable11) {
                                                            linearSystem.addGreaterThan(solverVariable11, solverVariable6, i32, 5);
                                                            return;
                                                        }
                                                        return;
                                                    }
                                                    return;
                                                }
                                                i31 = 4;
                                                i20 = i31;
                                                i30 = 5;
                                                z23 = true;
                                                z19 = true;
                                                z18 = z23;
                                                z17 = false;
                                                i19 = i30;
                                                i21 = 6;
                                                if (z18) {
                                                }
                                                z20 = z18;
                                                z21 = true;
                                                if (!z19) {
                                                }
                                                z22 = z21;
                                                if (this.mVisibility == i22) {
                                                }
                                                if (!z20) {
                                                }
                                                if (z16) {
                                                }
                                                constraintWidget6 = constraintWidget3;
                                                i24 = i20;
                                                i23 = i19;
                                                if (z22) {
                                                }
                                                if (z16) {
                                                }
                                                i25 = 5;
                                                if (z16) {
                                                }
                                                i17 = 0;
                                                i18 = 5;
                                                if (!z16) {
                                                }
                                            }
                                            i17 = 0;
                                            z16 = z2;
                                            i18 = 5;
                                            if (!z16) {
                                            }
                                        } else {
                                            linearSystem.addEquality(solverVariable6, solverVariable5, -constraintAnchor2.getMargin(), 8);
                                            if (z2) {
                                                linearSystem.addGreaterThan(createObjectVariable, solverVariable, 0, 5);
                                                i17 = 0;
                                                z16 = z2;
                                                i18 = 5;
                                                if (!z16) {
                                                }
                                            }
                                        }
                                    }
                                    i17 = 0;
                                    z16 = z2;
                                    i18 = 5;
                                    if (!z16) {
                                    }
                                } else if (i15 < 2 && z2 && z15) {
                                    linearSystem.addGreaterThan(createObjectVariable, solverVariable, 0, 8);
                                    boolean z29 = z || this.mBaseline.mTarget == null;
                                    if (!z && (constraintAnchor3 = this.mBaseline.mTarget) != null) {
                                        ConstraintWidget constraintWidget10 = constraintAnchor3.mOwner;
                                        z29 = constraintWidget10.mDimensionRatio != 0.0f && (dimensionBehaviourArr = constraintWidget10.mListDimensionBehaviors)[0] == (dimensionBehaviour2 = DimensionBehaviour.MATCH_CONSTRAINT) && dimensionBehaviourArr[1] == dimensionBehaviour2;
                                    }
                                    if (z29) {
                                        linearSystem.addGreaterThan(solverVariable2, solverVariable6, 0, 8);
                                        return;
                                    }
                                    return;
                                } else {
                                    return;
                                }
                            }
                        } else {
                            int max = Math.max(i7, i13);
                            if (i44 > 0) {
                                max = Math.min(i44, max);
                            }
                            linearSystem.addEquality(createObjectVariable2, createObjectVariable, max, 8);
                            i41 = i7;
                            z13 = false;
                        }
                        i14 = i41;
                        i16 = i44;
                        i15 = i9;
                        solverVariable4 = createObjectVariable3;
                        solverVariable6 = createObjectVariable2;
                        z14 = z13;
                        solverVariable5 = solverVariable3;
                        z15 = z4;
                        if (!z11) {
                        }
                        if (i15 < 2) {
                            return;
                        }
                        return;
                    }
                }
                if (!z13) {
                }
                i14 = i41;
                i16 = i44;
                i15 = i9;
                solverVariable4 = createObjectVariable3;
                solverVariable6 = createObjectVariable2;
                z14 = z13;
                solverVariable5 = solverVariable3;
                z15 = z4;
                if (!z11) {
                }
                if (i15 < 2) {
                }
            }
        }
        z12 = false;
        i11 = this.mWidthOverride;
        this.mWidthOverride = -1;
        i2 = i11;
        z12 = false;
        i12 = this.mHeightOverride;
        if (i12 != -1) {
        }
        i12 = i2;
        if (this.mVisibility != 8) {
        }
        if (z11) {
        }
        if (!z13) {
        }
        i14 = i41;
        i16 = i44;
        i15 = i9;
        solverVariable4 = createObjectVariable3;
        solverVariable6 = createObjectVariable2;
        z14 = z13;
        solverVariable5 = solverVariable3;
        z15 = z4;
        if (!z11) {
        }
        if (i15 < 2) {
        }
    }

    public void connect(ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, int i) {
        if (constraintAnchor.mOwner == this) {
            connect(constraintAnchor.mType, constraintAnchor2.mOwner, constraintAnchor2.mType, i);
        }
    }

    public void copy(ConstraintWidget constraintWidget, HashMap<ConstraintWidget, ConstraintWidget> hashMap) {
        this.mHorizontalResolution = constraintWidget.mHorizontalResolution;
        this.mVerticalResolution = constraintWidget.mVerticalResolution;
        this.mMatchConstraintDefaultWidth = constraintWidget.mMatchConstraintDefaultWidth;
        this.mMatchConstraintDefaultHeight = constraintWidget.mMatchConstraintDefaultHeight;
        int[] iArr = this.mResolvedMatchConstraintDefault;
        int[] iArr2 = constraintWidget.mResolvedMatchConstraintDefault;
        iArr[0] = iArr2[0];
        iArr[1] = iArr2[1];
        this.mMatchConstraintMinWidth = constraintWidget.mMatchConstraintMinWidth;
        this.mMatchConstraintMaxWidth = constraintWidget.mMatchConstraintMaxWidth;
        this.mMatchConstraintMinHeight = constraintWidget.mMatchConstraintMinHeight;
        this.mMatchConstraintMaxHeight = constraintWidget.mMatchConstraintMaxHeight;
        this.mMatchConstraintPercentHeight = constraintWidget.mMatchConstraintPercentHeight;
        this.mIsWidthWrapContent = constraintWidget.mIsWidthWrapContent;
        this.mIsHeightWrapContent = constraintWidget.mIsHeightWrapContent;
        this.mResolvedDimensionRatioSide = constraintWidget.mResolvedDimensionRatioSide;
        this.mResolvedDimensionRatio = constraintWidget.mResolvedDimensionRatio;
        int[] iArr3 = constraintWidget.mMaxDimension;
        this.mMaxDimension = Arrays.copyOf(iArr3, iArr3.length);
        this.mCircleConstraintAngle = constraintWidget.mCircleConstraintAngle;
        this.hasBaseline = constraintWidget.hasBaseline;
        this.inPlaceholder = constraintWidget.inPlaceholder;
        this.mLeft.reset();
        this.mTop.reset();
        this.mRight.reset();
        this.mBottom.reset();
        this.mBaseline.reset();
        this.mCenterX.reset();
        this.mCenterY.reset();
        this.mCenter.reset();
        this.mListDimensionBehaviors = (DimensionBehaviour[]) Arrays.copyOf(this.mListDimensionBehaviors, 2);
        ConstraintWidget constraintWidget2 = null;
        this.mParent = this.mParent == null ? null : hashMap.get(constraintWidget.mParent);
        this.mWidth = constraintWidget.mWidth;
        this.mHeight = constraintWidget.mHeight;
        this.mDimensionRatio = constraintWidget.mDimensionRatio;
        this.mDimensionRatioSide = constraintWidget.mDimensionRatioSide;
        this.mX = constraintWidget.mX;
        this.mY = constraintWidget.mY;
        this.mRelX = constraintWidget.mRelX;
        this.mRelY = constraintWidget.mRelY;
        this.mOffsetX = constraintWidget.mOffsetX;
        this.mOffsetY = constraintWidget.mOffsetY;
        this.mBaselineDistance = constraintWidget.mBaselineDistance;
        this.mMinWidth = constraintWidget.mMinWidth;
        this.mMinHeight = constraintWidget.mMinHeight;
        this.mHorizontalBiasPercent = constraintWidget.mHorizontalBiasPercent;
        this.mVerticalBiasPercent = constraintWidget.mVerticalBiasPercent;
        this.mCompanionWidget = constraintWidget.mCompanionWidget;
        this.mContainerItemSkip = constraintWidget.mContainerItemSkip;
        this.mVisibility = constraintWidget.mVisibility;
        this.mDebugName = constraintWidget.mDebugName;
        this.mType = constraintWidget.mType;
        this.mDistToTop = constraintWidget.mDistToTop;
        this.mDistToLeft = constraintWidget.mDistToLeft;
        this.mDistToRight = constraintWidget.mDistToRight;
        this.mDistToBottom = constraintWidget.mDistToBottom;
        this.mLeftHasCentered = constraintWidget.mLeftHasCentered;
        this.mRightHasCentered = constraintWidget.mRightHasCentered;
        this.mTopHasCentered = constraintWidget.mTopHasCentered;
        this.mBottomHasCentered = constraintWidget.mBottomHasCentered;
        this.mHorizontalWrapVisited = constraintWidget.mHorizontalWrapVisited;
        this.mVerticalWrapVisited = constraintWidget.mVerticalWrapVisited;
        this.mHorizontalChainStyle = constraintWidget.mHorizontalChainStyle;
        this.mVerticalChainStyle = constraintWidget.mVerticalChainStyle;
        this.mHorizontalChainFixedPosition = constraintWidget.mHorizontalChainFixedPosition;
        this.mVerticalChainFixedPosition = constraintWidget.mVerticalChainFixedPosition;
        float[] fArr = this.mWeight;
        float[] fArr2 = constraintWidget.mWeight;
        fArr[0] = fArr2[0];
        fArr[1] = fArr2[1];
        ConstraintWidget[] constraintWidgetArr = this.mListNextMatchConstraintsWidget;
        ConstraintWidget[] constraintWidgetArr2 = constraintWidget.mListNextMatchConstraintsWidget;
        constraintWidgetArr[0] = constraintWidgetArr2[0];
        constraintWidgetArr[1] = constraintWidgetArr2[1];
        ConstraintWidget[] constraintWidgetArr3 = this.mNextChainWidget;
        ConstraintWidget[] constraintWidgetArr4 = constraintWidget.mNextChainWidget;
        constraintWidgetArr3[0] = constraintWidgetArr4[0];
        constraintWidgetArr3[1] = constraintWidgetArr4[1];
        ConstraintWidget constraintWidget3 = constraintWidget.mHorizontalNextWidget;
        this.mHorizontalNextWidget = constraintWidget3 == null ? null : hashMap.get(constraintWidget3);
        ConstraintWidget constraintWidget4 = constraintWidget.mVerticalNextWidget;
        if (constraintWidget4 != null) {
            constraintWidget2 = hashMap.get(constraintWidget4);
        }
        this.mVerticalNextWidget = constraintWidget2;
    }

    public void createObjectVariables(LinearSystem linearSystem) {
        linearSystem.createObjectVariable(this.mLeft);
        linearSystem.createObjectVariable(this.mTop);
        linearSystem.createObjectVariable(this.mRight);
        linearSystem.createObjectVariable(this.mBottom);
        if (this.mBaselineDistance > 0) {
            linearSystem.createObjectVariable(this.mBaseline);
        }
    }

    public void ensureWidgetRuns() {
        if (this.horizontalRun == null) {
            this.horizontalRun = new HorizontalWidgetRun(this);
        }
        if (this.verticalRun == null) {
            this.verticalRun = new VerticalWidgetRun(this);
        }
    }

    public ConstraintAnchor getAnchor(ConstraintAnchor.Type type) {
        switch (type.ordinal()) {
            case 0:
                return null;
            case 1:
                return this.mLeft;
            case 2:
                return this.mTop;
            case 3:
                return this.mRight;
            case 4:
                return this.mBottom;
            case 5:
                return this.mBaseline;
            case 6:
                return this.mCenter;
            case 7:
                return this.mCenterX;
            case 8:
                return this.mCenterY;
            default:
                throw new AssertionError(type.name());
        }
    }

    public int getBottom() {
        return getY() + this.mHeight;
    }

    public DimensionBehaviour getDimensionBehaviour(int i) {
        if (i == 0) {
            return getHorizontalDimensionBehaviour();
        }
        if (i == 1) {
            return getVerticalDimensionBehaviour();
        }
        return null;
    }

    public int getHeight() {
        if (this.mVisibility == 8) {
            return 0;
        }
        return this.mHeight;
    }

    public DimensionBehaviour getHorizontalDimensionBehaviour() {
        return this.mListDimensionBehaviors[0];
    }

    public ConstraintWidget getNextChainMember(int i) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        if (i == 0) {
            ConstraintAnchor constraintAnchor3 = this.mRight;
            ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
            if (constraintAnchor4 == null || constraintAnchor4.mTarget != constraintAnchor3) {
                return null;
            }
            return constraintAnchor4.mOwner;
        } else if (i == 1 && (constraintAnchor2 = (constraintAnchor = this.mBottom).mTarget) != null && constraintAnchor2.mTarget == constraintAnchor) {
            return constraintAnchor2.mOwner;
        } else {
            return null;
        }
    }

    public ConstraintWidget getPreviousChainMember(int i) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        if (i == 0) {
            ConstraintAnchor constraintAnchor3 = this.mLeft;
            ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
            if (constraintAnchor4 == null || constraintAnchor4.mTarget != constraintAnchor3) {
                return null;
            }
            return constraintAnchor4.mOwner;
        } else if (i == 1 && (constraintAnchor2 = (constraintAnchor = this.mTop).mTarget) != null && constraintAnchor2.mTarget == constraintAnchor) {
            return constraintAnchor2.mOwner;
        } else {
            return null;
        }
    }

    public int getRight() {
        return getX() + this.mWidth;
    }

    public DimensionBehaviour getVerticalDimensionBehaviour() {
        return this.mListDimensionBehaviors[1];
    }

    public int getWidth() {
        if (this.mVisibility == 8) {
            return 0;
        }
        return this.mWidth;
    }

    public int getX() {
        ConstraintWidget constraintWidget = this.mParent;
        if (constraintWidget == null || !(constraintWidget instanceof ConstraintWidgetContainer)) {
            return this.mX;
        }
        return ((ConstraintWidgetContainer) constraintWidget).mPaddingLeft + this.mX;
    }

    public int getY() {
        ConstraintWidget constraintWidget = this.mParent;
        if (constraintWidget == null || !(constraintWidget instanceof ConstraintWidgetContainer)) {
            return this.mY;
        }
        return ((ConstraintWidgetContainer) constraintWidget).mPaddingTop + this.mY;
    }

    public boolean hasDanglingDimension(int i) {
        if (i == 0) {
            return (this.mLeft.mTarget != null ? 1 : 0) + (this.mRight.mTarget != null ? 1 : 0) < 2;
        }
        if ((this.mTop.mTarget != null ? 1 : 0) + (this.mBottom.mTarget != null ? 1 : 0) + (this.mBaseline.mTarget != null ? 1 : 0) < 2) {
            return true;
        }
        return false;
    }

    public boolean hasResolvedTargets(int i, int i2) {
        ConstraintAnchor constraintAnchor;
        ConstraintAnchor constraintAnchor2;
        if (i == 0) {
            ConstraintAnchor constraintAnchor3 = this.mLeft.mTarget;
            if (constraintAnchor3 != null && constraintAnchor3.mHasFinalValue && (constraintAnchor2 = this.mRight.mTarget) != null && constraintAnchor2.mHasFinalValue) {
                if ((constraintAnchor2.getFinalValue() - this.mRight.getMargin()) - (this.mLeft.getMargin() + this.mLeft.mTarget.getFinalValue()) >= i2) {
                    return true;
                }
                return false;
            }
        } else {
            ConstraintAnchor constraintAnchor4 = this.mTop.mTarget;
            if (constraintAnchor4 != null && constraintAnchor4.mHasFinalValue && (constraintAnchor = this.mBottom.mTarget) != null && constraintAnchor.mHasFinalValue) {
                if ((constraintAnchor.getFinalValue() - this.mBottom.getMargin()) - (this.mTop.getMargin() + this.mTop.mTarget.getFinalValue()) >= i2) {
                    return true;
                }
                return false;
            }
        }
        return false;
    }

    public void immediateConnect(ConstraintAnchor.Type type, ConstraintWidget constraintWidget, ConstraintAnchor.Type type2, int i, int i2) {
        getAnchor(type).connect(constraintWidget.getAnchor(type2), i, i2, true);
    }

    public final boolean isChainHead(int i) {
        int i2 = i * 2;
        ConstraintAnchor[] constraintAnchorArr = this.mListAnchors;
        if (!(constraintAnchorArr[i2].mTarget == null || constraintAnchorArr[i2].mTarget.mTarget == constraintAnchorArr[i2])) {
            int i3 = i2 + 1;
            return constraintAnchorArr[i3].mTarget != null && constraintAnchorArr[i3].mTarget.mTarget == constraintAnchorArr[i3];
        }
    }

    public boolean isInHorizontalChain() {
        ConstraintAnchor constraintAnchor = this.mLeft;
        ConstraintAnchor constraintAnchor2 = constraintAnchor.mTarget;
        if (constraintAnchor2 != null && constraintAnchor2.mTarget == constraintAnchor) {
            return true;
        }
        ConstraintAnchor constraintAnchor3 = this.mRight;
        ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
        return constraintAnchor4 != null && constraintAnchor4.mTarget == constraintAnchor3;
    }

    public boolean isInVerticalChain() {
        ConstraintAnchor constraintAnchor = this.mTop;
        ConstraintAnchor constraintAnchor2 = constraintAnchor.mTarget;
        if (constraintAnchor2 != null && constraintAnchor2.mTarget == constraintAnchor) {
            return true;
        }
        ConstraintAnchor constraintAnchor3 = this.mBottom;
        ConstraintAnchor constraintAnchor4 = constraintAnchor3.mTarget;
        return constraintAnchor4 != null && constraintAnchor4.mTarget == constraintAnchor3;
    }

    public boolean isMeasureRequested() {
        return this.mMeasureRequested && this.mVisibility != 8;
    }

    public boolean isResolvedHorizontally() {
        return this.resolvedHorizontal || (this.mLeft.mHasFinalValue && this.mRight.mHasFinalValue);
    }

    public boolean isResolvedVertically() {
        return this.resolvedVertical || (this.mTop.mHasFinalValue && this.mBottom.mHasFinalValue);
    }

    public void reset() {
        this.mLeft.reset();
        this.mTop.reset();
        this.mRight.reset();
        this.mBottom.reset();
        this.mBaseline.reset();
        this.mCenterX.reset();
        this.mCenterY.reset();
        this.mCenter.reset();
        this.mParent = null;
        this.mCircleConstraintAngle = 0.0f;
        this.mWidth = 0;
        this.mHeight = 0;
        this.mDimensionRatio = 0.0f;
        this.mDimensionRatioSide = -1;
        this.mX = 0;
        this.mY = 0;
        this.mOffsetX = 0;
        this.mOffsetY = 0;
        this.mBaselineDistance = 0;
        this.mMinWidth = 0;
        this.mMinHeight = 0;
        this.mHorizontalBiasPercent = 0.5f;
        this.mVerticalBiasPercent = 0.5f;
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour = DimensionBehaviour.FIXED;
        dimensionBehaviourArr[0] = dimensionBehaviour;
        dimensionBehaviourArr[1] = dimensionBehaviour;
        this.mCompanionWidget = null;
        this.mContainerItemSkip = 0;
        this.mVisibility = 0;
        this.mType = null;
        this.mHorizontalWrapVisited = false;
        this.mVerticalWrapVisited = false;
        this.mHorizontalChainStyle = 0;
        this.mVerticalChainStyle = 0;
        this.mHorizontalChainFixedPosition = false;
        this.mVerticalChainFixedPosition = false;
        float[] fArr = this.mWeight;
        fArr[0] = -1.0f;
        fArr[1] = -1.0f;
        this.mHorizontalResolution = -1;
        this.mVerticalResolution = -1;
        int[] iArr = this.mMaxDimension;
        iArr[0] = Integer.MAX_VALUE;
        iArr[1] = Integer.MAX_VALUE;
        this.mMatchConstraintDefaultWidth = 0;
        this.mMatchConstraintDefaultHeight = 0;
        this.mMatchConstraintPercentWidth = 1.0f;
        this.mMatchConstraintPercentHeight = 1.0f;
        this.mMatchConstraintMaxWidth = Integer.MAX_VALUE;
        this.mMatchConstraintMaxHeight = Integer.MAX_VALUE;
        this.mMatchConstraintMinWidth = 0;
        this.mMatchConstraintMinHeight = 0;
        this.mResolvedDimensionRatioSide = -1;
        this.mResolvedDimensionRatio = 1.0f;
        boolean[] zArr = this.isTerminalWidget;
        zArr[0] = true;
        zArr[1] = true;
        this.mInVirtualLayout = false;
        boolean[] zArr2 = this.mIsInBarrier;
        zArr2[0] = false;
        zArr2[1] = false;
        this.mMeasureRequested = true;
        int[] iArr2 = this.mResolvedMatchConstraintDefault;
        iArr2[0] = 0;
        iArr2[1] = 0;
        this.mWidthOverride = -1;
        this.mHeightOverride = -1;
    }

    public void resetAnchors() {
        ConstraintWidget constraintWidget = this.mParent;
        if (constraintWidget != null && (constraintWidget instanceof ConstraintWidgetContainer)) {
            Objects.requireNonNull((ConstraintWidgetContainer) constraintWidget);
        }
        int size = this.mAnchors.size();
        for (int i = 0; i < size; i++) {
            this.mAnchors.get(i).reset();
        }
    }

    public void resetFinalResolution() {
        this.resolvedHorizontal = false;
        this.resolvedVertical = false;
        this.horizontalSolvingPass = false;
        this.verticalSolvingPass = false;
        int size = this.mAnchors.size();
        for (int i = 0; i < size; i++) {
            ConstraintAnchor constraintAnchor = this.mAnchors.get(i);
            constraintAnchor.mHasFinalValue = false;
            constraintAnchor.mFinalValue = 0;
        }
    }

    public void resetSolverVariables(Cache cache) {
        this.mLeft.resetSolverVariable();
        this.mTop.resetSolverVariable();
        this.mRight.resetSolverVariable();
        this.mBottom.resetSolverVariable();
        this.mBaseline.resetSolverVariable();
        this.mCenter.resetSolverVariable();
        this.mCenterX.resetSolverVariable();
        this.mCenterY.resetSolverVariable();
    }

    public void setBaselineDistance(int i) {
        this.mBaselineDistance = i;
        this.hasBaseline = i > 0;
    }

    public void setFinalHorizontal(int i, int i2) {
        if (!this.resolvedHorizontal) {
            ConstraintAnchor constraintAnchor = this.mLeft;
            constraintAnchor.mFinalValue = i;
            constraintAnchor.mHasFinalValue = true;
            ConstraintAnchor constraintAnchor2 = this.mRight;
            constraintAnchor2.mFinalValue = i2;
            constraintAnchor2.mHasFinalValue = true;
            this.mX = i;
            this.mWidth = i2 - i;
            this.resolvedHorizontal = true;
        }
    }

    public void setFinalVertical(int i, int i2) {
        if (!this.resolvedVertical) {
            ConstraintAnchor constraintAnchor = this.mTop;
            constraintAnchor.mFinalValue = i;
            constraintAnchor.mHasFinalValue = true;
            ConstraintAnchor constraintAnchor2 = this.mBottom;
            constraintAnchor2.mFinalValue = i2;
            constraintAnchor2.mHasFinalValue = true;
            this.mY = i;
            this.mHeight = i2 - i;
            if (this.hasBaseline) {
                this.mBaseline.setFinalValue(i + this.mBaselineDistance);
            }
            this.resolvedVertical = true;
        }
    }

    public void setHeight(int i) {
        this.mHeight = i;
        int i2 = this.mMinHeight;
        if (i < i2) {
            this.mHeight = i2;
        }
    }

    public void setHorizontalDimensionBehaviour(DimensionBehaviour dimensionBehaviour) {
        this.mListDimensionBehaviors[0] = dimensionBehaviour;
    }

    public void setMinHeight(int i) {
        if (i < 0) {
            this.mMinHeight = 0;
        } else {
            this.mMinHeight = i;
        }
    }

    public void setMinWidth(int i) {
        if (i < 0) {
            this.mMinWidth = 0;
        } else {
            this.mMinWidth = i;
        }
    }

    public void setVerticalDimensionBehaviour(DimensionBehaviour dimensionBehaviour) {
        this.mListDimensionBehaviors[1] = dimensionBehaviour;
    }

    public void setWidth(int i) {
        this.mWidth = i;
        int i2 = this.mMinWidth;
        if (i < i2) {
            this.mWidth = i2;
        }
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        String str = "";
        sb.append(this.mType != null ? GeneratedOutlineSupport.outline22(GeneratedOutlineSupport.outline25("type: "), this.mType, " ") : str);
        if (this.mDebugName != null) {
            str = GeneratedOutlineSupport.outline22(GeneratedOutlineSupport.outline25("id: "), this.mDebugName, " ");
        }
        sb.append(str);
        sb.append("(");
        sb.append(this.mX);
        sb.append(", ");
        sb.append(this.mY);
        sb.append(") - (");
        sb.append(this.mWidth);
        sb.append(" x ");
        return GeneratedOutlineSupport.outline21(sb, this.mHeight, ")");
    }

    public void updateFromRuns(boolean z, boolean z2) {
        int i;
        int i2;
        HorizontalWidgetRun horizontalWidgetRun = this.horizontalRun;
        boolean z3 = z & horizontalWidgetRun.resolved;
        VerticalWidgetRun verticalWidgetRun = this.verticalRun;
        boolean z4 = z2 & verticalWidgetRun.resolved;
        int i3 = horizontalWidgetRun.start.value;
        int i4 = verticalWidgetRun.start.value;
        int i5 = horizontalWidgetRun.end.value;
        int i6 = verticalWidgetRun.end.value;
        int i7 = i6 - i4;
        if (i5 - i3 < 0 || i7 < 0 || i3 == Integer.MIN_VALUE || i3 == Integer.MAX_VALUE || i4 == Integer.MIN_VALUE || i4 == Integer.MAX_VALUE || i5 == Integer.MIN_VALUE || i5 == Integer.MAX_VALUE || i6 == Integer.MIN_VALUE || i6 == Integer.MAX_VALUE) {
            i5 = 0;
            i6 = 0;
            i3 = 0;
            i4 = 0;
        }
        int i8 = i5 - i3;
        int i9 = i6 - i4;
        if (z3) {
            this.mX = i3;
        }
        if (z4) {
            this.mY = i4;
        }
        if (this.mVisibility == 8) {
            this.mWidth = 0;
            this.mHeight = 0;
            return;
        }
        if (z3) {
            if (this.mListDimensionBehaviors[0] == DimensionBehaviour.FIXED && i8 < (i2 = this.mWidth)) {
                i8 = i2;
            }
            this.mWidth = i8;
            int i10 = this.mMinWidth;
            if (i8 < i10) {
                this.mWidth = i10;
            }
        }
        if (z4) {
            if (this.mListDimensionBehaviors[1] == DimensionBehaviour.FIXED && i9 < (i = this.mHeight)) {
                i9 = i;
            }
            this.mHeight = i9;
            int i11 = this.mMinHeight;
            if (i9 < i11) {
                this.mHeight = i11;
            }
        }
    }

    public void updateFromSolver(LinearSystem linearSystem, boolean z) {
        int i;
        int i2;
        VerticalWidgetRun verticalWidgetRun;
        HorizontalWidgetRun horizontalWidgetRun;
        int objectVariableValue = linearSystem.getObjectVariableValue(this.mLeft);
        int objectVariableValue2 = linearSystem.getObjectVariableValue(this.mTop);
        int objectVariableValue3 = linearSystem.getObjectVariableValue(this.mRight);
        int objectVariableValue4 = linearSystem.getObjectVariableValue(this.mBottom);
        if (z && (horizontalWidgetRun = this.horizontalRun) != null) {
            DependencyNode dependencyNode = horizontalWidgetRun.start;
            if (dependencyNode.resolved) {
                DependencyNode dependencyNode2 = horizontalWidgetRun.end;
                if (dependencyNode2.resolved) {
                    objectVariableValue = dependencyNode.value;
                    objectVariableValue3 = dependencyNode2.value;
                }
            }
        }
        if (z && (verticalWidgetRun = this.verticalRun) != null) {
            DependencyNode dependencyNode3 = verticalWidgetRun.start;
            if (dependencyNode3.resolved) {
                DependencyNode dependencyNode4 = verticalWidgetRun.end;
                if (dependencyNode4.resolved) {
                    objectVariableValue2 = dependencyNode3.value;
                    objectVariableValue4 = dependencyNode4.value;
                }
            }
        }
        int i3 = objectVariableValue4 - objectVariableValue2;
        if (objectVariableValue3 - objectVariableValue < 0 || i3 < 0 || objectVariableValue == Integer.MIN_VALUE || objectVariableValue == Integer.MAX_VALUE || objectVariableValue2 == Integer.MIN_VALUE || objectVariableValue2 == Integer.MAX_VALUE || objectVariableValue3 == Integer.MIN_VALUE || objectVariableValue3 == Integer.MAX_VALUE || objectVariableValue4 == Integer.MIN_VALUE || objectVariableValue4 == Integer.MAX_VALUE) {
            objectVariableValue4 = 0;
            objectVariableValue = 0;
            objectVariableValue2 = 0;
            objectVariableValue3 = 0;
        }
        int i4 = objectVariableValue3 - objectVariableValue;
        int i5 = objectVariableValue4 - objectVariableValue2;
        this.mX = objectVariableValue;
        this.mY = objectVariableValue2;
        if (this.mVisibility == 8) {
            this.mWidth = 0;
            this.mHeight = 0;
            return;
        }
        DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        DimensionBehaviour dimensionBehaviour = dimensionBehaviourArr[0];
        DimensionBehaviour dimensionBehaviour2 = DimensionBehaviour.FIXED;
        if (dimensionBehaviour == dimensionBehaviour2 && i4 < (i2 = this.mWidth)) {
            i4 = i2;
        }
        if (dimensionBehaviourArr[1] == dimensionBehaviour2 && i5 < (i = this.mHeight)) {
            i5 = i;
        }
        this.mWidth = i4;
        this.mHeight = i5;
        int i6 = this.mMinHeight;
        if (i5 < i6) {
            this.mHeight = i6;
        }
        int i7 = this.mMinWidth;
        if (i4 < i7) {
            this.mWidth = i7;
        }
        int i8 = this.mMatchConstraintMaxWidth;
        if (i8 > 0 && dimensionBehaviourArr[0] == DimensionBehaviour.MATCH_CONSTRAINT) {
            this.mWidth = Math.min(this.mWidth, i8);
        }
        int i9 = this.mMatchConstraintMaxHeight;
        if (i9 > 0 && this.mListDimensionBehaviors[1] == DimensionBehaviour.MATCH_CONSTRAINT) {
            this.mHeight = Math.min(this.mHeight, i9);
        }
        int i10 = this.mWidth;
        if (i4 != i10) {
            this.mWidthOverride = i10;
        }
        int i11 = this.mHeight;
        if (i5 != i11) {
            this.mHeightOverride = i11;
        }
    }

    public void connect(ConstraintAnchor.Type type, ConstraintWidget constraintWidget, ConstraintAnchor.Type type2, int i) {
        ConstraintAnchor.Type type3;
        ConstraintAnchor.Type type4;
        boolean z;
        ConstraintAnchor.Type type5 = ConstraintAnchor.Type.CENTER;
        if (type != type5) {
            ConstraintAnchor.Type type6 = ConstraintAnchor.Type.CENTER_X;
            if (type == type6 && (type2 == (type4 = ConstraintAnchor.Type.LEFT) || type2 == ConstraintAnchor.Type.RIGHT)) {
                ConstraintAnchor anchor = getAnchor(type4);
                ConstraintAnchor anchor2 = constraintWidget.getAnchor(type2);
                ConstraintAnchor anchor3 = getAnchor(ConstraintAnchor.Type.RIGHT);
                anchor.connect(anchor2, 0);
                anchor3.connect(anchor2, 0);
                getAnchor(type6).connect(anchor2, 0);
                return;
            }
            ConstraintAnchor.Type type7 = ConstraintAnchor.Type.CENTER_Y;
            if (type == type7 && (type2 == (type3 = ConstraintAnchor.Type.TOP) || type2 == ConstraintAnchor.Type.BOTTOM)) {
                ConstraintAnchor anchor4 = constraintWidget.getAnchor(type2);
                getAnchor(type3).connect(anchor4, 0);
                getAnchor(ConstraintAnchor.Type.BOTTOM).connect(anchor4, 0);
                getAnchor(type7).connect(anchor4, 0);
            } else if (type == type6 && type2 == type6) {
                ConstraintAnchor.Type type8 = ConstraintAnchor.Type.LEFT;
                getAnchor(type8).connect(constraintWidget.getAnchor(type8), 0);
                ConstraintAnchor.Type type9 = ConstraintAnchor.Type.RIGHT;
                getAnchor(type9).connect(constraintWidget.getAnchor(type9), 0);
                getAnchor(type6).connect(constraintWidget.getAnchor(type2), 0);
            } else if (type == type7 && type2 == type7) {
                ConstraintAnchor.Type type10 = ConstraintAnchor.Type.TOP;
                getAnchor(type10).connect(constraintWidget.getAnchor(type10), 0);
                ConstraintAnchor.Type type11 = ConstraintAnchor.Type.BOTTOM;
                getAnchor(type11).connect(constraintWidget.getAnchor(type11), 0);
                getAnchor(type7).connect(constraintWidget.getAnchor(type2), 0);
            } else {
                ConstraintAnchor anchor5 = getAnchor(type);
                ConstraintAnchor anchor6 = constraintWidget.getAnchor(type2);
                if (anchor5.isValidConnection(anchor6)) {
                    ConstraintAnchor.Type type12 = ConstraintAnchor.Type.BASELINE;
                    if (type == type12) {
                        ConstraintAnchor anchor7 = getAnchor(ConstraintAnchor.Type.TOP);
                        ConstraintAnchor anchor8 = getAnchor(ConstraintAnchor.Type.BOTTOM);
                        if (anchor7 != null) {
                            anchor7.reset();
                        }
                        if (anchor8 != null) {
                            anchor8.reset();
                        }
                    } else if (type == ConstraintAnchor.Type.TOP || type == ConstraintAnchor.Type.BOTTOM) {
                        ConstraintAnchor anchor9 = getAnchor(type12);
                        if (anchor9 != null) {
                            anchor9.reset();
                        }
                        ConstraintAnchor anchor10 = getAnchor(type5);
                        if (anchor10.mTarget != anchor6) {
                            anchor10.reset();
                        }
                        ConstraintAnchor opposite = getAnchor(type).getOpposite();
                        ConstraintAnchor anchor11 = getAnchor(type7);
                        if (anchor11.isConnected()) {
                            opposite.reset();
                            anchor11.reset();
                        }
                    } else if (type == ConstraintAnchor.Type.LEFT || type == ConstraintAnchor.Type.RIGHT) {
                        ConstraintAnchor anchor12 = getAnchor(type5);
                        if (anchor12.mTarget != anchor6) {
                            anchor12.reset();
                        }
                        ConstraintAnchor opposite2 = getAnchor(type).getOpposite();
                        ConstraintAnchor anchor13 = getAnchor(type6);
                        if (anchor13.isConnected()) {
                            opposite2.reset();
                            anchor13.reset();
                        }
                    }
                    anchor5.connect(anchor6, i);
                }
            }
        } else if (type2 == type5) {
            ConstraintAnchor.Type type13 = ConstraintAnchor.Type.LEFT;
            ConstraintAnchor anchor14 = getAnchor(type13);
            ConstraintAnchor.Type type14 = ConstraintAnchor.Type.RIGHT;
            ConstraintAnchor anchor15 = getAnchor(type14);
            ConstraintAnchor.Type type15 = ConstraintAnchor.Type.TOP;
            ConstraintAnchor anchor16 = getAnchor(type15);
            ConstraintAnchor.Type type16 = ConstraintAnchor.Type.BOTTOM;
            ConstraintAnchor anchor17 = getAnchor(type16);
            boolean z2 = true;
            if ((anchor14 == null || !anchor14.isConnected()) && (anchor15 == null || !anchor15.isConnected())) {
                connect(type13, constraintWidget, type13, 0);
                connect(type14, constraintWidget, type14, 0);
                z = true;
            } else {
                z = false;
            }
            if ((anchor16 == null || !anchor16.isConnected()) && (anchor17 == null || !anchor17.isConnected())) {
                connect(type15, constraintWidget, type15, 0);
                connect(type16, constraintWidget, type16, 0);
            } else {
                z2 = false;
            }
            if (z && z2) {
                getAnchor(type5).connect(constraintWidget.getAnchor(type5), 0);
            } else if (z) {
                ConstraintAnchor.Type type17 = ConstraintAnchor.Type.CENTER_X;
                getAnchor(type17).connect(constraintWidget.getAnchor(type17), 0);
            } else if (z2) {
                ConstraintAnchor.Type type18 = ConstraintAnchor.Type.CENTER_Y;
                getAnchor(type18).connect(constraintWidget.getAnchor(type18), 0);
            }
        } else {
            ConstraintAnchor.Type type19 = ConstraintAnchor.Type.LEFT;
            if (type2 == type19 || type2 == ConstraintAnchor.Type.RIGHT) {
                connect(type19, constraintWidget, type2, 0);
                connect(ConstraintAnchor.Type.RIGHT, constraintWidget, type2, 0);
                getAnchor(type5).connect(constraintWidget.getAnchor(type2), 0);
                return;
            }
            ConstraintAnchor.Type type20 = ConstraintAnchor.Type.TOP;
            if (type2 == type20 || type2 == ConstraintAnchor.Type.BOTTOM) {
                connect(type20, constraintWidget, type2, 0);
                connect(ConstraintAnchor.Type.BOTTOM, constraintWidget, type2, 0);
                getAnchor(type5).connect(constraintWidget.getAnchor(type2), 0);
            }
        }
    }
}
