package androidx.constraintlayout.core.widgets;

import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.constraintlayout.core.LinearSystem;
import androidx.constraintlayout.core.widgets.ConstraintAnchor;
import androidx.constraintlayout.core.widgets.ConstraintWidget;
import androidx.constraintlayout.core.widgets.analyzer.BasicMeasure;
import androidx.constraintlayout.core.widgets.analyzer.ChainRun;
import androidx.constraintlayout.core.widgets.analyzer.DependencyGraph;
import androidx.constraintlayout.core.widgets.analyzer.Direct;
import androidx.constraintlayout.core.widgets.analyzer.WidgetGroup;
import androidx.constraintlayout.core.widgets.analyzer.WidgetRun;
import androidx.constraintlayout.widget.ConstraintLayout;
import java.io.PrintStream;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Objects;

public class ConstraintWidgetContainer extends WidgetContainer {
    public WeakReference<ConstraintAnchor> horizontalWrapMax = null;
    public WeakReference<ConstraintAnchor> horizontalWrapMin = null;
    public BasicMeasure mBasicMeasureSolver = new BasicMeasure(this);
    public DependencyGraph mDependencyGraph = new DependencyGraph(this);
    public boolean mHeightMeasuredTooSmall = false;
    public ChainHead[] mHorizontalChainsArray = new ChainHead[4];
    public int mHorizontalChainsSize = 0;
    public boolean mIsRtl = false;
    public BasicMeasure.Measure mMeasure = new BasicMeasure.Measure();
    public BasicMeasure.Measurer mMeasurer = null;
    public int mOptimizationLevel = 257;
    public int mPaddingLeft;
    public int mPaddingTop;
    public LinearSystem mSystem = new LinearSystem();
    public ChainHead[] mVerticalChainsArray = new ChainHead[4];
    public int mVerticalChainsSize = 0;
    public boolean mWidthMeasuredTooSmall = false;
    public int pass;
    public WeakReference<ConstraintAnchor> verticalWrapMax = null;
    public WeakReference<ConstraintAnchor> verticalWrapMin = null;
    public HashSet<ConstraintWidget> widgetsToAdd = new HashSet<>();

    public static boolean measure(ConstraintWidget constraintWidget, BasicMeasure.Measurer measurer, BasicMeasure.Measure measure, int i) {
        int i2;
        int i3;
        if (measurer == null) {
            return false;
        }
        if (constraintWidget.mVisibility == 8 || (constraintWidget instanceof Guideline) || (constraintWidget instanceof Barrier)) {
            measure.measuredWidth = 0;
            measure.measuredHeight = 0;
            return false;
        }
        measure.horizontalBehavior = constraintWidget.getHorizontalDimensionBehaviour();
        measure.verticalBehavior = constraintWidget.getVerticalDimensionBehaviour();
        measure.horizontalDimension = constraintWidget.getWidth();
        measure.verticalDimension = constraintWidget.getHeight();
        measure.measuredNeedsSolverPass = false;
        measure.measureStrategy = i;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour = measure.horizontalBehavior;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
        boolean z = dimensionBehaviour == dimensionBehaviour2;
        boolean z2 = measure.verticalBehavior == dimensionBehaviour2;
        boolean z3 = z && constraintWidget.mDimensionRatio > 0.0f;
        boolean z4 = z2 && constraintWidget.mDimensionRatio > 0.0f;
        if (z && constraintWidget.hasDanglingDimension(0) && constraintWidget.mMatchConstraintDefaultWidth == 0 && !z3) {
            measure.horizontalBehavior = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
            if (z2 && constraintWidget.mMatchConstraintDefaultHeight == 0) {
                measure.horizontalBehavior = ConstraintWidget.DimensionBehaviour.FIXED;
            }
            z = false;
        }
        if (z2 && constraintWidget.hasDanglingDimension(1) && constraintWidget.mMatchConstraintDefaultHeight == 0 && !z4) {
            measure.verticalBehavior = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
            if (z && constraintWidget.mMatchConstraintDefaultWidth == 0) {
                measure.verticalBehavior = ConstraintWidget.DimensionBehaviour.FIXED;
            }
            z2 = false;
        }
        if (constraintWidget.isResolvedHorizontally()) {
            measure.horizontalBehavior = ConstraintWidget.DimensionBehaviour.FIXED;
            z = false;
        }
        if (constraintWidget.isResolvedVertically()) {
            measure.verticalBehavior = ConstraintWidget.DimensionBehaviour.FIXED;
            z2 = false;
        }
        if (z3) {
            if (constraintWidget.mResolvedMatchConstraintDefault[0] == 4) {
                measure.horizontalBehavior = ConstraintWidget.DimensionBehaviour.FIXED;
            } else if (!z2) {
                ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = measure.verticalBehavior;
                ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.FIXED;
                if (dimensionBehaviour3 == dimensionBehaviour4) {
                    i3 = measure.verticalDimension;
                } else {
                    measure.horizontalBehavior = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                    ((ConstraintLayout.Measurer) measurer).measure(constraintWidget, measure);
                    i3 = measure.measuredHeight;
                }
                measure.horizontalBehavior = dimensionBehaviour4;
                measure.horizontalDimension = (int) (constraintWidget.mDimensionRatio * ((float) i3));
            }
        }
        if (z4) {
            if (constraintWidget.mResolvedMatchConstraintDefault[1] == 4) {
                measure.verticalBehavior = ConstraintWidget.DimensionBehaviour.FIXED;
            } else if (!z) {
                ConstraintWidget.DimensionBehaviour dimensionBehaviour5 = measure.horizontalBehavior;
                ConstraintWidget.DimensionBehaviour dimensionBehaviour6 = ConstraintWidget.DimensionBehaviour.FIXED;
                if (dimensionBehaviour5 == dimensionBehaviour6) {
                    i2 = measure.horizontalDimension;
                } else {
                    measure.verticalBehavior = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                    ((ConstraintLayout.Measurer) measurer).measure(constraintWidget, measure);
                    i2 = measure.measuredWidth;
                }
                measure.verticalBehavior = dimensionBehaviour6;
                if (constraintWidget.mDimensionRatioSide == -1) {
                    measure.verticalDimension = (int) (((float) i2) / constraintWidget.mDimensionRatio);
                } else {
                    measure.verticalDimension = (int) (constraintWidget.mDimensionRatio * ((float) i2));
                }
            }
        }
        ((ConstraintLayout.Measurer) measurer).measure(constraintWidget, measure);
        constraintWidget.setWidth(measure.measuredWidth);
        constraintWidget.setHeight(measure.measuredHeight);
        constraintWidget.hasBaseline = measure.measuredHasBaseline;
        constraintWidget.setBaselineDistance(measure.measuredBaseline);
        measure.measureStrategy = 0;
        return measure.measuredNeedsSolverPass;
    }

    public void addChain(ConstraintWidget constraintWidget, int i) {
        if (i == 0) {
            int i2 = this.mHorizontalChainsSize + 1;
            ChainHead[] chainHeadArr = this.mHorizontalChainsArray;
            if (i2 >= chainHeadArr.length) {
                this.mHorizontalChainsArray = (ChainHead[]) Arrays.copyOf(chainHeadArr, chainHeadArr.length * 2);
            }
            ChainHead[] chainHeadArr2 = this.mHorizontalChainsArray;
            int i3 = this.mHorizontalChainsSize;
            chainHeadArr2[i3] = new ChainHead(constraintWidget, 0, this.mIsRtl);
            this.mHorizontalChainsSize = i3 + 1;
        } else if (i == 1) {
            int i4 = this.mVerticalChainsSize + 1;
            ChainHead[] chainHeadArr3 = this.mVerticalChainsArray;
            if (i4 >= chainHeadArr3.length) {
                this.mVerticalChainsArray = (ChainHead[]) Arrays.copyOf(chainHeadArr3, chainHeadArr3.length * 2);
            }
            ChainHead[] chainHeadArr4 = this.mVerticalChainsArray;
            int i5 = this.mVerticalChainsSize;
            chainHeadArr4[i5] = new ChainHead(constraintWidget, 1, this.mIsRtl);
            this.mVerticalChainsSize = i5 + 1;
        }
    }

    public boolean addChildrenToSolver(LinearSystem linearSystem) {
        boolean z;
        boolean optimizeFor = optimizeFor(64);
        addToSolver(linearSystem, optimizeFor);
        int size = this.mChildren.size();
        boolean z2 = false;
        for (int i = 0; i < size; i++) {
            ConstraintWidget constraintWidget = this.mChildren.get(i);
            boolean[] zArr = constraintWidget.mIsInBarrier;
            zArr[0] = false;
            zArr[1] = false;
            if (constraintWidget instanceof Barrier) {
                z2 = true;
            }
        }
        if (z2) {
            for (int i2 = 0; i2 < size; i2++) {
                ConstraintWidget constraintWidget2 = this.mChildren.get(i2);
                if (constraintWidget2 instanceof Barrier) {
                    Barrier barrier = (Barrier) constraintWidget2;
                    for (int i3 = 0; i3 < barrier.mWidgetsCount; i3++) {
                        ConstraintWidget constraintWidget3 = barrier.mWidgets[i3];
                        if (barrier.mAllowsGoneWidget || constraintWidget3.allowedInBarrier()) {
                            int i4 = barrier.mBarrierType;
                            if (i4 == 0 || i4 == 1) {
                                constraintWidget3.mIsInBarrier[0] = true;
                            } else if (i4 == 2 || i4 == 3) {
                                constraintWidget3.mIsInBarrier[1] = true;
                            }
                        }
                    }
                }
            }
        }
        this.widgetsToAdd.clear();
        for (int i5 = 0; i5 < size; i5++) {
            ConstraintWidget constraintWidget4 = this.mChildren.get(i5);
            if (constraintWidget4.addFirst()) {
                if (constraintWidget4 instanceof VirtualLayout) {
                    this.widgetsToAdd.add(constraintWidget4);
                } else {
                    constraintWidget4.addToSolver(linearSystem, optimizeFor);
                }
            }
        }
        while (this.widgetsToAdd.size() > 0) {
            int size2 = this.widgetsToAdd.size();
            Iterator<ConstraintWidget> it = this.widgetsToAdd.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                VirtualLayout virtualLayout = (VirtualLayout) it.next();
                HashSet<ConstraintWidget> hashSet = this.widgetsToAdd;
                int i6 = 0;
                while (true) {
                    if (i6 >= virtualLayout.mWidgetsCount) {
                        z = false;
                        continue;
                        break;
                    } else if (hashSet.contains(virtualLayout.mWidgets[i6])) {
                        z = true;
                        continue;
                        break;
                    } else {
                        i6++;
                    }
                }
                if (z) {
                    virtualLayout.addToSolver(linearSystem, optimizeFor);
                    this.widgetsToAdd.remove(virtualLayout);
                    break;
                }
            }
            if (size2 == this.widgetsToAdd.size()) {
                Iterator<ConstraintWidget> it2 = this.widgetsToAdd.iterator();
                while (it2.hasNext()) {
                    it2.next().addToSolver(linearSystem, optimizeFor);
                }
                this.widgetsToAdd.clear();
            }
        }
        if (LinearSystem.USE_DEPENDENCY_ORDERING) {
            HashSet<ConstraintWidget> hashSet2 = new HashSet<>();
            for (int i7 = 0; i7 < size; i7++) {
                ConstraintWidget constraintWidget5 = this.mChildren.get(i7);
                if (!constraintWidget5.addFirst()) {
                    hashSet2.add(constraintWidget5);
                }
            }
            addChildrenToSolverByDependency(this, linearSystem, hashSet2, getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT ? 0 : 1, false);
            Iterator<ConstraintWidget> it3 = hashSet2.iterator();
            while (it3.hasNext()) {
                ConstraintWidget next = it3.next();
                Optimizer.checkMatchParent(this, linearSystem, next);
                next.addToSolver(linearSystem, optimizeFor);
            }
        } else {
            for (int i8 = 0; i8 < size; i8++) {
                ConstraintWidget constraintWidget6 = this.mChildren.get(i8);
                if (constraintWidget6 instanceof ConstraintWidgetContainer) {
                    ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr = constraintWidget6.mListDimensionBehaviors;
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour = dimensionBehaviourArr[0];
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = dimensionBehaviourArr[1];
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                    if (dimensionBehaviour == dimensionBehaviour3) {
                        constraintWidget6.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                    }
                    if (dimensionBehaviour2 == dimensionBehaviour3) {
                        constraintWidget6.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                    }
                    constraintWidget6.addToSolver(linearSystem, optimizeFor);
                    if (dimensionBehaviour == dimensionBehaviour3) {
                        constraintWidget6.setHorizontalDimensionBehaviour(dimensionBehaviour);
                    }
                    if (dimensionBehaviour2 == dimensionBehaviour3) {
                        constraintWidget6.setVerticalDimensionBehaviour(dimensionBehaviour2);
                    }
                } else {
                    Optimizer.checkMatchParent(this, linearSystem, constraintWidget6);
                    if (!constraintWidget6.addFirst()) {
                        constraintWidget6.addToSolver(linearSystem, optimizeFor);
                    }
                }
            }
        }
        if (this.mHorizontalChainsSize > 0) {
            AppCompatDelegateImpl.Api17Impl.applyChainConstraints(this, linearSystem, null, 0);
        }
        if (this.mVerticalChainsSize > 0) {
            AppCompatDelegateImpl.Api17Impl.applyChainConstraints(this, linearSystem, null, 1);
        }
        return true;
    }

    public void addHorizontalWrapMaxVariable(ConstraintAnchor constraintAnchor) {
        WeakReference<ConstraintAnchor> weakReference = this.horizontalWrapMax;
        if (weakReference == null || weakReference.get() == null || constraintAnchor.getFinalValue() > this.horizontalWrapMax.get().getFinalValue()) {
            this.horizontalWrapMax = new WeakReference<>(constraintAnchor);
        }
    }

    public void addHorizontalWrapMinVariable(ConstraintAnchor constraintAnchor) {
        WeakReference<ConstraintAnchor> weakReference = this.horizontalWrapMin;
        if (weakReference == null || weakReference.get() == null || constraintAnchor.getFinalValue() > this.horizontalWrapMin.get().getFinalValue()) {
            this.horizontalWrapMin = new WeakReference<>(constraintAnchor);
        }
    }

    public void addVerticalWrapMaxVariable(ConstraintAnchor constraintAnchor) {
        WeakReference<ConstraintAnchor> weakReference = this.verticalWrapMax;
        if (weakReference == null || weakReference.get() == null || constraintAnchor.getFinalValue() > this.verticalWrapMax.get().getFinalValue()) {
            this.verticalWrapMax = new WeakReference<>(constraintAnchor);
        }
    }

    public void addVerticalWrapMinVariable(ConstraintAnchor constraintAnchor) {
        WeakReference<ConstraintAnchor> weakReference = this.verticalWrapMin;
        if (weakReference == null || weakReference.get() == null || constraintAnchor.getFinalValue() > this.verticalWrapMin.get().getFinalValue()) {
            this.verticalWrapMin = new WeakReference<>(constraintAnchor);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:38:0x00f1  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x0117  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x0144 A[EDGE_INSN: B:77:0x0144->B:62:0x0144 ?: BREAK  , SYNTHETIC] */
    public boolean directMeasureWithOrientation(boolean z, int i) {
        boolean z2;
        Iterator<WidgetRun> it;
        Iterator<WidgetRun> it2;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour;
        DependencyGraph dependencyGraph = this.mDependencyGraph;
        boolean z3 = true;
        boolean z4 = z & true;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = dependencyGraph.container.getDimensionBehaviour(0);
        ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = dependencyGraph.container.getDimensionBehaviour(1);
        int x = dependencyGraph.container.getX();
        int y = dependencyGraph.container.getY();
        if (z4 && (dimensionBehaviour2 == (dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) || dimensionBehaviour3 == dimensionBehaviour)) {
            Iterator<WidgetRun> it3 = dependencyGraph.mRuns.iterator();
            while (true) {
                if (!it3.hasNext()) {
                    break;
                }
                WidgetRun next = it3.next();
                if (next.orientation == i && !next.supportsWrapComputation()) {
                    z4 = false;
                    break;
                }
            }
            if (i == 0) {
                if (z4 && dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                    dependencyGraph.container.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                    ConstraintWidgetContainer constraintWidgetContainer = dependencyGraph.container;
                    constraintWidgetContainer.setWidth(dependencyGraph.computeWrap(constraintWidgetContainer, 0));
                    ConstraintWidgetContainer constraintWidgetContainer2 = dependencyGraph.container;
                    constraintWidgetContainer2.horizontalRun.dimension.resolve(constraintWidgetContainer2.getWidth());
                }
            } else if (z4 && dimensionBehaviour3 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                dependencyGraph.container.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                ConstraintWidgetContainer constraintWidgetContainer3 = dependencyGraph.container;
                constraintWidgetContainer3.setHeight(dependencyGraph.computeWrap(constraintWidgetContainer3, 1));
                ConstraintWidgetContainer constraintWidgetContainer4 = dependencyGraph.container;
                constraintWidgetContainer4.verticalRun.dimension.resolve(constraintWidgetContainer4.getHeight());
            }
        }
        if (i == 0) {
            ConstraintWidgetContainer constraintWidgetContainer5 = dependencyGraph.container;
            ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr = constraintWidgetContainer5.mListDimensionBehaviors;
            if (dimensionBehaviourArr[0] == ConstraintWidget.DimensionBehaviour.FIXED || dimensionBehaviourArr[0] == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                int width = constraintWidgetContainer5.getWidth() + x;
                dependencyGraph.container.horizontalRun.end.resolve(width);
                dependencyGraph.container.horizontalRun.dimension.resolve(width - x);
                z2 = true;
                dependencyGraph.measureWidgets();
                it = dependencyGraph.mRuns.iterator();
                while (it.hasNext()) {
                    WidgetRun next2 = it.next();
                    if (next2.orientation == i && (next2.widget != dependencyGraph.container || next2.resolved)) {
                        next2.applyToWidget();
                    }
                }
                it2 = dependencyGraph.mRuns.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                        break;
                    }
                    WidgetRun next3 = it2.next();
                    if (next3.orientation == i && ((z2 || next3.widget != dependencyGraph.container) && (!next3.start.resolved || !next3.end.resolved || (!(next3 instanceof ChainRun) && !next3.dimension.resolved)))) {
                        z3 = false;
                    }
                }
                z3 = false;
                dependencyGraph.container.setHorizontalDimensionBehaviour(dimensionBehaviour2);
                dependencyGraph.container.setVerticalDimensionBehaviour(dimensionBehaviour3);
                return z3;
            }
        } else {
            ConstraintWidgetContainer constraintWidgetContainer6 = dependencyGraph.container;
            ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr2 = constraintWidgetContainer6.mListDimensionBehaviors;
            if (dimensionBehaviourArr2[1] == ConstraintWidget.DimensionBehaviour.FIXED || dimensionBehaviourArr2[1] == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                int height = constraintWidgetContainer6.getHeight() + y;
                dependencyGraph.container.verticalRun.end.resolve(height);
                dependencyGraph.container.verticalRun.dimension.resolve(height - y);
                z2 = true;
                dependencyGraph.measureWidgets();
                it = dependencyGraph.mRuns.iterator();
                while (it.hasNext()) {
                }
                it2 = dependencyGraph.mRuns.iterator();
                while (true) {
                    if (!it2.hasNext()) {
                    }
                }
                z3 = false;
                dependencyGraph.container.setHorizontalDimensionBehaviour(dimensionBehaviour2);
                dependencyGraph.container.setVerticalDimensionBehaviour(dimensionBehaviour3);
                return z3;
            }
        }
        z2 = false;
        dependencyGraph.measureWidgets();
        it = dependencyGraph.mRuns.iterator();
        while (it.hasNext()) {
        }
        it2 = dependencyGraph.mRuns.iterator();
        while (true) {
            if (!it2.hasNext()) {
            }
        }
        z3 = false;
        dependencyGraph.container.setHorizontalDimensionBehaviour(dimensionBehaviour2);
        dependencyGraph.container.setVerticalDimensionBehaviour(dimensionBehaviour3);
        return z3;
    }

    public void invalidateGraph() {
        this.mDependencyGraph.mNeedBuildGraph = true;
    }

    /* JADX WARN: Type inference failed for: r12v3, types: [boolean] */
    /* JADX WARN: Type inference failed for: r12v7 */
    /* JADX WARN: Type inference failed for: r12v8 */
    /* JADX WARNING: Removed duplicated region for block: B:329:0x05a5  */
    /* JADX WARNING: Removed duplicated region for block: B:356:0x0601  */
    /* JADX WARNING: Removed duplicated region for block: B:361:0x0617  */
    /* JADX WARNING: Removed duplicated region for block: B:369:0x0636  */
    /* JADX WARNING: Removed duplicated region for block: B:379:0x065d  */
    /* JADX WARNING: Removed duplicated region for block: B:385:0x0672  */
    /* JADX WARNING: Removed duplicated region for block: B:391:0x068f  */
    /* JADX WARNING: Removed duplicated region for block: B:431:0x078a  */
    /* JADX WARNING: Removed duplicated region for block: B:443:0x07d1  */
    /* JADX WARNING: Removed duplicated region for block: B:454:0x07fe A[LOOP:32: B:453:0x07fc->B:454:0x07fe, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:466:0x0867  */
    /* JADX WARNING: Removed duplicated region for block: B:469:0x0884  */
    /* JADX WARNING: Removed duplicated region for block: B:470:0x0892  */
    /* JADX WARNING: Removed duplicated region for block: B:472:0x0895  */
    /* JADX WARNING: Removed duplicated region for block: B:486:0x08d7  */
    /* JADX WARNING: Removed duplicated region for block: B:487:0x08d9  */
    /* JADX WARNING: Removed duplicated region for block: B:491:0x08e4  */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // androidx.constraintlayout.core.widgets.WidgetContainer
    public void layout() {
        int i;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour;
        int i2;
        int i3;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2;
        boolean z;
        ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour3;
        boolean z2;
        int i4;
        int i5;
        boolean z3;
        boolean z4;
        boolean z5;
        int max;
        int max2;
        ?? r12;
        int i6;
        int i7;
        int max3;
        int max4;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour4;
        Exception e;
        int i8;
        int i9;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour5;
        int i10;
        int i11;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour6;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour7;
        WidgetGroup widgetGroup;
        WidgetGroup widgetGroup2;
        boolean z6;
        int measureWrap;
        int measureWrap2;
        int i12;
        int i13;
        this.mX = 0;
        this.mY = 0;
        this.mWidthMeasuredTooSmall = false;
        this.mHeightMeasuredTooSmall = false;
        int size = this.mChildren.size();
        int max5 = Math.max(0, getWidth());
        int max6 = Math.max(0, getHeight());
        ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr = this.mListDimensionBehaviors;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour8 = dimensionBehaviourArr[1];
        ConstraintWidget.DimensionBehaviour dimensionBehaviour9 = dimensionBehaviourArr[0];
        if (this.pass == 0 && Optimizer.enabled(this.mOptimizationLevel, 1)) {
            BasicMeasure.Measurer measurer = this.mMeasurer;
            ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour2 = getHorizontalDimensionBehaviour();
            ConstraintWidget.DimensionBehaviour verticalDimensionBehaviour = getVerticalDimensionBehaviour();
            Direct.hcount = 0;
            Direct.vcount = 0;
            resetFinalResolution();
            ArrayList<ConstraintWidget> arrayList = this.mChildren;
            int size2 = arrayList.size();
            for (int i14 = 0; i14 < size2; i14++) {
                arrayList.get(i14).resetFinalResolution();
            }
            boolean z7 = this.mIsRtl;
            if (horizontalDimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.FIXED) {
                setFinalHorizontal(0, getWidth());
            } else {
                ConstraintAnchor constraintAnchor = this.mLeft;
                constraintAnchor.mFinalValue = 0;
                constraintAnchor.mHasFinalValue = true;
                this.mX = 0;
            }
            boolean z8 = false;
            boolean z9 = false;
            for (int i15 = 0; i15 < size2; i15++) {
                ConstraintWidget constraintWidget = arrayList.get(i15);
                if (constraintWidget instanceof Guideline) {
                    Guideline guideline = (Guideline) constraintWidget;
                    if (guideline.mOrientation == 1) {
                        int i16 = guideline.mRelativeBegin;
                        if (i16 != -1) {
                            guideline.setFinalValue(i16);
                        } else if (guideline.mRelativeEnd != -1 && isResolvedHorizontally()) {
                            guideline.setFinalValue(getWidth() - guideline.mRelativeEnd);
                        } else if (isResolvedHorizontally()) {
                            guideline.setFinalValue((int) ((guideline.mRelativePercent * ((float) getWidth())) + 0.5f));
                        }
                        z8 = true;
                    }
                } else if ((constraintWidget instanceof Barrier) && ((Barrier) constraintWidget).getOrientation() == 0) {
                    z9 = true;
                }
            }
            if (z8) {
                for (int i17 = 0; i17 < size2; i17++) {
                    ConstraintWidget constraintWidget2 = arrayList.get(i17);
                    if (constraintWidget2 instanceof Guideline) {
                        Guideline guideline2 = (Guideline) constraintWidget2;
                        if (guideline2.mOrientation == 1) {
                            Direct.horizontalSolvingPass(0, guideline2, measurer, z7);
                        }
                    }
                }
            }
            Direct.horizontalSolvingPass(0, this, measurer, z7);
            if (z9) {
                for (int i18 = 0; i18 < size2; i18++) {
                    ConstraintWidget constraintWidget3 = arrayList.get(i18);
                    if (constraintWidget3 instanceof Barrier) {
                        Barrier barrier = (Barrier) constraintWidget3;
                        if (barrier.getOrientation() == 0 && barrier.allSolved()) {
                            Direct.horizontalSolvingPass(1, barrier, measurer, z7);
                        }
                    }
                }
            }
            if (verticalDimensionBehaviour == ConstraintWidget.DimensionBehaviour.FIXED) {
                setFinalVertical(0, getHeight());
            } else {
                ConstraintAnchor constraintAnchor2 = this.mTop;
                constraintAnchor2.mFinalValue = 0;
                constraintAnchor2.mHasFinalValue = true;
                this.mY = 0;
            }
            boolean z10 = false;
            boolean z11 = false;
            for (int i19 = 0; i19 < size2; i19++) {
                ConstraintWidget constraintWidget4 = arrayList.get(i19);
                if (constraintWidget4 instanceof Guideline) {
                    Guideline guideline3 = (Guideline) constraintWidget4;
                    if (guideline3.mOrientation == 0) {
                        int i20 = guideline3.mRelativeBegin;
                        if (i20 != -1) {
                            guideline3.setFinalValue(i20);
                        } else if (guideline3.mRelativeEnd != -1 && isResolvedVertically()) {
                            guideline3.setFinalValue(getHeight() - guideline3.mRelativeEnd);
                        } else if (isResolvedVertically()) {
                            guideline3.setFinalValue((int) ((guideline3.mRelativePercent * ((float) getHeight())) + 0.5f));
                        }
                        z10 = true;
                    }
                } else if ((constraintWidget4 instanceof Barrier) && ((Barrier) constraintWidget4).getOrientation() == 1) {
                    z11 = true;
                }
            }
            if (z10) {
                for (int i21 = 0; i21 < size2; i21++) {
                    ConstraintWidget constraintWidget5 = arrayList.get(i21);
                    if (constraintWidget5 instanceof Guideline) {
                        Guideline guideline4 = (Guideline) constraintWidget5;
                        if (guideline4.mOrientation == 0) {
                            Direct.verticalSolvingPass(1, guideline4, measurer);
                        }
                    }
                }
            }
            Direct.verticalSolvingPass(0, this, measurer);
            if (z11) {
                for (int i22 = 0; i22 < size2; i22++) {
                    ConstraintWidget constraintWidget6 = arrayList.get(i22);
                    if (constraintWidget6 instanceof Barrier) {
                        Barrier barrier2 = (Barrier) constraintWidget6;
                        if (barrier2.getOrientation() == 1 && barrier2.allSolved()) {
                            Direct.verticalSolvingPass(1, barrier2, measurer);
                        }
                    }
                }
            }
            for (int i23 = 0; i23 < size2; i23++) {
                ConstraintWidget constraintWidget7 = arrayList.get(i23);
                if (constraintWidget7.isMeasureRequested() && Direct.canMeasure(constraintWidget7)) {
                    measure(constraintWidget7, measurer, Direct.measure, 0);
                    if (!(constraintWidget7 instanceof Guideline)) {
                        Direct.horizontalSolvingPass(0, constraintWidget7, measurer, z7);
                        Direct.verticalSolvingPass(0, constraintWidget7, measurer);
                    } else if (((Guideline) constraintWidget7).mOrientation == 0) {
                        Direct.verticalSolvingPass(0, constraintWidget7, measurer);
                    } else {
                        Direct.horizontalSolvingPass(0, constraintWidget7, measurer, z7);
                    }
                }
            }
            for (int i24 = 0; i24 < size; i24++) {
                ConstraintWidget constraintWidget8 = this.mChildren.get(i24);
                if (constraintWidget8.isMeasureRequested() && !(constraintWidget8 instanceof Guideline) && !(constraintWidget8 instanceof Barrier) && !(constraintWidget8 instanceof VirtualLayout) && !constraintWidget8.mInVirtualLayout) {
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour10 = constraintWidget8.getDimensionBehaviour(0);
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour11 = constraintWidget8.getDimensionBehaviour(1);
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour12 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                    if (!(dimensionBehaviour10 == dimensionBehaviour12 && constraintWidget8.mMatchConstraintDefaultWidth != 1 && dimensionBehaviour11 == dimensionBehaviour12 && constraintWidget8.mMatchConstraintDefaultHeight != 1)) {
                        measure(constraintWidget8, this.mMeasurer, new BasicMeasure.Measure(), 0);
                    }
                }
            }
        }
        if (size <= 2 || (!(dimensionBehaviour9 == (dimensionBehaviour5 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) || dimensionBehaviour8 == dimensionBehaviour5) || !Optimizer.enabled(this.mOptimizationLevel, 1024))) {
            i = size;
            i8 = max6;
            dimensionBehaviour2 = dimensionBehaviour9;
            dimensionBehaviour = dimensionBehaviour8;
            i9 = max5;
        } else {
            BasicMeasure.Measurer measurer2 = this.mMeasurer;
            ArrayList<ConstraintWidget> arrayList2 = this.mChildren;
            int size3 = arrayList2.size();
            int i25 = 0;
            while (true) {
                if (i25 < size3) {
                    ConstraintWidget constraintWidget9 = arrayList2.get(i25);
                    if (AppCompatDelegateImpl.Api17Impl.validInGroup(getHorizontalDimensionBehaviour(), getVerticalDimensionBehaviour(), constraintWidget9.getHorizontalDimensionBehaviour(), constraintWidget9.getVerticalDimensionBehaviour()) && !(constraintWidget9 instanceof Flow)) {
                        i25++;
                    }
                } else {
                    ArrayList arrayList3 = null;
                    int i26 = 0;
                    ArrayList arrayList4 = null;
                    ArrayList arrayList5 = null;
                    ArrayList arrayList6 = null;
                    ArrayList arrayList7 = null;
                    ArrayList arrayList8 = null;
                    while (i26 < size3) {
                        ConstraintWidget constraintWidget10 = arrayList2.get(i26);
                        if (!AppCompatDelegateImpl.Api17Impl.validInGroup(getHorizontalDimensionBehaviour(), getVerticalDimensionBehaviour(), constraintWidget10.getHorizontalDimensionBehaviour(), constraintWidget10.getVerticalDimensionBehaviour())) {
                            measure(constraintWidget10, measurer2, this.mMeasure, 0);
                        }
                        boolean z12 = constraintWidget10 instanceof Guideline;
                        if (z12) {
                            Guideline guideline5 = (Guideline) constraintWidget10;
                            if (guideline5.mOrientation == 0) {
                                if (arrayList5 == null) {
                                    arrayList5 = new ArrayList();
                                }
                                arrayList5.add(guideline5);
                            }
                            if (guideline5.mOrientation == 1) {
                                if (arrayList3 == null) {
                                    arrayList3 = new ArrayList();
                                }
                                arrayList3.add(guideline5);
                            }
                        }
                        if (constraintWidget10 instanceof HelperWidget) {
                            if (constraintWidget10 instanceof Barrier) {
                                Barrier barrier3 = (Barrier) constraintWidget10;
                                if (barrier3.getOrientation() == 0) {
                                    if (arrayList4 == null) {
                                        arrayList4 = new ArrayList();
                                    }
                                    arrayList4.add(barrier3);
                                }
                                if (barrier3.getOrientation() == 1) {
                                    if (arrayList6 == null) {
                                        arrayList6 = new ArrayList();
                                    }
                                    arrayList6.add(barrier3);
                                }
                            } else {
                                HelperWidget helperWidget = (HelperWidget) constraintWidget10;
                                if (arrayList4 == null) {
                                    arrayList4 = new ArrayList();
                                }
                                arrayList4.add(helperWidget);
                                if (arrayList6 == null) {
                                    arrayList6 = new ArrayList();
                                }
                                arrayList6.add(helperWidget);
                            }
                        }
                        if (constraintWidget10.mLeft.mTarget == null && constraintWidget10.mRight.mTarget == null && !z12 && !(constraintWidget10 instanceof Barrier)) {
                            if (arrayList7 == null) {
                                arrayList7 = new ArrayList();
                            }
                            arrayList7.add(constraintWidget10);
                        }
                        if (constraintWidget10.mTop.mTarget == null && constraintWidget10.mBottom.mTarget == null && constraintWidget10.mBaseline.mTarget == null && !z12 && !(constraintWidget10 instanceof Barrier)) {
                            if (arrayList8 == null) {
                                arrayList8 = new ArrayList();
                            }
                            arrayList8.add(constraintWidget10);
                        }
                        i26++;
                        max6 = max6;
                        size = size;
                        dimensionBehaviour8 = dimensionBehaviour8;
                        max5 = max5;
                        dimensionBehaviour9 = dimensionBehaviour9;
                    }
                    i10 = max5;
                    i = size;
                    i11 = max6;
                    dimensionBehaviour6 = dimensionBehaviour9;
                    dimensionBehaviour7 = dimensionBehaviour8;
                    ArrayList<WidgetGroup> arrayList9 = new ArrayList<>();
                    if (arrayList3 != null) {
                        Iterator it = arrayList3.iterator();
                        while (it.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents((Guideline) it.next(), 0, arrayList9, null);
                        }
                    }
                    WidgetGroup widgetGroup3 = null;
                    int i27 = 0;
                    if (arrayList4 != null) {
                        Iterator it2 = arrayList4.iterator();
                        while (it2.hasNext()) {
                            HelperWidget helperWidget2 = (HelperWidget) it2.next();
                            WidgetGroup findDependents = AppCompatDelegateImpl.Api17Impl.findDependents(helperWidget2, i27, arrayList9, widgetGroup3);
                            helperWidget2.addDependents(arrayList9, i27, findDependents);
                            findDependents.cleanup(arrayList9);
                            widgetGroup3 = null;
                            i27 = 0;
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet = getAnchor(ConstraintAnchor.Type.LEFT).mDependents;
                    if (hashSet != null) {
                        Iterator<ConstraintAnchor> it3 = hashSet.iterator();
                        while (it3.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it3.next().mOwner, 0, arrayList9, null);
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet2 = getAnchor(ConstraintAnchor.Type.RIGHT).mDependents;
                    if (hashSet2 != null) {
                        Iterator<ConstraintAnchor> it4 = hashSet2.iterator();
                        while (it4.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it4.next().mOwner, 0, arrayList9, null);
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet3 = getAnchor(ConstraintAnchor.Type.CENTER).mDependents;
                    if (hashSet3 != null) {
                        Iterator<ConstraintAnchor> it5 = hashSet3.iterator();
                        while (it5.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it5.next().mOwner, 0, arrayList9, null);
                        }
                    }
                    WidgetGroup widgetGroup4 = null;
                    if (arrayList7 != null) {
                        Iterator it6 = arrayList7.iterator();
                        while (it6.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents((ConstraintWidget) it6.next(), 0, arrayList9, null);
                        }
                    }
                    if (arrayList5 != null) {
                        Iterator it7 = arrayList5.iterator();
                        while (it7.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents((Guideline) it7.next(), 1, arrayList9, null);
                        }
                    }
                    int i28 = 1;
                    if (arrayList6 != null) {
                        Iterator it8 = arrayList6.iterator();
                        while (it8.hasNext()) {
                            HelperWidget helperWidget3 = (HelperWidget) it8.next();
                            WidgetGroup findDependents2 = AppCompatDelegateImpl.Api17Impl.findDependents(helperWidget3, i28, arrayList9, widgetGroup4);
                            helperWidget3.addDependents(arrayList9, i28, findDependents2);
                            findDependents2.cleanup(arrayList9);
                            widgetGroup4 = null;
                            i28 = 1;
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet4 = getAnchor(ConstraintAnchor.Type.TOP).mDependents;
                    if (hashSet4 != null) {
                        Iterator<ConstraintAnchor> it9 = hashSet4.iterator();
                        while (it9.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it9.next().mOwner, 1, arrayList9, null);
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet5 = getAnchor(ConstraintAnchor.Type.BASELINE).mDependents;
                    if (hashSet5 != null) {
                        Iterator<ConstraintAnchor> it10 = hashSet5.iterator();
                        while (it10.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it10.next().mOwner, 1, arrayList9, null);
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet6 = getAnchor(ConstraintAnchor.Type.BOTTOM).mDependents;
                    if (hashSet6 != null) {
                        Iterator<ConstraintAnchor> it11 = hashSet6.iterator();
                        while (it11.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it11.next().mOwner, 1, arrayList9, null);
                        }
                    }
                    HashSet<ConstraintAnchor> hashSet7 = getAnchor(ConstraintAnchor.Type.CENTER).mDependents;
                    if (hashSet7 != null) {
                        Iterator<ConstraintAnchor> it12 = hashSet7.iterator();
                        while (it12.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents(it12.next().mOwner, 1, arrayList9, null);
                        }
                    }
                    if (arrayList8 != null) {
                        Iterator it13 = arrayList8.iterator();
                        while (it13.hasNext()) {
                            AppCompatDelegateImpl.Api17Impl.findDependents((ConstraintWidget) it13.next(), 1, arrayList9, null);
                        }
                    }
                    for (int i29 = 0; i29 < size3; i29++) {
                        ConstraintWidget constraintWidget11 = arrayList2.get(i29);
                        ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr2 = constraintWidget11.mListDimensionBehaviors;
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour13 = dimensionBehaviourArr2[0];
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour14 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                        if (dimensionBehaviour13 == dimensionBehaviour14 && dimensionBehaviourArr2[1] == dimensionBehaviour14) {
                            WidgetGroup findGroup = AppCompatDelegateImpl.Api17Impl.findGroup(arrayList9, constraintWidget11.horizontalGroup);
                            WidgetGroup findGroup2 = AppCompatDelegateImpl.Api17Impl.findGroup(arrayList9, constraintWidget11.verticalGroup);
                            if (!(findGroup == null || findGroup2 == null)) {
                                findGroup.moveTo(0, findGroup2);
                                findGroup2.orientation = 2;
                                arrayList9.remove(findGroup);
                            }
                        }
                    }
                    if (arrayList9.size() > 1) {
                        if (getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                            Iterator<WidgetGroup> it14 = arrayList9.iterator();
                            widgetGroup = null;
                            int i30 = 0;
                            while (it14.hasNext()) {
                                WidgetGroup next = it14.next();
                                if (next.orientation != 1 && (measureWrap2 = next.measureWrap(this.mSystem, 0)) > i30) {
                                    widgetGroup = next;
                                    i30 = measureWrap2;
                                }
                            }
                            if (widgetGroup != null) {
                                setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                                setWidth(i30);
                                if (getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                                    Iterator<WidgetGroup> it15 = arrayList9.iterator();
                                    widgetGroup2 = null;
                                    int i31 = 0;
                                    while (it15.hasNext()) {
                                        WidgetGroup next2 = it15.next();
                                        if (next2.orientation != 0 && (measureWrap = next2.measureWrap(this.mSystem, 1)) > i31) {
                                            widgetGroup2 = next2;
                                            i31 = measureWrap;
                                        }
                                    }
                                    if (widgetGroup2 != null) {
                                        setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                                        setHeight(i31);
                                        if (!(widgetGroup == null && widgetGroup2 == null)) {
                                            z6 = true;
                                        }
                                    }
                                }
                                widgetGroup2 = null;
                                z6 = true;
                            }
                        }
                        widgetGroup = null;
                        if (getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                        }
                        widgetGroup2 = null;
                        z6 = true;
                    }
                }
            }
            i10 = max5;
            i = size;
            i11 = max6;
            dimensionBehaviour6 = dimensionBehaviour9;
            dimensionBehaviour7 = dimensionBehaviour8;
            z6 = false;
            if (z6) {
                ConstraintWidget.DimensionBehaviour dimensionBehaviour15 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                dimensionBehaviour2 = dimensionBehaviour6;
                if (dimensionBehaviour2 == dimensionBehaviour15) {
                    i13 = i10;
                    if (i13 >= getWidth() || i13 <= 0) {
                        i3 = getWidth();
                        dimensionBehaviour = dimensionBehaviour7;
                        if (dimensionBehaviour != dimensionBehaviour15) {
                            i12 = i11;
                            if (i12 >= getHeight() || i12 <= 0) {
                                i2 = getHeight();
                                z = true;
                                boolean z13 = !optimizeFor(64) || optimizeFor(128);
                                LinearSystem linearSystem = this.mSystem;
                                Objects.requireNonNull(linearSystem);
                                linearSystem.newgraphOptimizer = false;
                                if (this.mOptimizationLevel != 0 && z13) {
                                    linearSystem.newgraphOptimizer = true;
                                }
                                ArrayList<ConstraintWidget> arrayList10 = this.mChildren;
                                horizontalDimensionBehaviour = getHorizontalDimensionBehaviour();
                                dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                if (horizontalDimensionBehaviour != dimensionBehaviour3 || getVerticalDimensionBehaviour() == dimensionBehaviour3) {
                                    i4 = 0;
                                    z2 = true;
                                } else {
                                    i4 = 0;
                                    z2 = false;
                                }
                                this.mHorizontalChainsSize = i4;
                                this.mVerticalChainsSize = i4;
                                for (i5 = 0; i5 < i; i5++) {
                                    ConstraintWidget constraintWidget12 = this.mChildren.get(i5);
                                    if (constraintWidget12 instanceof WidgetContainer) {
                                        ((WidgetContainer) constraintWidget12).layout();
                                    }
                                }
                                boolean optimizeFor = optimizeFor(64);
                                z3 = z;
                                int i32 = 0;
                                z4 = true;
                                while (z4) {
                                    int i33 = i32 + 1;
                                    try {
                                        this.mSystem.reset();
                                        this.mHorizontalChainsSize = 0;
                                        this.mVerticalChainsSize = 0;
                                        createObjectVariables(this.mSystem);
                                        for (int i34 = 0; i34 < i; i34++) {
                                            this.mChildren.get(i34).createObjectVariables(this.mSystem);
                                        }
                                        addChildrenToSolver(this.mSystem);
                                        try {
                                            WeakReference<ConstraintAnchor> weakReference = this.verticalWrapMin;
                                            if (!(weakReference == null || weakReference.get() == null)) {
                                                this.mSystem.addGreaterThan(this.mSystem.createObjectVariable(this.verticalWrapMin.get()), this.mSystem.createObjectVariable(this.mTop), 0, 5);
                                                try {
                                                    this.verticalWrapMin = null;
                                                } catch (Exception e2) {
                                                    e = e2;
                                                    z4 = true;
                                                    e.printStackTrace();
                                                    PrintStream printStream = System.out;
                                                    printStream.println("EXCEPTION : " + e);
                                                    if (!z4) {
                                                    }
                                                    int i35 = 0;
                                                    int i36 = 0;
                                                    while (i7 < i) {
                                                    }
                                                    max3 = Math.max(this.mMinWidth, i36);
                                                    max4 = Math.max(this.mMinHeight, i35);
                                                    dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                                    setWidth(max3);
                                                    this.mListDimensionBehaviors[0] = dimensionBehaviour4;
                                                    z3 = true;
                                                    z5 = true;
                                                    setHeight(max4);
                                                    this.mListDimensionBehaviors[1] = dimensionBehaviour4;
                                                    z3 = true;
                                                    z5 = true;
                                                    max = Math.max(this.mMinWidth, getWidth());
                                                    if (max > getWidth()) {
                                                    }
                                                    max2 = Math.max(this.mMinHeight, getHeight());
                                                    if (max2 <= getHeight()) {
                                                    }
                                                    if (!z3) {
                                                    }
                                                    i6 = 8;
                                                    if (i33 > i6) {
                                                    }
                                                    i32 = i33;
                                                }
                                            }
                                            WeakReference<ConstraintAnchor> weakReference2 = this.verticalWrapMax;
                                            if (!(weakReference2 == null || weakReference2.get() == null)) {
                                                this.mSystem.addGreaterThan(this.mSystem.createObjectVariable(this.mBottom), this.mSystem.createObjectVariable(this.verticalWrapMax.get()), 0, 5);
                                                this.verticalWrapMax = null;
                                            }
                                            WeakReference<ConstraintAnchor> weakReference3 = this.horizontalWrapMin;
                                            if (!(weakReference3 == null || weakReference3.get() == null)) {
                                                this.mSystem.addGreaterThan(this.mSystem.createObjectVariable(this.horizontalWrapMin.get()), this.mSystem.createObjectVariable(this.mLeft), 0, 5);
                                                this.horizontalWrapMin = null;
                                            }
                                            WeakReference<ConstraintAnchor> weakReference4 = this.horizontalWrapMax;
                                            if (weakReference4 != null && weakReference4.get() != null) {
                                                this.mSystem.addGreaterThan(this.mSystem.createObjectVariable(this.mRight), this.mSystem.createObjectVariable(this.horizontalWrapMax.get()), 0, 5);
                                                this.horizontalWrapMax = null;
                                            }
                                            this.mSystem.minimize();
                                            z4 = true;
                                        } catch (Exception e3) {
                                            e = e3;
                                            z4 = true;
                                            e.printStackTrace();
                                            PrintStream printStream2 = System.out;
                                            printStream2.println("EXCEPTION : " + e);
                                            if (!z4) {
                                            }
                                            int i352 = 0;
                                            int i362 = 0;
                                            while (i7 < i) {
                                            }
                                            max3 = Math.max(this.mMinWidth, i362);
                                            max4 = Math.max(this.mMinHeight, i352);
                                            dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                            setWidth(max3);
                                            this.mListDimensionBehaviors[0] = dimensionBehaviour4;
                                            z3 = true;
                                            z5 = true;
                                            setHeight(max4);
                                            this.mListDimensionBehaviors[1] = dimensionBehaviour4;
                                            z3 = true;
                                            z5 = true;
                                            max = Math.max(this.mMinWidth, getWidth());
                                            if (max > getWidth()) {
                                            }
                                            max2 = Math.max(this.mMinHeight, getHeight());
                                            if (max2 <= getHeight()) {
                                            }
                                            if (!z3) {
                                            }
                                            i6 = 8;
                                            if (i33 > i6) {
                                            }
                                            i32 = i33;
                                        }
                                    } catch (Exception e4) {
                                        e = e4;
                                        e.printStackTrace();
                                        PrintStream printStream22 = System.out;
                                        printStream22.println("EXCEPTION : " + e);
                                        if (!z4) {
                                        }
                                        int i3522 = 0;
                                        int i3622 = 0;
                                        while (i7 < i) {
                                        }
                                        max3 = Math.max(this.mMinWidth, i3622);
                                        max4 = Math.max(this.mMinHeight, i3522);
                                        dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                        setWidth(max3);
                                        this.mListDimensionBehaviors[0] = dimensionBehaviour4;
                                        z3 = true;
                                        z5 = true;
                                        setHeight(max4);
                                        this.mListDimensionBehaviors[1] = dimensionBehaviour4;
                                        z3 = true;
                                        z5 = true;
                                        max = Math.max(this.mMinWidth, getWidth());
                                        if (max > getWidth()) {
                                        }
                                        max2 = Math.max(this.mMinHeight, getHeight());
                                        if (max2 <= getHeight()) {
                                        }
                                        if (!z3) {
                                        }
                                        i6 = 8;
                                        if (i33 > i6) {
                                        }
                                        i32 = i33;
                                    }
                                    if (!z4) {
                                        LinearSystem linearSystem2 = this.mSystem;
                                        Optimizer.flags[2] = false;
                                        boolean optimizeFor2 = optimizeFor(64);
                                        updateFromSolver(linearSystem2, optimizeFor2);
                                        int size4 = this.mChildren.size();
                                        int i37 = 0;
                                        z5 = false;
                                        while (i37 < size4) {
                                            ConstraintWidget constraintWidget13 = this.mChildren.get(i37);
                                            constraintWidget13.updateFromSolver(linearSystem2, optimizeFor2);
                                            if ((constraintWidget13.mWidthOverride == -1 && constraintWidget13.mHeightOverride == -1) ? false : true) {
                                                z5 = true;
                                            }
                                            i37++;
                                            linearSystem2 = linearSystem2;
                                            optimizeFor2 = optimizeFor2;
                                        }
                                    } else {
                                        updateFromSolver(this.mSystem, optimizeFor);
                                        for (int i38 = 0; i38 < i; i38++) {
                                            this.mChildren.get(i38).updateFromSolver(this.mSystem, optimizeFor);
                                        }
                                        z5 = false;
                                    }
                                    if (z2 && i33 < 8 && Optimizer.flags[2]) {
                                        int i35222 = 0;
                                        int i36222 = 0;
                                        for (i7 = 0; i7 < i; i7++) {
                                            ConstraintWidget constraintWidget14 = this.mChildren.get(i7);
                                            i36222 = Math.max(i36222, constraintWidget14.getWidth() + constraintWidget14.mX);
                                            i35222 = Math.max(i35222, constraintWidget14.getHeight() + constraintWidget14.mY);
                                        }
                                        max3 = Math.max(this.mMinWidth, i36222);
                                        max4 = Math.max(this.mMinHeight, i35222);
                                        dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                        if (dimensionBehaviour2 == dimensionBehaviour4 && getWidth() < max3) {
                                            setWidth(max3);
                                            this.mListDimensionBehaviors[0] = dimensionBehaviour4;
                                            z3 = true;
                                            z5 = true;
                                        }
                                        if (dimensionBehaviour == dimensionBehaviour4 && getHeight() < max4) {
                                            setHeight(max4);
                                            this.mListDimensionBehaviors[1] = dimensionBehaviour4;
                                            z3 = true;
                                            z5 = true;
                                        }
                                    }
                                    max = Math.max(this.mMinWidth, getWidth());
                                    if (max > getWidth()) {
                                        setWidth(max);
                                        this.mListDimensionBehaviors[0] = ConstraintWidget.DimensionBehaviour.FIXED;
                                        z3 = true;
                                        z5 = true;
                                    }
                                    max2 = Math.max(this.mMinHeight, getHeight());
                                    if (max2 <= getHeight()) {
                                        setHeight(max2);
                                        r12 = 1;
                                        this.mListDimensionBehaviors[1] = ConstraintWidget.DimensionBehaviour.FIXED;
                                        z3 = true;
                                        z5 = true;
                                    } else {
                                        r12 = 1;
                                    }
                                    if (!z3) {
                                        ConstraintWidget.DimensionBehaviour dimensionBehaviour16 = this.mListDimensionBehaviors[0];
                                        ConstraintWidget.DimensionBehaviour dimensionBehaviour17 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                        if (dimensionBehaviour16 == dimensionBehaviour17 && i3 > 0 && getWidth() > i3) {
                                            this.mWidthMeasuredTooSmall = r12;
                                            this.mListDimensionBehaviors[0] = ConstraintWidget.DimensionBehaviour.FIXED;
                                            setWidth(i3);
                                            z3 = true;
                                            z5 = true;
                                        }
                                        ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr3 = this.mListDimensionBehaviors;
                                        char c = r12 == true ? 1 : 0;
                                        char c2 = r12 == true ? 1 : 0;
                                        char c3 = r12 == true ? 1 : 0;
                                        if (dimensionBehaviourArr3[c] == dimensionBehaviour17 && i2 > 0 && getHeight() > i2) {
                                            this.mHeightMeasuredTooSmall = r12;
                                            this.mListDimensionBehaviors[r12] = ConstraintWidget.DimensionBehaviour.FIXED;
                                            setHeight(i2);
                                            i6 = 8;
                                            z3 = true;
                                            z5 = true;
                                            z4 = i33 > i6 ? false : z5;
                                            i32 = i33;
                                        }
                                    }
                                    i6 = 8;
                                    if (i33 > i6) {
                                    }
                                    i32 = i33;
                                }
                                this.mChildren = arrayList10;
                                if (z3) {
                                    ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr4 = this.mListDimensionBehaviors;
                                    dimensionBehaviourArr4[0] = dimensionBehaviour2;
                                    dimensionBehaviourArr4[1] = dimensionBehaviour;
                                }
                                resetSolverVariables(this.mSystem.mCache);
                            }
                            setHeight(i12);
                            this.mHeightMeasuredTooSmall = true;
                        } else {
                            i12 = i11;
                        }
                        i2 = i12;
                        z = true;
                        if (!optimizeFor(64)) {
                        }
                        LinearSystem linearSystem3 = this.mSystem;
                        Objects.requireNonNull(linearSystem3);
                        linearSystem3.newgraphOptimizer = false;
                        linearSystem3.newgraphOptimizer = true;
                        ArrayList<ConstraintWidget> arrayList102 = this.mChildren;
                        horizontalDimensionBehaviour = getHorizontalDimensionBehaviour();
                        dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                        if (horizontalDimensionBehaviour != dimensionBehaviour3) {
                        }
                        i4 = 0;
                        z2 = true;
                        this.mHorizontalChainsSize = i4;
                        this.mVerticalChainsSize = i4;
                        while (i5 < i) {
                        }
                        boolean optimizeFor3 = optimizeFor(64);
                        z3 = z;
                        int i322 = 0;
                        z4 = true;
                        while (z4) {
                        }
                        this.mChildren = arrayList102;
                        if (z3) {
                        }
                        resetSolverVariables(this.mSystem.mCache);
                    }
                    setWidth(i13);
                    this.mWidthMeasuredTooSmall = true;
                } else {
                    i13 = i10;
                }
                i3 = i13;
                dimensionBehaviour = dimensionBehaviour7;
                if (dimensionBehaviour != dimensionBehaviour15) {
                }
                i2 = i12;
                z = true;
                if (!optimizeFor(64)) {
                }
                LinearSystem linearSystem32 = this.mSystem;
                Objects.requireNonNull(linearSystem32);
                linearSystem32.newgraphOptimizer = false;
                linearSystem32.newgraphOptimizer = true;
                ArrayList<ConstraintWidget> arrayList1022 = this.mChildren;
                horizontalDimensionBehaviour = getHorizontalDimensionBehaviour();
                dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                if (horizontalDimensionBehaviour != dimensionBehaviour3) {
                }
                i4 = 0;
                z2 = true;
                this.mHorizontalChainsSize = i4;
                this.mVerticalChainsSize = i4;
                while (i5 < i) {
                }
                boolean optimizeFor32 = optimizeFor(64);
                z3 = z;
                int i3222 = 0;
                z4 = true;
                while (z4) {
                }
                this.mChildren = arrayList1022;
                if (z3) {
                }
                resetSolverVariables(this.mSystem.mCache);
            }
            i8 = i11;
            dimensionBehaviour = dimensionBehaviour7;
            i9 = i10;
            dimensionBehaviour2 = dimensionBehaviour6;
        }
        i3 = i9;
        i2 = i8;
        z = false;
        if (!optimizeFor(64)) {
        }
        LinearSystem linearSystem322 = this.mSystem;
        Objects.requireNonNull(linearSystem322);
        linearSystem322.newgraphOptimizer = false;
        linearSystem322.newgraphOptimizer = true;
        ArrayList<ConstraintWidget> arrayList10222 = this.mChildren;
        horizontalDimensionBehaviour = getHorizontalDimensionBehaviour();
        dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
        if (horizontalDimensionBehaviour != dimensionBehaviour3) {
        }
        i4 = 0;
        z2 = true;
        this.mHorizontalChainsSize = i4;
        this.mVerticalChainsSize = i4;
        while (i5 < i) {
        }
        boolean optimizeFor322 = optimizeFor(64);
        z3 = z;
        int i32222 = 0;
        z4 = true;
        while (z4) {
        }
        this.mChildren = arrayList10222;
        if (z3) {
        }
        resetSolverVariables(this.mSystem.mCache);
    }

    public boolean optimizeFor(int i) {
        return (this.mOptimizationLevel & i) == i;
    }

    @Override // androidx.constraintlayout.core.widgets.ConstraintWidget, androidx.constraintlayout.core.widgets.WidgetContainer
    public void reset() {
        this.mSystem.reset();
        this.mPaddingLeft = 0;
        this.mPaddingTop = 0;
        super.reset();
    }

    public void setMeasurer(BasicMeasure.Measurer measurer) {
        this.mMeasurer = measurer;
        this.mDependencyGraph.mMeasurer = measurer;
    }

    public void setOptimizationLevel(int i) {
        this.mOptimizationLevel = i;
        LinearSystem.USE_DEPENDENCY_ORDERING = optimizeFor(512);
    }

    @Override // androidx.constraintlayout.core.widgets.ConstraintWidget
    public void updateFromRuns(boolean z, boolean z2) {
        super.updateFromRuns(z, z2);
        int size = this.mChildren.size();
        for (int i = 0; i < size; i++) {
            this.mChildren.get(i).updateFromRuns(z, z2);
        }
    }
}
