package androidx.constraintlayout.helper.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.constraintlayout.motion.widget.KeyAttributes;
import androidx.constraintlayout.motion.widget.KeyPosition;
import androidx.constraintlayout.motion.widget.MotionController;
import androidx.constraintlayout.motion.widget.MotionHelper;
import androidx.constraintlayout.motion.widget.MotionLayout;
import androidx.constraintlayout.motion.widget.MotionPaths;
import androidx.constraintlayout.motion.widget.MotionScene;
import androidx.constraintlayout.motion.widget.ViewTransition;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.constraintlayout.widget.R$styleable;
import java.util.HashMap;
import java.util.Iterator;

public class MotionEffect extends MotionHelper {
    public int fadeMove = -1;
    public float motionEffectAlpha = 0.1f;
    public int motionEffectEnd = 50;
    public int motionEffectStart = 49;
    public boolean motionEffectStrictMove = true;
    public int motionEffectTranslationX = 0;
    public int motionEffectTranslationY = 0;
    public int viewTransitionId = -1;

    public MotionEffect(Context context) {
        super(context);
    }

    public final void init(Context context, AttributeSet attributeSet) {
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.MotionEffect);
            int indexCount = obtainStyledAttributes.getIndexCount();
            for (int i = 0; i < indexCount; i++) {
                int index = obtainStyledAttributes.getIndex(i);
                if (index == R$styleable.MotionEffect_motionEffect_start) {
                    int i2 = obtainStyledAttributes.getInt(index, this.motionEffectStart);
                    this.motionEffectStart = i2;
                    this.motionEffectStart = Math.max(Math.min(i2, 99), 0);
                } else if (index == R$styleable.MotionEffect_motionEffect_end) {
                    int i3 = obtainStyledAttributes.getInt(index, this.motionEffectEnd);
                    this.motionEffectEnd = i3;
                    this.motionEffectEnd = Math.max(Math.min(i3, 99), 0);
                } else if (index == R$styleable.MotionEffect_motionEffect_translationX) {
                    this.motionEffectTranslationX = obtainStyledAttributes.getDimensionPixelOffset(index, this.motionEffectTranslationX);
                } else if (index == R$styleable.MotionEffect_motionEffect_translationY) {
                    this.motionEffectTranslationY = obtainStyledAttributes.getDimensionPixelOffset(index, this.motionEffectTranslationY);
                } else if (index == R$styleable.MotionEffect_motionEffect_alpha) {
                    this.motionEffectAlpha = obtainStyledAttributes.getFloat(index, this.motionEffectAlpha);
                } else if (index == R$styleable.MotionEffect_motionEffect_move) {
                    this.fadeMove = obtainStyledAttributes.getInt(index, this.fadeMove);
                } else if (index == R$styleable.MotionEffect_motionEffect_strict) {
                    this.motionEffectStrictMove = obtainStyledAttributes.getBoolean(index, this.motionEffectStrictMove);
                } else if (index == R$styleable.MotionEffect_motionEffect_viewTransition) {
                    this.viewTransitionId = obtainStyledAttributes.getResourceId(index, this.viewTransitionId);
                }
            }
            int i4 = this.motionEffectStart;
            int i5 = this.motionEffectEnd;
            if (i4 == i5) {
                if (i4 > 0) {
                    this.motionEffectStart = i4 - 1;
                } else {
                    this.motionEffectEnd = i5 + 1;
                }
            }
            obtainStyledAttributes.recycle();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:64:0x019b, code lost:
        if (r14 == 0.0f) goto L_0x019d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x01af, code lost:
        if (r1 == 0.0f) goto L_0x019d;
     */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x01c6  */
    @Override // androidx.constraintlayout.motion.widget.MotionHelper
    public void onPreSetup(MotionLayout motionLayout, HashMap<View, MotionController> hashMap) {
        KeyAttributes keyAttributes;
        KeyAttributes keyAttributes2;
        KeyAttributes keyAttributes3;
        KeyAttributes keyAttributes4;
        KeyAttributes keyAttributes5;
        boolean z;
        KeyAttributes keyAttributes6;
        int i;
        MotionEffect motionEffect = this;
        HashMap<View, MotionController> hashMap2 = hashMap;
        View[] views = motionEffect.getViews((ConstraintLayout) getParent());
        if (views == null) {
            Log.v("FadeMove", AppCompatDelegateImpl.Api17Impl.getLoc() + " views = null");
            return;
        }
        KeyAttributes keyAttributes7 = new KeyAttributes();
        KeyAttributes keyAttributes8 = new KeyAttributes();
        keyAttributes7.setValue("alpha", Float.valueOf(motionEffect.motionEffectAlpha));
        keyAttributes8.setValue("alpha", Float.valueOf(motionEffect.motionEffectAlpha));
        int i2 = motionEffect.motionEffectStart;
        keyAttributes7.mFramePosition = i2;
        keyAttributes8.mFramePosition = motionEffect.motionEffectEnd;
        KeyPosition keyPosition = new KeyPosition();
        keyPosition.mFramePosition = i2;
        keyPosition.mPositionType = 0;
        keyPosition.setValue("percentX", 0);
        keyPosition.setValue("percentY", 0);
        KeyPosition keyPosition2 = new KeyPosition();
        keyPosition2.mFramePosition = motionEffect.motionEffectEnd;
        keyPosition2.mPositionType = 0;
        keyPosition2.setValue("percentX", 1);
        keyPosition2.setValue("percentY", 1);
        KeyAttributes keyAttributes9 = null;
        if (motionEffect.motionEffectTranslationX > 0) {
            keyAttributes2 = new KeyAttributes();
            keyAttributes = new KeyAttributes();
            keyAttributes2.setValue("translationX", Integer.valueOf(motionEffect.motionEffectTranslationX));
            keyAttributes2.mFramePosition = motionEffect.motionEffectEnd;
            keyAttributes.setValue("translationX", 0);
            keyAttributes.mFramePosition = motionEffect.motionEffectEnd - 1;
        } else {
            keyAttributes2 = null;
            keyAttributes = null;
        }
        if (motionEffect.motionEffectTranslationY > 0) {
            KeyAttributes keyAttributes10 = new KeyAttributes();
            KeyAttributes keyAttributes11 = new KeyAttributes();
            keyAttributes10.setValue("translationY", Integer.valueOf(motionEffect.motionEffectTranslationY));
            keyAttributes10.mFramePosition = motionEffect.motionEffectEnd;
            keyAttributes11.setValue("translationY", 0);
            keyAttributes11.mFramePosition = motionEffect.motionEffectEnd - 1;
            keyAttributes3 = keyAttributes10;
            keyAttributes9 = keyAttributes11;
        } else {
            keyAttributes3 = null;
        }
        int i3 = motionEffect.fadeMove;
        if (i3 == -1) {
            int[] iArr = new int[4];
            int i4 = 0;
            while (i4 < views.length) {
                MotionController motionController = hashMap2.get(views[i4]);
                if (motionController == null) {
                    keyAttributes6 = keyAttributes9;
                } else {
                    MotionPaths motionPaths = motionController.mEndMotionPath;
                    float f = motionPaths.x;
                    MotionPaths motionPaths2 = motionController.mStartMotionPath;
                    keyAttributes6 = keyAttributes9;
                    float f2 = f - motionPaths2.x;
                    float f3 = motionPaths.y - motionPaths2.y;
                    if (f3 < 0.0f) {
                        i = 1;
                        iArr[1] = iArr[1] + 1;
                    } else {
                        i = 1;
                    }
                    if (f3 > 0.0f) {
                        iArr[0] = iArr[0] + 1;
                    }
                    if (f2 > 0.0f) {
                        iArr[3] = iArr[3] + 1;
                    }
                    if (f2 < 0.0f) {
                        iArr[2] = iArr[2] + i;
                    }
                }
                i4++;
                keyAttributes9 = keyAttributes6;
            }
            keyAttributes4 = keyAttributes9;
            int i5 = iArr[0];
            i3 = 0;
            for (int i6 = 1; i6 < 4; i6++) {
                if (i5 < iArr[i6]) {
                    i5 = iArr[i6];
                    i3 = i6;
                }
            }
        } else {
            keyAttributes4 = keyAttributes9;
        }
        int i7 = 0;
        while (i7 < views.length) {
            MotionController motionController2 = hashMap2.get(views[i7]);
            if (motionController2 != null) {
                MotionPaths motionPaths3 = motionController2.mEndMotionPath;
                float f4 = motionPaths3.x;
                MotionPaths motionPaths4 = motionController2.mStartMotionPath;
                float f5 = f4 - motionPaths4.x;
                float f6 = motionPaths3.y - motionPaths4.y;
                if (i3 == 0) {
                    if (f6 <= 0.0f || (motionEffect.motionEffectStrictMove && f5 != 0.0f)) {
                        z = true;
                        if (z) {
                            int i8 = motionEffect.viewTransitionId;
                            if (i8 == -1) {
                                motionController2.mKeyList.add(keyAttributes7);
                                motionController2.mKeyList.add(keyAttributes8);
                                motionController2.mKeyList.add(keyPosition);
                                motionController2.mKeyList.add(keyPosition2);
                                if (motionEffect.motionEffectTranslationX > 0) {
                                    motionController2.mKeyList.add(keyAttributes2);
                                    motionController2.mKeyList.add(keyAttributes);
                                }
                                if (motionEffect.motionEffectTranslationY > 0) {
                                    motionController2.mKeyList.add(keyAttributes3);
                                    motionController2.mKeyList.add(keyAttributes4);
                                    keyAttributes5 = keyAttributes4;
                                }
                            } else {
                                keyAttributes5 = keyAttributes4;
                                MotionScene motionScene = motionLayout.mScene;
                                if (motionScene != null) {
                                    Iterator<ViewTransition> it = motionScene.mViewTransitionController.viewTransitions.iterator();
                                    while (true) {
                                        if (!it.hasNext()) {
                                            break;
                                        }
                                        ViewTransition next = it.next();
                                        if (next.mId == i8) {
                                            next.mKeyFrames.addAllFrames(motionController2);
                                            break;
                                        }
                                    }
                                }
                            }
                            i7++;
                            motionEffect = this;
                            hashMap2 = hashMap;
                            keyAttributes4 = keyAttributes5;
                        }
                    }
                } else if (i3 == 1) {
                    if (f6 < 0.0f) {
                        if (motionEffect.motionEffectStrictMove) {
                        }
                    }
                    z = true;
                    if (z) {
                    }
                } else if (i3 == 2) {
                    if (f5 < 0.0f) {
                        if (motionEffect.motionEffectStrictMove) {
                        }
                    }
                    z = true;
                    if (z) {
                    }
                } else {
                    if (i3 == 3 && f5 > 0.0f && (!motionEffect.motionEffectStrictMove || f6 == 0.0f)) {
                        z = false;
                        if (z) {
                        }
                    }
                    z = true;
                    if (z) {
                    }
                }
                z = false;
                if (z) {
                }
            }
            keyAttributes5 = keyAttributes4;
            i7++;
            motionEffect = this;
            hashMap2 = hashMap;
            keyAttributes4 = keyAttributes5;
        }
    }

    public MotionEffect(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init(context, attributeSet);
    }

    public MotionEffect(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init(context, attributeSet);
    }
}
