package androidx.constraintlayout.motion.utils;

import android.util.Log;
import android.view.View;
import androidx.constraintlayout.core.motion.utils.CurveFit;
import androidx.constraintlayout.core.motion.utils.KeyCycleOscillator$CycleOscillator;
import androidx.constraintlayout.core.motion.utils.KeyCycleOscillator$WavePoint;
import androidx.constraintlayout.core.motion.utils.Oscillator;
import androidx.constraintlayout.motion.widget.MotionLayout;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.Objects;

public abstract class ViewOscillator {
    public KeyCycleOscillator$CycleOscillator mCycleOscillator;
    public String mType;
    public ArrayList<KeyCycleOscillator$WavePoint> mWavePoints = new ArrayList<>();

    public class AlphaSet extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setAlpha(get(f));
        }
    }

    public class CustomSet extends ViewOscillator {
        public float[] value = new float[1];

        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            this.value[0] = get(f);
            throw null;
        }
    }

    public class ElevationSet extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setElevation(get(f));
        }
    }

    public class PathRotateSet extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
        }
    }

    public class ProgressSet extends ViewOscillator {
        public boolean mNoMethod = false;

        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            if (view instanceof MotionLayout) {
                ((MotionLayout) view).setProgress(get(f));
            } else if (!this.mNoMethod) {
                Method method = null;
                try {
                    method = view.getClass().getMethod("setProgress", Float.TYPE);
                } catch (NoSuchMethodException unused) {
                    this.mNoMethod = true;
                }
                if (method != null) {
                    try {
                        method.invoke(view, Float.valueOf(get(f)));
                    } catch (IllegalAccessException e) {
                        Log.e("ViewOscillator", "unable to setProgress", e);
                    } catch (InvocationTargetException e2) {
                        Log.e("ViewOscillator", "unable to setProgress", e2);
                    }
                }
            }
        }
    }

    public class RotationSet extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setRotation(get(f));
        }
    }

    public class RotationXset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setRotationX(get(f));
        }
    }

    public class RotationYset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setRotationY(get(f));
        }
    }

    public class ScaleXset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setScaleX(get(f));
        }
    }

    public class ScaleYset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setScaleY(get(f));
        }
    }

    public class TranslationXset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setTranslationX(get(f));
        }
    }

    public class TranslationYset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setTranslationY(get(f));
        }
    }

    public class TranslationZset extends ViewOscillator {
        @Override // androidx.constraintlayout.motion.utils.ViewOscillator
        public void setProperty(View view, float f) {
            view.setTranslationZ(get(f));
        }
    }

    public float get(float f) {
        KeyCycleOscillator$CycleOscillator keyCycleOscillator$CycleOscillator = this.mCycleOscillator;
        CurveFit curveFit = keyCycleOscillator$CycleOscillator.mCurveFit;
        if (curveFit != null) {
            curveFit.getPos((double) f, keyCycleOscillator$CycleOscillator.mSplineValueCache);
        } else {
            double[] dArr = keyCycleOscillator$CycleOscillator.mSplineValueCache;
            dArr[0] = (double) keyCycleOscillator$CycleOscillator.mOffset[0];
            dArr[1] = (double) keyCycleOscillator$CycleOscillator.mPhase[0];
            dArr[2] = (double) keyCycleOscillator$CycleOscillator.mValues[0];
        }
        double[] dArr2 = keyCycleOscillator$CycleOscillator.mSplineValueCache;
        return (float) ((keyCycleOscillator$CycleOscillator.mOscillator.getValue((double) f, dArr2[1]) * keyCycleOscillator$CycleOscillator.mSplineValueCache[2]) + dArr2[0]);
    }

    public float getSlope(float f) {
        double d;
        double d2;
        double d3;
        double d4;
        KeyCycleOscillator$CycleOscillator keyCycleOscillator$CycleOscillator = this.mCycleOscillator;
        CurveFit curveFit = keyCycleOscillator$CycleOscillator.mCurveFit;
        if (curveFit != null) {
            double d5 = (double) f;
            curveFit.getSlope(d5, keyCycleOscillator$CycleOscillator.mSplineSlopeCache);
            keyCycleOscillator$CycleOscillator.mCurveFit.getPos(d5, keyCycleOscillator$CycleOscillator.mSplineValueCache);
        } else {
            double[] dArr = keyCycleOscillator$CycleOscillator.mSplineSlopeCache;
            dArr[0] = 0.0d;
            dArr[1] = 0.0d;
            dArr[2] = 0.0d;
        }
        double d6 = (double) f;
        double value = keyCycleOscillator$CycleOscillator.mOscillator.getValue(d6, keyCycleOscillator$CycleOscillator.mSplineValueCache[1]);
        Oscillator oscillator = keyCycleOscillator$CycleOscillator.mOscillator;
        double d7 = keyCycleOscillator$CycleOscillator.mSplineValueCache[1];
        double d8 = keyCycleOscillator$CycleOscillator.mSplineSlopeCache[1];
        double p = oscillator.getP(d6) + d7;
        if (d6 <= 0.0d) {
            d6 = 1.0E-5d;
        } else if (d6 >= 1.0d) {
            d6 = 0.999999d;
        }
        int binarySearch = Arrays.binarySearch(oscillator.mPosition, d6);
        if (binarySearch <= 0 && binarySearch != 0) {
            int i = (-binarySearch) - 1;
            float[] fArr = oscillator.mPeriod;
            int i2 = i - 1;
            double[] dArr2 = oscillator.mPosition;
            double d9 = ((double) (fArr[i] - fArr[i2])) / (dArr2[i] - dArr2[i2]);
            d = (((double) fArr[i2]) - (d9 * dArr2[i2])) + (d6 * d9);
        } else {
            d = 0.0d;
        }
        double d10 = d + d8;
        switch (oscillator.mType) {
            case 1:
                d2 = 0.0d;
                break;
            case 2:
                d3 = d10 * 4.0d;
                d4 = Math.signum((((p * 4.0d) + 3.0d) % 4.0d) - 2.0d);
                d2 = d3 * d4;
                break;
            case 3:
                d2 = d10 * 2.0d;
                break;
            case 4:
                d2 = (-d10) * 2.0d;
                break;
            case 5:
                d3 = d10 * -6.283185307179586d;
                d4 = Math.sin(p * 6.283185307179586d);
                d2 = d3 * d4;
                break;
            case 6:
                d3 = d10 * 4.0d;
                d4 = (((p * 4.0d) + 2.0d) % 4.0d) - 2.0d;
                d2 = d3 * d4;
                break;
            case 7:
                d2 = oscillator.mCustomCurve.getSlope(p % 1.0d, 0);
                break;
            default:
                d3 = d10 * 6.283185307179586d;
                d4 = Math.cos(p * 6.283185307179586d);
                d2 = d3 * d4;
                break;
        }
        double[] dArr3 = keyCycleOscillator$CycleOscillator.mSplineSlopeCache;
        return (float) ((d2 * keyCycleOscillator$CycleOscillator.mSplineValueCache[2]) + (value * dArr3[2]) + dArr3[0]);
    }

    public abstract void setProperty(View view, float f);

    public String toString() {
        String str = this.mType;
        new DecimalFormat("##.##");
        Iterator<KeyCycleOscillator$WavePoint> it = this.mWavePoints.iterator();
        if (!it.hasNext()) {
            return str;
        }
        StringBuilder sb = new StringBuilder();
        sb.append(str);
        sb.append("[");
        Objects.requireNonNull(it.next());
        throw null;
    }
}
