package androidx.constraintlayout.motion.widget;

import android.graphics.Rect;
import android.util.Log;
import android.util.SparseArray;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Interpolator;
import androidx.constraintlayout.core.motion.utils.ArcCurveFit;
import androidx.constraintlayout.core.motion.utils.CurveFit;
import androidx.constraintlayout.core.motion.utils.Easing;
import androidx.constraintlayout.core.motion.utils.KeyCache;
import androidx.constraintlayout.core.motion.utils.KeyCycleOscillator$1;
import androidx.constraintlayout.core.motion.utils.KeyCycleOscillator$CycleOscillator;
import androidx.constraintlayout.core.motion.utils.KeyCycleOscillator$WavePoint;
import androidx.constraintlayout.core.motion.utils.Oscillator;
import androidx.constraintlayout.motion.utils.ViewOscillator;
import androidx.constraintlayout.motion.utils.ViewSpline;
import androidx.constraintlayout.motion.utils.ViewTimeCycle;
import androidx.constraintlayout.utils.widget.MotionLabel;
import androidx.constraintlayout.widget.ConstraintAttribute;
import androidx.constraintlayout.widget.ConstraintLayout;
import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Objects;

public class MotionController {
    public int MAX_DIMENSION = 4;
    public CurveFit mArcSpline;
    public int[] mAttributeInterpolatorCount;
    public String[] mAttributeNames;
    public HashMap<String, ViewSpline> mAttributesMap;
    public int mCurveFitType = -1;
    public HashMap<String, ViewOscillator> mCycleMap;
    public MotionPaths mEndMotionPath = new MotionPaths();
    public MotionConstrainedPoint mEndPoint = new MotionConstrainedPoint();
    public int mId;
    public double[] mInterpolateData;
    public int[] mInterpolateVariables;
    public double[] mInterpolateVelocity;
    public ArrayList<Key> mKeyList = new ArrayList<>();
    public ArrayList<MotionPaths> mMotionPaths = new ArrayList<>();
    public float mMotionStagger = Float.NaN;
    public boolean mNoMovement = false;
    public int mPathMotionArc = -1;
    public Interpolator mQuantizeMotionInterpolator = null;
    public float mQuantizeMotionPhase = Float.NaN;
    public int mQuantizeMotionSteps = -1;
    public CurveFit[] mSpline;
    public float mStaggerOffset = 0.0f;
    public float mStaggerScale = 1.0f;
    public MotionPaths mStartMotionPath = new MotionPaths();
    public MotionConstrainedPoint mStartPoint = new MotionConstrainedPoint();
    public Rect mTempRect = new Rect();
    public HashMap<String, ViewTimeCycle> mTimeCycleAttributesMap;
    public int mTransformPivotTarget = -1;
    public View mTransformPivotView = null;
    public float[] mValuesBuff = new float[4];
    public float[] mVelocity = new float[1];
    public View mView;

    public MotionController(View view) {
        this.mView = view;
        this.mId = view.getId();
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (layoutParams instanceof ConstraintLayout.LayoutParams) {
            String str = ((ConstraintLayout.LayoutParams) layoutParams).constraintTag;
        }
    }

    public final float getAdjustedPosition(float f, float[] fArr) {
        float f2 = 0.0f;
        float f3 = 1.0f;
        if (fArr != null) {
            fArr[0] = 1.0f;
        } else {
            float f4 = this.mStaggerScale;
            if (((double) f4) != 1.0d) {
                float f5 = this.mStaggerOffset;
                if (f < f5) {
                    f = 0.0f;
                }
                if (f > f5 && ((double) f) < 1.0d) {
                    f = Math.min((f - f5) * f4, 1.0f);
                }
            }
        }
        Easing easing = this.mStartMotionPath.mKeyFrameEasing;
        float f6 = Float.NaN;
        Iterator<MotionPaths> it = this.mMotionPaths.iterator();
        while (it.hasNext()) {
            MotionPaths next = it.next();
            Easing easing2 = next.mKeyFrameEasing;
            if (easing2 != null) {
                float f7 = next.time;
                if (f7 < f) {
                    easing = easing2;
                    f2 = f7;
                } else if (Float.isNaN(f6)) {
                    f6 = next.time;
                }
            }
        }
        if (easing != null) {
            if (!Float.isNaN(f6)) {
                f3 = f6;
            }
            float f8 = f3 - f2;
            double d = (double) ((f - f2) / f8);
            f = (((float) easing.get(d)) * f8) + f2;
            if (fArr != null) {
                fArr[0] = (float) easing.getDiff(d);
            }
        }
        return f;
    }

    public void getCenter(double d, float[] fArr, float[] fArr2) {
        double[] dArr = new double[4];
        double[] dArr2 = new double[4];
        this.mSpline[0].getPos(d, dArr);
        this.mSpline[0].getSlope(d, dArr2);
        float f = 0.0f;
        Arrays.fill(fArr2, 0.0f);
        MotionPaths motionPaths = this.mStartMotionPath;
        int[] iArr = this.mInterpolateVariables;
        float f2 = motionPaths.x;
        float f3 = motionPaths.y;
        float f4 = motionPaths.width;
        float f5 = motionPaths.height;
        float f6 = 0.0f;
        float f7 = 0.0f;
        float f8 = 0.0f;
        for (int i = 0; i < iArr.length; i++) {
            float f9 = (float) dArr[i];
            float f10 = (float) dArr2[i];
            int i2 = iArr[i];
            if (i2 == 1) {
                f2 = f9;
                f = f10;
            } else if (i2 == 2) {
                f3 = f9;
                f6 = f10;
            } else if (i2 == 3) {
                f4 = f9;
                f7 = f10;
            } else if (i2 == 4) {
                f5 = f9;
                f8 = f10;
            }
        }
        float f11 = 2.0f;
        float f12 = (f7 / 2.0f) + f;
        float f13 = (f8 / 2.0f) + f6;
        MotionController motionController = motionPaths.mRelativeToController;
        if (motionController != null) {
            float[] fArr3 = new float[2];
            float[] fArr4 = new float[2];
            motionController.getCenter(d, fArr3, fArr4);
            float f14 = fArr3[0];
            float f15 = fArr3[1];
            float f16 = fArr4[0];
            float f17 = fArr4[1];
            double d2 = (double) f2;
            double d3 = (double) f3;
            float cos = (float) ((((double) f15) - (Math.cos(d3) * d2)) - ((double) (f5 / 2.0f)));
            double d4 = (double) f16;
            double d5 = (double) f;
            double sin = (Math.sin(d3) * d5) + d4;
            double d6 = (double) f6;
            f13 = (float) ((Math.sin(d3) * d6) + (((double) f17) - (Math.cos(d3) * d5)));
            f3 = cos;
            f12 = (float) ((Math.cos(d3) * d6) + sin);
            f2 = (float) (((Math.sin(d3) * d2) + ((double) f14)) - ((double) (f4 / 2.0f)));
            f11 = 2.0f;
        }
        fArr[0] = (f4 / f11) + f2 + 0.0f;
        fArr[1] = (f5 / f11) + f3 + 0.0f;
        fArr2[0] = f12;
        fArr2[1] = f13;
    }

    public void getDpDt(float f, float f2, float f3, float[] fArr) {
        double[] dArr;
        float adjustedPosition = getAdjustedPosition(f, this.mVelocity);
        CurveFit[] curveFitArr = this.mSpline;
        int i = 0;
        if (curveFitArr != null) {
            double d = (double) adjustedPosition;
            curveFitArr[0].getSlope(d, this.mInterpolateVelocity);
            this.mSpline[0].getPos(d, this.mInterpolateData);
            float f4 = this.mVelocity[0];
            while (true) {
                dArr = this.mInterpolateVelocity;
                if (i >= dArr.length) {
                    break;
                }
                dArr[i] = dArr[i] * ((double) f4);
                i++;
            }
            CurveFit curveFit = this.mArcSpline;
            if (curveFit != null) {
                double[] dArr2 = this.mInterpolateData;
                if (dArr2.length > 0) {
                    curveFit.getPos(d, dArr2);
                    this.mArcSpline.getSlope(d, this.mInterpolateVelocity);
                    this.mStartMotionPath.setDpDt(f2, f3, fArr, this.mInterpolateVariables, this.mInterpolateVelocity, this.mInterpolateData);
                    return;
                }
                return;
            }
            this.mStartMotionPath.setDpDt(f2, f3, fArr, this.mInterpolateVariables, dArr, this.mInterpolateData);
            return;
        }
        MotionPaths motionPaths = this.mEndMotionPath;
        float f5 = motionPaths.x;
        MotionPaths motionPaths2 = this.mStartMotionPath;
        float f6 = f5 - motionPaths2.x;
        float f7 = motionPaths.y - motionPaths2.y;
        fArr[0] = (((motionPaths.width - motionPaths2.width) + f6) * f2) + ((1.0f - f2) * f6);
        fArr[1] = (((motionPaths.height - motionPaths2.height) + f7) * f3) + ((1.0f - f3) * f7);
    }

    public boolean interpolate(View view, float f, long j, KeyCache keyCache) {
        boolean z;
        ViewTimeCycle.PathRotate pathRotate;
        boolean z2;
        float f2;
        boolean z3;
        ViewTimeCycle.PathRotate pathRotate2;
        double d;
        float f3;
        double d2;
        float f4;
        float f5;
        ViewTimeCycle.PathRotate pathRotate3;
        MotionController motionController = this;
        View view2 = view;
        float adjustedPosition = motionController.getAdjustedPosition(f, null);
        int i = motionController.mQuantizeMotionSteps;
        if (i != -1) {
            float f6 = 1.0f / ((float) i);
            float floor = ((float) Math.floor((double) (adjustedPosition / f6))) * f6;
            float f7 = (adjustedPosition % f6) / f6;
            if (!Float.isNaN(motionController.mQuantizeMotionPhase)) {
                f7 = (f7 + motionController.mQuantizeMotionPhase) % 1.0f;
            }
            Interpolator interpolator = motionController.mQuantizeMotionInterpolator;
            adjustedPosition = ((interpolator != null ? interpolator.getInterpolation(f7) : ((double) f7) > 0.5d ? 1.0f : 0.0f) * f6) + floor;
        }
        float f8 = adjustedPosition;
        HashMap<String, ViewSpline> hashMap = motionController.mAttributesMap;
        if (hashMap != null) {
            for (ViewSpline viewSpline : hashMap.values()) {
                viewSpline.setProperty(view2, f8);
            }
        }
        HashMap<String, ViewTimeCycle> hashMap2 = motionController.mTimeCycleAttributesMap;
        if (hashMap2 != null) {
            pathRotate = null;
            z = false;
            for (ViewTimeCycle viewTimeCycle : hashMap2.values()) {
                if (viewTimeCycle instanceof ViewTimeCycle.PathRotate) {
                    pathRotate = (ViewTimeCycle.PathRotate) viewTimeCycle;
                } else {
                    z |= viewTimeCycle.setProperty(view, f8, j, keyCache);
                }
            }
        } else {
            z = false;
            pathRotate = null;
        }
        CurveFit[] curveFitArr = motionController.mSpline;
        if (curveFitArr != null) {
            double d3 = (double) f8;
            curveFitArr[0].getPos(d3, motionController.mInterpolateData);
            motionController.mSpline[0].getSlope(d3, motionController.mInterpolateVelocity);
            CurveFit curveFit = motionController.mArcSpline;
            if (curveFit != null) {
                double[] dArr = motionController.mInterpolateData;
                if (dArr.length > 0) {
                    curveFit.getPos(d3, dArr);
                    motionController.mArcSpline.getSlope(d3, motionController.mInterpolateVelocity);
                }
            }
            if (!motionController.mNoMovement) {
                MotionPaths motionPaths = motionController.mStartMotionPath;
                int[] iArr = motionController.mInterpolateVariables;
                double[] dArr2 = motionController.mInterpolateData;
                double[] dArr3 = motionController.mInterpolateVelocity;
                float f9 = motionPaths.x;
                float f10 = motionPaths.y;
                float f11 = motionPaths.width;
                float f12 = motionPaths.height;
                if (iArr.length != 0) {
                    f4 = f9;
                    if (motionPaths.mTempValue.length <= iArr[iArr.length - 1]) {
                        int i2 = iArr[iArr.length - 1] + 1;
                        motionPaths.mTempValue = new double[i2];
                        motionPaths.mTempDelta = new double[i2];
                    }
                } else {
                    f4 = f9;
                }
                float f13 = f11;
                float f14 = f12;
                Arrays.fill(motionPaths.mTempValue, Double.NaN);
                for (int i3 = 0; i3 < iArr.length; i3++) {
                    motionPaths.mTempValue[iArr[i3]] = dArr2[i3];
                    motionPaths.mTempDelta[iArr[i3]] = dArr3[i3];
                }
                float f15 = Float.NaN;
                float f16 = 0.0f;
                float f17 = f4;
                float f18 = f10;
                z3 = z;
                float f19 = 0.0f;
                int i4 = 0;
                float f20 = 0.0f;
                float f21 = 0.0f;
                while (true) {
                    double[] dArr4 = motionPaths.mTempValue;
                    f3 = f8;
                    if (i4 >= dArr4.length) {
                        break;
                    }
                    if (Double.isNaN(dArr4[i4])) {
                        pathRotate3 = pathRotate;
                    } else {
                        double d4 = 0.0d;
                        if (!Double.isNaN(motionPaths.mTempValue[i4])) {
                            d4 = motionPaths.mTempValue[i4] + 0.0d;
                        }
                        pathRotate3 = pathRotate;
                        float f22 = (float) d4;
                        float f23 = (float) motionPaths.mTempDelta[i4];
                        if (i4 == 1) {
                            f16 = f23;
                            f17 = f22;
                        } else if (i4 == 2) {
                            f19 = f23;
                            f18 = f22;
                        } else if (i4 == 3) {
                            f20 = f23;
                            f13 = f22;
                        } else if (i4 == 4) {
                            f21 = f23;
                            f14 = f22;
                        } else if (i4 == 5) {
                            f15 = f22;
                        }
                    }
                    i4++;
                    pathRotate = pathRotate3;
                    f8 = f3;
                }
                MotionController motionController2 = motionPaths.mRelativeToController;
                if (motionController2 != null) {
                    float[] fArr = new float[2];
                    float[] fArr2 = new float[2];
                    motionController2.getCenter(d3, fArr, fArr2);
                    float f24 = fArr[0];
                    float f25 = fArr[1];
                    float f26 = fArr2[0];
                    float f27 = fArr2[1];
                    d = d3;
                    double d5 = (double) f17;
                    double d6 = (double) f18;
                    float sin = (float) (((Math.sin(d6) * d5) + ((double) f24)) - ((double) (f13 / 2.0f)));
                    pathRotate2 = pathRotate;
                    float cos = (float) ((((double) f25) - (Math.cos(d6) * d5)) - ((double) (f14 / 2.0f)));
                    double d7 = (double) f16;
                    f5 = f13;
                    double d8 = (double) f19;
                    float cos2 = (float) ((Math.cos(d6) * d5 * d8) + (Math.sin(d6) * d7) + ((double) f26));
                    float sin2 = (float) ((Math.sin(d6) * d5 * d8) + (((double) f27) - (Math.cos(d6) * d7)));
                    if (dArr3.length >= 2) {
                        dArr3[0] = (double) cos2;
                        dArr3[1] = (double) sin2;
                    }
                    if (!Float.isNaN(f15)) {
                        view2 = view;
                        view2.setRotation((float) (Math.toDegrees(Math.atan2((double) sin2, (double) cos2)) + ((double) f15)));
                    } else {
                        view2 = view;
                    }
                    f17 = sin;
                    f18 = cos;
                } else {
                    pathRotate2 = pathRotate;
                    d = d3;
                    f5 = f13;
                    if (!Float.isNaN(f15)) {
                        view2.setRotation((float) (Math.toDegrees(Math.atan2((double) ((f21 / 2.0f) + f19), (double) ((f20 / 2.0f) + f16))) + ((double) f15) + ((double) 0.0f)));
                    }
                }
                if (view2 instanceof FloatLayout) {
                    ((MotionLabel) ((FloatLayout) view2)).layout(f17, f18, f5 + f17, f18 + f14);
                } else {
                    float f28 = f17 + 0.5f;
                    int i5 = (int) f28;
                    float f29 = f18 + 0.5f;
                    int i6 = (int) f29;
                    int i7 = (int) (f28 + f5);
                    int i8 = (int) (f29 + f14);
                    int i9 = i7 - i5;
                    int i10 = i8 - i6;
                    if ((i9 == view.getMeasuredWidth() && i10 == view.getMeasuredHeight()) ? false : true) {
                        view2.measure(View.MeasureSpec.makeMeasureSpec(i9, 1073741824), View.MeasureSpec.makeMeasureSpec(i10, 1073741824));
                    }
                    view2.layout(i5, i6, i7, i8);
                }
            } else {
                f3 = f8;
                pathRotate2 = pathRotate;
                z3 = z;
                d = d3;
            }
            motionController = this;
            if (motionController.mTransformPivotTarget != -1) {
                if (motionController.mTransformPivotView == null) {
                    motionController.mTransformPivotView = ((View) view.getParent()).findViewById(motionController.mTransformPivotTarget);
                }
                View view3 = motionController.mTransformPivotView;
                if (view3 != null) {
                    float bottom = ((float) (motionController.mTransformPivotView.getBottom() + view3.getTop())) / 2.0f;
                    float right = ((float) (motionController.mTransformPivotView.getRight() + motionController.mTransformPivotView.getLeft())) / 2.0f;
                    if (view.getRight() - view.getLeft() > 0 && view.getBottom() - view.getTop() > 0) {
                        view2.setPivotX(right - ((float) view.getLeft()));
                        view2.setPivotY(bottom - ((float) view.getTop()));
                    }
                }
            }
            HashMap<String, ViewSpline> hashMap3 = motionController.mAttributesMap;
            if (hashMap3 != null) {
                for (ViewSpline viewSpline2 : hashMap3.values()) {
                    if (viewSpline2 instanceof ViewSpline.PathRotate) {
                        double[] dArr5 = motionController.mInterpolateVelocity;
                        if (dArr5.length > 1) {
                            d2 = d;
                            view2.setRotation(((float) ((ViewSpline.PathRotate) viewSpline2).mCurveFit.getPos(d2, 0)) + ((float) Math.toDegrees(Math.atan2(dArr5[1], dArr5[0]))));
                            d = d2;
                        }
                    }
                    d2 = d;
                    d = d2;
                }
            }
            if (pathRotate2 != null) {
                double[] dArr6 = motionController.mInterpolateVelocity;
                view2.setRotation(pathRotate2.get(f3, j, view, keyCache) + ((float) Math.toDegrees(Math.atan2(dArr6[1], dArr6[0]))));
                z2 = z3 | pathRotate2.mContinue;
            } else {
                z2 = z3;
            }
            int i11 = 1;
            while (true) {
                CurveFit[] curveFitArr2 = motionController.mSpline;
                if (i11 >= curveFitArr2.length) {
                    break;
                }
                curveFitArr2[i11].getPos(d, motionController.mValuesBuff);
                motionController.mStartMotionPath.attributes.get(motionController.mAttributeNames[i11 - 1]).setInterpolatedValue(view2, motionController.mValuesBuff);
                i11++;
            }
            MotionConstrainedPoint motionConstrainedPoint = motionController.mStartPoint;
            if (motionConstrainedPoint.mVisibilityMode == 0) {
                if (f3 <= 0.0f) {
                    view2.setVisibility(motionConstrainedPoint.visibility);
                } else if (f3 >= 1.0f) {
                    view2.setVisibility(motionController.mEndPoint.visibility);
                } else if (motionController.mEndPoint.visibility != motionConstrainedPoint.visibility) {
                    view2.setVisibility(0);
                }
            }
            f2 = f3;
        } else {
            MotionPaths motionPaths2 = motionController.mStartMotionPath;
            float f30 = motionPaths2.x;
            MotionPaths motionPaths3 = motionController.mEndMotionPath;
            f2 = f8;
            float outline0 = GeneratedOutlineSupport.outline0(motionPaths3.x, f30, f2, f30);
            float f31 = motionPaths2.y;
            float outline02 = GeneratedOutlineSupport.outline0(motionPaths3.y, f31, f2, f31);
            float f32 = motionPaths2.width;
            float f33 = motionPaths3.width;
            float outline03 = GeneratedOutlineSupport.outline0(f33, f32, f2, f32);
            float f34 = motionPaths2.height;
            float f35 = motionPaths3.height;
            float f36 = outline0 + 0.5f;
            int i12 = (int) f36;
            float f37 = outline02 + 0.5f;
            int i13 = (int) f37;
            int i14 = (int) (f36 + outline03);
            int outline04 = (int) (f37 + GeneratedOutlineSupport.outline0(f35, f34, f2, f34));
            int i15 = i14 - i12;
            int i16 = outline04 - i13;
            if (!(f33 == f32 && f35 == f34)) {
                view2.measure(View.MeasureSpec.makeMeasureSpec(i15, 1073741824), View.MeasureSpec.makeMeasureSpec(i16, 1073741824));
            }
            view2.layout(i12, i13, i14, outline04);
            z2 = z;
        }
        HashMap<String, ViewOscillator> hashMap4 = motionController.mCycleMap;
        if (hashMap4 != null) {
            for (ViewOscillator viewOscillator : hashMap4.values()) {
                if (viewOscillator instanceof ViewOscillator.PathRotateSet) {
                    double[] dArr7 = motionController.mInterpolateVelocity;
                    view2.setRotation(((ViewOscillator.PathRotateSet) viewOscillator).get(f2) + ((float) Math.toDegrees(Math.atan2(dArr7[1], dArr7[0]))));
                } else {
                    viewOscillator.setProperty(view2, f2);
                }
            }
        }
        return z2;
    }

    public final void readView(MotionPaths motionPaths) {
        motionPaths.setBounds((float) ((int) this.mView.getX()), (float) ((int) this.mView.getY()), (float) this.mView.getWidth(), (float) this.mView.getHeight());
    }

    public void rotate(Rect rect, Rect rect2, int i, int i2, int i3) {
        if (i == 1) {
            int i4 = rect.left + rect.right;
            rect2.left = ((rect.top + rect.bottom) - rect.width()) / 2;
            rect2.top = i3 - ((rect.height() + i4) / 2);
            rect2.right = rect.width() + rect2.left;
            rect2.bottom = rect.height() + rect2.top;
        } else if (i == 2) {
            int i5 = rect.left + rect.right;
            rect2.left = i2 - ((rect.width() + (rect.top + rect.bottom)) / 2);
            rect2.top = (i5 - rect.height()) / 2;
            rect2.right = rect.width() + rect2.left;
            rect2.bottom = rect.height() + rect2.top;
        } else if (i == 3) {
            int i6 = rect.left + rect.right;
            rect2.left = ((rect.height() / 2) + rect.top) - (i6 / 2);
            rect2.top = i3 - ((rect.height() + i6) / 2);
            rect2.right = rect.width() + rect2.left;
            rect2.bottom = rect.height() + rect2.top;
        } else if (i == 4) {
            int i7 = rect.left + rect.right;
            rect2.left = i2 - ((rect.width() + (rect.bottom + rect.top)) / 2);
            rect2.top = (i7 - rect.height()) / 2;
            rect2.right = rect.width() + rect2.left;
            rect2.bottom = rect.height() + rect2.top;
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public void setup(int i, int i2, long j) {
        HashSet<String> hashSet;
        String str;
        String str2;
        String str3;
        String str4;
        MotionController motionController;
        Object obj;
        Iterator<ViewOscillator> it;
        Class cls;
        int i3;
        Iterator it2;
        Object obj2;
        String str5;
        String str6;
        String str7;
        String str8;
        String str9;
        String str10;
        String str11;
        String str12;
        String str13;
        String str14;
        ViewOscillator.CustomSet customSet;
        char c;
        ViewOscillator rotationXset;
        MotionPaths[] motionPathsArr;
        String str15;
        String str16;
        double[] dArr;
        int i4;
        float[] fArr;
        int[] iArr;
        ConstraintAttribute constraintAttribute;
        String str17;
        HashSet<String> hashSet2;
        Iterator it3;
        String str18;
        HashMap<String, Integer> hashMap;
        ViewTimeCycle.CustomSet customSet2;
        Object obj3;
        MotionController motionController2;
        char c2;
        ConstraintAttribute constraintAttribute2;
        Integer num;
        Iterator<String> it4;
        HashSet<String> hashSet3;
        Object obj4;
        String str19;
        ViewSpline.CustomSet customSet3;
        String str20;
        String str21;
        char c3;
        ViewSpline viewSpline;
        ConstraintAttribute constraintAttribute3;
        String str22;
        String str23;
        String str24;
        MotionController motionController3 = this;
        new HashSet();
        HashSet hashSet4 = new HashSet();
        HashSet<String> hashSet5 = new HashSet<>();
        HashSet hashSet6 = new HashSet();
        HashMap<String, Integer> hashMap2 = new HashMap<>();
        int i5 = motionController3.mPathMotionArc;
        if (i5 != -1) {
            motionController3.mStartMotionPath.mPathMotionArc = i5;
        }
        MotionConstrainedPoint motionConstrainedPoint = motionController3.mStartPoint;
        MotionConstrainedPoint motionConstrainedPoint2 = motionController3.mEndPoint;
        String str25 = "alpha";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.alpha, motionConstrainedPoint2.alpha)) {
            hashSet5.add(str25);
        }
        String str26 = "elevation";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.elevation, motionConstrainedPoint2.elevation)) {
            hashSet5.add(str26);
        }
        int i6 = motionConstrainedPoint.visibility;
        int i7 = motionConstrainedPoint2.visibility;
        if (i6 != i7 && motionConstrainedPoint.mVisibilityMode == 0 && (i6 == 0 || i7 == 0)) {
            hashSet5.add(str25);
        }
        String str27 = "rotation";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.rotation, motionConstrainedPoint2.rotation)) {
            hashSet5.add(str27);
        }
        if (!Float.isNaN(motionConstrainedPoint.mPathRotate) || !Float.isNaN(motionConstrainedPoint2.mPathRotate)) {
            hashSet5.add("transitionPathRotate");
        }
        String str28 = "progress";
        if (!Float.isNaN(motionConstrainedPoint.mProgress) || !Float.isNaN(motionConstrainedPoint2.mProgress)) {
            hashSet5.add(str28);
        }
        if (motionConstrainedPoint.diff(motionConstrainedPoint.rotationX, motionConstrainedPoint2.rotationX)) {
            hashSet5.add("rotationX");
        }
        String str29 = "rotationY";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.rotationY, motionConstrainedPoint2.rotationY)) {
            hashSet5.add(str29);
        }
        if (motionConstrainedPoint.diff(motionConstrainedPoint.mPivotX, motionConstrainedPoint2.mPivotX)) {
            hashSet5.add("transformPivotX");
        }
        if (motionConstrainedPoint.diff(motionConstrainedPoint.mPivotY, motionConstrainedPoint2.mPivotY)) {
            hashSet5.add("transformPivotY");
        }
        String str30 = "scaleX";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.scaleX, motionConstrainedPoint2.scaleX)) {
            hashSet5.add(str30);
        }
        String str31 = "scaleY";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.scaleY, motionConstrainedPoint2.scaleY)) {
            hashSet5.add(str31);
        }
        String str32 = "translationX";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.translationX, motionConstrainedPoint2.translationX)) {
            hashSet5.add(str32);
        }
        Object obj5 = "rotationX";
        String str33 = "translationY";
        if (motionConstrainedPoint.diff(motionConstrainedPoint.translationY, motionConstrainedPoint2.translationY)) {
            hashSet5.add(str33);
        }
        boolean diff = motionConstrainedPoint.diff(motionConstrainedPoint.translationZ, motionConstrainedPoint2.translationZ);
        String str34 = "translationZ";
        if (diff) {
            hashSet5.add(str34);
        }
        ArrayList<Key> arrayList = motionController3.mKeyList;
        if (arrayList != null) {
            Iterator<Key> it5 = arrayList.iterator();
            while (it5.hasNext()) {
                Key next = it5.next();
                if (next instanceof KeyPosition) {
                    KeyPosition keyPosition = (KeyPosition) next;
                    str23 = str29;
                    str22 = str32;
                    MotionPaths motionPaths = new MotionPaths(i, i2, keyPosition, motionController3.mStartMotionPath, motionController3.mEndMotionPath);
                    int binarySearch = Collections.binarySearch(motionController3.mMotionPaths, motionPaths);
                    if (binarySearch == 0) {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25(" KeyPath position \"");
                        str24 = str33;
                        outline25.append(motionPaths.position);
                        outline25.append("\" outside of range");
                        Log.e("MotionController", outline25.toString());
                    } else {
                        str24 = str33;
                    }
                    motionController3.mMotionPaths.add((-binarySearch) - 1, motionPaths);
                    int i8 = keyPosition.mCurveFit;
                    if (i8 != -1) {
                        motionController3.mCurveFitType = i8;
                    }
                } else {
                    str22 = str32;
                    str24 = str33;
                    str23 = str29;
                    next.setInterpolation(hashMap2);
                    next.getAttributeNames(hashSet5);
                }
                it5 = it5;
                str33 = str24;
                str29 = str23;
                str32 = str22;
            }
        }
        String str35 = str32;
        String str36 = str33;
        String str37 = str29;
        char c4 = 1;
        if (!hashSet5.isEmpty()) {
            motionController3.mAttributesMap = new HashMap<>();
            Iterator<String> it6 = hashSet5.iterator();
            while (it6.hasNext()) {
                String next2 = it6.next();
                if (next2.startsWith("CUSTOM,")) {
                    SparseArray sparseArray = new SparseArray();
                    String str38 = next2.split(",")[c4];
                    for (Iterator<Key> it7 = motionController3.mKeyList.iterator(); it7.hasNext(); it7 = it7) {
                        Key next3 = it7.next();
                        HashMap<String, ConstraintAttribute> hashMap3 = next3.mCustomConstraints;
                        if (!(hashMap3 == null || (constraintAttribute3 = hashMap3.get(str38)) == null)) {
                            sparseArray.append(next3.mFramePosition, constraintAttribute3);
                        }
                        it6 = it6;
                    }
                    it4 = it6;
                    ViewSpline.CustomSet customSet4 = new ViewSpline.CustomSet(next2, sparseArray);
                    hashSet3 = hashSet5;
                    obj4 = obj5;
                    str19 = str37;
                    str20 = str35;
                    customSet3 = customSet4;
                    str21 = str36;
                } else {
                    it4 = it6;
                    switch (next2.hashCode()) {
                        case -1249320806:
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            if (next2.equals(obj4)) {
                                c3 = 0;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case -1249320805:
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            if (!next2.equals(str19)) {
                                obj4 = obj5;
                                c3 = 65535;
                                break;
                            } else {
                                obj4 = obj5;
                                c3 = 1;
                                break;
                            }
                        case -1225497657:
                            str21 = str36;
                            str20 = str35;
                            if (!next2.equals(str20)) {
                                obj4 = obj5;
                                str19 = str37;
                                c3 = 65535;
                                break;
                            } else {
                                obj4 = obj5;
                                str19 = str37;
                                c3 = 2;
                                break;
                            }
                        case -1225497656:
                            str21 = str36;
                            if (!next2.equals(str21)) {
                                obj4 = obj5;
                                str19 = str37;
                                str20 = str35;
                                c3 = 65535;
                                break;
                            } else {
                                obj4 = obj5;
                                str19 = str37;
                                str20 = str35;
                                c3 = 3;
                                break;
                            }
                        case -1225497655:
                            if (next2.equals(str34)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 4;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -1001078227:
                            if (next2.equals(str28)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 5;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -908189618:
                            if (next2.equals(str30)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 6;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -908189617:
                            if (next2.equals(str31)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 7;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -797520672:
                            if (next2.equals("waveVariesBy")) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = '\b';
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -760884510:
                            if (next2.equals("transformPivotX")) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = '\t';
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -760884509:
                            if (next2.equals("transformPivotY")) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = '\n';
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -40300674:
                            if (next2.equals(str27)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 11;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case -4379043:
                            if (next2.equals(str26)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = '\f';
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case 37232917:
                            if (next2.equals("transitionPathRotate")) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = StringUtil.CARRIAGE_RETURN;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case 92909918:
                            if (next2.equals(str25)) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 14;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        case 156108012:
                            if (next2.equals("waveOffset")) {
                                obj4 = obj5;
                                str21 = str36;
                                str19 = str37;
                                str20 = str35;
                                c3 = 15;
                                break;
                            }
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                        default:
                            obj4 = obj5;
                            str21 = str36;
                            str19 = str37;
                            str20 = str35;
                            c3 = 65535;
                            break;
                    }
                    switch (c3) {
                        case 0:
                            viewSpline = new ViewSpline.RotationXset();
                            break;
                        case 1:
                            viewSpline = new ViewSpline.RotationYset();
                            break;
                        case 2:
                            viewSpline = new ViewSpline.TranslationXset();
                            break;
                        case 3:
                            viewSpline = new ViewSpline.TranslationYset();
                            break;
                        case 4:
                            viewSpline = new ViewSpline.TranslationZset();
                            break;
                        case 5:
                            viewSpline = new ViewSpline.ProgressSet();
                            break;
                        case 6:
                            viewSpline = new ViewSpline.ScaleXset();
                            break;
                        case 7:
                            viewSpline = new ViewSpline.ScaleYset();
                            break;
                        case '\b':
                            viewSpline = new ViewSpline.AlphaSet();
                            break;
                        case '\t':
                            viewSpline = new ViewSpline.PivotXset();
                            break;
                        case '\n':
                            viewSpline = new ViewSpline.PivotYset();
                            break;
                        case 11:
                            viewSpline = new ViewSpline.RotationSet();
                            break;
                        case '\f':
                            viewSpline = new ViewSpline.ElevationSet();
                            break;
                        case '\r':
                            viewSpline = new ViewSpline.PathRotate();
                            break;
                        case 14:
                            viewSpline = new ViewSpline.AlphaSet();
                            break;
                        case 15:
                            viewSpline = new ViewSpline.AlphaSet();
                            break;
                        default:
                            viewSpline = null;
                            break;
                    }
                    hashSet3 = hashSet5;
                    customSet3 = viewSpline;
                }
                if (customSet3 == null) {
                    obj5 = obj4;
                } else {
                    customSet3.mType = next2;
                    obj5 = obj4;
                    motionController3.mAttributesMap.put(next2, customSet3);
                }
                str36 = str21;
                str35 = str20;
                str37 = str19;
                hashSet5 = hashSet3;
                c4 = 1;
                it6 = it4;
            }
            hashSet = hashSet5;
            str3 = str36;
            str = str37;
            str2 = str35;
            ArrayList<Key> arrayList2 = motionController3.mKeyList;
            if (arrayList2 != null) {
                Iterator<Key> it8 = arrayList2.iterator();
                while (it8.hasNext()) {
                    Key next4 = it8.next();
                    if (next4 instanceof KeyAttributes) {
                        next4.addValues(motionController3.mAttributesMap);
                    }
                }
            }
            motionController3.mStartPoint.addValues(motionController3.mAttributesMap, 0);
            motionController3.mEndPoint.addValues(motionController3.mAttributesMap, 100);
            for (Iterator<String> it9 = motionController3.mAttributesMap.keySet().iterator(); it9.hasNext(); it9 = it9) {
                String next5 = it9.next();
                int intValue = (!hashMap2.containsKey(next5) || (num = hashMap2.get(next5)) == null) ? 0 : num.intValue();
                ViewSpline viewSpline2 = motionController3.mAttributesMap.get(next5);
                if (viewSpline2 != null) {
                    viewSpline2.setup(intValue);
                }
            }
        } else {
            hashSet = hashSet5;
            str3 = str36;
            str = str37;
            str2 = str35;
        }
        if (!hashSet4.isEmpty()) {
            if (motionController3.mTimeCycleAttributesMap == null) {
                motionController3.mTimeCycleAttributesMap = new HashMap<>();
            }
            Iterator it10 = hashSet4.iterator();
            while (it10.hasNext()) {
                String str39 = (String) it10.next();
                if (!motionController3.mTimeCycleAttributesMap.containsKey(str39)) {
                    if (!str39.startsWith("CUSTOM,")) {
                        it3 = it10;
                        hashMap = hashMap2;
                        switch (str39.hashCode()) {
                            case -1249320806:
                                obj3 = obj5;
                                if (str39.equals(obj3)) {
                                    c2 = 0;
                                    break;
                                }
                                c2 = 65535;
                                break;
                            case -1249320805:
                                if (str39.equals(str)) {
                                    obj3 = obj5;
                                    c2 = 1;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -1225497657:
                                if (str39.equals(str2)) {
                                    obj3 = obj5;
                                    c2 = 2;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -1225497656:
                                if (str39.equals(str3)) {
                                    obj3 = obj5;
                                    c2 = 3;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -1225497655:
                                if (str39.equals(str34)) {
                                    obj3 = obj5;
                                    c2 = 4;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -1001078227:
                                if (str39.equals(str28)) {
                                    obj3 = obj5;
                                    c2 = 5;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -908189618:
                                if (str39.equals(str30)) {
                                    obj3 = obj5;
                                    c2 = 6;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -908189617:
                                if (str39.equals(str31)) {
                                    obj3 = obj5;
                                    c2 = 7;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -40300674:
                                if (str39.equals(str27)) {
                                    obj3 = obj5;
                                    c2 = '\b';
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case -4379043:
                                if (str39.equals(str26)) {
                                    obj3 = obj5;
                                    c2 = '\t';
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case 37232917:
                                if (str39.equals("transitionPathRotate")) {
                                    obj3 = obj5;
                                    c2 = '\n';
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            case 92909918:
                                if (str39.equals(str25)) {
                                    obj3 = obj5;
                                    c2 = 11;
                                    break;
                                }
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                            default:
                                obj3 = obj5;
                                c2 = 65535;
                                break;
                        }
                        switch (c2) {
                            case 0:
                                customSet2 = new ViewTimeCycle.RotationXset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 1:
                                customSet2 = new ViewTimeCycle.RotationYset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 2:
                                customSet2 = new ViewTimeCycle.TranslationXset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 3:
                                customSet2 = new ViewTimeCycle.TranslationYset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 4:
                                customSet2 = new ViewTimeCycle.TranslationZset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 5:
                                customSet2 = new ViewTimeCycle.ProgressSet();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 6:
                                customSet2 = new ViewTimeCycle.ScaleXset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 7:
                                customSet2 = new ViewTimeCycle.ScaleYset();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case '\b':
                                customSet2 = new ViewTimeCycle.RotationSet();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case '\t':
                                customSet2 = new ViewTimeCycle.ElevationSet();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case '\n':
                                customSet2 = new ViewTimeCycle.PathRotate();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            case 11:
                                customSet2 = new ViewTimeCycle.AlphaSet();
                                str18 = str;
                                customSet2.last_time = j;
                                break;
                            default:
                                str18 = str;
                                customSet2 = null;
                                break;
                        }
                    } else {
                        SparseArray sparseArray2 = new SparseArray();
                        it3 = it10;
                        String str40 = str39.split(",")[1];
                        hashMap = hashMap2;
                        for (Iterator<Key> it11 = motionController3.mKeyList.iterator(); it11.hasNext(); it11 = it11) {
                            Key next6 = it11.next();
                            HashMap<String, ConstraintAttribute> hashMap4 = next6.mCustomConstraints;
                            if (!(hashMap4 == null || (constraintAttribute2 = hashMap4.get(str40)) == null)) {
                                sparseArray2.append(next6.mFramePosition, constraintAttribute2);
                            }
                        }
                        customSet2 = new ViewTimeCycle.CustomSet(str39, sparseArray2);
                        str18 = str;
                        obj3 = obj5;
                    }
                    if (customSet2 == null) {
                        motionController2 = this;
                    } else {
                        customSet2.mType = str39;
                        motionController2 = this;
                        motionController2.mTimeCycleAttributesMap.put(str39, customSet2);
                    }
                    it10 = it3;
                    obj5 = obj3;
                    motionController3 = motionController2;
                    hashMap2 = hashMap;
                    str = str18;
                }
            }
            HashMap<String, Integer> hashMap5 = hashMap2;
            str4 = str;
            motionController = motionController3;
            obj = obj5;
            ArrayList<Key> arrayList3 = motionController.mKeyList;
            if (arrayList3 != null) {
                Iterator<Key> it12 = arrayList3.iterator();
                while (it12.hasNext()) {
                    it12.next();
                }
            }
            Iterator<String> it13 = motionController.mTimeCycleAttributesMap.keySet().iterator();
            while (it13.hasNext()) {
                String next7 = it13.next();
                motionController.mTimeCycleAttributesMap.get(next7).setup(hashMap5.containsKey(next7) ? hashMap5.get(next7).intValue() : 0);
                it13 = it13;
                hashMap5 = hashMap5;
            }
        } else {
            motionController = motionController3;
            str4 = str;
            obj = obj5;
        }
        int size = motionController.mMotionPaths.size() + 2;
        MotionPaths[] motionPathsArr2 = new MotionPaths[size];
        motionPathsArr2[0] = motionController.mStartMotionPath;
        motionPathsArr2[size - 1] = motionController.mEndMotionPath;
        if (motionController.mMotionPaths.size() > 0 && motionController.mCurveFitType == -1) {
            motionController.mCurveFitType = 0;
        }
        Iterator<MotionPaths> it14 = motionController.mMotionPaths.iterator();
        int i9 = 1;
        while (it14.hasNext()) {
            motionPathsArr2[i9] = it14.next();
            i9++;
        }
        HashSet hashSet7 = new HashSet();
        Iterator<String> it15 = motionController.mEndMotionPath.attributes.keySet().iterator();
        while (it15.hasNext()) {
            String next8 = it15.next();
            if (motionController.mStartMotionPath.attributes.containsKey(next8)) {
                StringBuilder sb = new StringBuilder();
                str17 = str2;
                sb.append("CUSTOM,");
                sb.append(next8);
                hashSet2 = hashSet;
                if (!hashSet2.contains(sb.toString())) {
                    hashSet7.add(next8);
                }
            } else {
                str17 = str2;
                hashSet2 = hashSet;
            }
            it15 = it15;
            hashSet = hashSet2;
            obj = obj;
            str2 = str17;
        }
        Object obj6 = obj;
        String str41 = str2;
        String[] strArr = (String[]) hashSet7.toArray(new String[0]);
        motionController.mAttributeNames = strArr;
        motionController.mAttributeInterpolatorCount = new int[strArr.length];
        int i10 = 0;
        while (true) {
            String[] strArr2 = motionController.mAttributeNames;
            if (i10 < strArr2.length) {
                String str42 = strArr2[i10];
                motionController.mAttributeInterpolatorCount[i10] = 0;
                int i11 = 0;
                while (true) {
                    if (i11 < size) {
                        if (!motionPathsArr2[i11].attributes.containsKey(str42) || (constraintAttribute = motionPathsArr2[i11].attributes.get(str42)) == null) {
                            i11++;
                        } else {
                            int[] iArr2 = motionController.mAttributeInterpolatorCount;
                            iArr2[i10] = constraintAttribute.numberOfInterpolatedValues() + iArr2[i10];
                        }
                    }
                }
                i10++;
            } else {
                boolean z = motionPathsArr2[0].mPathMotionArc != -1;
                int length = strArr2.length + 18;
                boolean[] zArr = new boolean[length];
                int i12 = 1;
                while (i12 < size) {
                    MotionPaths motionPaths2 = motionPathsArr2[i12];
                    MotionPaths motionPaths3 = motionPathsArr2[i12 - 1];
                    boolean diff2 = motionPaths2.diff(motionPaths2.x, motionPaths3.x);
                    boolean diff3 = motionPaths2.diff(motionPaths2.y, motionPaths3.y);
                    zArr[0] = motionPaths2.diff(motionPaths2.position, motionPaths3.position) | zArr[0];
                    boolean z2 = diff3 | diff2 | z;
                    zArr[1] = zArr[1] | z2;
                    zArr[2] = z2 | zArr[2];
                    zArr[3] = zArr[3] | motionPaths2.diff(motionPaths2.width, motionPaths3.width);
                    zArr[4] = motionPaths2.diff(motionPaths2.height, motionPaths3.height) | zArr[4];
                    i12++;
                    str28 = str28;
                    str34 = str34;
                    str3 = str3;
                    str30 = str30;
                    str31 = str31;
                    str27 = str27;
                    str26 = str26;
                }
                String str43 = str3;
                String str44 = str31;
                String str45 = str34;
                String str46 = str30;
                String str47 = str26;
                String str48 = str27;
                String str49 = str28;
                int i13 = 0;
                for (int i14 = 1; i14 < length; i14++) {
                    if (zArr[i14]) {
                        i13++;
                    }
                }
                motionController.mInterpolateVariables = new int[i13];
                int max = Math.max(2, i13);
                motionController.mInterpolateData = new double[max];
                motionController.mInterpolateVelocity = new double[max];
                int i15 = 0;
                for (int i16 = 1; i16 < length; i16++) {
                    if (zArr[i16]) {
                        motionController.mInterpolateVariables[i15] = i16;
                        i15++;
                    }
                }
                int[] iArr3 = new int[2];
                iArr3[1] = motionController.mInterpolateVariables.length;
                iArr3[0] = size;
                Class cls2 = double.class;
                double[][] dArr2 = (double[][]) Array.newInstance(cls2, iArr3);
                double[] dArr3 = new double[size];
                for (int i17 = 0; i17 < size; i17++) {
                    MotionPaths motionPaths4 = motionPathsArr2[i17];
                    double[] dArr4 = dArr2[i17];
                    int[] iArr4 = motionController.mInterpolateVariables;
                    float[] fArr2 = {motionPaths4.position, motionPaths4.x, motionPaths4.y, motionPaths4.width, motionPaths4.height, motionPaths4.mPathRotate};
                    int i18 = 0;
                    int i19 = 0;
                    while (i18 < iArr4.length) {
                        if (iArr4[i18] < 6) {
                            iArr = iArr4;
                            fArr = fArr2;
                            dArr4[i19] = (double) fArr2[iArr4[i18]];
                            i19++;
                        } else {
                            iArr = iArr4;
                            fArr = fArr2;
                        }
                        i18++;
                        iArr4 = iArr;
                        fArr2 = fArr;
                    }
                    dArr3[i17] = (double) motionPathsArr2[i17].time;
                }
                int i20 = 0;
                while (true) {
                    int[] iArr5 = motionController.mInterpolateVariables;
                    if (i20 < iArr5.length) {
                        if (iArr5[i20] < MotionPaths.names.length) {
                            String outline22 = GeneratedOutlineSupport.outline22(new StringBuilder(), MotionPaths.names[motionController.mInterpolateVariables[i20]], " [");
                            for (int i21 = 0; i21 < size; i21++) {
                                StringBuilder outline252 = GeneratedOutlineSupport.outline25(outline22);
                                outline252.append(dArr2[i21][i20]);
                                outline22 = outline252.toString();
                            }
                        }
                        i20++;
                    } else {
                        motionController.mSpline = new CurveFit[(motionController.mAttributeNames.length + 1)];
                        int i22 = 0;
                        while (true) {
                            String[] strArr3 = motionController.mAttributeNames;
                            if (i22 < strArr3.length) {
                                String str50 = strArr3[i22];
                                double[] dArr5 = null;
                                double[][] dArr6 = null;
                                int i23 = 0;
                                int i24 = 0;
                                while (i23 < size) {
                                    if (motionPathsArr2[i23].attributes.containsKey(str50)) {
                                        if (dArr6 == null) {
                                            dArr5 = new double[size];
                                            ConstraintAttribute constraintAttribute4 = motionPathsArr2[i23].attributes.get(str50);
                                            if (constraintAttribute4 == null) {
                                                i4 = 0;
                                            } else {
                                                i4 = constraintAttribute4.numberOfInterpolatedValues();
                                            }
                                            int[] iArr6 = new int[2];
                                            iArr6[1] = i4;
                                            iArr6[0] = size;
                                            dArr6 = (double[][]) Array.newInstance(cls2, iArr6);
                                        }
                                        dArr5[i24] = (double) motionPathsArr2[i23].time;
                                        MotionPaths motionPaths5 = motionPathsArr2[i23];
                                        double[] dArr7 = dArr6[i24];
                                        ConstraintAttribute constraintAttribute5 = motionPaths5.attributes.get(str50);
                                        if (constraintAttribute5 == null) {
                                            str15 = str50;
                                            motionPathsArr = motionPathsArr2;
                                            dArr = dArr5;
                                            str16 = str25;
                                        } else {
                                            str15 = str50;
                                            dArr = dArr5;
                                            if (constraintAttribute5.numberOfInterpolatedValues() == 1) {
                                                str16 = str25;
                                                dArr7[0] = (double) constraintAttribute5.getValueToInterpolate();
                                            } else {
                                                str16 = str25;
                                                int numberOfInterpolatedValues = constraintAttribute5.numberOfInterpolatedValues();
                                                float[] fArr3 = new float[numberOfInterpolatedValues];
                                                constraintAttribute5.getValuesToInterpolate(fArr3);
                                                int i25 = 0;
                                                int i26 = 0;
                                                while (i25 < numberOfInterpolatedValues) {
                                                    dArr7[i26] = (double) fArr3[i25];
                                                    i25++;
                                                    numberOfInterpolatedValues = numberOfInterpolatedValues;
                                                    motionPathsArr2 = motionPathsArr2;
                                                    i26++;
                                                }
                                            }
                                            motionPathsArr = motionPathsArr2;
                                        }
                                        i24++;
                                        dArr5 = dArr;
                                    } else {
                                        str15 = str50;
                                        motionPathsArr = motionPathsArr2;
                                        str16 = str25;
                                    }
                                    i23++;
                                    str50 = str15;
                                    motionPathsArr2 = motionPathsArr;
                                    str25 = str16;
                                }
                                i22++;
                                motionController.mSpline[i22] = CurveFit.get(motionController.mCurveFitType, Arrays.copyOf(dArr5, i24), (double[][]) Arrays.copyOf(dArr6, i24));
                                motionPathsArr2 = motionPathsArr2;
                                str25 = str25;
                            } else {
                                String str51 = str25;
                                motionController.mSpline[0] = CurveFit.get(motionController.mCurveFitType, dArr3, dArr2);
                                if (motionPathsArr2[0].mPathMotionArc != -1) {
                                    int[] iArr7 = new int[size];
                                    double[] dArr8 = new double[size];
                                    int[] iArr8 = new int[2];
                                    iArr8[1] = 2;
                                    iArr8[0] = size;
                                    double[][] dArr9 = (double[][]) Array.newInstance(cls2, iArr8);
                                    for (int i27 = 0; i27 < size; i27++) {
                                        iArr7[i27] = motionPathsArr2[i27].mPathMotionArc;
                                        dArr8[i27] = (double) motionPathsArr2[i27].time;
                                        dArr9[i27][0] = (double) motionPathsArr2[i27].x;
                                        dArr9[i27][1] = (double) motionPathsArr2[i27].y;
                                    }
                                    motionController.mArcSpline = new ArcCurveFit(iArr7, dArr8, dArr9);
                                }
                                motionController.mCycleMap = new HashMap<>();
                                if (motionController.mKeyList != null) {
                                    Iterator it16 = hashSet6.iterator();
                                    while (it16.hasNext()) {
                                        String str52 = (String) it16.next();
                                        if (str52.startsWith("CUSTOM")) {
                                            it2 = it16;
                                            customSet = new ViewOscillator.CustomSet();
                                            str14 = str51;
                                            str9 = str49;
                                            obj2 = obj6;
                                            str8 = str45;
                                            str7 = str43;
                                            str10 = str46;
                                            str11 = str44;
                                            str12 = str48;
                                            str13 = str47;
                                            str5 = str4;
                                            str6 = str41;
                                        } else {
                                            switch (str52.hashCode()) {
                                                case -1249320806:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    if (str52.equals(obj2)) {
                                                        c = 0;
                                                        break;
                                                    }
                                                    c = 65535;
                                                    break;
                                                case -1249320805:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    if (!str52.equals(str5)) {
                                                        obj2 = obj6;
                                                        c = 65535;
                                                        break;
                                                    } else {
                                                        obj2 = obj6;
                                                        c = 1;
                                                        break;
                                                    }
                                                case -1225497657:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    str6 = str41;
                                                    if (!str52.equals(str6)) {
                                                        obj2 = obj6;
                                                        str5 = str4;
                                                        c = 65535;
                                                        break;
                                                    } else {
                                                        obj2 = obj6;
                                                        str5 = str4;
                                                        c = 2;
                                                        break;
                                                    }
                                                case -1225497656:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (str52.equals(str7)) {
                                                        obj2 = obj6;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 3;
                                                        break;
                                                    }
                                                    obj2 = obj6;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                                case -1225497655:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    str8 = str45;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (!str52.equals(str8)) {
                                                        str7 = str43;
                                                        obj2 = obj6;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 65535;
                                                        break;
                                                    } else {
                                                        obj2 = obj6;
                                                        str7 = str43;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 4;
                                                        break;
                                                    }
                                                case -1001078227:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (str52.equals(str9)) {
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 5;
                                                        break;
                                                    }
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                                case -908189618:
                                                    str14 = str51;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (!str52.equals(str10)) {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 65535;
                                                        break;
                                                    } else {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 6;
                                                        break;
                                                    }
                                                case -908189617:
                                                    str14 = str51;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (!str52.equals(str11)) {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 65535;
                                                        break;
                                                    } else {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 7;
                                                        break;
                                                    }
                                                case -797520672:
                                                    str14 = str51;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (str52.equals("waveVariesBy")) {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = '\b';
                                                        break;
                                                    }
                                                    str9 = str49;
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                                case -40300674:
                                                    str14 = str51;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    if (str52.equals(str12)) {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = '\t';
                                                        break;
                                                    }
                                                    str9 = str49;
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                                case -4379043:
                                                    str14 = str51;
                                                    str13 = str47;
                                                    if (str52.equals(str13)) {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str12 = str48;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = '\n';
                                                        break;
                                                    }
                                                    str9 = str49;
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                                case 37232917:
                                                    str14 = str51;
                                                    if (!str52.equals("transitionPathRotate")) {
                                                        str13 = str47;
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str12 = str48;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 65535;
                                                        break;
                                                    } else {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str12 = str48;
                                                        str13 = str47;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = 11;
                                                        break;
                                                    }
                                                case 92909918:
                                                    str14 = str51;
                                                    if (str52.equals(str14)) {
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str12 = str48;
                                                        str13 = str47;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = '\f';
                                                        break;
                                                    }
                                                    str9 = str49;
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                                case 156108012:
                                                    if (str52.equals("waveOffset")) {
                                                        str14 = str51;
                                                        str9 = str49;
                                                        obj2 = obj6;
                                                        str8 = str45;
                                                        str7 = str43;
                                                        str10 = str46;
                                                        str11 = str44;
                                                        str12 = str48;
                                                        str13 = str47;
                                                        str5 = str4;
                                                        str6 = str41;
                                                        c = StringUtil.CARRIAGE_RETURN;
                                                        break;
                                                    }
                                                default:
                                                    str14 = str51;
                                                    str9 = str49;
                                                    obj2 = obj6;
                                                    str8 = str45;
                                                    str7 = str43;
                                                    str10 = str46;
                                                    str11 = str44;
                                                    str12 = str48;
                                                    str13 = str47;
                                                    str5 = str4;
                                                    str6 = str41;
                                                    c = 65535;
                                                    break;
                                            }
                                            switch (c) {
                                                case 0:
                                                    rotationXset = new ViewOscillator.RotationXset();
                                                    break;
                                                case 1:
                                                    rotationXset = new ViewOscillator.RotationYset();
                                                    break;
                                                case 2:
                                                    rotationXset = new ViewOscillator.TranslationXset();
                                                    break;
                                                case 3:
                                                    rotationXset = new ViewOscillator.TranslationYset();
                                                    break;
                                                case 4:
                                                    rotationXset = new ViewOscillator.TranslationZset();
                                                    break;
                                                case 5:
                                                    rotationXset = new ViewOscillator.ProgressSet();
                                                    break;
                                                case 6:
                                                    rotationXset = new ViewOscillator.ScaleXset();
                                                    break;
                                                case 7:
                                                    rotationXset = new ViewOscillator.ScaleYset();
                                                    break;
                                                case '\b':
                                                    rotationXset = new ViewOscillator.AlphaSet();
                                                    break;
                                                case '\t':
                                                    rotationXset = new ViewOscillator.RotationSet();
                                                    break;
                                                case '\n':
                                                    rotationXset = new ViewOscillator.ElevationSet();
                                                    break;
                                                case 11:
                                                    rotationXset = new ViewOscillator.PathRotateSet();
                                                    break;
                                                case '\f':
                                                    rotationXset = new ViewOscillator.AlphaSet();
                                                    break;
                                                case '\r':
                                                    rotationXset = new ViewOscillator.AlphaSet();
                                                    break;
                                                default:
                                                    rotationXset = null;
                                                    break;
                                            }
                                            it2 = it16;
                                            customSet = rotationXset;
                                        }
                                        if (customSet == null) {
                                            str51 = str14;
                                        } else {
                                            customSet.mType = str52;
                                            str51 = str14;
                                            motionController.mCycleMap.put(str52, customSet);
                                        }
                                        it16 = it2;
                                        str47 = str13;
                                        str48 = str12;
                                        str44 = str11;
                                        str46 = str10;
                                        str49 = str9;
                                        str45 = str8;
                                        str43 = str7;
                                        str41 = str6;
                                        str4 = str5;
                                        obj6 = obj2;
                                    }
                                    Iterator<Key> it17 = motionController.mKeyList.iterator();
                                    while (it17.hasNext()) {
                                        it17.next();
                                    }
                                    Iterator<ViewOscillator> it18 = motionController.mCycleMap.values().iterator();
                                    while (it18.hasNext()) {
                                        ViewOscillator next9 = it18.next();
                                        int size2 = next9.mWavePoints.size();
                                        if (size2 == 0) {
                                            cls = cls2;
                                            it = it18;
                                        } else {
                                            Collections.sort(next9.mWavePoints, new KeyCycleOscillator$1(next9));
                                            double[] dArr10 = new double[size2];
                                            int[] iArr9 = new int[2];
                                            iArr9[1] = 3;
                                            iArr9[0] = size2;
                                            double[][] dArr11 = (double[][]) Array.newInstance(cls2, iArr9);
                                            next9.mCycleOscillator = new KeyCycleOscillator$CycleOscillator(0, null, 0, size2);
                                            Iterator<KeyCycleOscillator$WavePoint> it19 = next9.mWavePoints.iterator();
                                            if (!it19.hasNext()) {
                                                KeyCycleOscillator$CycleOscillator keyCycleOscillator$CycleOscillator = next9.mCycleOscillator;
                                                int length2 = keyCycleOscillator$CycleOscillator.mPosition.length;
                                                int[] iArr10 = new int[2];
                                                iArr10[1] = 3;
                                                iArr10[0] = length2;
                                                double[][] dArr12 = (double[][]) Array.newInstance(cls2, iArr10);
                                                float[] fArr4 = keyCycleOscillator$CycleOscillator.mValues;
                                                keyCycleOscillator$CycleOscillator.mSplineValueCache = new double[(fArr4.length + 2)];
                                                keyCycleOscillator$CycleOscillator.mSplineSlopeCache = new double[(fArr4.length + 2)];
                                                if (keyCycleOscillator$CycleOscillator.mPosition[0] > 0.0d) {
                                                    keyCycleOscillator$CycleOscillator.mOscillator.addPoint(0.0d, keyCycleOscillator$CycleOscillator.mPeriod[0]);
                                                }
                                                double[] dArr13 = keyCycleOscillator$CycleOscillator.mPosition;
                                                int length3 = dArr13.length - 1;
                                                if (dArr13[length3] < 1.0d) {
                                                    keyCycleOscillator$CycleOscillator.mOscillator.addPoint(1.0d, keyCycleOscillator$CycleOscillator.mPeriod[length3]);
                                                }
                                                for (int i28 = 0; i28 < dArr12.length; i28++) {
                                                    dArr12[i28][0] = (double) keyCycleOscillator$CycleOscillator.mOffset[i28];
                                                    dArr12[i28][1] = (double) keyCycleOscillator$CycleOscillator.mPhase[i28];
                                                    dArr12[i28][2] = (double) keyCycleOscillator$CycleOscillator.mValues[i28];
                                                    keyCycleOscillator$CycleOscillator.mOscillator.addPoint(keyCycleOscillator$CycleOscillator.mPosition[i28], keyCycleOscillator$CycleOscillator.mPeriod[i28]);
                                                }
                                                Oscillator oscillator = keyCycleOscillator$CycleOscillator.mOscillator;
                                                double d = 0.0d;
                                                int i29 = 0;
                                                while (true) {
                                                    float[] fArr5 = oscillator.mPeriod;
                                                    if (i29 < fArr5.length) {
                                                        d += (double) fArr5[i29];
                                                        i29++;
                                                    } else {
                                                        double d2 = 0.0d;
                                                        int i30 = 1;
                                                        while (true) {
                                                            float[] fArr6 = oscillator.mPeriod;
                                                            if (i30 < fArr6.length) {
                                                                int i31 = i30 - 1;
                                                                float f = (fArr6[i31] + fArr6[i30]) / 2.0f;
                                                                double[] dArr14 = oscillator.mPosition;
                                                                d2 = ((dArr14[i30] - dArr14[i31]) * ((double) f)) + d2;
                                                                i30++;
                                                            } else {
                                                                int i32 = 0;
                                                                while (true) {
                                                                    float[] fArr7 = oscillator.mPeriod;
                                                                    if (i32 < fArr7.length) {
                                                                        fArr7[i32] = (float) (((double) fArr7[i32]) * (d / d2));
                                                                        i32++;
                                                                        it18 = it18;
                                                                        cls2 = cls2;
                                                                    } else {
                                                                        cls = cls2;
                                                                        it = it18;
                                                                        oscillator.mArea[0] = 0.0d;
                                                                        int i33 = 1;
                                                                        while (true) {
                                                                            float[] fArr8 = oscillator.mPeriod;
                                                                            if (i33 < fArr8.length) {
                                                                                int i34 = i33 - 1;
                                                                                double[] dArr15 = oscillator.mPosition;
                                                                                double d3 = dArr15[i33] - dArr15[i34];
                                                                                double[] dArr16 = oscillator.mArea;
                                                                                dArr16[i33] = (d3 * ((double) ((fArr8[i34] + fArr8[i33]) / 2.0f))) + dArr16[i34];
                                                                                i33++;
                                                                            } else {
                                                                                double[] dArr17 = keyCycleOscillator$CycleOscillator.mPosition;
                                                                                if (dArr17.length > 1) {
                                                                                    i3 = 0;
                                                                                    keyCycleOscillator$CycleOscillator.mCurveFit = CurveFit.get(0, dArr17, dArr12);
                                                                                } else {
                                                                                    i3 = 0;
                                                                                    keyCycleOscillator$CycleOscillator.mCurveFit = null;
                                                                                }
                                                                                CurveFit.get(i3, dArr10, dArr11);
                                                                            }
                                                                        }
                                                                    }
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            } else {
                                                Objects.requireNonNull(it19.next());
                                                throw null;
                                            }
                                        }
                                        it18 = it;
                                        cls2 = cls;
                                    }
                                    return;
                                }
                                return;
                            }
                        }
                    }
                }
            }
        }
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25(" start: x: ");
        outline25.append(this.mStartMotionPath.x);
        outline25.append(" y: ");
        outline25.append(this.mStartMotionPath.y);
        outline25.append(" end: x: ");
        outline25.append(this.mEndMotionPath.x);
        outline25.append(" y: ");
        outline25.append(this.mEndMotionPath.y);
        return outline25.toString();
    }
}
