package androidx.constraintlayout.utils.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.ViewParent;
import android.view.animation.Interpolator;
import androidx.constraintlayout.core.motion.utils.CurveFit;
import androidx.constraintlayout.core.motion.utils.VelocityMatrix;
import androidx.constraintlayout.motion.utils.ViewOscillator;
import androidx.constraintlayout.motion.utils.ViewSpline;
import androidx.constraintlayout.motion.widget.MotionController;
import androidx.constraintlayout.motion.widget.MotionInterpolator;
import androidx.constraintlayout.motion.widget.MotionLayout;
import androidx.constraintlayout.motion.widget.MotionPaths;
import androidx.constraintlayout.widget.R$styleable;
import java.util.HashMap;

public class MotionTelltales extends MockView {
    public Matrix mInvertMatrix;
    public MotionLayout mMotionLayout;
    public Paint mPaintTelltales;
    public int mTailColor;
    public float mTailScale;
    public int mVelocityMode;
    public float[] velocity;

    public MotionTelltales(Context context) {
        super(context);
        this.mPaintTelltales = new Paint();
        this.velocity = new float[2];
        this.mInvertMatrix = new Matrix();
        this.mVelocityMode = 0;
        this.mTailColor = -65281;
        this.mTailScale = 0.25f;
        init(context, null);
    }

    @Override // androidx.constraintlayout.utils.widget.MockView
    private void init(Context context, AttributeSet attributeSet) {
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.MotionTelltales);
            int indexCount = obtainStyledAttributes.getIndexCount();
            for (int i = 0; i < indexCount; i++) {
                int index = obtainStyledAttributes.getIndex(i);
                if (index == R$styleable.MotionTelltales_telltales_tailColor) {
                    this.mTailColor = obtainStyledAttributes.getColor(index, this.mTailColor);
                } else if (index == R$styleable.MotionTelltales_telltales_velocityMode) {
                    this.mVelocityMode = obtainStyledAttributes.getInt(index, this.mVelocityMode);
                } else if (index == R$styleable.MotionTelltales_telltales_tailScale) {
                    this.mTailScale = obtainStyledAttributes.getFloat(index, this.mTailScale);
                }
            }
            obtainStyledAttributes.recycle();
        }
        this.mPaintTelltales.setColor(this.mTailColor);
        this.mPaintTelltales.setStrokeWidth(5.0f);
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
    }

    @Override // androidx.constraintlayout.utils.widget.MockView
    public void onDraw(Canvas canvas) {
        float f;
        int i;
        int i2;
        int i3;
        int i4;
        float[] fArr;
        float[] fArr2;
        int i5;
        int i6;
        ViewSpline viewSpline;
        ViewSpline viewSpline2;
        ViewSpline viewSpline3;
        ViewSpline viewSpline4;
        float[] fArr3;
        float f2;
        int i7;
        double[] dArr;
        float f3;
        int i8;
        VelocityMatrix velocityMatrix;
        MotionTelltales motionTelltales = this;
        super.onDraw(canvas);
        getMatrix().invert(motionTelltales.mInvertMatrix);
        if (motionTelltales.mMotionLayout == null) {
            ViewParent parent = getParent();
            if (parent instanceof MotionLayout) {
                motionTelltales.mMotionLayout = (MotionLayout) parent;
                return;
            }
            return;
        }
        int width = getWidth();
        int height = getHeight();
        int i9 = 5;
        float[] fArr4 = {0.1f, 0.25f, 0.5f, 0.75f, 0.9f};
        int i10 = 0;
        while (i10 < i9) {
            float f4 = fArr4[i10];
            int i11 = 0;
            while (i11 < i9) {
                float f5 = fArr4[i11];
                MotionLayout motionLayout = motionTelltales.mMotionLayout;
                float[] fArr5 = motionTelltales.velocity;
                int i12 = motionTelltales.mVelocityMode;
                float f6 = motionLayout.mLastVelocity;
                float f7 = motionLayout.mTransitionLastPosition;
                if (motionLayout.mInterpolator != null) {
                    float signum = Math.signum(motionLayout.mTransitionGoalPosition - f7);
                    float interpolation = motionLayout.mInterpolator.getInterpolation(motionLayout.mTransitionLastPosition + 1.0E-5f);
                    float interpolation2 = motionLayout.mInterpolator.getInterpolation(motionLayout.mTransitionLastPosition);
                    f6 = (((interpolation - interpolation2) / 1.0E-5f) * signum) / motionLayout.mTransitionDuration;
                    f7 = interpolation2;
                }
                Interpolator interpolator = motionLayout.mInterpolator;
                if (interpolator instanceof MotionInterpolator) {
                    f6 = ((MotionInterpolator) interpolator).getVelocity();
                }
                MotionController motionController = motionLayout.mFrameArrayList.get(motionTelltales);
                if ((i12 & 1) == 0) {
                    int width2 = getWidth();
                    int height2 = getHeight();
                    float adjustedPosition = motionController.getAdjustedPosition(f7, motionController.mVelocity);
                    HashMap<String, ViewSpline> hashMap = motionController.mAttributesMap;
                    ViewSpline viewSpline5 = hashMap == null ? null : hashMap.get("translationX");
                    HashMap<String, ViewSpline> hashMap2 = motionController.mAttributesMap;
                    fArr = fArr4;
                    if (hashMap2 == null) {
                        i6 = i12;
                        viewSpline = null;
                    } else {
                        viewSpline = hashMap2.get("translationY");
                        i6 = i12;
                    }
                    HashMap<String, ViewSpline> hashMap3 = motionController.mAttributesMap;
                    i4 = i10;
                    if (hashMap3 == null) {
                        i3 = i11;
                        viewSpline2 = null;
                    } else {
                        viewSpline2 = hashMap3.get("rotation");
                        i3 = i11;
                    }
                    HashMap<String, ViewSpline> hashMap4 = motionController.mAttributesMap;
                    i2 = height;
                    if (hashMap4 == null) {
                        i = width;
                        viewSpline3 = null;
                    } else {
                        viewSpline3 = hashMap4.get("scaleX");
                        i = width;
                    }
                    HashMap<String, ViewSpline> hashMap5 = motionController.mAttributesMap;
                    if (hashMap5 == null) {
                        f = f6;
                        viewSpline4 = null;
                    } else {
                        viewSpline4 = hashMap5.get("scaleY");
                        f = f6;
                    }
                    HashMap<String, ViewOscillator> hashMap6 = motionController.mCycleMap;
                    ViewOscillator viewOscillator = hashMap6 == null ? null : hashMap6.get("translationX");
                    HashMap<String, ViewOscillator> hashMap7 = motionController.mCycleMap;
                    ViewOscillator viewOscillator2 = hashMap7 == null ? null : hashMap7.get("translationY");
                    HashMap<String, ViewOscillator> hashMap8 = motionController.mCycleMap;
                    ViewOscillator viewOscillator3 = hashMap8 == null ? null : hashMap8.get("rotation");
                    HashMap<String, ViewOscillator> hashMap9 = motionController.mCycleMap;
                    ViewOscillator viewOscillator4 = hashMap9 == null ? null : hashMap9.get("scaleX");
                    HashMap<String, ViewOscillator> hashMap10 = motionController.mCycleMap;
                    ViewOscillator viewOscillator5 = hashMap10 == null ? null : hashMap10.get("scaleY");
                    VelocityMatrix velocityMatrix2 = new VelocityMatrix();
                    velocityMatrix2.mDRotate = 0.0f;
                    velocityMatrix2.mDTranslateY = 0.0f;
                    velocityMatrix2.mDTranslateX = 0.0f;
                    velocityMatrix2.mDScaleY = 0.0f;
                    velocityMatrix2.mDScaleX = 0.0f;
                    velocityMatrix2.setRotationVelocity(viewSpline2, adjustedPosition);
                    velocityMatrix2.setTranslationVelocity(viewSpline5, viewSpline, adjustedPosition);
                    velocityMatrix2.setScaleVelocity(viewSpline3, viewSpline4, adjustedPosition);
                    if (viewOscillator3 != null) {
                        velocityMatrix2.mDRotate = viewOscillator3.getSlope(adjustedPosition);
                    }
                    if (viewOscillator != null) {
                        velocityMatrix2.mDTranslateX = viewOscillator.getSlope(adjustedPosition);
                    }
                    if (viewOscillator2 != null) {
                        velocityMatrix2.mDTranslateY = viewOscillator2.getSlope(adjustedPosition);
                    }
                    if (viewOscillator4 != null) {
                        velocityMatrix2.mDScaleX = viewOscillator4.getSlope(adjustedPosition);
                    }
                    if (viewOscillator5 != null) {
                        velocityMatrix2.mDScaleY = viewOscillator5.getSlope(adjustedPosition);
                    }
                    CurveFit curveFit = motionController.mArcSpline;
                    if (curveFit != null) {
                        double[] dArr2 = motionController.mInterpolateData;
                        if (dArr2.length > 0) {
                            double d = (double) adjustedPosition;
                            curveFit.getPos(d, dArr2);
                            motionController.mArcSpline.getSlope(d, motionController.mInterpolateVelocity);
                            velocityMatrix = velocityMatrix2;
                            i8 = i6;
                            fArr3 = fArr5;
                            f3 = f5;
                            motionController.mStartMotionPath.setDpDt(f5, f4, fArr5, motionController.mInterpolateVariables, motionController.mInterpolateVelocity, motionController.mInterpolateData);
                        } else {
                            velocityMatrix = velocityMatrix2;
                            f3 = f5;
                            fArr3 = fArr5;
                            i8 = i6;
                        }
                        velocityMatrix.applyTransform(f3, f4, width2, height2, fArr3);
                        i7 = i8;
                        f2 = f3;
                    } else if (motionController.mSpline != null) {
                        double adjustedPosition2 = (double) motionController.getAdjustedPosition(adjustedPosition, motionController.mVelocity);
                        motionController.mSpline[0].getSlope(adjustedPosition2, motionController.mInterpolateVelocity);
                        motionController.mSpline[0].getPos(adjustedPosition2, motionController.mInterpolateData);
                        float f8 = motionController.mVelocity[0];
                        int i13 = 0;
                        while (true) {
                            dArr = motionController.mInterpolateVelocity;
                            if (i13 >= dArr.length) {
                                break;
                            }
                            dArr[i13] = dArr[i13] * ((double) f8);
                            i13++;
                        }
                        i7 = i6;
                        fArr3 = fArr5;
                        f2 = f5;
                        motionController.mStartMotionPath.setDpDt(f5, f4, fArr5, motionController.mInterpolateVariables, dArr, motionController.mInterpolateData);
                        velocityMatrix2.applyTransform(f2, f4, width2, height2, fArr3);
                    } else {
                        MotionPaths motionPaths = motionController.mEndMotionPath;
                        float f9 = motionPaths.x;
                        MotionPaths motionPaths2 = motionController.mStartMotionPath;
                        float f10 = f9 - motionPaths2.x;
                        float f11 = motionPaths.y - motionPaths2.y;
                        fArr5[0] = (((motionPaths.width - motionPaths2.width) + f10) * f5) + ((1.0f - f5) * f10);
                        fArr5[1] = (((motionPaths.height - motionPaths2.height) + f11) * f4) + ((1.0f - f4) * f11);
                        velocityMatrix2.mDRotate = 0.0f;
                        velocityMatrix2.mDTranslateY = 0.0f;
                        velocityMatrix2.mDTranslateX = 0.0f;
                        velocityMatrix2.mDScaleY = 0.0f;
                        velocityMatrix2.mDScaleX = 0.0f;
                        velocityMatrix2.setRotationVelocity(viewSpline2, adjustedPosition);
                        velocityMatrix2.setTranslationVelocity(viewSpline5, viewSpline, adjustedPosition);
                        velocityMatrix2.setScaleVelocity(viewSpline3, viewSpline4, adjustedPosition);
                        if (viewOscillator3 != null) {
                            velocityMatrix2.mDRotate = viewOscillator3.getSlope(adjustedPosition);
                        }
                        if (viewOscillator != null) {
                            velocityMatrix2.mDTranslateX = viewOscillator.getSlope(adjustedPosition);
                        }
                        if (viewOscillator2 != null) {
                            velocityMatrix2.mDTranslateY = viewOscillator2.getSlope(adjustedPosition);
                        }
                        if (viewOscillator4 != null) {
                            velocityMatrix2.mDScaleX = viewOscillator4.getSlope(adjustedPosition);
                        }
                        if (viewOscillator5 != null) {
                            velocityMatrix2.mDScaleY = viewOscillator5.getSlope(adjustedPosition);
                        }
                        i5 = i6;
                        fArr2 = fArr5;
                        velocityMatrix2.applyTransform(f5, f4, width2, height2, fArr5);
                    }
                    i5 = i7;
                    f5 = f2;
                    fArr2 = fArr3;
                } else {
                    i = width;
                    i2 = height;
                    f = f6;
                    fArr = fArr4;
                    i4 = i10;
                    i5 = i12;
                    fArr2 = fArr5;
                    i3 = i11;
                    motionController.getDpDt(f7, f5, f4, fArr2);
                }
                if (i5 < 2) {
                    fArr2[0] = fArr2[0] * f;
                    fArr2[1] = fArr2[1] * f;
                }
                motionTelltales = this;
                motionTelltales.mInvertMatrix.mapVectors(motionTelltales.velocity);
                width = i;
                float f12 = ((float) width) * f5;
                height = i2;
                float f13 = ((float) height) * f4;
                float[] fArr6 = motionTelltales.velocity;
                float f14 = fArr6[0];
                float f15 = motionTelltales.mTailScale;
                float f16 = f13 - (fArr6[1] * f15);
                motionTelltales.mInvertMatrix.mapVectors(fArr6);
                canvas.drawLine(f12, f13, f12 - (f14 * f15), f16, motionTelltales.mPaintTelltales);
                i11 = i3 + 1;
                fArr4 = fArr;
                i10 = i4;
                i9 = 5;
            }
            i10++;
            i9 = 5;
        }
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        postInvalidate();
    }

    public void setText(CharSequence charSequence) {
        this.mText = charSequence.toString();
        requestLayout();
    }

    public MotionTelltales(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.mPaintTelltales = new Paint();
        this.velocity = new float[2];
        this.mInvertMatrix = new Matrix();
        this.mVelocityMode = 0;
        this.mTailColor = -65281;
        this.mTailScale = 0.25f;
        init(context, attributeSet);
    }

    public MotionTelltales(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.mPaintTelltales = new Paint();
        this.velocity = new float[2];
        this.mInvertMatrix = new Matrix();
        this.mVelocityMode = 0;
        this.mTailColor = -65281;
        this.mTailScale = 0.25f;
        init(context, attributeSet);
    }
}
