package androidx.core.view;

import android.content.ClipData;
import android.net.Uri;
import android.os.Bundle;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.Locale;
import java.util.Objects;

public final class ContentInfoCompat {
    public final ClipData mClip;
    public final Bundle mExtras;
    public final int mFlags;
    public final Uri mLinkUri;
    public final int mSource;

    public final class Builder {
        public ClipData mClip;
        public Bundle mExtras;
        public int mFlags;
        public Uri mLinkUri;
        public int mSource;

        public Builder(ClipData clipData, int i) {
            this.mClip = clipData;
            this.mSource = i;
        }
    }

    public ContentInfoCompat(Builder builder) {
        ClipData clipData = builder.mClip;
        Objects.requireNonNull(clipData);
        this.mClip = clipData;
        int i = builder.mSource;
        if (i < 0) {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%d, %d] (too low)", "source", 0, 3));
        } else if (i <= 3) {
            this.mSource = i;
            int i2 = builder.mFlags;
            if ((i2 & 1) == i2) {
                this.mFlags = i2;
                this.mLinkUri = builder.mLinkUri;
                this.mExtras = builder.mExtras;
                return;
            }
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Requested flags 0x");
            outline25.append(Integer.toHexString(i2));
            outline25.append(", but only 0x");
            outline25.append(Integer.toHexString(1));
            outline25.append(" are allowed");
            throw new IllegalArgumentException(outline25.toString());
        } else {
            throw new IllegalArgumentException(String.format(Locale.US, "%s is out of range of [%d, %d] (too high)", "source", 0, 3));
        }
    }

    public String toString() {
        String str;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("ContentInfoCompat{clip=");
        outline25.append(this.mClip);
        outline25.append(", source=");
        int i = this.mSource;
        outline25.append(i != 0 ? i != 1 ? i != 2 ? i != 3 ? String.valueOf(i) : "SOURCE_DRAG_AND_DROP" : "SOURCE_INPUT_METHOD" : "SOURCE_CLIPBOARD" : "SOURCE_APP");
        outline25.append(", flags=");
        int i2 = this.mFlags;
        if ((i2 & 1) != 0) {
            str = "FLAG_CONVERT_TO_PLAIN_TEXT";
        } else {
            str = String.valueOf(i2);
        }
        outline25.append(str);
        outline25.append(", linkUri=");
        outline25.append(this.mLinkUri);
        outline25.append(", extras=");
        outline25.append(this.mExtras);
        outline25.append("}");
        return outline25.toString();
    }
}
