package androidx.core.widget;

import android.content.ClipData;
import android.content.Context;
import android.text.Editable;
import android.text.Selection;
import android.text.SpannableStringBuilder;
import android.text.Spanned;
import android.util.Log;
import android.view.View;
import android.widget.TextView;
import androidx.core.view.ContentInfoCompat;

public final class TextViewOnReceiveContentListener {
    public static CharSequence coerceToText(Context context, ClipData.Item item, int i) {
        if ((i & 1) == 0) {
            return item.coerceToStyledText(context);
        }
        CharSequence coerceToText = item.coerceToText(context);
        if (coerceToText instanceof Spanned) {
            return coerceToText.toString();
        }
        return coerceToText;
    }

    public static void replaceSelection(Editable editable, CharSequence charSequence) {
        int selectionStart = Selection.getSelectionStart(editable);
        int selectionEnd = Selection.getSelectionEnd(editable);
        int max = Math.max(0, Math.min(selectionStart, selectionEnd));
        int max2 = Math.max(0, Math.max(selectionStart, selectionEnd));
        Selection.setSelection(editable, max2);
        editable.replace(max, max2, charSequence);
    }

    public ContentInfoCompat onReceiveContent(View view, ContentInfoCompat contentInfoCompat) {
        if (Log.isLoggable("ReceiveContent", 3)) {
            Log.d("ReceiveContent", "onReceive: " + contentInfoCompat);
        }
        int i = contentInfoCompat.mSource;
        if (i == 2) {
            return contentInfoCompat;
        }
        int i2 = 0;
        if (i == 3) {
            TextView textView = (TextView) view;
            ClipData clipData = contentInfoCompat.mClip;
            Context context = textView.getContext();
            int i3 = contentInfoCompat.mFlags;
            SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
            while (i2 < clipData.getItemCount()) {
                CharSequence coerceToText = coerceToText(context, clipData.getItemAt(i2), i3);
                if (coerceToText != null) {
                    spannableStringBuilder.append(coerceToText);
                }
                i2++;
            }
            replaceSelection((Editable) textView.getText(), spannableStringBuilder);
            return null;
        }
        ClipData clipData2 = contentInfoCompat.mClip;
        int i4 = contentInfoCompat.mFlags;
        TextView textView2 = (TextView) view;
        Editable editable = (Editable) textView2.getText();
        Context context2 = textView2.getContext();
        boolean z = false;
        while (i2 < clipData2.getItemCount()) {
            CharSequence coerceToText2 = coerceToText(context2, clipData2.getItemAt(i2), i4);
            if (coerceToText2 != null) {
                if (!z) {
                    replaceSelection(editable, coerceToText2);
                    z = true;
                } else {
                    editable.insert(Selection.getSelectionEnd(editable), "\n");
                    editable.insert(Selection.getSelectionEnd(editable), coerceToText2);
                }
            }
            i2++;
        }
        return null;
    }
}
