package androidx.databinding;

import android.annotation.TargetApi;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.util.SparseIntArray;
import android.view.Choreographer;
import android.view.View;
import android.view.ViewGroup;
import androidx.databinding.library.R$id;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleObserver;
import androidx.lifecycle.OnLifecycleEvent;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;

public abstract class ViewDataBinding extends BaseObservable {
    public static final View.OnAttachStateChangeListener ROOT_REATTACHED_LISTENER = new View.OnAttachStateChangeListener() {
        /* class androidx.databinding.ViewDataBinding.AnonymousClass6 */

        @TargetApi(19)
        public void onViewAttachedToWindow(View view) {
            (view != null ? (ViewDataBinding) view.getTag(R$id.dataBinding) : null).mRebindRunnable.run();
            view.removeOnAttachStateChangeListener(this);
        }

        public void onViewDetachedFromWindow(View view) {
        }
    };
    public static int SDK_INT;
    public static final boolean USE_CHOREOGRAPHER;
    public static final ReferenceQueue<ViewDataBinding> sReferenceQueue = new ReferenceQueue<>();
    public Choreographer mChoreographer;
    public final Choreographer.FrameCallback mFrameCallback;
    public boolean mIsExecutingPendingBindings;
    public boolean mPendingRebind;
    public boolean mRebindHalted;
    public final Runnable mRebindRunnable;
    public final View mRoot;
    public Handler mUIThreadHandler;

    public static class OnStartListener implements LifecycleObserver {
        @OnLifecycleEvent(Lifecycle.Event.ON_START)
        public void onStart() {
            throw null;
        }
    }

    public abstract class WeakListener<T> extends WeakReference<ViewDataBinding> {
    }

    static {
        int i = Build.VERSION.SDK_INT;
        SDK_INT = i;
        USE_CHOREOGRAPHER = i >= 16;
    }

    public ViewDataBinding(Object obj, View view, int i) {
        if (obj == null) {
            this.mRebindRunnable = new Runnable() {
                /* class androidx.databinding.ViewDataBinding.AnonymousClass7 */

                public void run() {
                    synchronized (this) {
                        ViewDataBinding.this.mPendingRebind = false;
                    }
                    do {
                    } while (ViewDataBinding.sReferenceQueue.poll() != null);
                    if (!ViewDataBinding.this.mRoot.isAttachedToWindow()) {
                        View view = ViewDataBinding.this.mRoot;
                        View.OnAttachStateChangeListener onAttachStateChangeListener = ViewDataBinding.ROOT_REATTACHED_LISTENER;
                        view.removeOnAttachStateChangeListener(onAttachStateChangeListener);
                        ViewDataBinding.this.mRoot.addOnAttachStateChangeListener(onAttachStateChangeListener);
                        return;
                    }
                    ViewDataBinding.this.executePendingBindings();
                }
            };
            this.mPendingRebind = false;
            this.mRebindHalted = false;
            WeakListener[] weakListenerArr = new WeakListener[i];
            this.mRoot = view;
            if (Looper.myLooper() == null) {
                throw new IllegalStateException("DataBinding must be created in view's UI Thread");
            } else if (USE_CHOREOGRAPHER) {
                this.mChoreographer = Choreographer.getInstance();
                this.mFrameCallback = new Choreographer.FrameCallback() {
                    /* class androidx.databinding.ViewDataBinding.AnonymousClass8 */

                    public void doFrame(long j) {
                        ViewDataBinding.this.mRebindRunnable.run();
                    }
                };
            } else {
                this.mFrameCallback = null;
                this.mUIThreadHandler = new Handler(Looper.myLooper());
            }
        } else {
            throw new IllegalArgumentException("The provided bindingComponent parameter must be an instance of DataBindingComponent. See  https://issuetracker.google.com/issues/116541301 for details of why this parameter is not defined as DataBindingComponent");
        }
    }

    public static boolean isNumeric(String str, int i) {
        int length = str.length();
        if (length == i) {
            return false;
        }
        while (i < length) {
            if (!Character.isDigit(str.charAt(i))) {
                return false;
            }
            i++;
        }
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x0076  */
    /* JADX WARNING: Removed duplicated region for block: B:43:? A[ORIG_RETURN, RETURN, SYNTHETIC] */
    public static void mapBindings(DataBindingComponent dataBindingComponent, View view, Object[] objArr, SparseIntArray sparseIntArray, boolean z) {
        int id;
        int i;
        String str = null;
        if ((view != null ? (ViewDataBinding) view.getTag(R$id.dataBinding) : null) == null) {
            Object tag = view.getTag();
            if (tag instanceof String) {
                str = (String) tag;
            }
            boolean z2 = true;
            if (z && str != null && str.startsWith("layout")) {
                int lastIndexOf = str.lastIndexOf(95);
                if (lastIndexOf > 0) {
                    int i2 = lastIndexOf + 1;
                    if (isNumeric(str, i2)) {
                        int parseTagInt = parseTagInt(str, i2);
                        if (objArr[parseTagInt] == null) {
                            objArr[parseTagInt] = view;
                        }
                        objArr[i] = view;
                        if (view instanceof ViewGroup) {
                        }
                    }
                }
            } else if (str != null && str.startsWith("binding_")) {
                int parseTagInt2 = parseTagInt(str, 8);
                if (objArr[parseTagInt2] == null) {
                    objArr[parseTagInt2] = view;
                }
                if (!z2 && (id = view.getId()) > 0 && sparseIntArray != null && (i = sparseIntArray.get(id, -1)) >= 0 && objArr[i] == null) {
                    objArr[i] = view;
                }
                if (view instanceof ViewGroup) {
                    ViewGroup viewGroup = (ViewGroup) view;
                    int childCount = viewGroup.getChildCount();
                    for (int i3 = 0; i3 < childCount; i3++) {
                        mapBindings(dataBindingComponent, viewGroup.getChildAt(i3), objArr, sparseIntArray, false);
                    }
                    return;
                }
                return;
            }
            z2 = false;
            objArr[i] = view;
            if (view instanceof ViewGroup) {
            }
        }
    }

    public static int parseTagInt(String str, int i) {
        int length = str.length();
        int i2 = 0;
        while (i < length) {
            i2 = (i2 * 10) + (str.charAt(i) - '0');
            i++;
        }
        return i2;
    }

    public abstract void executeBindings();

    public void executePendingBindings() {
        if (this.mIsExecutingPendingBindings) {
            requestRebind();
        } else if (hasPendingBindings()) {
            this.mIsExecutingPendingBindings = true;
            this.mRebindHalted = false;
            executeBindings();
            this.mIsExecutingPendingBindings = false;
        }
    }

    public abstract boolean hasPendingBindings();

    /* JADX WARNING: Code restructure failed: missing block: B:10:0x000f, code lost:
        r2.mChoreographer.postFrameCallback(r2.mFrameCallback);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0017, code lost:
        r2.mUIThreadHandler.post(r2.mRebindRunnable);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x000d, code lost:
        if (androidx.databinding.ViewDataBinding.USE_CHOREOGRAPHER == false) goto L_0x0017;
     */
    public void requestRebind() {
        synchronized (this) {
            if (!this.mPendingRebind) {
                this.mPendingRebind = true;
            }
        }
    }

    public static Object[] mapBindings(DataBindingComponent dataBindingComponent, View view, int i, SparseIntArray sparseIntArray) {
        Object[] objArr = new Object[i];
        mapBindings(dataBindingComponent, view, objArr, sparseIntArray, true);
        return objArr;
    }
}
