package androidx.emoji.widget;

import android.text.method.KeyListener;
import android.view.inputmethod.EditorInfo;
import android.view.inputmethod.InputConnection;
import android.widget.EditText;
import androidx.appcompat.app.AppCompatDelegateImpl;

public final class EmojiEditTextHelper {
    public int mEmojiReplaceStrategy = 0;
    public final HelperInternal mHelper;
    public int mMaxEmojiCount = Integer.MAX_VALUE;

    public abstract class HelperInternal {
        public abstract KeyListener getKeyListener(KeyListener keyListener);

        public abstract InputConnection onCreateInputConnection(InputConnection inputConnection, EditorInfo editorInfo);

        public abstract void setEmojiReplaceStrategy(int i);

        public abstract void setMaxEmojiCount(int i);
    }

    public class HelperInternal19 extends HelperInternal {
        public final EditText mEditText;
        public final EmojiTextWatcher mTextWatcher;

        public HelperInternal19(EditText editText) {
            this.mEditText = editText;
            EmojiTextWatcher emojiTextWatcher = new EmojiTextWatcher(editText);
            this.mTextWatcher = emojiTextWatcher;
            editText.addTextChangedListener(emojiTextWatcher);
            if (EmojiEditableFactory.sInstance == null) {
                synchronized (EmojiEditableFactory.sInstanceLock) {
                    if (EmojiEditableFactory.sInstance == null) {
                        EmojiEditableFactory.sInstance = new EmojiEditableFactory();
                    }
                }
            }
            editText.setEditableFactory(EmojiEditableFactory.sInstance);
        }

        @Override // androidx.emoji.widget.EmojiEditTextHelper.HelperInternal
        public KeyListener getKeyListener(KeyListener keyListener) {
            if (keyListener instanceof EmojiKeyListener) {
                return keyListener;
            }
            return new EmojiKeyListener(keyListener);
        }

        @Override // androidx.emoji.widget.EmojiEditTextHelper.HelperInternal
        public InputConnection onCreateInputConnection(InputConnection inputConnection, EditorInfo editorInfo) {
            if (inputConnection instanceof EmojiInputConnection) {
                return inputConnection;
            }
            new EmojiInputConnection(this.mEditText, inputConnection, editorInfo);
            throw null;
        }

        @Override // androidx.emoji.widget.EmojiEditTextHelper.HelperInternal
        public void setEmojiReplaceStrategy(int i) {
            this.mTextWatcher.mEmojiReplaceStrategy = i;
        }

        @Override // androidx.emoji.widget.EmojiEditTextHelper.HelperInternal
        public void setMaxEmojiCount(int i) {
            this.mTextWatcher.mMaxEmojiCount = i;
        }
    }

    public EmojiEditTextHelper(EditText editText) {
        AppCompatDelegateImpl.Api17Impl.checkNotNull(editText, "editText cannot be null");
        this.mHelper = new HelperInternal19(editText);
    }

    public KeyListener getKeyListener(KeyListener keyListener) {
        AppCompatDelegateImpl.Api17Impl.checkNotNull(keyListener, "keyListener cannot be null");
        return this.mHelper.getKeyListener(keyListener);
    }

    public InputConnection onCreateInputConnection(InputConnection inputConnection, EditorInfo editorInfo) {
        if (inputConnection == null) {
            return null;
        }
        return this.mHelper.onCreateInputConnection(inputConnection, editorInfo);
    }

    public void setMaxEmojiCount(int i) {
        if (i >= 0) {
            this.mMaxEmojiCount = i;
            this.mHelper.setMaxEmojiCount(i);
            return;
        }
        throw new IllegalArgumentException("maxEmojiCount should be greater than 0");
    }
}
