package androidx.fragment.app;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.content.Context;
import android.graphics.Rect;
import android.transition.Transition;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.collection.ArrayMap;
import androidx.collection.MapCollections;
import androidx.core.app.SharedElementCallback;
import androidx.core.os.CancellationSignal;
import androidx.core.view.OneShotPreDrawListener;
import androidx.core.view.ViewCompat;
import androidx.fragment.app.SpecialEffectsController;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public class DefaultSpecialEffectsController extends SpecialEffectsController {

    public class AnimationInfo extends SpecialEffectsInfo {
        public FragmentAnim$AnimationOrAnimator mAnimation;
        public boolean mIsPop;
        public boolean mLoadedAnim = false;

        public AnimationInfo(SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation, CancellationSignal cancellationSignal, boolean z) {
            super(fragmentStateManagerOperation, cancellationSignal);
            this.mIsPop = z;
        }

        public FragmentAnim$AnimationOrAnimator getAnimation(Context context) {
            if (this.mLoadedAnim) {
                return this.mAnimation;
            }
            SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation = this.mOperation;
            FragmentAnim$AnimationOrAnimator loadAnimation = AppCompatDelegateImpl.Api17Impl.loadAnimation(context, fragmentStateManagerOperation.mFragment, fragmentStateManagerOperation.mFinalState == SpecialEffectsController$Operation$State.VISIBLE, this.mIsPop);
            this.mAnimation = loadAnimation;
            this.mLoadedAnim = true;
            return loadAnimation;
        }
    }

    public abstract class SpecialEffectsInfo {
        public final SpecialEffectsController.FragmentStateManagerOperation mOperation;
        public final CancellationSignal mSignal;

        public SpecialEffectsInfo(SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation, CancellationSignal cancellationSignal) {
            this.mOperation = fragmentStateManagerOperation;
            this.mSignal = cancellationSignal;
        }

        public void completeSpecialEffect() {
            SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation = this.mOperation;
            if (fragmentStateManagerOperation.mSpecialEffectsSignals.remove(this.mSignal) && fragmentStateManagerOperation.mSpecialEffectsSignals.isEmpty()) {
                fragmentStateManagerOperation.complete();
            }
        }

        public boolean isVisibilityUnchanged() {
            SpecialEffectsController$Operation$State specialEffectsController$Operation$State;
            SpecialEffectsController$Operation$State from = SpecialEffectsController$Operation$State.from(this.mOperation.mFragment.mView);
            SpecialEffectsController$Operation$State specialEffectsController$Operation$State2 = this.mOperation.mFinalState;
            return from == specialEffectsController$Operation$State2 || !(from == (specialEffectsController$Operation$State = SpecialEffectsController$Operation$State.VISIBLE) || specialEffectsController$Operation$State2 == specialEffectsController$Operation$State);
        }
    }

    public class TransitionInfo extends SpecialEffectsInfo {
        public final boolean mOverlapAllowed;
        public final Object mSharedElementTransition;
        public final Object mTransition;

        public TransitionInfo(SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation, CancellationSignal cancellationSignal, boolean z, boolean z2) {
            super(fragmentStateManagerOperation, cancellationSignal);
            Object obj;
            Object obj2;
            boolean z3;
            if (fragmentStateManagerOperation.mFinalState == SpecialEffectsController$Operation$State.VISIBLE) {
                if (z) {
                    obj2 = fragmentStateManagerOperation.mFragment.getReenterTransition();
                } else {
                    obj2 = fragmentStateManagerOperation.mFragment.getEnterTransition();
                }
                this.mTransition = obj2;
                if (z) {
                    z3 = fragmentStateManagerOperation.mFragment.getAllowReturnTransitionOverlap();
                } else {
                    z3 = fragmentStateManagerOperation.mFragment.getAllowEnterTransitionOverlap();
                }
                this.mOverlapAllowed = z3;
            } else {
                if (z) {
                    obj = fragmentStateManagerOperation.mFragment.getReturnTransition();
                } else {
                    obj = fragmentStateManagerOperation.mFragment.getExitTransition();
                }
                this.mTransition = obj;
                this.mOverlapAllowed = true;
            }
            if (!z2) {
                this.mSharedElementTransition = null;
            } else if (z) {
                this.mSharedElementTransition = fragmentStateManagerOperation.mFragment.getSharedElementReturnTransition();
            } else {
                this.mSharedElementTransition = fragmentStateManagerOperation.mFragment.getSharedElementEnterTransition();
            }
        }

        public final FragmentTransitionImpl getHandlingImpl(Object obj) {
            if (obj == null) {
                return null;
            }
            FragmentTransitionImpl fragmentTransitionImpl = FragmentTransition.PLATFORM_IMPL;
            if (obj instanceof Transition) {
                return fragmentTransitionImpl;
            }
            FragmentTransitionImpl fragmentTransitionImpl2 = FragmentTransition.SUPPORT_IMPL;
            if (fragmentTransitionImpl2 != null && fragmentTransitionImpl2.canHandle(obj)) {
                return fragmentTransitionImpl2;
            }
            throw new IllegalArgumentException("Transition " + obj + " for fragment " + this.mOperation.mFragment + " is not a valid framework Transition or AndroidX Transition");
        }
    }

    public DefaultSpecialEffectsController(ViewGroup viewGroup) {
        super(viewGroup);
    }

    public void captureTransitioningViews(ArrayList<View> arrayList, View view) {
        if (view instanceof ViewGroup) {
            ViewGroup viewGroup = (ViewGroup) view;
            if (!viewGroup.isTransitionGroup()) {
                int childCount = viewGroup.getChildCount();
                for (int i = 0; i < childCount; i++) {
                    View childAt = viewGroup.getChildAt(i);
                    if (childAt.getVisibility() == 0) {
                        captureTransitioningViews(arrayList, childAt);
                    }
                }
            } else if (!arrayList.contains(view)) {
                arrayList.add(viewGroup);
            }
        } else if (!arrayList.contains(view)) {
            arrayList.add(view);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:89:0x02f7, code lost:
        r1 = r11.get(r10.get(r1));
     */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x057b  */
    /* JADX WARNING: Removed duplicated region for block: B:195:0x062a  */
    /* JADX WARNING: Removed duplicated region for block: B:214:0x06c2 A[LOOP:11: B:212:0x06bc->B:214:0x06c2, LOOP_END] */
    @Override // androidx.fragment.app.SpecialEffectsController
    public void executeOperations(List<SpecialEffectsController.FragmentStateManagerOperation> list, final boolean z) {
        ArrayList arrayList;
        HashMap hashMap;
        String str;
        ArrayList arrayList2;
        Iterator it;
        Iterator it2;
        Iterator it3;
        ArrayList arrayList3;
        String str2;
        View view;
        Object obj;
        String str3;
        ArrayList<View> arrayList4;
        View view2;
        SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation;
        Object obj2;
        SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation2;
        Object obj3;
        ArrayMap arrayMap;
        ArrayList arrayList5;
        ArrayList arrayList6;
        View view3;
        SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation3;
        SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation4;
        HashMap hashMap2;
        ArrayList<View> arrayList7;
        String str4;
        ArrayList<View> arrayList8;
        View view4;
        final Rect rect;
        final FragmentTransitionImpl fragmentTransitionImpl;
        SharedElementCallback sharedElementCallback;
        SharedElementCallback sharedElementCallback2;
        Object obj4;
        int i;
        View view5;
        final View view6;
        boolean z2 = z;
        final SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation5 = null;
        final SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation6 = null;
        for (SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation7 : list) {
            SpecialEffectsController$Operation$State from = SpecialEffectsController$Operation$State.from(fragmentStateManagerOperation7.mFragment.mView);
            int ordinal = fragmentStateManagerOperation7.mFinalState.ordinal();
            if (ordinal != 0) {
                if (ordinal != 1) {
                    if (!(ordinal == 2 || ordinal == 3)) {
                    }
                } else if (from != SpecialEffectsController$Operation$State.VISIBLE) {
                    fragmentStateManagerOperation6 = fragmentStateManagerOperation7;
                }
            }
            if (from == SpecialEffectsController$Operation$State.VISIBLE && fragmentStateManagerOperation5 == null) {
                fragmentStateManagerOperation5 = fragmentStateManagerOperation7;
            }
        }
        ArrayList arrayList9 = new ArrayList();
        ArrayList arrayList10 = new ArrayList();
        final ArrayList arrayList11 = new ArrayList(list);
        Iterator<SpecialEffectsController.FragmentStateManagerOperation> it4 = list.iterator();
        while (it4.hasNext()) {
            final SpecialEffectsController.FragmentStateManagerOperation next = it4.next();
            CancellationSignal cancellationSignal = new CancellationSignal();
            next.onStart();
            next.mSpecialEffectsSignals.add(cancellationSignal);
            arrayList9.add(new AnimationInfo(next, cancellationSignal, z2));
            CancellationSignal cancellationSignal2 = new CancellationSignal();
            next.onStart();
            next.mSpecialEffectsSignals.add(cancellationSignal2);
            arrayList10.add(new TransitionInfo(next, cancellationSignal2, z2, !z2 ? next == fragmentStateManagerOperation6 : next == fragmentStateManagerOperation5));
            next.mCompletionListeners.add(new Runnable() {
                /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass1 */

                public void run() {
                    if (arrayList11.contains(next)) {
                        arrayList11.remove(next);
                        DefaultSpecialEffectsController defaultSpecialEffectsController = DefaultSpecialEffectsController.this;
                        SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation = next;
                        Objects.requireNonNull(defaultSpecialEffectsController);
                        fragmentStateManagerOperation.mFinalState.applyState(fragmentStateManagerOperation.mFragment.mView);
                    }
                }
            });
        }
        HashMap hashMap3 = new HashMap();
        Iterator it5 = arrayList10.iterator();
        FragmentTransitionImpl fragmentTransitionImpl2 = null;
        while (it5.hasNext()) {
            TransitionInfo transitionInfo = (TransitionInfo) it5.next();
            if (!transitionInfo.isVisibilityUnchanged()) {
                FragmentTransitionImpl handlingImpl = transitionInfo.getHandlingImpl(transitionInfo.mTransition);
                FragmentTransitionImpl handlingImpl2 = transitionInfo.getHandlingImpl(transitionInfo.mSharedElementTransition);
                if (handlingImpl == null || handlingImpl2 == null || handlingImpl == handlingImpl2) {
                    if (handlingImpl == null) {
                        handlingImpl = handlingImpl2;
                    }
                    if (fragmentTransitionImpl2 == null) {
                        fragmentTransitionImpl2 = handlingImpl;
                    } else if (!(handlingImpl == null || fragmentTransitionImpl2 == handlingImpl)) {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Mixing framework transitions and AndroidX transitions is not allowed. Fragment ");
                        outline25.append(transitionInfo.mOperation.mFragment);
                        outline25.append(" returned Transition ");
                        outline25.append(transitionInfo.mTransition);
                        outline25.append(" which uses a different Transition  type than other Fragments.");
                        throw new IllegalArgumentException(outline25.toString());
                    }
                } else {
                    StringBuilder outline252 = GeneratedOutlineSupport.outline25("Mixing framework transitions and AndroidX transitions is not allowed. Fragment ");
                    outline252.append(transitionInfo.mOperation.mFragment);
                    outline252.append(" returned Transition ");
                    outline252.append(transitionInfo.mTransition);
                    outline252.append(" which uses a different Transition  type than its shared element transition ");
                    outline252.append(transitionInfo.mSharedElementTransition);
                    throw new IllegalArgumentException(outline252.toString());
                }
            }
        }
        String str5 = "FragmentManager";
        if (fragmentTransitionImpl2 == null) {
            Iterator it6 = arrayList10.iterator();
            while (it6.hasNext()) {
                TransitionInfo transitionInfo2 = (TransitionInfo) it6.next();
                hashMap3.put(transitionInfo2.mOperation, Boolean.FALSE);
                transitionInfo2.completeSpecialEffect();
            }
            arrayList = arrayList9;
            arrayList3 = arrayList11;
            hashMap = hashMap3;
            str = str5;
        } else {
            View view7 = new View(this.mContainer.getContext());
            Rect rect2 = new Rect();
            ArrayList<View> arrayList12 = new ArrayList<>();
            ArrayList<View> arrayList13 = new ArrayList<>();
            ArrayMap arrayMap2 = new ArrayMap();
            Iterator it7 = arrayList10.iterator();
            Object obj5 = null;
            Rect rect3 = rect2;
            SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation8 = fragmentStateManagerOperation6;
            arrayList = arrayList9;
            View view8 = null;
            boolean z3 = false;
            View view9 = view7;
            SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation9 = fragmentStateManagerOperation5;
            while (it7.hasNext()) {
                Object obj6 = ((TransitionInfo) it7.next()).mSharedElementTransition;
                if (!(obj6 != null) || fragmentStateManagerOperation9 == null || fragmentStateManagerOperation8 == null) {
                    rect = rect3;
                    arrayMap = arrayMap2;
                    view3 = view8;
                    arrayList5 = arrayList10;
                    arrayList6 = arrayList11;
                    hashMap2 = hashMap3;
                    str4 = str5;
                    arrayList7 = arrayList12;
                    fragmentStateManagerOperation4 = fragmentStateManagerOperation5;
                    view4 = view9;
                    arrayList8 = arrayList13;
                    fragmentTransitionImpl = fragmentTransitionImpl2;
                    fragmentStateManagerOperation3 = fragmentStateManagerOperation6;
                } else {
                    Object wrapTransitionInSet = fragmentTransitionImpl2.wrapTransitionInSet(fragmentTransitionImpl2.cloneTransition(obj6));
                    ArrayList<String> sharedElementSourceNames = fragmentStateManagerOperation8.mFragment.getSharedElementSourceNames();
                    view3 = view8;
                    ArrayList<String> sharedElementSourceNames2 = fragmentStateManagerOperation9.mFragment.getSharedElementSourceNames();
                    arrayList6 = arrayList11;
                    arrayList5 = arrayList10;
                    int i2 = 0;
                    for (ArrayList<String> sharedElementTargetNames = fragmentStateManagerOperation9.mFragment.getSharedElementTargetNames(); i2 < sharedElementTargetNames.size(); sharedElementTargetNames = sharedElementTargetNames) {
                        int indexOf = sharedElementSourceNames.indexOf(sharedElementTargetNames.get(i2));
                        if (indexOf != -1) {
                            sharedElementSourceNames.set(indexOf, sharedElementSourceNames2.get(i2));
                        }
                        i2++;
                    }
                    ArrayList<String> sharedElementTargetNames2 = fragmentStateManagerOperation8.mFragment.getSharedElementTargetNames();
                    if (!z2) {
                        sharedElementCallback2 = fragmentStateManagerOperation9.mFragment.getExitTransitionCallback();
                        sharedElementCallback = fragmentStateManagerOperation8.mFragment.getEnterTransitionCallback();
                    } else {
                        sharedElementCallback2 = fragmentStateManagerOperation9.mFragment.getEnterTransitionCallback();
                        sharedElementCallback = fragmentStateManagerOperation8.mFragment.getExitTransitionCallback();
                    }
                    int size = sharedElementSourceNames.size();
                    int i3 = 0;
                    while (i3 < size) {
                        arrayMap2.put(sharedElementSourceNames.get(i3), sharedElementTargetNames2.get(i3));
                        i3++;
                        size = size;
                        fragmentTransitionImpl2 = fragmentTransitionImpl2;
                    }
                    ArrayMap<String, View> arrayMap3 = new ArrayMap<>();
                    findNamedViews(arrayMap3, fragmentStateManagerOperation9.mFragment.mView);
                    MapCollections.retainAllHelper(arrayMap3, sharedElementSourceNames);
                    if (sharedElementCallback2 == null) {
                        MapCollections.retainAllHelper(arrayMap2, arrayMap3.keySet());
                        final ArrayMap<String, View> arrayMap4 = new ArrayMap<>();
                        findNamedViews(arrayMap4, fragmentStateManagerOperation8.mFragment.mView);
                        MapCollections.retainAllHelper(arrayMap4, sharedElementTargetNames2);
                        MapCollections.retainAllHelper(arrayMap4, arrayMap2.values());
                        if (sharedElementCallback == null) {
                            FragmentTransition.retainValues(arrayMap2, arrayMap4);
                            retainMatchingViews(arrayMap3, arrayMap2.keySet());
                            retainMatchingViews(arrayMap4, arrayMap2.values());
                            if (arrayMap2.isEmpty()) {
                                arrayList12.clear();
                                arrayList13.clear();
                                obj5 = null;
                                rect = rect3;
                                arrayMap = arrayMap2;
                                arrayList7 = arrayList12;
                                fragmentStateManagerOperation4 = fragmentStateManagerOperation5;
                                fragmentStateManagerOperation3 = fragmentStateManagerOperation6;
                                view4 = view9;
                                str4 = str5;
                                hashMap2 = hashMap3;
                                arrayList8 = arrayList13;
                                fragmentTransitionImpl = fragmentTransitionImpl2;
                            } else {
                                FragmentTransition.callSharedElementStartEnd(fragmentStateManagerOperation8.mFragment, fragmentStateManagerOperation9.mFragment, z2, arrayMap3, true);
                                arrayMap = arrayMap2;
                                rect = rect3;
                                arrayList8 = arrayList13;
                                view4 = view9;
                                OneShotPreDrawListener.add(this.mContainer, new Runnable(this) {
                                    /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass6 */

                                    public void run() {
                                        FragmentTransition.callSharedElementStartEnd(fragmentStateManagerOperation6.mFragment, fragmentStateManagerOperation5.mFragment, z, arrayMap4, false);
                                    }
                                });
                                arrayList12.addAll(arrayMap3.values());
                                if (!sharedElementSourceNames.isEmpty()) {
                                    i = 0;
                                    view5 = arrayMap3.get(sharedElementSourceNames.get(0));
                                    obj4 = wrapTransitionInSet;
                                    fragmentTransitionImpl = fragmentTransitionImpl2;
                                    fragmentTransitionImpl.setEpicenter(obj4, view5);
                                } else {
                                    obj4 = wrapTransitionInSet;
                                    fragmentTransitionImpl = fragmentTransitionImpl2;
                                    i = 0;
                                    view5 = view3;
                                }
                                arrayList8.addAll(arrayMap4.values());
                                if (!sharedElementTargetNames2.isEmpty() && view6 != null) {
                                    OneShotPreDrawListener.add(this.mContainer, new Runnable(this) {
                                        /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass7 */

                                        public void run() {
                                            fragmentTransitionImpl.getBoundsOnScreen(view6, rect);
                                        }
                                    });
                                    z3 = true;
                                }
                                fragmentTransitionImpl.setSharedElementTargets(obj4, view4, arrayList12);
                                str4 = str5;
                                arrayList7 = arrayList12;
                                fragmentTransitionImpl.scheduleRemoveTargets(obj4, null, null, null, null, obj4, arrayList8);
                                Boolean bool = Boolean.TRUE;
                                hashMap2 = hashMap3;
                                fragmentStateManagerOperation4 = fragmentStateManagerOperation5;
                                hashMap2.put(fragmentStateManagerOperation4, bool);
                                fragmentStateManagerOperation3 = fragmentStateManagerOperation6;
                                hashMap2.put(fragmentStateManagerOperation3, bool);
                                view3 = view5;
                                obj5 = obj4;
                                fragmentStateManagerOperation9 = fragmentStateManagerOperation4;
                                fragmentStateManagerOperation8 = fragmentStateManagerOperation3;
                            }
                        } else {
                            throw null;
                        }
                    } else {
                        throw null;
                    }
                }
                rect3 = rect;
                view9 = view4;
                str5 = str4;
                arrayList12 = arrayList7;
                fragmentStateManagerOperation5 = fragmentStateManagerOperation4;
                view8 = view3;
                arrayList10 = arrayList5;
                arrayMap2 = arrayMap;
                z2 = z;
                hashMap3 = hashMap2;
                arrayList11 = arrayList6;
                fragmentTransitionImpl2 = fragmentTransitionImpl;
                arrayList13 = arrayList8;
                fragmentStateManagerOperation6 = fragmentStateManagerOperation3;
            }
            View view10 = view8;
            arrayList3 = arrayList11;
            hashMap = hashMap3;
            String str6 = str5;
            View view11 = view9;
            ArrayList<View> arrayList14 = arrayList12;
            SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation10 = fragmentStateManagerOperation6;
            ArrayList arrayList15 = new ArrayList();
            Iterator it8 = arrayList10.iterator();
            Object obj7 = null;
            Object obj8 = null;
            while (it8.hasNext()) {
                TransitionInfo transitionInfo3 = (TransitionInfo) it8.next();
                if (transitionInfo3.isVisibilityUnchanged()) {
                    hashMap.put(transitionInfo3.mOperation, Boolean.FALSE);
                    transitionInfo3.completeSpecialEffect();
                    obj8 = obj8;
                    obj = obj5;
                    view = view11;
                    str3 = str6;
                    arrayList4 = arrayList14;
                    view2 = view10;
                    fragmentStateManagerOperation = fragmentStateManagerOperation10;
                } else {
                    Object cloneTransition = fragmentTransitionImpl2.cloneTransition(transitionInfo3.mTransition);
                    SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation11 = transitionInfo3.mOperation;
                    boolean z4 = obj5 != null && (fragmentStateManagerOperation11 == fragmentStateManagerOperation9 || fragmentStateManagerOperation11 == fragmentStateManagerOperation8);
                    if (cloneTransition == null) {
                        if (!z4) {
                            hashMap.put(fragmentStateManagerOperation11, Boolean.FALSE);
                            transitionInfo3.completeSpecialEffect();
                        }
                        obj8 = obj8;
                        obj = obj5;
                        view = view11;
                        str3 = str6;
                        arrayList4 = arrayList14;
                        view2 = view10;
                        fragmentStateManagerOperation = fragmentStateManagerOperation10;
                    } else {
                        str3 = str6;
                        final ArrayList<View> arrayList16 = new ArrayList<>();
                        obj = obj5;
                        captureTransitioningViews(arrayList16, fragmentStateManagerOperation11.mFragment.mView);
                        if (z4) {
                            if (fragmentStateManagerOperation11 == fragmentStateManagerOperation9) {
                                arrayList16.removeAll(arrayList14);
                            } else {
                                arrayList16.removeAll(arrayList13);
                            }
                        }
                        if (arrayList16.isEmpty()) {
                            fragmentTransitionImpl2.addTarget(cloneTransition, view11);
                            obj3 = obj8;
                            view = view11;
                            arrayList4 = arrayList14;
                            fragmentStateManagerOperation2 = fragmentStateManagerOperation11;
                            obj2 = cloneTransition;
                            fragmentStateManagerOperation = fragmentStateManagerOperation10;
                        } else {
                            fragmentTransitionImpl2.addTargets(cloneTransition, arrayList16);
                            obj3 = obj8;
                            fragmentStateManagerOperation2 = fragmentStateManagerOperation11;
                            view = view11;
                            fragmentStateManagerOperation = fragmentStateManagerOperation10;
                            fragmentTransitionImpl2.scheduleRemoveTargets(cloneTransition, cloneTransition, arrayList16, null, null, null, null);
                            if (fragmentStateManagerOperation2.mFinalState == SpecialEffectsController$Operation$State.GONE) {
                                arrayList3.remove(fragmentStateManagerOperation2);
                                ArrayList<View> arrayList17 = new ArrayList<>(arrayList16);
                                arrayList17.remove(fragmentStateManagerOperation2.mFragment.mView);
                                arrayList4 = arrayList14;
                                obj2 = cloneTransition;
                                fragmentTransitionImpl2.scheduleHideFragmentView(obj2, fragmentStateManagerOperation2.mFragment.mView, arrayList17);
                                OneShotPreDrawListener.add(this.mContainer, new Runnable(this) {
                                    /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass8 */

                                    public void run() {
                                        FragmentTransition.setViewVisibility(arrayList16, 4);
                                    }
                                });
                            } else {
                                arrayList4 = arrayList14;
                                obj2 = cloneTransition;
                            }
                        }
                        if (fragmentStateManagerOperation2.mFinalState == SpecialEffectsController$Operation$State.VISIBLE) {
                            arrayList15.addAll(arrayList16);
                            if (z3) {
                                fragmentTransitionImpl2.setEpicenter(obj2, rect3);
                            }
                            view2 = view10;
                        } else {
                            view2 = view10;
                            fragmentTransitionImpl2.setEpicenter(obj2, view2);
                        }
                        hashMap.put(fragmentStateManagerOperation2, Boolean.TRUE);
                        if (transitionInfo3.mOverlapAllowed) {
                            obj8 = fragmentTransitionImpl2.mergeTransitionsTogether(obj3, obj2, null);
                        } else {
                            obj7 = fragmentTransitionImpl2.mergeTransitionsTogether(obj7, obj2, null);
                            obj8 = obj3;
                        }
                    }
                    fragmentStateManagerOperation8 = fragmentStateManagerOperation;
                }
                it8 = it8;
                fragmentStateManagerOperation10 = fragmentStateManagerOperation;
                view10 = view2;
                arrayList14 = arrayList4;
                str6 = str3;
                obj5 = obj;
                view11 = view;
            }
            String str7 = str6;
            Object mergeTransitionsInSequence = fragmentTransitionImpl2.mergeTransitionsInSequence(obj8, obj7, obj5);
            Iterator it9 = arrayList10.iterator();
            while (it9.hasNext()) {
                final TransitionInfo transitionInfo4 = (TransitionInfo) it9.next();
                if (!transitionInfo4.isVisibilityUnchanged()) {
                    Object obj9 = transitionInfo4.mTransition;
                    SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation12 = transitionInfo4.mOperation;
                    boolean z5 = obj5 != null && (fragmentStateManagerOperation12 == fragmentStateManagerOperation9 || fragmentStateManagerOperation12 == fragmentStateManagerOperation10);
                    if (obj9 != null || z5) {
                        ViewGroup viewGroup = this.mContainer;
                        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                        if (!viewGroup.isLaidOut()) {
                            if (FragmentManager.isLoggingEnabled(2)) {
                                StringBuilder outline253 = GeneratedOutlineSupport.outline25("SpecialEffectsController: Container ");
                                outline253.append(this.mContainer);
                                outline253.append(" has not been laid out. Completing operation ");
                                outline253.append(fragmentStateManagerOperation12);
                                str2 = str7;
                                Log.v(str2, outline253.toString());
                            } else {
                                str2 = str7;
                            }
                            transitionInfo4.completeSpecialEffect();
                        } else {
                            str2 = str7;
                            fragmentTransitionImpl2.setListenerForTransitionEnd(transitionInfo4.mOperation.mFragment, mergeTransitionsInSequence, transitionInfo4.mSignal, new Runnable(this) {
                                /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass9 */

                                public void run() {
                                    transitionInfo4.completeSpecialEffect();
                                }
                            });
                        }
                    } else {
                        str2 = str7;
                    }
                    str7 = str2;
                }
            }
            str = str7;
            ViewGroup viewGroup2 = this.mContainer;
            AtomicInteger atomicInteger2 = ViewCompat.sNextGeneratedId;
            if (viewGroup2.isLaidOut()) {
                FragmentTransition.setViewVisibility(arrayList15, 4);
                ArrayList<String> prepareSetNameOverridesReordered = fragmentTransitionImpl2.prepareSetNameOverridesReordered(arrayList13);
                fragmentTransitionImpl2.beginDelayedTransition(this.mContainer, mergeTransitionsInSequence);
                arrayList2 = arrayList3;
                fragmentTransitionImpl2.setNameOverridesReordered(this.mContainer, arrayList14, arrayList13, prepareSetNameOverridesReordered, arrayMap2);
                FragmentTransition.setViewVisibility(arrayList15, 0);
                fragmentTransitionImpl2.swapSharedElementTargets(obj5, arrayList14, arrayList13);
                boolean containsValue = hashMap.containsValue(Boolean.TRUE);
                final ViewGroup viewGroup3 = this.mContainer;
                Context context = viewGroup3.getContext();
                ArrayList arrayList18 = new ArrayList();
                it = arrayList.iterator();
                boolean z6 = false;
                while (it.hasNext()) {
                    final AnimationInfo animationInfo = (AnimationInfo) it.next();
                    if (animationInfo.isVisibilityUnchanged()) {
                        animationInfo.completeSpecialEffect();
                    } else {
                        FragmentAnim$AnimationOrAnimator animation = animationInfo.getAnimation(context);
                        if (animation == null) {
                            animationInfo.completeSpecialEffect();
                        } else {
                            final Animator animator = animation.animator;
                            if (animator == null) {
                                arrayList18.add(animationInfo);
                            } else {
                                final SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation13 = animationInfo.mOperation;
                                Fragment fragment = fragmentStateManagerOperation13.mFragment;
                                if (Boolean.TRUE.equals(hashMap.get(fragmentStateManagerOperation13))) {
                                    if (FragmentManager.isLoggingEnabled(2)) {
                                        Log.v(str, "Ignoring Animator set on " + fragment + " as this Fragment was involved in a Transition.");
                                    }
                                    animationInfo.completeSpecialEffect();
                                } else {
                                    final boolean z7 = fragmentStateManagerOperation13.mFinalState == SpecialEffectsController$Operation$State.GONE;
                                    if (z7) {
                                        arrayList2.remove(fragmentStateManagerOperation13);
                                    }
                                    final View view12 = fragment.mView;
                                    viewGroup3.startViewTransition(view12);
                                    animator.addListener(new AnimatorListenerAdapter(this) {
                                        /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass2 */

                                        public void onAnimationEnd(Animator animator) {
                                            viewGroup3.endViewTransition(view12);
                                            if (z7) {
                                                fragmentStateManagerOperation13.mFinalState.applyState(view12);
                                            }
                                            animationInfo.completeSpecialEffect();
                                        }
                                    });
                                    animator.setTarget(view12);
                                    animator.start();
                                    animationInfo.mSignal.setOnCancelListener(new CancellationSignal.OnCancelListener(this) {
                                        /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass3 */

                                        @Override // androidx.core.os.CancellationSignal.OnCancelListener
                                        public void onCancel() {
                                            animator.end();
                                        }
                                    });
                                    z6 = true;
                                    it = it;
                                    hashMap = hashMap;
                                }
                            }
                        }
                    }
                }
                it2 = arrayList18.iterator();
                while (it2.hasNext()) {
                    final AnimationInfo animationInfo2 = (AnimationInfo) it2.next();
                    SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation14 = animationInfo2.mOperation;
                    Fragment fragment2 = fragmentStateManagerOperation14.mFragment;
                    if (containsValue) {
                        if (FragmentManager.isLoggingEnabled(2)) {
                            Log.v(str, "Ignoring Animation set on " + fragment2 + " as Animations cannot run alongside Transitions.");
                        }
                        animationInfo2.completeSpecialEffect();
                    } else if (z6) {
                        if (FragmentManager.isLoggingEnabled(2)) {
                            Log.v(str, "Ignoring Animation set on " + fragment2 + " as Animations cannot run alongside Animators.");
                        }
                        animationInfo2.completeSpecialEffect();
                    } else {
                        final View view13 = fragment2.mView;
                        FragmentAnim$AnimationOrAnimator animation2 = animationInfo2.getAnimation(context);
                        Objects.requireNonNull(animation2);
                        Animation animation3 = animation2.animation;
                        Objects.requireNonNull(animation3);
                        if (fragmentStateManagerOperation14.mFinalState != SpecialEffectsController$Operation$State.REMOVED) {
                            view13.startAnimation(animation3);
                            animationInfo2.completeSpecialEffect();
                        } else {
                            viewGroup3.startViewTransition(view13);
                            FragmentAnim$EndViewTransitionAnimation fragmentAnim$EndViewTransitionAnimation = new FragmentAnim$EndViewTransitionAnimation(animation3, viewGroup3, view13);
                            fragmentAnim$EndViewTransitionAnimation.setAnimationListener(new Animation.AnimationListener(this) {
                                /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass4 */

                                public void onAnimationEnd(Animation animation) {
                                    viewGroup3.post(new Runnable() {
                                        /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass4.AnonymousClass1 */

                                        public void run() {
                                            AnonymousClass4 r0 = AnonymousClass4.this;
                                            viewGroup3.endViewTransition(view13);
                                            animationInfo2.completeSpecialEffect();
                                        }
                                    });
                                }

                                public void onAnimationRepeat(Animation animation) {
                                }

                                public void onAnimationStart(Animation animation) {
                                }
                            });
                            view13.startAnimation(fragmentAnim$EndViewTransitionAnimation);
                        }
                        animationInfo2.mSignal.setOnCancelListener(new CancellationSignal.OnCancelListener(this) {
                            /* class androidx.fragment.app.DefaultSpecialEffectsController.AnonymousClass5 */

                            @Override // androidx.core.os.CancellationSignal.OnCancelListener
                            public void onCancel() {
                                view13.clearAnimation();
                                viewGroup3.endViewTransition(view13);
                                animationInfo2.completeSpecialEffect();
                            }
                        });
                    }
                }
                it3 = arrayList2.iterator();
                while (it3.hasNext()) {
                    SpecialEffectsController.FragmentStateManagerOperation fragmentStateManagerOperation15 = (SpecialEffectsController.FragmentStateManagerOperation) it3.next();
                    fragmentStateManagerOperation15.mFinalState.applyState(fragmentStateManagerOperation15.mFragment.mView);
                }
                arrayList2.clear();
            }
        }
        arrayList2 = arrayList3;
        boolean containsValue2 = hashMap.containsValue(Boolean.TRUE);
        final ViewGroup viewGroup32 = this.mContainer;
        Context context2 = viewGroup32.getContext();
        ArrayList arrayList182 = new ArrayList();
        it = arrayList.iterator();
        boolean z62 = false;
        while (it.hasNext()) {
        }
        it2 = arrayList182.iterator();
        while (it2.hasNext()) {
        }
        it3 = arrayList2.iterator();
        while (it3.hasNext()) {
        }
        arrayList2.clear();
    }

    public void findNamedViews(Map<String, View> map, View view) {
        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
        String transitionName = view.getTransitionName();
        if (transitionName != null) {
            map.put(transitionName, view);
        }
        if (view instanceof ViewGroup) {
            ViewGroup viewGroup = (ViewGroup) view;
            int childCount = viewGroup.getChildCount();
            for (int i = 0; i < childCount; i++) {
                View childAt = viewGroup.getChildAt(i);
                if (childAt.getVisibility() == 0) {
                    findNamedViews(map, childAt);
                }
            }
        }
    }

    public void retainMatchingViews(ArrayMap<String, View> arrayMap, Collection<String> collection) {
        Iterator it = ((MapCollections.EntrySet) arrayMap.entrySet()).iterator();
        while (true) {
            MapCollections.MapIterator mapIterator = (MapCollections.MapIterator) it;
            if (mapIterator.hasNext()) {
                mapIterator.next();
                AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                if (!collection.contains(((View) mapIterator.getValue()).getTransitionName())) {
                    mapIterator.remove();
                }
            } else {
                return;
            }
        }
    }
}
