package androidx.fragment.app;

import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.os.CancellationSignal;
import androidx.core.view.ViewCompat;
import androidx.fragment.R$id;
import androidx.fragment.app.FragmentManager;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public abstract class SpecialEffectsController {
    public final ViewGroup mContainer;
    public boolean mIsContainerPostponed = false;
    public boolean mOperationDirectionIsPop = false;
    public final ArrayList<FragmentStateManagerOperation> mPendingOperations = new ArrayList<>();
    public final ArrayList<FragmentStateManagerOperation> mRunningOperations = new ArrayList<>();

    public class FragmentStateManagerOperation {
        public final List<Runnable> mCompletionListeners = new ArrayList();
        public SpecialEffectsController$Operation$State mFinalState;
        public final Fragment mFragment;
        public final FragmentStateManager mFragmentStateManager;
        public boolean mIsCanceled = false;
        public boolean mIsComplete = false;
        public SpecialEffectsController$Operation$LifecycleImpact mLifecycleImpact;
        public final HashSet<CancellationSignal> mSpecialEffectsSignals = new HashSet<>();

        public FragmentStateManagerOperation(SpecialEffectsController$Operation$State specialEffectsController$Operation$State, SpecialEffectsController$Operation$LifecycleImpact specialEffectsController$Operation$LifecycleImpact, FragmentStateManager fragmentStateManager, CancellationSignal cancellationSignal) {
            Fragment fragment = fragmentStateManager.mFragment;
            this.mFinalState = specialEffectsController$Operation$State;
            this.mLifecycleImpact = specialEffectsController$Operation$LifecycleImpact;
            this.mFragment = fragment;
            cancellationSignal.setOnCancelListener(new SpecialEffectsController$Operation$1(this));
            this.mFragmentStateManager = fragmentStateManager;
        }

        public final void cancel() {
            if (!this.mIsCanceled) {
                this.mIsCanceled = true;
                if (this.mSpecialEffectsSignals.isEmpty()) {
                    complete();
                    return;
                }
                Iterator it = new ArrayList(this.mSpecialEffectsSignals).iterator();
                while (it.hasNext()) {
                    ((CancellationSignal) it.next()).cancel();
                }
            }
        }

        public void complete() {
            if (!this.mIsComplete) {
                if (FragmentManager.isLoggingEnabled(2)) {
                    Log.v("FragmentManager", "SpecialEffectsController: " + this + " has called complete.");
                }
                this.mIsComplete = true;
                for (Runnable runnable : this.mCompletionListeners) {
                    runnable.run();
                }
            }
            this.mFragmentStateManager.moveToExpectedState();
        }

        public final void mergeWith(SpecialEffectsController$Operation$State specialEffectsController$Operation$State, SpecialEffectsController$Operation$LifecycleImpact specialEffectsController$Operation$LifecycleImpact) {
            int ordinal = specialEffectsController$Operation$LifecycleImpact.ordinal();
            if (ordinal != 0) {
                if (ordinal != 1) {
                    if (ordinal == 2) {
                        if (FragmentManager.isLoggingEnabled(2)) {
                            StringBuilder outline25 = GeneratedOutlineSupport.outline25("SpecialEffectsController: For fragment ");
                            outline25.append(this.mFragment);
                            outline25.append(" mFinalState = ");
                            outline25.append(this.mFinalState);
                            outline25.append(" -> REMOVED. mLifecycleImpact  = ");
                            outline25.append(this.mLifecycleImpact);
                            outline25.append(" to REMOVING.");
                            Log.v("FragmentManager", outline25.toString());
                        }
                        this.mFinalState = SpecialEffectsController$Operation$State.REMOVED;
                        this.mLifecycleImpact = SpecialEffectsController$Operation$LifecycleImpact.REMOVING;
                    }
                } else if (this.mFinalState == SpecialEffectsController$Operation$State.REMOVED) {
                    if (FragmentManager.isLoggingEnabled(2)) {
                        StringBuilder outline252 = GeneratedOutlineSupport.outline25("SpecialEffectsController: For fragment ");
                        outline252.append(this.mFragment);
                        outline252.append(" mFinalState = REMOVED -> VISIBLE. mLifecycleImpact = ");
                        outline252.append(this.mLifecycleImpact);
                        outline252.append(" to ADDING.");
                        Log.v("FragmentManager", outline252.toString());
                    }
                    this.mFinalState = SpecialEffectsController$Operation$State.VISIBLE;
                    this.mLifecycleImpact = SpecialEffectsController$Operation$LifecycleImpact.ADDING;
                }
            } else if (this.mFinalState != SpecialEffectsController$Operation$State.REMOVED) {
                if (FragmentManager.isLoggingEnabled(2)) {
                    StringBuilder outline253 = GeneratedOutlineSupport.outline25("SpecialEffectsController: For fragment ");
                    outline253.append(this.mFragment);
                    outline253.append(" mFinalState = ");
                    outline253.append(this.mFinalState);
                    outline253.append(" -> ");
                    outline253.append(specialEffectsController$Operation$State);
                    outline253.append(". ");
                    Log.v("FragmentManager", outline253.toString());
                }
                this.mFinalState = specialEffectsController$Operation$State;
            }
        }

        public void onStart() {
            if (this.mLifecycleImpact == SpecialEffectsController$Operation$LifecycleImpact.ADDING) {
                Fragment fragment = this.mFragmentStateManager.mFragment;
                View findFocus = fragment.mView.findFocus();
                if (findFocus != null) {
                    fragment.setFocusedView(findFocus);
                    if (FragmentManager.isLoggingEnabled(2)) {
                        Log.v("FragmentManager", "requestFocus: Saved focused view " + findFocus + " for Fragment " + fragment);
                    }
                }
                View requireView = this.mFragment.requireView();
                if (requireView.getParent() == null) {
                    this.mFragmentStateManager.addViewToContainer();
                    requireView.setAlpha(0.0f);
                }
                if (requireView.getAlpha() == 0.0f && requireView.getVisibility() == 0) {
                    requireView.setVisibility(4);
                }
                requireView.setAlpha(fragment.getPostOnViewCreatedAlpha());
            }
        }

        public String toString() {
            StringBuilder outline28 = GeneratedOutlineSupport.outline28("Operation ", "{");
            outline28.append(Integer.toHexString(System.identityHashCode(this)));
            outline28.append("} ");
            outline28.append("{");
            outline28.append("mFinalState = ");
            outline28.append(this.mFinalState);
            outline28.append("} ");
            outline28.append("{");
            outline28.append("mLifecycleImpact = ");
            outline28.append(this.mLifecycleImpact);
            outline28.append("} ");
            outline28.append("{");
            outline28.append("mFragment = ");
            outline28.append(this.mFragment);
            outline28.append("}");
            return outline28.toString();
        }
    }

    public SpecialEffectsController(ViewGroup viewGroup) {
        this.mContainer = viewGroup;
    }

    public static SpecialEffectsController getOrCreateController(ViewGroup viewGroup, FragmentManager fragmentManager) {
        return getOrCreateController(viewGroup, fragmentManager.getSpecialEffectsControllerFactory());
    }

    public final void enqueue(SpecialEffectsController$Operation$State specialEffectsController$Operation$State, SpecialEffectsController$Operation$LifecycleImpact specialEffectsController$Operation$LifecycleImpact, FragmentStateManager fragmentStateManager) {
        synchronized (this.mPendingOperations) {
            CancellationSignal cancellationSignal = new CancellationSignal();
            FragmentStateManagerOperation findPendingOperation = findPendingOperation(fragmentStateManager.mFragment);
            if (findPendingOperation != null) {
                findPendingOperation.mergeWith(specialEffectsController$Operation$State, specialEffectsController$Operation$LifecycleImpact);
                return;
            }
            final FragmentStateManagerOperation fragmentStateManagerOperation = new FragmentStateManagerOperation(specialEffectsController$Operation$State, specialEffectsController$Operation$LifecycleImpact, fragmentStateManager, cancellationSignal);
            this.mPendingOperations.add(fragmentStateManagerOperation);
            fragmentStateManagerOperation.mCompletionListeners.add(new Runnable() {
                /* class androidx.fragment.app.SpecialEffectsController.AnonymousClass1 */

                public void run() {
                    if (SpecialEffectsController.this.mPendingOperations.contains(fragmentStateManagerOperation)) {
                        FragmentStateManagerOperation fragmentStateManagerOperation = fragmentStateManagerOperation;
                        fragmentStateManagerOperation.mFinalState.applyState(fragmentStateManagerOperation.mFragment.mView);
                    }
                }
            });
            fragmentStateManagerOperation.mCompletionListeners.add(new Runnable() {
                /* class androidx.fragment.app.SpecialEffectsController.AnonymousClass2 */

                public void run() {
                    SpecialEffectsController.this.mPendingOperations.remove(fragmentStateManagerOperation);
                    SpecialEffectsController.this.mRunningOperations.remove(fragmentStateManagerOperation);
                }
            });
        }
    }

    public abstract void executeOperations(List<FragmentStateManagerOperation> list, boolean z);

    public void executePendingOperations() {
        if (!this.mIsContainerPostponed) {
            ViewGroup viewGroup = this.mContainer;
            AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
            if (!viewGroup.isAttachedToWindow()) {
                forceCompleteAllOperations();
                this.mOperationDirectionIsPop = false;
                return;
            }
            synchronized (this.mPendingOperations) {
                if (!this.mPendingOperations.isEmpty()) {
                    ArrayList arrayList = new ArrayList(this.mRunningOperations);
                    this.mRunningOperations.clear();
                    Iterator it = arrayList.iterator();
                    while (it.hasNext()) {
                        FragmentStateManagerOperation fragmentStateManagerOperation = (FragmentStateManagerOperation) it.next();
                        if (FragmentManager.isLoggingEnabled(2)) {
                            Log.v("FragmentManager", "SpecialEffectsController: Cancelling operation " + fragmentStateManagerOperation);
                        }
                        fragmentStateManagerOperation.cancel();
                        if (!fragmentStateManagerOperation.mIsComplete) {
                            this.mRunningOperations.add(fragmentStateManagerOperation);
                        }
                    }
                    updateFinalState();
                    ArrayList arrayList2 = new ArrayList(this.mPendingOperations);
                    this.mPendingOperations.clear();
                    this.mRunningOperations.addAll(arrayList2);
                    Iterator it2 = arrayList2.iterator();
                    while (it2.hasNext()) {
                        ((FragmentStateManagerOperation) it2.next()).onStart();
                    }
                    executeOperations(arrayList2, this.mOperationDirectionIsPop);
                    this.mOperationDirectionIsPop = false;
                }
            }
        }
    }

    public final FragmentStateManagerOperation findPendingOperation(Fragment fragment) {
        Iterator<FragmentStateManagerOperation> it = this.mPendingOperations.iterator();
        while (it.hasNext()) {
            FragmentStateManagerOperation next = it.next();
            if (next.mFragment.equals(fragment) && !next.mIsCanceled) {
                return next;
            }
        }
        return null;
    }

    public void forceCompleteAllOperations() {
        String str;
        String str2;
        ViewGroup viewGroup = this.mContainer;
        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
        boolean isAttachedToWindow = viewGroup.isAttachedToWindow();
        synchronized (this.mPendingOperations) {
            updateFinalState();
            Iterator<FragmentStateManagerOperation> it = this.mPendingOperations.iterator();
            while (it.hasNext()) {
                it.next().onStart();
            }
            Iterator it2 = new ArrayList(this.mRunningOperations).iterator();
            while (it2.hasNext()) {
                FragmentStateManagerOperation fragmentStateManagerOperation = (FragmentStateManagerOperation) it2.next();
                if (FragmentManager.isLoggingEnabled(2)) {
                    StringBuilder sb = new StringBuilder();
                    sb.append("SpecialEffectsController: ");
                    if (isAttachedToWindow) {
                        str2 = "";
                    } else {
                        str2 = "Container " + this.mContainer + " is not attached to window. ";
                    }
                    sb.append(str2);
                    sb.append("Cancelling running operation ");
                    sb.append(fragmentStateManagerOperation);
                    Log.v("FragmentManager", sb.toString());
                }
                fragmentStateManagerOperation.cancel();
            }
            Iterator it3 = new ArrayList(this.mPendingOperations).iterator();
            while (it3.hasNext()) {
                FragmentStateManagerOperation fragmentStateManagerOperation2 = (FragmentStateManagerOperation) it3.next();
                if (FragmentManager.isLoggingEnabled(2)) {
                    StringBuilder sb2 = new StringBuilder();
                    sb2.append("SpecialEffectsController: ");
                    if (isAttachedToWindow) {
                        str = "";
                    } else {
                        str = "Container " + this.mContainer + " is not attached to window. ";
                    }
                    sb2.append(str);
                    sb2.append("Cancelling pending operation ");
                    sb2.append(fragmentStateManagerOperation2);
                    Log.v("FragmentManager", sb2.toString());
                }
                fragmentStateManagerOperation2.cancel();
            }
        }
    }

    public void markPostponedState() {
        synchronized (this.mPendingOperations) {
            updateFinalState();
            this.mIsContainerPostponed = false;
            int size = this.mPendingOperations.size() - 1;
            while (true) {
                if (size < 0) {
                    break;
                }
                FragmentStateManagerOperation fragmentStateManagerOperation = this.mPendingOperations.get(size);
                SpecialEffectsController$Operation$State from = SpecialEffectsController$Operation$State.from(fragmentStateManagerOperation.mFragment.mView);
                SpecialEffectsController$Operation$State specialEffectsController$Operation$State = fragmentStateManagerOperation.mFinalState;
                SpecialEffectsController$Operation$State specialEffectsController$Operation$State2 = SpecialEffectsController$Operation$State.VISIBLE;
                if (specialEffectsController$Operation$State == specialEffectsController$Operation$State2 && from != specialEffectsController$Operation$State2) {
                    this.mIsContainerPostponed = fragmentStateManagerOperation.mFragment.isPostponed();
                    break;
                }
                size--;
            }
        }
    }

    public final void updateFinalState() {
        Iterator<FragmentStateManagerOperation> it = this.mPendingOperations.iterator();
        while (it.hasNext()) {
            FragmentStateManagerOperation next = it.next();
            if (next.mLifecycleImpact == SpecialEffectsController$Operation$LifecycleImpact.ADDING) {
                next.mergeWith(SpecialEffectsController$Operation$State.from(next.mFragment.requireView().getVisibility()), SpecialEffectsController$Operation$LifecycleImpact.NONE);
            }
        }
    }

    public static SpecialEffectsController getOrCreateController(ViewGroup viewGroup, FragmentManager.AnonymousClass4 r4) {
        int i = R$id.special_effects_controller_view_tag;
        Object tag = viewGroup.getTag(i);
        if (tag instanceof SpecialEffectsController) {
            return (SpecialEffectsController) tag;
        }
        Objects.requireNonNull(r4);
        DefaultSpecialEffectsController defaultSpecialEffectsController = new DefaultSpecialEffectsController(viewGroup);
        viewGroup.setTag(i, defaultSpecialEffectsController);
        return defaultSpecialEffectsController;
    }
}
