package androidx.lifecycle;

import android.app.Application;
import androidx.savedstate.SavedStateRegistry;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.lang.reflect.InvocationTargetException;

public class ViewModelProvider {
    public final Factory mFactory;
    public final ViewModelStore mViewModelStore;

    public class AndroidViewModelFactory extends NewInstanceFactory {
        public static AndroidViewModelFactory sInstance;
        public Application mApplication;

        public AndroidViewModelFactory(Application application) {
            this.mApplication = application;
        }

        @Override // androidx.lifecycle.ViewModelProvider.Factory, androidx.lifecycle.ViewModelProvider.NewInstanceFactory
        public <T extends ViewModel> T create(Class<T> cls) {
            if (!AndroidViewModel.class.isAssignableFrom(cls)) {
                return (T) super.create(cls);
            }
            try {
                return cls.getConstructor(Application.class).newInstance(this.mApplication);
            } catch (NoSuchMethodException e) {
                throw new RuntimeException("Cannot create an instance of " + cls, e);
            } catch (IllegalAccessException e2) {
                throw new RuntimeException("Cannot create an instance of " + cls, e2);
            } catch (InstantiationException e3) {
                throw new RuntimeException("Cannot create an instance of " + cls, e3);
            } catch (InvocationTargetException e4) {
                throw new RuntimeException("Cannot create an instance of " + cls, e4);
            }
        }
    }

    public interface Factory {
        <T extends ViewModel> T create(Class<T> cls);
    }

    public abstract class KeyedFactory implements Factory {
        public abstract <T extends ViewModel> T create(String str, Class<T> cls);
    }

    public class NewInstanceFactory implements Factory {
        public static NewInstanceFactory sInstance;

        @Override // androidx.lifecycle.ViewModelProvider.Factory
        public <T extends ViewModel> T create(Class<T> cls) {
            try {
                return cls.newInstance();
            } catch (InstantiationException e) {
                throw new RuntimeException("Cannot create an instance of " + cls, e);
            } catch (IllegalAccessException e2) {
                throw new RuntimeException("Cannot create an instance of " + cls, e2);
            }
        }
    }

    public ViewModelProvider(ViewModelStore viewModelStore, Factory factory) {
        this.mFactory = factory;
        this.mViewModelStore = viewModelStore;
    }

    public <T extends ViewModel> T get(Class<T> cls) {
        Object obj;
        String canonicalName = cls.getCanonicalName();
        if (canonicalName != null) {
            String outline18 = GeneratedOutlineSupport.outline18("androidx.lifecycle.ViewModelProvider.DefaultKey:", canonicalName);
            T t = (T) this.mViewModelStore.mMap.get(outline18);
            if (cls.isInstance(t)) {
                Factory factory = this.mFactory;
                if (factory instanceof KeyedFactory) {
                    SavedStateViewModelFactory savedStateViewModelFactory = (SavedStateViewModelFactory) ((KeyedFactory) factory);
                    SavedStateRegistry savedStateRegistry = savedStateViewModelFactory.mSavedStateRegistry;
                    Lifecycle lifecycle = savedStateViewModelFactory.mLifecycle;
                    SavedStateHandleController savedStateHandleController = (SavedStateHandleController) t.getTag("androidx.lifecycle.savedstate.vm.tag");
                    if (savedStateHandleController != null && !savedStateHandleController.mIsAttached) {
                        savedStateHandleController.attachToLifecycle(savedStateRegistry, lifecycle);
                        SavedStateHandleController.tryToAddRecreator(savedStateRegistry, lifecycle);
                    }
                }
            } else {
                Factory factory2 = this.mFactory;
                if (factory2 instanceof KeyedFactory) {
                    obj = ((KeyedFactory) factory2).create(outline18, cls);
                } else {
                    obj = factory2.create(cls);
                }
                t = (T) obj;
                ViewModel put = this.mViewModelStore.mMap.put(outline18, t);
                if (put != null) {
                    put.onCleared();
                }
            }
            return t;
        }
        throw new IllegalArgumentException("Local and anonymous classes can not be ViewModels");
    }
}
