package androidx.media;

import android.app.Service;
import android.content.Intent;
import android.os.Binder;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.Messenger;
import android.os.Parcelable;
import android.os.RemoteException;
import android.service.media.MediaBrowserService;
import android.support.v4.media.MediaBrowserCompat;
import android.support.v4.media.session.MediaSessionCompat;
import android.support.v4.os.ResultReceiver;
import android.text.TextUtils;
import android.util.Log;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.collection.ArrayMap;
import androidx.core.util.Pair;
import androidx.media.MediaBrowserServiceCompatApi26;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.FileDescriptor;
import java.io.PrintWriter;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

public abstract class MediaBrowserServiceCompat extends Service {
    public static final boolean DEBUG = Log.isLoggable("MBServiceCompat", 3);
    public final ArrayMap<IBinder, ConnectionRecord> mConnections = new ArrayMap<>();
    public final ServiceHandler mHandler = new ServiceHandler();
    public MediaBrowserServiceImpl mImpl;

    public class ConnectionRecord implements IBinder.DeathRecipient {
        public final ServiceCallbacks callbacks;
        public final String pkg;
        public final HashMap<String, List<Pair<IBinder, Bundle>>> subscriptions = new HashMap<>();

        public ConnectionRecord(String str, int i, int i2, Bundle bundle, ServiceCallbacks serviceCallbacks) {
            this.pkg = str;
            if (Build.VERSION.SDK_INT >= 28) {
                new MediaSessionManagerImplApi28$RemoteUserInfoImplApi28(str, i, i2);
            }
            this.callbacks = serviceCallbacks;
        }

        public void binderDied() {
            MediaBrowserServiceCompat.this.mHandler.post(new Runnable() {
                /* class androidx.media.MediaBrowserServiceCompat.ConnectionRecord.AnonymousClass1 */

                public void run() {
                    ConnectionRecord connectionRecord = ConnectionRecord.this;
                    MediaBrowserServiceCompat.this.mConnections.remove(((ServiceCallbacksCompat) connectionRecord.callbacks).asBinder());
                }
            });
        }
    }

    public interface MediaBrowserServiceImpl {
        void onCreate();
    }

    public class MediaBrowserServiceImplApi21 implements MediaBrowserServiceImpl, MediaBrowserServiceCompatApi21$ServiceCompatProxy {
        public Messenger mMessenger;
        public final List<Bundle> mRootExtrasList = new ArrayList();
        public Object mServiceObj;

        public MediaBrowserServiceImplApi21() {
        }

        @Override // androidx.media.MediaBrowserServiceCompat.MediaBrowserServiceImpl
        public void onCreate() {
            MediaBrowserServiceCompatApi21$MediaBrowserServiceAdaptor mediaBrowserServiceCompatApi21$MediaBrowserServiceAdaptor = new MediaBrowserServiceCompatApi21$MediaBrowserServiceAdaptor(MediaBrowserServiceCompat.this, this);
            this.mServiceObj = mediaBrowserServiceCompatApi21$MediaBrowserServiceAdaptor;
            mediaBrowserServiceCompatApi21$MediaBrowserServiceAdaptor.onCreate();
        }
    }

    public class MediaBrowserServiceImplApi23 extends MediaBrowserServiceImplApi21 implements MediaBrowserServiceCompatApi23$ServiceCompatProxy {
        public MediaBrowserServiceImplApi23() {
            super();
        }

        @Override // androidx.media.MediaBrowserServiceCompat.MediaBrowserServiceImplApi21, androidx.media.MediaBrowserServiceCompat.MediaBrowserServiceImpl
        public void onCreate() {
            MediaBrowserServiceCompatApi23$MediaBrowserServiceAdaptor mediaBrowserServiceCompatApi23$MediaBrowserServiceAdaptor = new MediaBrowserServiceCompatApi23$MediaBrowserServiceAdaptor(MediaBrowserServiceCompat.this, this);
            this.mServiceObj = mediaBrowserServiceCompatApi23$MediaBrowserServiceAdaptor;
            mediaBrowserServiceCompatApi23$MediaBrowserServiceAdaptor.onCreate();
        }
    }

    public class MediaBrowserServiceImplApi26 extends MediaBrowserServiceImplApi23 implements MediaBrowserServiceCompatApi26.ServiceCompatProxy {
        public MediaBrowserServiceImplApi26() {
            super();
        }

        @Override // androidx.media.MediaBrowserServiceCompat.MediaBrowserServiceImplApi21, androidx.media.MediaBrowserServiceCompat.MediaBrowserServiceImpl, androidx.media.MediaBrowserServiceCompat.MediaBrowserServiceImplApi23
        public void onCreate() {
            MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
            Field field = MediaBrowserServiceCompatApi26.sResultFlags;
            MediaBrowserServiceCompatApi26.MediaBrowserServiceAdaptor mediaBrowserServiceAdaptor = new MediaBrowserServiceCompatApi26.MediaBrowserServiceAdaptor(mediaBrowserServiceCompat, this);
            this.mServiceObj = mediaBrowserServiceAdaptor;
            mediaBrowserServiceAdaptor.onCreate();
        }
    }

    public class MediaBrowserServiceImplApi28 extends MediaBrowserServiceImplApi26 {
        public MediaBrowserServiceImplApi28(MediaBrowserServiceCompat mediaBrowserServiceCompat) {
            super();
        }
    }

    public static class Result<T> {
        public final Object mDebug;
        public int mFlags;
        public boolean mSendErrorCalled;
        public boolean mSendResultCalled;

        public Result(Object obj) {
            this.mDebug = obj;
        }

        public boolean isDone() {
            return this.mSendResultCalled || this.mSendErrorCalled;
        }

        public void onErrorSent(Bundle bundle) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("It is not supported to send an error for ");
            outline25.append(this.mDebug);
            throw new UnsupportedOperationException(outline25.toString());
        }

        public abstract void onResultSent(T t);

        public void sendResult(T t) {
            if (this.mSendResultCalled || this.mSendErrorCalled) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("sendResult() called when either sendResult() or sendError() had already been called for: ");
                outline25.append(this.mDebug);
                throw new IllegalStateException(outline25.toString());
            }
            this.mSendResultCalled = true;
            onResultSent(null);
        }
    }

    public class ServiceBinderImpl {
        public ServiceBinderImpl() {
        }
    }

    public interface ServiceCallbacks {
    }

    public static class ServiceCallbacksCompat implements ServiceCallbacks {
        public final Messenger mCallbacks;

        public ServiceCallbacksCompat(Messenger messenger) {
            this.mCallbacks = messenger;
        }

        public IBinder asBinder() {
            return this.mCallbacks.getBinder();
        }

        public void onLoadChildren(String str, List<MediaBrowserCompat.MediaItem> list, Bundle bundle, Bundle bundle2) {
            Bundle bundle3 = new Bundle();
            bundle3.putString("data_media_item_id", str);
            bundle3.putBundle("data_options", bundle);
            bundle3.putBundle("data_notify_children_changed_options", bundle2);
            if (list != null) {
                bundle3.putParcelableArrayList("data_media_item_list", list instanceof ArrayList ? (ArrayList) list : new ArrayList<>(list));
            }
            sendRequest(3, bundle3);
        }

        public final void sendRequest(int i, Bundle bundle) {
            Message obtain = Message.obtain();
            obtain.what = i;
            obtain.arg1 = 2;
            obtain.setData(bundle);
            this.mCallbacks.send(obtain);
        }
    }

    public final class ServiceHandler extends Handler {
        public final ServiceBinderImpl mServiceBinderImpl;

        public ServiceHandler() {
            this.mServiceBinderImpl = new ServiceBinderImpl();
        }

        public void handleMessage(Message message) {
            Bundle data = message.getData();
            switch (message.what) {
                case 1:
                    Bundle bundle = data.getBundle("data_root_hints");
                    MediaSessionCompat.ensureClassLoader(bundle);
                    ServiceBinderImpl serviceBinderImpl = this.mServiceBinderImpl;
                    String string = data.getString("data_package_name");
                    int i = data.getInt("data_calling_pid");
                    int i2 = data.getInt("data_calling_uid");
                    ServiceCallbacksCompat serviceCallbacksCompat = new ServiceCallbacksCompat(message.replyTo);
                    MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                    Objects.requireNonNull(mediaBrowserServiceCompat);
                    boolean z = false;
                    if (string != null) {
                        String[] packagesForUid = mediaBrowserServiceCompat.getPackageManager().getPackagesForUid(i2);
                        int length = packagesForUid.length;
                        int i3 = 0;
                        while (true) {
                            if (i3 < length) {
                                if (packagesForUid[i3].equals(string)) {
                                    z = true;
                                } else {
                                    i3++;
                                }
                            }
                        }
                    }
                    if (z) {
                        MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(serviceCallbacksCompat, string, i, i2, bundle) {
                            /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass1 */
                            public final /* synthetic */ ServiceCallbacks val$callbacks;
                            public final /* synthetic */ int val$pid;
                            public final /* synthetic */ String val$pkg;
                            public final /* synthetic */ Bundle val$rootHints;
                            public final /* synthetic */ int val$uid;

                            {
                                this.val$callbacks = r2;
                                this.val$pkg = r3;
                                this.val$pid = r4;
                                this.val$uid = r5;
                                this.val$rootHints = r6;
                            }

                            public void run() {
                                MediaBrowserServiceCompat.this.mConnections.remove(((ServiceCallbacksCompat) this.val$callbacks).asBinder());
                                MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                                String str = this.val$pkg;
                                int i = this.val$pid;
                                int i2 = this.val$uid;
                                new HashMap();
                                if (Build.VERSION.SDK_INT >= 28) {
                                    new MediaSessionManagerImplApi28$RemoteUserInfoImplApi28(str, i, i2);
                                }
                                Objects.requireNonNull(MediaBrowserServiceCompat.this);
                                MediaBrowserServiceCompat.this.onGetRoot(this.val$pkg, this.val$uid, this.val$rootHints);
                                Objects.requireNonNull(MediaBrowserServiceCompat.this);
                                Log.i("MBServiceCompat", "No root for client " + this.val$pkg + " from service " + AnonymousClass1.class.getName());
                                try {
                                    ((ServiceCallbacksCompat) this.val$callbacks).sendRequest(2, null);
                                } catch (RemoteException unused) {
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Calling onConnectFailed() failed. Ignoring. pkg=");
                                    outline25.append(this.val$pkg);
                                    Log.w("MBServiceCompat", outline25.toString());
                                }
                            }
                        });
                        return;
                    }
                    throw new IllegalArgumentException("Package/uid mismatch: uid=" + i2 + " package=" + string);
                case 2:
                    ServiceBinderImpl serviceBinderImpl2 = this.mServiceBinderImpl;
                    MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(new ServiceCallbacksCompat(message.replyTo)) {
                        /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass2 */
                        public final /* synthetic */ ServiceCallbacks val$callbacks;

                        {
                            this.val$callbacks = r2;
                        }

                        public void run() {
                            ConnectionRecord remove = MediaBrowserServiceCompat.this.mConnections.remove(((ServiceCallbacksCompat) this.val$callbacks).asBinder());
                            if (remove != null) {
                                ((ServiceCallbacksCompat) remove.callbacks).asBinder().unlinkToDeath(remove, 0);
                            }
                        }
                    });
                    return;
                case 3:
                    Bundle bundle2 = data.getBundle("data_options");
                    MediaSessionCompat.ensureClassLoader(bundle2);
                    ServiceBinderImpl serviceBinderImpl3 = this.mServiceBinderImpl;
                    String string2 = data.getString("data_media_item_id");
                    IBinder binder = data.getBinder("data_callback_token");
                    MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(new ServiceCallbacksCompat(message.replyTo), string2, binder, bundle2) {
                        /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass3 */
                        public final /* synthetic */ ServiceCallbacks val$callbacks;
                        public final /* synthetic */ String val$id;
                        public final /* synthetic */ Bundle val$options;
                        public final /* synthetic */ IBinder val$token;

                        {
                            this.val$callbacks = r2;
                            this.val$id = r3;
                            this.val$token = r4;
                            this.val$options = r5;
                        }

                        public void run() {
                            ConnectionRecord connectionRecord = MediaBrowserServiceCompat.this.mConnections.get(((ServiceCallbacksCompat) this.val$callbacks).asBinder());
                            if (connectionRecord == null) {
                                StringBuilder outline25 = GeneratedOutlineSupport.outline25("addSubscription for callback that isn't registered id=");
                                outline25.append(this.val$id);
                                Log.w("MBServiceCompat", outline25.toString());
                                return;
                            }
                            MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                            String str = this.val$id;
                            IBinder iBinder = this.val$token;
                            Bundle bundle = this.val$options;
                            Objects.requireNonNull(mediaBrowserServiceCompat);
                            List<Pair<IBinder, Bundle>> list = connectionRecord.subscriptions.get(str);
                            if (list == null) {
                                list = new ArrayList<>();
                            }
                            for (Pair<IBinder, Bundle> pair : list) {
                                if (iBinder == pair.first && AppCompatDelegateImpl.Api17Impl.areSameOptions(bundle, pair.second)) {
                                    return;
                                }
                            }
                            list.add(new Pair<>(iBinder, bundle));
                            connectionRecord.subscriptions.put(str, list);
                            AnonymousClass1 r11 = new Result<List<MediaBrowserCompat.MediaItem>>(str, connectionRecord, str, bundle, null) {
                                /* class androidx.media.MediaBrowserServiceCompat.AnonymousClass1 */
                                public final /* synthetic */ ConnectionRecord val$connection;
                                public final /* synthetic */ Bundle val$notifyChildrenChangedOptions;
                                public final /* synthetic */ String val$parentId;
                                public final /* synthetic */ Bundle val$subscribeOptions;

                                {
                                    this.val$connection = r3;
                                    this.val$parentId = r4;
                                    this.val$subscribeOptions = r5;
                                    this.val$notifyChildrenChangedOptions = r6;
                                }

                                /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
                                @Override // androidx.media.MediaBrowserServiceCompat.Result
                                public void onResultSent(List<MediaBrowserCompat.MediaItem> list) {
                                    List<MediaBrowserCompat.MediaItem> list2 = list;
                                    if (MediaBrowserServiceCompat.this.mConnections.get(((ServiceCallbacksCompat) this.val$connection.callbacks).asBinder()) == this.val$connection) {
                                        if ((this.mFlags & 1) != 0) {
                                            MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                                            Bundle bundle = this.val$subscribeOptions;
                                            Objects.requireNonNull(mediaBrowserServiceCompat);
                                            if (list2 == null) {
                                                list2 = null;
                                            } else {
                                                int i = bundle.getInt(MediaBrowserCompat.EXTRA_PAGE, -1);
                                                int i2 = bundle.getInt(MediaBrowserCompat.EXTRA_PAGE_SIZE, -1);
                                                if (!(i == -1 && i2 == -1)) {
                                                    int i3 = i2 * i;
                                                    int i4 = i3 + i2;
                                                    if (i < 0 || i2 < 1 || i3 >= list2.size()) {
                                                        list2 = Collections.emptyList();
                                                    } else {
                                                        if (i4 > list2.size()) {
                                                            i4 = list2.size();
                                                        }
                                                        list2 = list2.subList(i3, i4);
                                                    }
                                                }
                                            }
                                        }
                                        try {
                                            ((ServiceCallbacksCompat) this.val$connection.callbacks).onLoadChildren(this.val$parentId, list2, this.val$subscribeOptions, this.val$notifyChildrenChangedOptions);
                                        } catch (RemoteException unused) {
                                            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Calling onLoadChildren() failed for id=");
                                            outline25.append(this.val$parentId);
                                            outline25.append(" package=");
                                            outline25.append(this.val$connection.pkg);
                                            Log.w("MBServiceCompat", outline25.toString());
                                        }
                                    } else if (MediaBrowserServiceCompat.DEBUG) {
                                        StringBuilder outline252 = GeneratedOutlineSupport.outline25("Not sending onLoadChildren result for connection that has been disconnected. pkg=");
                                        outline252.append(this.val$connection.pkg);
                                        outline252.append(" id=");
                                        outline252.append(this.val$parentId);
                                        Log.d("MBServiceCompat", outline252.toString());
                                    }
                                }
                            };
                            if (bundle == null) {
                                mediaBrowserServiceCompat.onLoadChildren(str, r11);
                            } else {
                                mediaBrowserServiceCompat.onLoadChildren1(str, r11);
                            }
                            if (r11.isDone()) {
                                mediaBrowserServiceCompat.onSubscribe();
                                return;
                            }
                            StringBuilder outline252 = GeneratedOutlineSupport.outline25("onLoadChildren must call detach() or sendResult() before returning for package=");
                            outline252.append(connectionRecord.pkg);
                            outline252.append(" id=");
                            outline252.append(str);
                            throw new IllegalStateException(outline252.toString());
                        }
                    });
                    return;
                case 4:
                    ServiceBinderImpl serviceBinderImpl4 = this.mServiceBinderImpl;
                    String string3 = data.getString("data_media_item_id");
                    IBinder binder2 = data.getBinder("data_callback_token");
                    MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(new ServiceCallbacksCompat(message.replyTo), string3, binder2) {
                        /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass4 */
                        public final /* synthetic */ ServiceCallbacks val$callbacks;
                        public final /* synthetic */ String val$id;
                        public final /* synthetic */ IBinder val$token;

                        {
                            this.val$callbacks = r2;
                            this.val$id = r3;
                            this.val$token = r4;
                        }

                        public void run() {
                            ConnectionRecord connectionRecord = MediaBrowserServiceCompat.this.mConnections.get(((ServiceCallbacksCompat) this.val$callbacks).asBinder());
                            if (connectionRecord == null) {
                                StringBuilder outline25 = GeneratedOutlineSupport.outline25("removeSubscription for callback that isn't registered id=");
                                outline25.append(this.val$id);
                                Log.w("MBServiceCompat", outline25.toString());
                                return;
                            }
                            MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                            String str = this.val$id;
                            IBinder iBinder = this.val$token;
                            Objects.requireNonNull(mediaBrowserServiceCompat);
                            boolean z = false;
                            if (iBinder == null) {
                                try {
                                    if (connectionRecord.subscriptions.remove(str) != null) {
                                        z = true;
                                    }
                                } catch (Throwable th) {
                                    mediaBrowserServiceCompat.onUnsubscribe();
                                    throw th;
                                }
                            } else {
                                List<Pair<IBinder, Bundle>> list = connectionRecord.subscriptions.get(str);
                                if (list != null) {
                                    Iterator<Pair<IBinder, Bundle>> it = list.iterator();
                                    while (it.hasNext()) {
                                        if (iBinder == it.next().first) {
                                            it.remove();
                                            z = true;
                                        }
                                    }
                                    if (list.size() == 0) {
                                        connectionRecord.subscriptions.remove(str);
                                    }
                                }
                            }
                            mediaBrowserServiceCompat.onUnsubscribe();
                            if (!z) {
                                StringBuilder outline252 = GeneratedOutlineSupport.outline25("removeSubscription called for ");
                                outline252.append(this.val$id);
                                outline252.append(" which is not subscribed");
                                Log.w("MBServiceCompat", outline252.toString());
                            }
                        }
                    });
                    return;
                case 5:
                    ServiceBinderImpl serviceBinderImpl5 = this.mServiceBinderImpl;
                    String string4 = data.getString("data_media_item_id");
                    ResultReceiver resultReceiver = (ResultReceiver) data.getParcelable("data_result_receiver");
                    ServiceCallbacksCompat serviceCallbacksCompat2 = new ServiceCallbacksCompat(message.replyTo);
                    Objects.requireNonNull(serviceBinderImpl5);
                    if (!TextUtils.isEmpty(string4) && resultReceiver != null) {
                        MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(serviceCallbacksCompat2, string4, resultReceiver) {
                            /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass5 */
                            public final /* synthetic */ ServiceCallbacks val$callbacks;
                            public final /* synthetic */ String val$mediaId;
                            public final /* synthetic */ ResultReceiver val$receiver;

                            {
                                this.val$callbacks = r2;
                                this.val$mediaId = r3;
                                this.val$receiver = r4;
                            }

                            public void run() {
                                if (MediaBrowserServiceCompat.this.mConnections.get(((ServiceCallbacksCompat) this.val$callbacks).asBinder()) == null) {
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("getMediaItem for callback that isn't registered id=");
                                    outline25.append(this.val$mediaId);
                                    Log.w("MBServiceCompat", outline25.toString());
                                    return;
                                }
                                MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                                String str = this.val$mediaId;
                                AnonymousClass2 r3 = new Result<MediaBrowserCompat.MediaItem>(mediaBrowserServiceCompat, str, this.val$receiver) {
                                    /* class androidx.media.MediaBrowserServiceCompat.AnonymousClass2 */
                                    public final /* synthetic */ ResultReceiver val$receiver;

                                    {
                                        this.val$receiver = r3;
                                    }

                                    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
                                    @Override // androidx.media.MediaBrowserServiceCompat.Result
                                    public void onResultSent(MediaBrowserCompat.MediaItem mediaItem) {
                                        MediaBrowserCompat.MediaItem mediaItem2 = mediaItem;
                                        if ((this.mFlags & 2) != 0) {
                                            this.val$receiver.send(-1, null);
                                            return;
                                        }
                                        Bundle bundle = new Bundle();
                                        bundle.putParcelable("media_item", mediaItem2);
                                        this.val$receiver.send(0, bundle);
                                    }
                                };
                                mediaBrowserServiceCompat.onLoadItem(r3);
                                if (!r3.isDone()) {
                                    throw new IllegalStateException(GeneratedOutlineSupport.outline18("onLoadItem must call detach() or sendResult() before returning for id=", str));
                                }
                            }
                        });
                        return;
                    }
                    return;
                case 6:
                    Bundle bundle3 = data.getBundle("data_root_hints");
                    MediaSessionCompat.ensureClassLoader(bundle3);
                    ServiceBinderImpl serviceBinderImpl6 = this.mServiceBinderImpl;
                    MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(new ServiceCallbacksCompat(message.replyTo), data.getString("data_package_name"), data.getInt("data_calling_pid"), data.getInt("data_calling_uid"), bundle3) {
                        /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass6 */
                        public final /* synthetic */ ServiceCallbacks val$callbacks;
                        public final /* synthetic */ int val$pid;
                        public final /* synthetic */ String val$pkg;
                        public final /* synthetic */ Bundle val$rootHints;
                        public final /* synthetic */ int val$uid;

                        {
                            this.val$callbacks = r2;
                            this.val$pkg = r3;
                            this.val$pid = r4;
                            this.val$uid = r5;
                            this.val$rootHints = r6;
                        }

                        public void run() {
                            IBinder asBinder = ((ServiceCallbacksCompat) this.val$callbacks).asBinder();
                            MediaBrowserServiceCompat.this.mConnections.remove(asBinder);
                            ConnectionRecord connectionRecord = new ConnectionRecord(this.val$pkg, this.val$pid, this.val$uid, this.val$rootHints, this.val$callbacks);
                            MediaBrowserServiceCompat.this.mConnections.put(asBinder, connectionRecord);
                            try {
                                asBinder.linkToDeath(connectionRecord, 0);
                            } catch (RemoteException unused) {
                                Log.w("MBServiceCompat", "IBinder is already dead.");
                            }
                        }
                    });
                    return;
                case 7:
                    ServiceBinderImpl serviceBinderImpl7 = this.mServiceBinderImpl;
                    MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(new ServiceCallbacksCompat(message.replyTo)) {
                        /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass7 */
                        public final /* synthetic */ ServiceCallbacks val$callbacks;

                        {
                            this.val$callbacks = r2;
                        }

                        public void run() {
                            IBinder asBinder = ((ServiceCallbacksCompat) this.val$callbacks).asBinder();
                            ConnectionRecord remove = MediaBrowserServiceCompat.this.mConnections.remove(asBinder);
                            if (remove != null) {
                                asBinder.unlinkToDeath(remove, 0);
                            }
                        }
                    });
                    return;
                case 8:
                    Bundle bundle4 = data.getBundle("data_search_extras");
                    MediaSessionCompat.ensureClassLoader(bundle4);
                    ServiceBinderImpl serviceBinderImpl8 = this.mServiceBinderImpl;
                    String string5 = data.getString("data_search_query");
                    ResultReceiver resultReceiver2 = (ResultReceiver) data.getParcelable("data_result_receiver");
                    ServiceCallbacksCompat serviceCallbacksCompat3 = new ServiceCallbacksCompat(message.replyTo);
                    Objects.requireNonNull(serviceBinderImpl8);
                    if (!TextUtils.isEmpty(string5) && resultReceiver2 != null) {
                        MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(serviceCallbacksCompat3, string5, bundle4, resultReceiver2) {
                            /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass8 */
                            public final /* synthetic */ ServiceCallbacks val$callbacks;
                            public final /* synthetic */ Bundle val$extras;
                            public final /* synthetic */ String val$query;
                            public final /* synthetic */ ResultReceiver val$receiver;

                            {
                                this.val$callbacks = r2;
                                this.val$query = r3;
                                this.val$extras = r4;
                                this.val$receiver = r5;
                            }

                            public void run() {
                                if (MediaBrowserServiceCompat.this.mConnections.get(((ServiceCallbacksCompat) this.val$callbacks).asBinder()) == null) {
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("search for callback that isn't registered query=");
                                    outline25.append(this.val$query);
                                    Log.w("MBServiceCompat", outline25.toString());
                                    return;
                                }
                                MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                                String str = this.val$query;
                                AnonymousClass3 r3 = new Result<List<MediaBrowserCompat.MediaItem>>(mediaBrowserServiceCompat, str, this.val$receiver) {
                                    /* class androidx.media.MediaBrowserServiceCompat.AnonymousClass3 */
                                    public final /* synthetic */ ResultReceiver val$receiver;

                                    {
                                        this.val$receiver = r3;
                                    }

                                    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
                                    @Override // androidx.media.MediaBrowserServiceCompat.Result
                                    public void onResultSent(List<MediaBrowserCompat.MediaItem> list) {
                                        List<MediaBrowserCompat.MediaItem> list2 = list;
                                        if ((this.mFlags & 4) != 0 || list2 == null) {
                                            this.val$receiver.send(-1, null);
                                            return;
                                        }
                                        Bundle bundle = new Bundle();
                                        bundle.putParcelableArray("search_results", (Parcelable[]) list2.toArray(new MediaBrowserCompat.MediaItem[0]));
                                        this.val$receiver.send(0, bundle);
                                    }
                                };
                                mediaBrowserServiceCompat.onSearch(r3);
                                if (!r3.isDone()) {
                                    throw new IllegalStateException(GeneratedOutlineSupport.outline18("onSearch must call detach() or sendResult() before returning for query=", str));
                                }
                            }
                        });
                        return;
                    }
                    return;
                case 9:
                    Bundle bundle5 = data.getBundle("data_custom_action_extras");
                    MediaSessionCompat.ensureClassLoader(bundle5);
                    ServiceBinderImpl serviceBinderImpl9 = this.mServiceBinderImpl;
                    String string6 = data.getString("data_custom_action");
                    ResultReceiver resultReceiver3 = (ResultReceiver) data.getParcelable("data_result_receiver");
                    ServiceCallbacksCompat serviceCallbacksCompat4 = new ServiceCallbacksCompat(message.replyTo);
                    Objects.requireNonNull(serviceBinderImpl9);
                    if (!TextUtils.isEmpty(string6) && resultReceiver3 != null) {
                        MediaBrowserServiceCompat.this.mHandler.postOrRun(new Runnable(serviceCallbacksCompat4, string6, bundle5, resultReceiver3) {
                            /* class androidx.media.MediaBrowserServiceCompat.ServiceBinderImpl.AnonymousClass9 */
                            public final /* synthetic */ String val$action;
                            public final /* synthetic */ ServiceCallbacks val$callbacks;
                            public final /* synthetic */ Bundle val$extras;
                            public final /* synthetic */ ResultReceiver val$receiver;

                            {
                                this.val$callbacks = r2;
                                this.val$action = r3;
                                this.val$extras = r4;
                                this.val$receiver = r5;
                            }

                            public void run() {
                                if (MediaBrowserServiceCompat.this.mConnections.get(((ServiceCallbacksCompat) this.val$callbacks).asBinder()) == null) {
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("sendCustomAction for callback that isn't registered action=");
                                    outline25.append(this.val$action);
                                    outline25.append(", extras=");
                                    outline25.append(this.val$extras);
                                    Log.w("MBServiceCompat", outline25.toString());
                                    return;
                                }
                                MediaBrowserServiceCompat mediaBrowserServiceCompat = MediaBrowserServiceCompat.this;
                                String str = this.val$action;
                                Bundle bundle = this.val$extras;
                                AnonymousClass4 r4 = new Result<Bundle>(mediaBrowserServiceCompat, str, this.val$receiver) {
                                    /* class androidx.media.MediaBrowserServiceCompat.AnonymousClass4 */
                                    public final /* synthetic */ ResultReceiver val$receiver;

                                    {
                                        this.val$receiver = r3;
                                    }

                                    @Override // androidx.media.MediaBrowserServiceCompat.Result
                                    public void onErrorSent(Bundle bundle) {
                                        this.val$receiver.send(-1, bundle);
                                    }

                                    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
                                    @Override // androidx.media.MediaBrowserServiceCompat.Result
                                    public void onResultSent(Bundle bundle) {
                                        this.val$receiver.send(0, bundle);
                                    }
                                };
                                mediaBrowserServiceCompat.onCustomAction(r4);
                                if (!r4.isDone()) {
                                    throw new IllegalStateException("onCustomAction must call detach() or sendResult() or sendError() before returning for action=" + str + " extras=" + bundle);
                                }
                            }
                        });
                        return;
                    }
                    return;
                default:
                    Log.w("MBServiceCompat", "Unhandled message: " + message + "\n  Service version: " + 2 + "\n  Client version: " + message.arg1);
                    return;
            }
        }

        public void postOrRun(Runnable runnable) {
            if (Thread.currentThread() == getLooper().getThread()) {
                runnable.run();
            } else {
                post(runnable);
            }
        }

        public boolean sendMessageAtTime(Message message, long j) {
            Bundle data = message.getData();
            data.setClassLoader(MediaBrowserCompat.class.getClassLoader());
            data.putInt("data_calling_uid", Binder.getCallingUid());
            data.putInt("data_calling_pid", Binder.getCallingPid());
            return super.sendMessageAtTime(message, j);
        }
    }

    public void dump(FileDescriptor fileDescriptor, PrintWriter printWriter, String[] strArr) {
    }

    public IBinder onBind(Intent intent) {
        return ((MediaBrowserService) ((MediaBrowserServiceImplApi21) this.mImpl).mServiceObj).onBind(intent);
    }

    public void onCreate() {
        super.onCreate();
        int i = Build.VERSION.SDK_INT;
        if (i >= 28) {
            this.mImpl = new MediaBrowserServiceImplApi28(this);
        } else if (i >= 26) {
            this.mImpl = new MediaBrowserServiceImplApi26();
        } else if (i >= 23) {
            this.mImpl = new MediaBrowserServiceImplApi23();
        } else {
            this.mImpl = new MediaBrowserServiceImplApi21();
        }
        this.mImpl.onCreate();
    }

    /* JADX WARN: Incorrect args count in method signature: (Ljava/lang/String;Landroid/os/Bundle;Landroidx/media/MediaBrowserServiceCompat$Result<Landroid/os/Bundle;>;)V */
    public void onCustomAction(Result result) {
        if (result.mSendResultCalled || result.mSendErrorCalled) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("sendError() called when either sendResult() or sendError() had already been called for: ");
            outline25.append(result.mDebug);
            throw new IllegalStateException(outline25.toString());
        }
        result.mSendErrorCalled = true;
        result.onErrorSent(null);
    }

    public abstract void onGetRoot(String str, int i, Bundle bundle);

    public abstract void onLoadChildren(String str, Result<List<MediaBrowserCompat.MediaItem>> result);

    /* JADX WARN: Incorrect args count in method signature: (Ljava/lang/String;Landroidx/media/MediaBrowserServiceCompat$Result<Ljava/util/List<Landroid/support/v4/media/MediaBrowserCompat$MediaItem;>;>;Landroid/os/Bundle;)V */
    public void onLoadChildren1(String str, Result result) {
        result.mFlags = 1;
        onLoadChildren(str, result);
    }

    /* JADX WARN: Incorrect args count in method signature: (Ljava/lang/String;Landroidx/media/MediaBrowserServiceCompat$Result<Landroid/support/v4/media/MediaBrowserCompat$MediaItem;>;)V */
    public void onLoadItem(Result result) {
        result.mFlags = 2;
        result.sendResult(null);
    }

    /* JADX WARN: Incorrect args count in method signature: (Ljava/lang/String;Landroid/os/Bundle;Landroidx/media/MediaBrowserServiceCompat$Result<Ljava/util/List<Landroid/support/v4/media/MediaBrowserCompat$MediaItem;>;>;)V */
    public void onSearch(Result result) {
        result.mFlags = 4;
        result.sendResult(null);
    }

    public void onSubscribe() {
    }

    public void onUnsubscribe() {
    }
}
