package androidx.recyclerview.widget;

import androidx.core.util.Pools$Pool;
import androidx.core.util.Pools$SimplePool;
import androidx.recyclerview.widget.OpReorderer;
import androidx.recyclerview.widget.RecyclerView;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

public final class AdapterHelper implements OpReorderer.Callback {
    public final Callback mCallback;
    public int mExistingUpdateTypes = 0;
    public final OpReorderer mOpReorderer;
    public final ArrayList<UpdateOp> mPendingUpdates = new ArrayList<>();
    public final ArrayList<UpdateOp> mPostponedList = new ArrayList<>();
    public Pools$Pool<UpdateOp> mUpdateOpPool = new Pools$SimplePool(30);

    public interface Callback {
    }

    public static final class UpdateOp {
        public int cmd;
        public int itemCount;
        public Object payload;
        public int positionStart;

        public UpdateOp(int i, int i2, int i3, Object obj) {
            this.cmd = i;
            this.positionStart = i2;
            this.itemCount = i3;
            this.payload = obj;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof UpdateOp)) {
                return false;
            }
            UpdateOp updateOp = (UpdateOp) obj;
            int i = this.cmd;
            if (i != updateOp.cmd) {
                return false;
            }
            if (i == 8 && Math.abs(this.itemCount - this.positionStart) == 1 && this.itemCount == updateOp.positionStart && this.positionStart == updateOp.itemCount) {
                return true;
            }
            if (this.itemCount != updateOp.itemCount || this.positionStart != updateOp.positionStart) {
                return false;
            }
            Object obj2 = this.payload;
            if (obj2 != null) {
                if (!obj2.equals(updateOp.payload)) {
                    return false;
                }
            } else if (updateOp.payload != null) {
                return false;
            }
            return true;
        }

        public int hashCode() {
            return (((this.cmd * 31) + this.positionStart) * 31) + this.itemCount;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append(Integer.toHexString(System.identityHashCode(this)));
            sb.append("[");
            int i = this.cmd;
            sb.append(i != 1 ? i != 2 ? i != 4 ? i != 8 ? "??" : "mv" : "up" : "rm" : "add");
            sb.append(",s:");
            sb.append(this.positionStart);
            sb.append("c:");
            sb.append(this.itemCount);
            sb.append(",p:");
            sb.append(this.payload);
            sb.append("]");
            return sb.toString();
        }
    }

    public AdapterHelper(Callback callback) {
        this.mCallback = callback;
        this.mOpReorderer = new OpReorderer(this);
    }

    public final boolean canFindInPreLayout(int i) {
        int size = this.mPostponedList.size();
        for (int i2 = 0; i2 < size; i2++) {
            UpdateOp updateOp = this.mPostponedList.get(i2);
            int i3 = updateOp.cmd;
            if (i3 == 8) {
                if (findPositionOffset(updateOp.itemCount, i2 + 1) == i) {
                    return true;
                }
            } else if (i3 == 1) {
                int i4 = updateOp.positionStart;
                int i5 = updateOp.itemCount + i4;
                while (i4 < i5) {
                    if (findPositionOffset(i4, i2 + 1) == i) {
                        return true;
                    }
                    i4++;
                }
                continue;
            } else {
                continue;
            }
        }
        return false;
    }

    public void consumePostponedUpdates() {
        int size = this.mPostponedList.size();
        for (int i = 0; i < size; i++) {
            ((RecyclerView.AnonymousClass6) this.mCallback).dispatchUpdate(this.mPostponedList.get(i));
        }
        recycleUpdateOpsAndClearList(this.mPostponedList);
        this.mExistingUpdateTypes = 0;
    }

    public void consumeUpdatesInOnePass() {
        consumePostponedUpdates();
        int size = this.mPendingUpdates.size();
        for (int i = 0; i < size; i++) {
            UpdateOp updateOp = this.mPendingUpdates.get(i);
            int i2 = updateOp.cmd;
            if (i2 == 1) {
                ((RecyclerView.AnonymousClass6) this.mCallback).dispatchUpdate(updateOp);
                ((RecyclerView.AnonymousClass6) this.mCallback).offsetPositionsForAdd(updateOp.positionStart, updateOp.itemCount);
            } else if (i2 == 2) {
                ((RecyclerView.AnonymousClass6) this.mCallback).dispatchUpdate(updateOp);
                Callback callback = this.mCallback;
                int i3 = updateOp.positionStart;
                int i4 = updateOp.itemCount;
                RecyclerView.AnonymousClass6 r4 = (RecyclerView.AnonymousClass6) callback;
                RecyclerView.this.offsetPositionRecordsForRemove(i3, i4, true);
                RecyclerView recyclerView = RecyclerView.this;
                recyclerView.mItemsAddedOrRemoved = true;
                recyclerView.mState.mDeletedInvisibleItemCountSincePreviousLayout += i4;
            } else if (i2 == 4) {
                ((RecyclerView.AnonymousClass6) this.mCallback).dispatchUpdate(updateOp);
                ((RecyclerView.AnonymousClass6) this.mCallback).markViewHoldersUpdated(updateOp.positionStart, updateOp.itemCount, updateOp.payload);
            } else if (i2 == 8) {
                ((RecyclerView.AnonymousClass6) this.mCallback).dispatchUpdate(updateOp);
                ((RecyclerView.AnonymousClass6) this.mCallback).offsetPositionsForMove(updateOp.positionStart, updateOp.itemCount);
            }
        }
        recycleUpdateOpsAndClearList(this.mPendingUpdates);
        this.mExistingUpdateTypes = 0;
    }

    public final void dispatchAndUpdateViewHolders(UpdateOp updateOp) {
        int i;
        int i2 = updateOp.cmd;
        if (i2 == 1 || i2 == 8) {
            throw new IllegalArgumentException("should not dispatch add or move for pre layout");
        }
        int updatePositionWithPostponed = updatePositionWithPostponed(updateOp.positionStart, i2);
        int i3 = updateOp.positionStart;
        int i4 = updateOp.cmd;
        if (i4 == 2) {
            i = 0;
        } else if (i4 == 4) {
            i = 1;
        } else {
            throw new IllegalArgumentException("op should be remove or update." + updateOp);
        }
        int i5 = 1;
        for (int i6 = 1; i6 < updateOp.itemCount; i6++) {
            int updatePositionWithPostponed2 = updatePositionWithPostponed((i * i6) + updateOp.positionStart, updateOp.cmd);
            int i7 = updateOp.cmd;
            if (i7 == 2 ? updatePositionWithPostponed2 == updatePositionWithPostponed : i7 == 4 && updatePositionWithPostponed2 == updatePositionWithPostponed + 1) {
                i5++;
            } else {
                UpdateOp obtainUpdateOp = obtainUpdateOp(i7, updatePositionWithPostponed, i5, updateOp.payload);
                dispatchFirstPassAndUpdateViewHolders(obtainUpdateOp, i3);
                recycleUpdateOp(obtainUpdateOp);
                if (updateOp.cmd == 4) {
                    i3 += i5;
                }
                updatePositionWithPostponed = updatePositionWithPostponed2;
                i5 = 1;
            }
        }
        Object obj = updateOp.payload;
        recycleUpdateOp(updateOp);
        if (i5 > 0) {
            UpdateOp obtainUpdateOp2 = obtainUpdateOp(updateOp.cmd, updatePositionWithPostponed, i5, obj);
            dispatchFirstPassAndUpdateViewHolders(obtainUpdateOp2, i3);
            recycleUpdateOp(obtainUpdateOp2);
        }
    }

    public void dispatchFirstPassAndUpdateViewHolders(UpdateOp updateOp, int i) {
        ((RecyclerView.AnonymousClass6) this.mCallback).dispatchUpdate(updateOp);
        int i2 = updateOp.cmd;
        if (i2 == 2) {
            Callback callback = this.mCallback;
            int i3 = updateOp.itemCount;
            RecyclerView.AnonymousClass6 r0 = (RecyclerView.AnonymousClass6) callback;
            RecyclerView.this.offsetPositionRecordsForRemove(i, i3, true);
            RecyclerView recyclerView = RecyclerView.this;
            recyclerView.mItemsAddedOrRemoved = true;
            recyclerView.mState.mDeletedInvisibleItemCountSincePreviousLayout += i3;
        } else if (i2 == 4) {
            ((RecyclerView.AnonymousClass6) this.mCallback).markViewHoldersUpdated(i, updateOp.itemCount, updateOp.payload);
        } else {
            throw new IllegalArgumentException("only remove and update ops can be dispatched in first pass");
        }
    }

    public int findPositionOffset(int i, int i2) {
        int size = this.mPostponedList.size();
        while (i2 < size) {
            UpdateOp updateOp = this.mPostponedList.get(i2);
            int i3 = updateOp.cmd;
            if (i3 == 8) {
                int i4 = updateOp.positionStart;
                if (i4 == i) {
                    i = updateOp.itemCount;
                } else {
                    if (i4 < i) {
                        i--;
                    }
                    if (updateOp.itemCount <= i) {
                        i++;
                    }
                }
            } else {
                int i5 = updateOp.positionStart;
                if (i5 > i) {
                    continue;
                } else if (i3 == 2) {
                    int i6 = updateOp.itemCount;
                    if (i < i5 + i6) {
                        return -1;
                    }
                    i -= i6;
                } else if (i3 == 1) {
                    i += updateOp.itemCount;
                }
            }
            i2++;
        }
        return i;
    }

    public boolean hasPendingUpdates() {
        return this.mPendingUpdates.size() > 0;
    }

    public UpdateOp obtainUpdateOp(int i, int i2, int i3, Object obj) {
        UpdateOp acquire = this.mUpdateOpPool.acquire();
        if (acquire == null) {
            return new UpdateOp(i, i2, i3, obj);
        }
        acquire.cmd = i;
        acquire.positionStart = i2;
        acquire.itemCount = i3;
        acquire.payload = obj;
        return acquire;
    }

    public final void postponeAndUpdateViewHolders(UpdateOp updateOp) {
        this.mPostponedList.add(updateOp);
        int i = updateOp.cmd;
        if (i == 1) {
            ((RecyclerView.AnonymousClass6) this.mCallback).offsetPositionsForAdd(updateOp.positionStart, updateOp.itemCount);
        } else if (i == 2) {
            Callback callback = this.mCallback;
            RecyclerView.AnonymousClass6 r0 = (RecyclerView.AnonymousClass6) callback;
            RecyclerView.this.offsetPositionRecordsForRemove(updateOp.positionStart, updateOp.itemCount, false);
            RecyclerView.this.mItemsAddedOrRemoved = true;
        } else if (i == 4) {
            ((RecyclerView.AnonymousClass6) this.mCallback).markViewHoldersUpdated(updateOp.positionStart, updateOp.itemCount, updateOp.payload);
        } else if (i == 8) {
            ((RecyclerView.AnonymousClass6) this.mCallback).offsetPositionsForMove(updateOp.positionStart, updateOp.itemCount);
        } else {
            throw new IllegalArgumentException("Unknown update op type for " + updateOp);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:172:0x0009 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x006b  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0070  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x008e  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x0092  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x009e  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x00a3  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00d2  */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x00d7  */
    /* JADX WARNING: Removed duplicated region for block: B:62:0x00fa  */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x00ff  */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x0118  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0127  */
    public void preProcess() {
        char c;
        boolean z;
        boolean z2;
        boolean z3;
        int i;
        int i2;
        int i3;
        boolean z4;
        UpdateOp updateOp;
        int i4;
        int i5;
        OpReorderer opReorderer = this.mOpReorderer;
        ArrayList<UpdateOp> arrayList = this.mPendingUpdates;
        Objects.requireNonNull(opReorderer);
        while (true) {
            int size = arrayList.size() - 1;
            boolean z5 = false;
            while (true) {
                if (size < 0) {
                    size = -1;
                    break;
                }
                if (arrayList.get(size).cmd != 8) {
                    z5 = true;
                } else if (z5) {
                    break;
                }
                size--;
            }
            UpdateOp updateOp2 = null;
            if (size == -1) {
                break;
            }
            int i6 = size + 1;
            UpdateOp updateOp3 = arrayList.get(size);
            UpdateOp updateOp4 = arrayList.get(i6);
            int i7 = updateOp4.cmd;
            if (i7 == 1) {
                int i8 = updateOp3.itemCount;
                int i9 = updateOp4.positionStart;
                int i10 = i8 < i9 ? -1 : 0;
                int i11 = updateOp3.positionStart;
                if (i11 < i9) {
                    i10++;
                }
                if (i9 <= i11) {
                    updateOp3.positionStart = i11 + updateOp4.itemCount;
                }
                int i12 = updateOp4.positionStart;
                if (i12 <= i8) {
                    updateOp3.itemCount = i8 + updateOp4.itemCount;
                }
                updateOp4.positionStart = i12 + i10;
                arrayList.set(size, updateOp4);
                arrayList.set(i6, updateOp3);
            } else if (i7 == 2) {
                int i13 = updateOp3.positionStart;
                int i14 = updateOp3.itemCount;
                if (i13 < i14) {
                    if (updateOp4.positionStart == i13 && updateOp4.itemCount == i14 - i13) {
                        z4 = false;
                    } else {
                        z3 = false;
                        z2 = false;
                        i = updateOp4.positionStart;
                        if (i14 < i) {
                            updateOp4.positionStart = i - 1;
                        } else {
                            int i15 = updateOp4.itemCount;
                            if (i14 < i + i15) {
                                updateOp4.itemCount = i15 - 1;
                                updateOp3.cmd = 2;
                                updateOp3.itemCount = 1;
                                if (updateOp4.itemCount == 0) {
                                    arrayList.remove(i6);
                                    ((AdapterHelper) opReorderer.mCallback).recycleUpdateOp(updateOp4);
                                }
                            }
                        }
                        i2 = updateOp3.positionStart;
                        i3 = updateOp4.positionStart;
                        if (i2 <= i3) {
                            updateOp4.positionStart = i3 + 1;
                        } else {
                            int i16 = i3 + updateOp4.itemCount;
                            if (i2 < i16) {
                                updateOp2 = ((AdapterHelper) opReorderer.mCallback).obtainUpdateOp(2, i2 + 1, i16 - i2, null);
                                updateOp4.itemCount = updateOp3.positionStart - updateOp4.positionStart;
                            }
                        }
                        if (z3) {
                            arrayList.set(size, updateOp4);
                            arrayList.remove(i6);
                            ((AdapterHelper) opReorderer.mCallback).recycleUpdateOp(updateOp3);
                        } else {
                            if (z2) {
                                if (updateOp2 != null) {
                                    int i17 = updateOp3.positionStart;
                                    if (i17 > updateOp2.positionStart) {
                                        updateOp3.positionStart = i17 - updateOp2.itemCount;
                                    }
                                    int i18 = updateOp3.itemCount;
                                    if (i18 > updateOp2.positionStart) {
                                        updateOp3.itemCount = i18 - updateOp2.itemCount;
                                    }
                                }
                                int i19 = updateOp3.positionStart;
                                if (i19 > updateOp4.positionStart) {
                                    updateOp3.positionStart = i19 - updateOp4.itemCount;
                                }
                                int i20 = updateOp3.itemCount;
                                if (i20 > updateOp4.positionStart) {
                                    updateOp3.itemCount = i20 - updateOp4.itemCount;
                                }
                            } else {
                                if (updateOp2 != null) {
                                    int i21 = updateOp3.positionStart;
                                    if (i21 >= updateOp2.positionStart) {
                                        updateOp3.positionStart = i21 - updateOp2.itemCount;
                                    }
                                    int i22 = updateOp3.itemCount;
                                    if (i22 >= updateOp2.positionStart) {
                                        updateOp3.itemCount = i22 - updateOp2.itemCount;
                                    }
                                }
                                int i23 = updateOp3.positionStart;
                                if (i23 >= updateOp4.positionStart) {
                                    updateOp3.positionStart = i23 - updateOp4.itemCount;
                                }
                                int i24 = updateOp3.itemCount;
                                if (i24 >= updateOp4.positionStart) {
                                    updateOp3.itemCount = i24 - updateOp4.itemCount;
                                }
                            }
                            arrayList.set(size, updateOp4);
                            if (updateOp3.positionStart != updateOp3.itemCount) {
                                arrayList.set(i6, updateOp3);
                            } else {
                                arrayList.remove(i6);
                            }
                            if (updateOp2 != null) {
                                arrayList.add(size, updateOp2);
                            }
                        }
                    }
                } else if (updateOp4.positionStart == i14 + 1 && updateOp4.itemCount == i13 - i14) {
                    z4 = true;
                } else {
                    z3 = false;
                    z2 = true;
                    i = updateOp4.positionStart;
                    if (i14 < i) {
                    }
                    i2 = updateOp3.positionStart;
                    i3 = updateOp4.positionStart;
                    if (i2 <= i3) {
                    }
                    if (z3) {
                    }
                }
                z2 = z4;
                z3 = true;
                i = updateOp4.positionStart;
                if (i14 < i) {
                }
                i2 = updateOp3.positionStart;
                i3 = updateOp4.positionStart;
                if (i2 <= i3) {
                }
                if (z3) {
                }
            } else if (i7 == 4) {
                int i25 = updateOp3.itemCount;
                int i26 = updateOp4.positionStart;
                if (i25 < i26) {
                    updateOp4.positionStart = i26 - 1;
                } else {
                    int i27 = updateOp4.itemCount;
                    if (i25 < i26 + i27) {
                        updateOp4.itemCount = i27 - 1;
                        updateOp = ((AdapterHelper) opReorderer.mCallback).obtainUpdateOp(4, updateOp3.positionStart, 1, updateOp4.payload);
                        i4 = updateOp3.positionStart;
                        i5 = updateOp4.positionStart;
                        if (i4 > i5) {
                            updateOp4.positionStart = i5 + 1;
                        } else {
                            int i28 = i5 + updateOp4.itemCount;
                            if (i4 < i28) {
                                int i29 = i28 - i4;
                                updateOp2 = ((AdapterHelper) opReorderer.mCallback).obtainUpdateOp(4, i4 + 1, i29, updateOp4.payload);
                                updateOp4.itemCount -= i29;
                            }
                        }
                        arrayList.set(i6, updateOp3);
                        if (updateOp4.itemCount <= 0) {
                            arrayList.set(size, updateOp4);
                        } else {
                            arrayList.remove(size);
                            ((AdapterHelper) opReorderer.mCallback).recycleUpdateOp(updateOp4);
                        }
                        if (updateOp != null) {
                            arrayList.add(size, updateOp);
                        }
                        if (updateOp2 == null) {
                            arrayList.add(size, updateOp2);
                        }
                    }
                }
                updateOp = null;
                i4 = updateOp3.positionStart;
                i5 = updateOp4.positionStart;
                if (i4 > i5) {
                }
                arrayList.set(i6, updateOp3);
                if (updateOp4.itemCount <= 0) {
                }
                if (updateOp != null) {
                }
                if (updateOp2 == null) {
                }
            }
        }
        int size2 = this.mPendingUpdates.size();
        for (int i30 = 0; i30 < size2; i30++) {
            UpdateOp updateOp5 = this.mPendingUpdates.get(i30);
            int i31 = updateOp5.cmd;
            if (i31 == 1) {
                postponeAndUpdateViewHolders(updateOp5);
            } else if (i31 == 2) {
                int i32 = updateOp5.positionStart;
                int i33 = updateOp5.itemCount + i32;
                int i34 = i32;
                int i35 = 0;
                char c2 = 65535;
                while (i34 < i33) {
                    if (((RecyclerView.AnonymousClass6) this.mCallback).findViewHolder(i34) != null || canFindInPreLayout(i34)) {
                        if (c2 == 0) {
                            dispatchAndUpdateViewHolders(obtainUpdateOp(2, i32, i35, null));
                            z = true;
                        } else {
                            z = false;
                        }
                        c = 1;
                    } else {
                        if (c2 == 1) {
                            postponeAndUpdateViewHolders(obtainUpdateOp(2, i32, i35, null));
                            z = true;
                        } else {
                            z = false;
                        }
                        c = 0;
                    }
                    if (z) {
                        i34 -= i35;
                        i33 -= i35;
                        i35 = 1;
                    } else {
                        i35++;
                    }
                    i34++;
                    c2 = c;
                }
                if (i35 != updateOp5.itemCount) {
                    recycleUpdateOp(updateOp5);
                    updateOp5 = obtainUpdateOp(2, i32, i35, null);
                }
                if (c2 == 0) {
                    dispatchAndUpdateViewHolders(updateOp5);
                } else {
                    postponeAndUpdateViewHolders(updateOp5);
                }
            } else if (i31 == 4) {
                int i36 = updateOp5.positionStart;
                int i37 = updateOp5.itemCount + i36;
                int i38 = i36;
                int i39 = 0;
                char c3 = 65535;
                while (i36 < i37) {
                    if (((RecyclerView.AnonymousClass6) this.mCallback).findViewHolder(i36) != null || canFindInPreLayout(i36)) {
                        if (c3 == 0) {
                            dispatchAndUpdateViewHolders(obtainUpdateOp(4, i38, i39, updateOp5.payload));
                            i38 = i36;
                            i39 = 0;
                        }
                        c3 = 1;
                    } else {
                        if (c3 == 1) {
                            postponeAndUpdateViewHolders(obtainUpdateOp(4, i38, i39, updateOp5.payload));
                            i38 = i36;
                            i39 = 0;
                        }
                        c3 = 0;
                    }
                    i39++;
                    i36++;
                }
                if (i39 != updateOp5.itemCount) {
                    Object obj = updateOp5.payload;
                    recycleUpdateOp(updateOp5);
                    updateOp5 = obtainUpdateOp(4, i38, i39, obj);
                }
                if (c3 == 0) {
                    dispatchAndUpdateViewHolders(updateOp5);
                } else {
                    postponeAndUpdateViewHolders(updateOp5);
                }
            } else if (i31 == 8) {
                postponeAndUpdateViewHolders(updateOp5);
            }
        }
        this.mPendingUpdates.clear();
    }

    public void recycleUpdateOp(UpdateOp updateOp) {
        updateOp.payload = null;
        this.mUpdateOpPool.release(updateOp);
    }

    public void recycleUpdateOpsAndClearList(List<UpdateOp> list) {
        int size = list.size();
        for (int i = 0; i < size; i++) {
            recycleUpdateOp(list.get(i));
        }
        list.clear();
    }

    public final int updatePositionWithPostponed(int i, int i2) {
        int i3;
        int i4;
        for (int size = this.mPostponedList.size() - 1; size >= 0; size--) {
            UpdateOp updateOp = this.mPostponedList.get(size);
            int i5 = updateOp.cmd;
            if (i5 == 8) {
                int i6 = updateOp.positionStart;
                int i7 = updateOp.itemCount;
                if (i6 < i7) {
                    i4 = i6;
                    i3 = i7;
                } else {
                    i3 = i6;
                    i4 = i7;
                }
                if (i < i4 || i > i3) {
                    if (i < i6) {
                        if (i2 == 1) {
                            updateOp.positionStart = i6 + 1;
                            updateOp.itemCount = i7 + 1;
                        } else if (i2 == 2) {
                            updateOp.positionStart = i6 - 1;
                            updateOp.itemCount = i7 - 1;
                        }
                    }
                } else if (i4 == i6) {
                    if (i2 == 1) {
                        updateOp.itemCount = i7 + 1;
                    } else if (i2 == 2) {
                        updateOp.itemCount = i7 - 1;
                    }
                    i++;
                } else {
                    if (i2 == 1) {
                        updateOp.positionStart = i6 + 1;
                    } else if (i2 == 2) {
                        updateOp.positionStart = i6 - 1;
                    }
                    i--;
                }
            } else {
                int i8 = updateOp.positionStart;
                if (i8 <= i) {
                    if (i5 == 1) {
                        i -= updateOp.itemCount;
                    } else if (i5 == 2) {
                        i += updateOp.itemCount;
                    }
                } else if (i2 == 1) {
                    updateOp.positionStart = i8 + 1;
                } else if (i2 == 2) {
                    updateOp.positionStart = i8 - 1;
                }
            }
        }
        for (int size2 = this.mPostponedList.size() - 1; size2 >= 0; size2--) {
            UpdateOp updateOp2 = this.mPostponedList.get(size2);
            if (updateOp2.cmd == 8) {
                int i9 = updateOp2.itemCount;
                if (i9 == updateOp2.positionStart || i9 < 0) {
                    this.mPostponedList.remove(size2);
                    recycleUpdateOp(updateOp2);
                }
            } else if (updateOp2.itemCount <= 0) {
                this.mPostponedList.remove(size2);
                recycleUpdateOp(updateOp2);
            }
        }
        return i;
    }
}
