package androidx.savedstate;

import android.annotation.SuppressLint;
import android.os.Bundle;
import androidx.lifecycle.Lifecycle;
import androidx.lifecycle.LifecycleEventObserver;
import androidx.lifecycle.LifecycleOwner;
import androidx.lifecycle.LifecycleRegistry;
import androidx.lifecycle.SavedStateHandleController;
import androidx.lifecycle.ViewModel;
import androidx.lifecycle.ViewModelStore;
import androidx.lifecycle.ViewModelStoreOwner;
import androidx.savedstate.SavedStateRegistry;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.lang.reflect.Constructor;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Objects;
import java.util.Set;

@SuppressLint({"RestrictedApi"})
public final class Recreator implements LifecycleEventObserver {
    public final SavedStateRegistryOwner mOwner;

    public static final class SavedStateProvider implements SavedStateRegistry.SavedStateProvider {
        public final Set<String> mClasses = new HashSet();

        public SavedStateProvider(SavedStateRegistry savedStateRegistry) {
            savedStateRegistry.registerSavedStateProvider("androidx.savedstate.Restarter", this);
        }

        @Override // androidx.savedstate.SavedStateRegistry.SavedStateProvider
        public Bundle saveState() {
            Bundle bundle = new Bundle();
            bundle.putStringArrayList("classes_to_restore", new ArrayList<>(this.mClasses));
            return bundle;
        }
    }

    public Recreator(SavedStateRegistryOwner savedStateRegistryOwner) {
        this.mOwner = savedStateRegistryOwner;
    }

    @Override // androidx.lifecycle.LifecycleEventObserver
    public void onStateChanged(LifecycleOwner lifecycleOwner, Lifecycle.Event event) {
        Class cls;
        if (event == Lifecycle.Event.ON_CREATE) {
            LifecycleRegistry lifecycleRegistry = (LifecycleRegistry) lifecycleOwner.getLifecycle();
            lifecycleRegistry.enforceMainThreadIfNeeded("removeObserver");
            lifecycleRegistry.mObserverMap.remove(this);
            Bundle consumeRestoredStateForKey = this.mOwner.getSavedStateRegistry().consumeRestoredStateForKey("androidx.savedstate.Restarter");
            if (consumeRestoredStateForKey != null) {
                ArrayList<String> stringArrayList = consumeRestoredStateForKey.getStringArrayList("classes_to_restore");
                if (stringArrayList != null) {
                    Iterator<String> it = stringArrayList.iterator();
                    while (it.hasNext()) {
                        String next = it.next();
                        try {
                            try {
                                Constructor<? extends U> declaredConstructor = Class.forName(next, false, Recreator.class.getClassLoader()).asSubclass(SavedStateRegistry.AutoRecreated.class).getDeclaredConstructor(new Class[0]);
                                declaredConstructor.setAccessible(true);
                                try {
                                    SavedStateRegistry.AutoRecreated autoRecreated = (SavedStateRegistry.AutoRecreated) declaredConstructor.newInstance(new Object[0]);
                                    SavedStateRegistryOwner savedStateRegistryOwner = this.mOwner;
                                    Objects.requireNonNull((SavedStateHandleController.OnRecreation) autoRecreated);
                                    if (savedStateRegistryOwner instanceof ViewModelStoreOwner) {
                                        ViewModelStore viewModelStore = ((ViewModelStoreOwner) savedStateRegistryOwner).getViewModelStore();
                                        SavedStateRegistry savedStateRegistry = savedStateRegistryOwner.getSavedStateRegistry();
                                        Objects.requireNonNull(viewModelStore);
                                        Iterator it2 = new HashSet(viewModelStore.mMap.keySet()).iterator();
                                        while (it2.hasNext()) {
                                            HashMap<String, ViewModel> hashMap = viewModelStore.mMap;
                                            Lifecycle lifecycle = savedStateRegistryOwner.getLifecycle();
                                            SavedStateHandleController savedStateHandleController = (SavedStateHandleController) hashMap.get((String) it2.next()).getTag("androidx.lifecycle.savedstate.vm.tag");
                                            if (savedStateHandleController != null && !savedStateHandleController.mIsAttached) {
                                                savedStateHandleController.attachToLifecycle(savedStateRegistry, lifecycle);
                                                SavedStateHandleController.tryToAddRecreator(savedStateRegistry, lifecycle);
                                            }
                                        }
                                        if (!new HashSet(viewModelStore.mMap.keySet()).isEmpty()) {
                                            savedStateRegistry.runOnNextRecreation(SavedStateHandleController.OnRecreation.class);
                                        }
                                    } else {
                                        throw new IllegalStateException("Internal error: OnRecreation should be registered only on componentsthat implement ViewModelStoreOwner");
                                    }
                                } catch (Exception e) {
                                    throw new RuntimeException(GeneratedOutlineSupport.outline18("Failed to instantiate ", next), e);
                                }
                            } catch (NoSuchMethodException e2) {
                                StringBuilder outline25 = GeneratedOutlineSupport.outline25("Class");
                                outline25.append(cls.getSimpleName());
                                outline25.append(" must have default constructor in order to be automatically recreated");
                                throw new IllegalStateException(outline25.toString(), e2);
                            }
                        } catch (ClassNotFoundException e3) {
                            throw new RuntimeException(GeneratedOutlineSupport.outline19("Class ", next, " wasn't found"), e3);
                        }
                    }
                    return;
                }
                throw new IllegalStateException("Bundle with restored state for the component \"androidx.savedstate.Restarter\" must contain list of strings by the key \"classes_to_restore\"");
            }
            return;
        }
        throw new AssertionError("Next event must be ON_CREATE");
    }
}
