package androidx.vectordrawable.graphics.drawable;

import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.ColorFilter;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.PathMeasure;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffColorFilter;
import android.graphics.Rect;
import android.graphics.Shader;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.VectorDrawable;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Log;
import android.util.TypedValue;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.collection.ArrayMap;
import androidx.core.content.res.ComplexColorCompat;
import androidx.core.content.res.ResourcesCompat$ThemeCompat;
import androidx.core.graphics.PathParser$PathDataNode;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Objects;
import org.xbill.DNS.KEYRecord;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

public class VectorDrawableCompat extends VectorDrawableCommon {
    public static final PorterDuff.Mode DEFAULT_TINT_MODE = PorterDuff.Mode.SRC_IN;
    public boolean mAllowCaching;
    public ColorFilter mColorFilter;
    public boolean mMutated;
    public PorterDuffColorFilter mTintFilter;
    public final Rect mTmpBounds;
    public final float[] mTmpFloats;
    public final Matrix mTmpMatrix;
    public VectorDrawableCompatState mVectorState;

    public class VClipPath extends VPath {
        public VClipPath() {
        }

        public VClipPath(VClipPath vClipPath) {
            super(vClipPath);
        }
    }

    public abstract class VObject {
        public VObject(AnonymousClass1 r1) {
        }

        public boolean isStateful() {
            return false;
        }

        public boolean onStateChanged(int[] iArr) {
            return false;
        }
    }

    public class VectorDrawableCompatState extends Drawable.ConstantState {
        public boolean mAutoMirrored;
        public boolean mCacheDirty;
        public boolean mCachedAutoMirrored;
        public Bitmap mCachedBitmap;
        public int mCachedRootAlpha;
        public ColorStateList mCachedTint;
        public PorterDuff.Mode mCachedTintMode;
        public int mChangingConfigurations;
        public Paint mTempPaint;
        public ColorStateList mTint;
        public PorterDuff.Mode mTintMode;
        public VPathRenderer mVPathRenderer;

        public VectorDrawableCompatState(VectorDrawableCompatState vectorDrawableCompatState) {
            this.mTint = null;
            this.mTintMode = VectorDrawableCompat.DEFAULT_TINT_MODE;
            if (vectorDrawableCompatState != null) {
                this.mChangingConfigurations = vectorDrawableCompatState.mChangingConfigurations;
                VPathRenderer vPathRenderer = new VPathRenderer(vectorDrawableCompatState.mVPathRenderer);
                this.mVPathRenderer = vPathRenderer;
                if (vectorDrawableCompatState.mVPathRenderer.mFillPaint != null) {
                    vPathRenderer.mFillPaint = new Paint(vectorDrawableCompatState.mVPathRenderer.mFillPaint);
                }
                if (vectorDrawableCompatState.mVPathRenderer.mStrokePaint != null) {
                    this.mVPathRenderer.mStrokePaint = new Paint(vectorDrawableCompatState.mVPathRenderer.mStrokePaint);
                }
                this.mTint = vectorDrawableCompatState.mTint;
                this.mTintMode = vectorDrawableCompatState.mTintMode;
                this.mAutoMirrored = vectorDrawableCompatState.mAutoMirrored;
            }
        }

        public int getChangingConfigurations() {
            return this.mChangingConfigurations;
        }

        public boolean isStateful() {
            VPathRenderer vPathRenderer = this.mVPathRenderer;
            if (vPathRenderer.mIsStateful == null) {
                vPathRenderer.mIsStateful = Boolean.valueOf(vPathRenderer.mRootGroup.isStateful());
            }
            return vPathRenderer.mIsStateful.booleanValue();
        }

        public Drawable newDrawable() {
            return new VectorDrawableCompat(this);
        }

        public void updateCachedBitmap(int i, int i2) {
            this.mCachedBitmap.eraseColor(0);
            Canvas canvas = new Canvas(this.mCachedBitmap);
            VPathRenderer vPathRenderer = this.mVPathRenderer;
            vPathRenderer.drawGroupTree(vPathRenderer.mRootGroup, VPathRenderer.IDENTITY_MATRIX, canvas, i, i2, null);
        }

        public Drawable newDrawable(Resources resources) {
            return new VectorDrawableCompat(this);
        }

        public VectorDrawableCompatState() {
            this.mTint = null;
            this.mTintMode = VectorDrawableCompat.DEFAULT_TINT_MODE;
            this.mVPathRenderer = new VPathRenderer();
        }
    }

    public VectorDrawableCompat() {
        this.mAllowCaching = true;
        this.mTmpFloats = new float[9];
        this.mTmpMatrix = new Matrix();
        this.mTmpBounds = new Rect();
        this.mVectorState = new VectorDrawableCompatState();
    }

    public static VectorDrawableCompat createFromXmlInner(Resources resources, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
        VectorDrawableCompat vectorDrawableCompat = new VectorDrawableCompat();
        vectorDrawableCompat.inflate(resources, xmlPullParser, attributeSet, theme);
        return vectorDrawableCompat;
    }

    public boolean canApplyTheme() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable == null) {
            return false;
        }
        drawable.canApplyTheme();
        return false;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:35:0x00d3, code lost:
        if ((r1 == r7.getWidth() && r3 == r6.mCachedBitmap.getHeight()) == false) goto L_0x00d5;
     */
    public void draw(Canvas canvas) {
        Paint paint;
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.draw(canvas);
            return;
        }
        copyBounds(this.mTmpBounds);
        if (this.mTmpBounds.width() > 0 && this.mTmpBounds.height() > 0) {
            ColorFilter colorFilter = this.mColorFilter;
            if (colorFilter == null) {
                colorFilter = this.mTintFilter;
            }
            canvas.getMatrix(this.mTmpMatrix);
            this.mTmpMatrix.getValues(this.mTmpFloats);
            boolean z = false;
            float abs = Math.abs(this.mTmpFloats[0]);
            float abs2 = Math.abs(this.mTmpFloats[4]);
            float abs3 = Math.abs(this.mTmpFloats[1]);
            float abs4 = Math.abs(this.mTmpFloats[3]);
            if (!(abs3 == 0.0f && abs4 == 0.0f)) {
                abs = 1.0f;
                abs2 = 1.0f;
            }
            int min = Math.min(2048, (int) (((float) this.mTmpBounds.width()) * abs));
            int min2 = Math.min(2048, (int) (((float) this.mTmpBounds.height()) * abs2));
            if (min > 0 && min2 > 0) {
                int save = canvas.save();
                Rect rect = this.mTmpBounds;
                canvas.translate((float) rect.left, (float) rect.top);
                if (isAutoMirrored() && AppCompatDelegateImpl.Api17Impl.getLayoutDirection(this) == 1) {
                    canvas.translate((float) this.mTmpBounds.width(), 0.0f);
                    canvas.scale(-1.0f, 1.0f);
                }
                this.mTmpBounds.offsetTo(0, 0);
                VectorDrawableCompatState vectorDrawableCompatState = this.mVectorState;
                Bitmap bitmap = vectorDrawableCompatState.mCachedBitmap;
                if (bitmap != null) {
                }
                vectorDrawableCompatState.mCachedBitmap = Bitmap.createBitmap(min, min2, Bitmap.Config.ARGB_8888);
                vectorDrawableCompatState.mCacheDirty = true;
                if (!this.mAllowCaching) {
                    this.mVectorState.updateCachedBitmap(min, min2);
                } else {
                    VectorDrawableCompatState vectorDrawableCompatState2 = this.mVectorState;
                    if (!(!vectorDrawableCompatState2.mCacheDirty && vectorDrawableCompatState2.mCachedTint == vectorDrawableCompatState2.mTint && vectorDrawableCompatState2.mCachedTintMode == vectorDrawableCompatState2.mTintMode && vectorDrawableCompatState2.mCachedAutoMirrored == vectorDrawableCompatState2.mAutoMirrored && vectorDrawableCompatState2.mCachedRootAlpha == vectorDrawableCompatState2.mVPathRenderer.getRootAlpha())) {
                        this.mVectorState.updateCachedBitmap(min, min2);
                        VectorDrawableCompatState vectorDrawableCompatState3 = this.mVectorState;
                        vectorDrawableCompatState3.mCachedTint = vectorDrawableCompatState3.mTint;
                        vectorDrawableCompatState3.mCachedTintMode = vectorDrawableCompatState3.mTintMode;
                        vectorDrawableCompatState3.mCachedRootAlpha = vectorDrawableCompatState3.mVPathRenderer.getRootAlpha();
                        vectorDrawableCompatState3.mCachedAutoMirrored = vectorDrawableCompatState3.mAutoMirrored;
                        vectorDrawableCompatState3.mCacheDirty = false;
                    }
                }
                VectorDrawableCompatState vectorDrawableCompatState4 = this.mVectorState;
                Rect rect2 = this.mTmpBounds;
                if (vectorDrawableCompatState4.mVPathRenderer.getRootAlpha() < 255) {
                    z = true;
                }
                if (z || colorFilter != null) {
                    if (vectorDrawableCompatState4.mTempPaint == null) {
                        Paint paint2 = new Paint();
                        vectorDrawableCompatState4.mTempPaint = paint2;
                        paint2.setFilterBitmap(true);
                    }
                    vectorDrawableCompatState4.mTempPaint.setAlpha(vectorDrawableCompatState4.mVPathRenderer.getRootAlpha());
                    vectorDrawableCompatState4.mTempPaint.setColorFilter(colorFilter);
                    paint = vectorDrawableCompatState4.mTempPaint;
                } else {
                    paint = null;
                }
                canvas.drawBitmap(vectorDrawableCompatState4.mCachedBitmap, (Rect) null, rect2, paint);
                canvas.restoreToCount(save);
            }
        }
    }

    public int getAlpha() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.getAlpha();
        }
        return this.mVectorState.mVPathRenderer.getRootAlpha();
    }

    public int getChangingConfigurations() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.getChangingConfigurations();
        }
        return super.getChangingConfigurations() | this.mVectorState.getChangingConfigurations();
    }

    public ColorFilter getColorFilter() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.getColorFilter();
        }
        return this.mColorFilter;
    }

    public Drawable.ConstantState getConstantState() {
        if (this.mDelegateDrawable != null && Build.VERSION.SDK_INT >= 24) {
            return new VectorDrawableDelegateState(this.mDelegateDrawable.getConstantState());
        }
        this.mVectorState.mChangingConfigurations = getChangingConfigurations();
        return this.mVectorState;
    }

    public int getIntrinsicHeight() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.getIntrinsicHeight();
        }
        return (int) this.mVectorState.mVPathRenderer.mBaseHeight;
    }

    public int getIntrinsicWidth() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.getIntrinsicWidth();
        }
        return (int) this.mVectorState.mVPathRenderer.mBaseWidth;
    }

    public int getOpacity() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.getOpacity();
        }
        return -3;
    }

    @Override // android.graphics.drawable.Drawable
    public void inflate(Resources resources, XmlPullParser xmlPullParser, AttributeSet attributeSet) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.inflate(resources, xmlPullParser, attributeSet);
        } else {
            inflate(resources, xmlPullParser, attributeSet, null);
        }
    }

    public void invalidateSelf() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.invalidateSelf();
        } else {
            super.invalidateSelf();
        }
    }

    public boolean isAutoMirrored() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.isAutoMirrored();
        }
        return this.mVectorState.mAutoMirrored;
    }

    public boolean isStateful() {
        VectorDrawableCompatState vectorDrawableCompatState;
        ColorStateList colorStateList;
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.isStateful();
        }
        return super.isStateful() || ((vectorDrawableCompatState = this.mVectorState) != null && (vectorDrawableCompatState.isStateful() || ((colorStateList = this.mVectorState.mTint) != null && colorStateList.isStateful())));
    }

    public Drawable mutate() {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.mutate();
            return this;
        }
        if (!this.mMutated && super.mutate() == this) {
            this.mVectorState = new VectorDrawableCompatState(this.mVectorState);
            this.mMutated = true;
        }
        return this;
    }

    public void onBoundsChange(Rect rect) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.setBounds(rect);
        }
    }

    public boolean onStateChange(int[] iArr) {
        PorterDuff.Mode mode;
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.setState(iArr);
        }
        boolean z = false;
        VectorDrawableCompatState vectorDrawableCompatState = this.mVectorState;
        ColorStateList colorStateList = vectorDrawableCompatState.mTint;
        if (!(colorStateList == null || (mode = vectorDrawableCompatState.mTintMode) == null)) {
            this.mTintFilter = updateTintFilter(colorStateList, mode);
            invalidateSelf();
            z = true;
        }
        if (vectorDrawableCompatState.isStateful()) {
            boolean onStateChanged = vectorDrawableCompatState.mVPathRenderer.mRootGroup.onStateChanged(iArr);
            vectorDrawableCompatState.mCacheDirty |= onStateChanged;
            if (onStateChanged) {
                invalidateSelf();
                return true;
            }
        }
        return z;
    }

    public void scheduleSelf(Runnable runnable, long j) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.scheduleSelf(runnable, j);
        } else {
            super.scheduleSelf(runnable, j);
        }
    }

    public void setAlpha(int i) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.setAlpha(i);
        } else if (this.mVectorState.mVPathRenderer.getRootAlpha() != i) {
            this.mVectorState.mVPathRenderer.setRootAlpha(i);
            invalidateSelf();
        }
    }

    public void setAutoMirrored(boolean z) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.setAutoMirrored(z);
        } else {
            this.mVectorState.mAutoMirrored = z;
        }
    }

    public void setColorFilter(ColorFilter colorFilter) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.setColorFilter(colorFilter);
            return;
        }
        this.mColorFilter = colorFilter;
        invalidateSelf();
    }

    public void setTint(int i) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            AppCompatDelegateImpl.Api17Impl.setTint(drawable, i);
        } else {
            setTintList(ColorStateList.valueOf(i));
        }
    }

    public void setTintList(ColorStateList colorStateList) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            AppCompatDelegateImpl.Api17Impl.setTintList(drawable, colorStateList);
            return;
        }
        VectorDrawableCompatState vectorDrawableCompatState = this.mVectorState;
        if (vectorDrawableCompatState.mTint != colorStateList) {
            vectorDrawableCompatState.mTint = colorStateList;
            this.mTintFilter = updateTintFilter(colorStateList, vectorDrawableCompatState.mTintMode);
            invalidateSelf();
        }
    }

    public void setTintMode(PorterDuff.Mode mode) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            AppCompatDelegateImpl.Api17Impl.setTintMode(drawable, mode);
            return;
        }
        VectorDrawableCompatState vectorDrawableCompatState = this.mVectorState;
        if (vectorDrawableCompatState.mTintMode != mode) {
            vectorDrawableCompatState.mTintMode = mode;
            this.mTintFilter = updateTintFilter(vectorDrawableCompatState.mTint, mode);
            invalidateSelf();
        }
    }

    public boolean setVisible(boolean z, boolean z2) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            return drawable.setVisible(z, z2);
        }
        return super.setVisible(z, z2);
    }

    public void unscheduleSelf(Runnable runnable) {
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.unscheduleSelf(runnable);
        } else {
            super.unscheduleSelf(runnable);
        }
    }

    public PorterDuffColorFilter updateTintFilter(ColorStateList colorStateList, PorterDuff.Mode mode) {
        if (colorStateList == null || mode == null) {
            return null;
        }
        return new PorterDuffColorFilter(colorStateList.getColorForState(getState(), 0), mode);
    }

    public class VectorDrawableDelegateState extends Drawable.ConstantState {
        public final Drawable.ConstantState mDelegateState;

        public VectorDrawableDelegateState(Drawable.ConstantState constantState) {
            this.mDelegateState = constantState;
        }

        public boolean canApplyTheme() {
            return this.mDelegateState.canApplyTheme();
        }

        public int getChangingConfigurations() {
            return this.mDelegateState.getChangingConfigurations();
        }

        public Drawable newDrawable() {
            VectorDrawableCompat vectorDrawableCompat = new VectorDrawableCompat();
            vectorDrawableCompat.mDelegateDrawable = (VectorDrawable) this.mDelegateState.newDrawable();
            return vectorDrawableCompat;
        }

        public Drawable newDrawable(Resources resources) {
            VectorDrawableCompat vectorDrawableCompat = new VectorDrawableCompat();
            vectorDrawableCompat.mDelegateDrawable = (VectorDrawable) this.mDelegateState.newDrawable(resources);
            return vectorDrawableCompat;
        }

        public Drawable newDrawable(Resources resources, Resources.Theme theme) {
            VectorDrawableCompat vectorDrawableCompat = new VectorDrawableCompat();
            vectorDrawableCompat.mDelegateDrawable = (VectorDrawable) this.mDelegateState.newDrawable(resources, theme);
            return vectorDrawableCompat;
        }
    }

    public abstract class VPath extends VObject {
        public int mChangingConfigurations;
        public int mFillRule = 0;
        public PathParser$PathDataNode[] mNodes = null;
        public String mPathName;

        public VPath() {
            super(null);
        }

        public PathParser$PathDataNode[] getPathData() {
            return this.mNodes;
        }

        public String getPathName() {
            return this.mPathName;
        }

        public void setPathData(PathParser$PathDataNode[] pathParser$PathDataNodeArr) {
            if (!AppCompatDelegateImpl.Api17Impl.canMorph(this.mNodes, pathParser$PathDataNodeArr)) {
                this.mNodes = AppCompatDelegateImpl.Api17Impl.deepCopyNodes(pathParser$PathDataNodeArr);
                return;
            }
            PathParser$PathDataNode[] pathParser$PathDataNodeArr2 = this.mNodes;
            for (int i = 0; i < pathParser$PathDataNodeArr.length; i++) {
                pathParser$PathDataNodeArr2[i].mType = pathParser$PathDataNodeArr[i].mType;
                for (int i2 = 0; i2 < pathParser$PathDataNodeArr[i].mParams.length; i2++) {
                    pathParser$PathDataNodeArr2[i].mParams[i2] = pathParser$PathDataNodeArr[i].mParams[i2];
                }
            }
        }

        public VPath(VPath vPath) {
            super(null);
            this.mPathName = vPath.mPathName;
            this.mChangingConfigurations = vPath.mChangingConfigurations;
            this.mNodes = AppCompatDelegateImpl.Api17Impl.deepCopyNodes(vPath.mNodes);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:201:0x04da  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x00b7  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x00c4  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00d6  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x00e9  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00f7  */
    @Override // android.graphics.drawable.Drawable
    public void inflate(Resources resources, XmlPullParser xmlPullParser, AttributeSet attributeSet, Resources.Theme theme) {
        int i;
        ColorStateList colorStateList;
        int i2;
        VPathRenderer vPathRenderer;
        int i3;
        VPathRenderer vPathRenderer2;
        ArrayDeque arrayDeque;
        VGroup vGroup;
        VFullPath vFullPath;
        TypedArray typedArray;
        TypedArray typedArray2;
        int i4;
        int i5;
        Drawable drawable = this.mDelegateDrawable;
        if (drawable != null) {
            drawable.inflate(resources, xmlPullParser, attributeSet, theme);
            return;
        }
        VectorDrawableCompatState vectorDrawableCompatState = this.mVectorState;
        vectorDrawableCompatState.mVPathRenderer = new VPathRenderer();
        TypedArray obtainAttributes = ResourcesCompat$ThemeCompat.obtainAttributes(resources, theme, attributeSet, AndroidResources.STYLEABLE_VECTOR_DRAWABLE_TYPE_ARRAY);
        VectorDrawableCompatState vectorDrawableCompatState2 = this.mVectorState;
        VPathRenderer vPathRenderer3 = vectorDrawableCompatState2.mVPathRenderer;
        if (!ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "tintMode")) {
            i = -1;
        } else {
            i = obtainAttributes.getInt(6, -1);
        }
        PorterDuff.Mode mode = PorterDuff.Mode.SRC_IN;
        int i6 = 3;
        if (i == 3) {
            mode = PorterDuff.Mode.SRC_OVER;
        } else if (i != 5) {
            if (i != 9) {
                switch (i) {
                    case 14:
                        mode = PorterDuff.Mode.MULTIPLY;
                        break;
                    case 15:
                        mode = PorterDuff.Mode.SCREEN;
                        break;
                    case 16:
                        mode = PorterDuff.Mode.ADD;
                        break;
                }
            } else {
                mode = PorterDuff.Mode.SRC_ATOP;
            }
        }
        vectorDrawableCompatState2.mTintMode = mode;
        int i7 = 1;
        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "tint")) {
            TypedValue typedValue = new TypedValue();
            obtainAttributes.getValue(1, typedValue);
            int i8 = typedValue.type;
            if (i8 == 2) {
                throw new UnsupportedOperationException("Failed to resolve attribute at index " + 1 + ": " + typedValue);
            } else if (i8 < 28 || i8 > 31) {
                Resources resources2 = obtainAttributes.getResources();
                try {
                    colorStateList = AppCompatDelegateImpl.Api17Impl.createFromXml(resources2, resources2.getXml(obtainAttributes.getResourceId(1, 0)), theme);
                } catch (Exception e) {
                    Log.e("CSLCompat", "Failed to inflate ColorStateList.", e);
                }
                if (colorStateList != null) {
                    vectorDrawableCompatState2.mTint = colorStateList;
                }
                boolean z = vectorDrawableCompatState2.mAutoMirrored;
                if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "autoMirrored")) {
                    z = obtainAttributes.getBoolean(5, z);
                }
                vectorDrawableCompatState2.mAutoMirrored = z;
                float f = vPathRenderer3.mViewportWidth;
                if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "viewportWidth")) {
                    f = obtainAttributes.getFloat(7, f);
                }
                vPathRenderer3.mViewportWidth = f;
                float f2 = vPathRenderer3.mViewportHeight;
                if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "viewportHeight")) {
                    f2 = obtainAttributes.getFloat(8, f2);
                }
                vPathRenderer3.mViewportHeight = f2;
                if (vPathRenderer3.mViewportWidth <= 0.0f) {
                    throw new XmlPullParserException(obtainAttributes.getPositionDescription() + "<vector> tag requires viewportWidth > 0");
                } else if (f2 > 0.0f) {
                    vPathRenderer3.mBaseWidth = obtainAttributes.getDimension(3, vPathRenderer3.mBaseWidth);
                    float dimension = obtainAttributes.getDimension(2, vPathRenderer3.mBaseHeight);
                    vPathRenderer3.mBaseHeight = dimension;
                    if (vPathRenderer3.mBaseWidth <= 0.0f) {
                        throw new XmlPullParserException(obtainAttributes.getPositionDescription() + "<vector> tag requires width > 0");
                    } else if (dimension > 0.0f) {
                        float alpha = vPathRenderer3.getAlpha();
                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "alpha")) {
                            alpha = obtainAttributes.getFloat(4, alpha);
                        }
                        vPathRenderer3.setAlpha(alpha);
                        String string = obtainAttributes.getString(0);
                        if (string != null) {
                            vPathRenderer3.mRootName = string;
                            vPathRenderer3.mVGTargetsMap.put(string, vPathRenderer3);
                        }
                        obtainAttributes.recycle();
                        vectorDrawableCompatState.mChangingConfigurations = getChangingConfigurations();
                        vectorDrawableCompatState.mCacheDirty = true;
                        VectorDrawableCompatState vectorDrawableCompatState3 = this.mVectorState;
                        VPathRenderer vPathRenderer4 = vectorDrawableCompatState3.mVPathRenderer;
                        ArrayDeque arrayDeque2 = new ArrayDeque();
                        arrayDeque2.push(vPathRenderer4.mRootGroup);
                        int eventType = xmlPullParser.getEventType();
                        int depth = xmlPullParser.getDepth() + 1;
                        boolean z2 = true;
                        while (eventType != i7 && (xmlPullParser.getDepth() >= depth || eventType != i6)) {
                            if (eventType == 2) {
                                String name = xmlPullParser.getName();
                                VGroup vGroup2 = (VGroup) arrayDeque2.peek();
                                if ("path".equals(name)) {
                                    VFullPath vFullPath2 = new VFullPath();
                                    TypedArray obtainAttributes2 = ResourcesCompat$ThemeCompat.obtainAttributes(resources, theme, attributeSet, AndroidResources.STYLEABLE_VECTOR_DRAWABLE_PATH);
                                    vFullPath2.mThemeAttrs = null;
                                    if (!ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "pathData")) {
                                        arrayDeque = arrayDeque2;
                                        vPathRenderer2 = vPathRenderer4;
                                        typedArray = obtainAttributes2;
                                        vFullPath = vFullPath2;
                                        i2 = depth;
                                        vGroup = vGroup2;
                                    } else {
                                        String string2 = obtainAttributes2.getString(0);
                                        if (string2 != null) {
                                            vFullPath2.mPathName = string2;
                                        }
                                        String string3 = obtainAttributes2.getString(2);
                                        if (string3 != null) {
                                            vFullPath2.mNodes = AppCompatDelegateImpl.Api17Impl.createNodesFromPathData(string3);
                                        }
                                        arrayDeque = arrayDeque2;
                                        vPathRenderer2 = vPathRenderer4;
                                        i2 = depth;
                                        vGroup = vGroup2;
                                        vFullPath = vFullPath2;
                                        vFullPath.mFillColor = ResourcesCompat$ThemeCompat.getNamedComplexColor(obtainAttributes2, xmlPullParser, theme, "fillColor", 1, 0);
                                        float f3 = vFullPath.mFillAlpha;
                                        if (!ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "fillAlpha")) {
                                            typedArray2 = obtainAttributes2;
                                        } else {
                                            typedArray2 = obtainAttributes2;
                                            f3 = typedArray2.getFloat(12, f3);
                                        }
                                        vFullPath.mFillAlpha = f3;
                                        if (!ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "strokeLineCap")) {
                                            i4 = -1;
                                        } else {
                                            i4 = typedArray2.getInt(8, -1);
                                        }
                                        Paint.Cap cap = vFullPath.mStrokeLineCap;
                                        if (i4 == 0) {
                                            cap = Paint.Cap.BUTT;
                                        } else if (i4 == 1) {
                                            cap = Paint.Cap.ROUND;
                                        } else if (i4 == 2) {
                                            cap = Paint.Cap.SQUARE;
                                        }
                                        vFullPath.mStrokeLineCap = cap;
                                        if (!ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "strokeLineJoin")) {
                                            i5 = -1;
                                        } else {
                                            i5 = typedArray2.getInt(9, -1);
                                        }
                                        Paint.Join join = vFullPath.mStrokeLineJoin;
                                        if (i5 == 0) {
                                            join = Paint.Join.MITER;
                                        } else if (i5 == 1) {
                                            join = Paint.Join.ROUND;
                                        } else if (i5 == 2) {
                                            join = Paint.Join.BEVEL;
                                        }
                                        vFullPath.mStrokeLineJoin = join;
                                        float f4 = vFullPath.mStrokeMiterlimit;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "strokeMiterLimit")) {
                                            f4 = typedArray2.getFloat(10, f4);
                                        }
                                        vFullPath.mStrokeMiterlimit = f4;
                                        typedArray = typedArray2;
                                        vFullPath.mStrokeColor = ResourcesCompat$ThemeCompat.getNamedComplexColor(typedArray2, xmlPullParser, theme, "strokeColor", 3, 0);
                                        float f5 = vFullPath.mStrokeAlpha;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "strokeAlpha")) {
                                            f5 = typedArray.getFloat(11, f5);
                                        }
                                        vFullPath.mStrokeAlpha = f5;
                                        float f6 = vFullPath.mStrokeWidth;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "strokeWidth")) {
                                            f6 = typedArray.getFloat(4, f6);
                                        }
                                        vFullPath.mStrokeWidth = f6;
                                        float f7 = vFullPath.mTrimPathEnd;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "trimPathEnd")) {
                                            f7 = typedArray.getFloat(6, f7);
                                        }
                                        vFullPath.mTrimPathEnd = f7;
                                        float f8 = vFullPath.mTrimPathOffset;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "trimPathOffset")) {
                                            f8 = typedArray.getFloat(7, f8);
                                        }
                                        vFullPath.mTrimPathOffset = f8;
                                        float f9 = vFullPath.mTrimPathStart;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "trimPathStart")) {
                                            f9 = typedArray.getFloat(5, f9);
                                        }
                                        vFullPath.mTrimPathStart = f9;
                                        int i9 = vFullPath.mFillRule;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "fillType")) {
                                            i9 = typedArray.getInt(13, i9);
                                        }
                                        vFullPath.mFillRule = i9;
                                    }
                                    typedArray.recycle();
                                    vGroup.mChildren.add(vFullPath);
                                    if (vFullPath.getPathName() != null) {
                                        vPathRenderer = vPathRenderer2;
                                        vPathRenderer.mVGTargetsMap.put(vFullPath.getPathName(), vFullPath);
                                    } else {
                                        vPathRenderer = vPathRenderer2;
                                    }
                                    vectorDrawableCompatState3.mChangingConfigurations |= vFullPath.mChangingConfigurations;
                                    arrayDeque2 = arrayDeque;
                                    z2 = false;
                                } else {
                                    vPathRenderer = vPathRenderer4;
                                    i2 = depth;
                                    if ("clip-path".equals(name)) {
                                        VClipPath vClipPath = new VClipPath();
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "pathData")) {
                                            TypedArray obtainAttributes3 = ResourcesCompat$ThemeCompat.obtainAttributes(resources, theme, attributeSet, AndroidResources.STYLEABLE_VECTOR_DRAWABLE_CLIP_PATH);
                                            String string4 = obtainAttributes3.getString(0);
                                            if (string4 != null) {
                                                vClipPath.mPathName = string4;
                                            }
                                            String string5 = obtainAttributes3.getString(1);
                                            if (string5 != null) {
                                                vClipPath.mNodes = AppCompatDelegateImpl.Api17Impl.createNodesFromPathData(string5);
                                            }
                                            if (!ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "fillType")) {
                                                i3 = 0;
                                            } else {
                                                i3 = obtainAttributes3.getInt(2, 0);
                                            }
                                            vClipPath.mFillRule = i3;
                                            obtainAttributes3.recycle();
                                        }
                                        vGroup2.mChildren.add(vClipPath);
                                        if (vClipPath.getPathName() != null) {
                                            vPathRenderer.mVGTargetsMap.put(vClipPath.getPathName(), vClipPath);
                                        }
                                        vectorDrawableCompatState3.mChangingConfigurations = vClipPath.mChangingConfigurations | vectorDrawableCompatState3.mChangingConfigurations;
                                    } else if ("group".equals(name)) {
                                        VGroup vGroup3 = new VGroup();
                                        TypedArray obtainAttributes4 = ResourcesCompat$ThemeCompat.obtainAttributes(resources, theme, attributeSet, AndroidResources.STYLEABLE_VECTOR_DRAWABLE_GROUP);
                                        vGroup3.mThemeAttrs = null;
                                        float f10 = vGroup3.mRotate;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "rotation")) {
                                            f10 = obtainAttributes4.getFloat(5, f10);
                                        }
                                        vGroup3.mRotate = f10;
                                        vGroup3.mPivotX = obtainAttributes4.getFloat(1, vGroup3.mPivotX);
                                        vGroup3.mPivotY = obtainAttributes4.getFloat(2, vGroup3.mPivotY);
                                        float f11 = vGroup3.mScaleX;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "scaleX")) {
                                            f11 = obtainAttributes4.getFloat(3, f11);
                                        }
                                        vGroup3.mScaleX = f11;
                                        float f12 = vGroup3.mScaleY;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "scaleY")) {
                                            f12 = obtainAttributes4.getFloat(4, f12);
                                        }
                                        vGroup3.mScaleY = f12;
                                        float f13 = vGroup3.mTranslateX;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "translateX")) {
                                            f13 = obtainAttributes4.getFloat(6, f13);
                                        }
                                        vGroup3.mTranslateX = f13;
                                        float f14 = vGroup3.mTranslateY;
                                        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "translateY")) {
                                            f14 = obtainAttributes4.getFloat(7, f14);
                                        }
                                        vGroup3.mTranslateY = f14;
                                        String string6 = obtainAttributes4.getString(0);
                                        if (string6 != null) {
                                            vGroup3.mGroupName = string6;
                                        }
                                        vGroup3.updateLocalMatrix();
                                        obtainAttributes4.recycle();
                                        vGroup2.mChildren.add(vGroup3);
                                        arrayDeque2 = arrayDeque2;
                                        arrayDeque2.push(vGroup3);
                                        if (vGroup3.getGroupName() != null) {
                                            vPathRenderer.mVGTargetsMap.put(vGroup3.getGroupName(), vGroup3);
                                        }
                                        vectorDrawableCompatState3.mChangingConfigurations = vGroup3.mChangingConfigurations | vectorDrawableCompatState3.mChangingConfigurations;
                                    }
                                    arrayDeque2 = arrayDeque2;
                                }
                            } else {
                                vPathRenderer = vPathRenderer4;
                                i2 = depth;
                                if (eventType == 3 && "group".equals(xmlPullParser.getName())) {
                                    arrayDeque2.pop();
                                }
                            }
                            eventType = xmlPullParser.next();
                            i6 = 3;
                            i7 = 1;
                            vPathRenderer4 = vPathRenderer;
                            depth = i2;
                        }
                        if (!z2) {
                            this.mTintFilter = updateTintFilter(vectorDrawableCompatState.mTint, vectorDrawableCompatState.mTintMode);
                            return;
                        }
                        throw new XmlPullParserException("no path defined");
                    } else {
                        throw new XmlPullParserException(obtainAttributes.getPositionDescription() + "<vector> tag requires height > 0");
                    }
                } else {
                    throw new XmlPullParserException(obtainAttributes.getPositionDescription() + "<vector> tag requires viewportHeight > 0");
                }
            } else {
                colorStateList = ColorStateList.valueOf(typedValue.data);
                if (colorStateList != null) {
                }
                boolean z3 = vectorDrawableCompatState2.mAutoMirrored;
                if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "autoMirrored")) {
                }
                vectorDrawableCompatState2.mAutoMirrored = z3;
                float f15 = vPathRenderer3.mViewportWidth;
                if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "viewportWidth")) {
                }
                vPathRenderer3.mViewportWidth = f15;
                float f22 = vPathRenderer3.mViewportHeight;
                if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "viewportHeight")) {
                }
                vPathRenderer3.mViewportHeight = f22;
                if (vPathRenderer3.mViewportWidth <= 0.0f) {
                }
            }
        }
        colorStateList = null;
        if (colorStateList != null) {
        }
        boolean z32 = vectorDrawableCompatState2.mAutoMirrored;
        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "autoMirrored")) {
        }
        vectorDrawableCompatState2.mAutoMirrored = z32;
        float f152 = vPathRenderer3.mViewportWidth;
        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "viewportWidth")) {
        }
        vPathRenderer3.mViewportWidth = f152;
        float f222 = vPathRenderer3.mViewportHeight;
        if (ResourcesCompat$ThemeCompat.hasAttribute(xmlPullParser, "viewportHeight")) {
        }
        vPathRenderer3.mViewportHeight = f222;
        if (vPathRenderer3.mViewportWidth <= 0.0f) {
        }
    }

    public VectorDrawableCompat(VectorDrawableCompatState vectorDrawableCompatState) {
        this.mAllowCaching = true;
        this.mTmpFloats = new float[9];
        this.mTmpMatrix = new Matrix();
        this.mTmpBounds = new Rect();
        this.mVectorState = vectorDrawableCompatState;
        this.mTintFilter = updateTintFilter(vectorDrawableCompatState.mTint, vectorDrawableCompatState.mTintMode);
    }

    public class VFullPath extends VPath {
        public float mFillAlpha = 1.0f;
        public ComplexColorCompat mFillColor;
        public float mStrokeAlpha = 1.0f;
        public ComplexColorCompat mStrokeColor;
        public Paint.Cap mStrokeLineCap = Paint.Cap.BUTT;
        public Paint.Join mStrokeLineJoin = Paint.Join.MITER;
        public float mStrokeMiterlimit = 4.0f;
        public float mStrokeWidth = 0.0f;
        public int[] mThemeAttrs;
        public float mTrimPathEnd = 1.0f;
        public float mTrimPathOffset = 0.0f;
        public float mTrimPathStart = 0.0f;

        public VFullPath() {
        }

        public float getFillAlpha() {
            return this.mFillAlpha;
        }

        public int getFillColor() {
            return this.mFillColor.mColor;
        }

        public float getStrokeAlpha() {
            return this.mStrokeAlpha;
        }

        public int getStrokeColor() {
            return this.mStrokeColor.mColor;
        }

        public float getStrokeWidth() {
            return this.mStrokeWidth;
        }

        public float getTrimPathEnd() {
            return this.mTrimPathEnd;
        }

        public float getTrimPathOffset() {
            return this.mTrimPathOffset;
        }

        public float getTrimPathStart() {
            return this.mTrimPathStart;
        }

        @Override // androidx.vectordrawable.graphics.drawable.VectorDrawableCompat.VObject
        public boolean isStateful() {
            return this.mFillColor.isStateful() || this.mStrokeColor.isStateful();
        }

        @Override // androidx.vectordrawable.graphics.drawable.VectorDrawableCompat.VObject
        public boolean onStateChanged(int[] iArr) {
            return this.mStrokeColor.onStateChanged(iArr) | this.mFillColor.onStateChanged(iArr);
        }

        public void setFillAlpha(float f) {
            this.mFillAlpha = f;
        }

        public void setFillColor(int i) {
            this.mFillColor.mColor = i;
        }

        public void setStrokeAlpha(float f) {
            this.mStrokeAlpha = f;
        }

        public void setStrokeColor(int i) {
            this.mStrokeColor.mColor = i;
        }

        public void setStrokeWidth(float f) {
            this.mStrokeWidth = f;
        }

        public void setTrimPathEnd(float f) {
            this.mTrimPathEnd = f;
        }

        public void setTrimPathOffset(float f) {
            this.mTrimPathOffset = f;
        }

        public void setTrimPathStart(float f) {
            this.mTrimPathStart = f;
        }

        public VFullPath(VFullPath vFullPath) {
            super(vFullPath);
            this.mThemeAttrs = vFullPath.mThemeAttrs;
            this.mStrokeColor = vFullPath.mStrokeColor;
            this.mStrokeWidth = vFullPath.mStrokeWidth;
            this.mStrokeAlpha = vFullPath.mStrokeAlpha;
            this.mFillColor = vFullPath.mFillColor;
            this.mFillRule = vFullPath.mFillRule;
            this.mFillAlpha = vFullPath.mFillAlpha;
            this.mTrimPathStart = vFullPath.mTrimPathStart;
            this.mTrimPathEnd = vFullPath.mTrimPathEnd;
            this.mTrimPathOffset = vFullPath.mTrimPathOffset;
            this.mStrokeLineCap = vFullPath.mStrokeLineCap;
            this.mStrokeLineJoin = vFullPath.mStrokeLineJoin;
            this.mStrokeMiterlimit = vFullPath.mStrokeMiterlimit;
        }
    }

    public class VPathRenderer {
        public static final Matrix IDENTITY_MATRIX = new Matrix();
        public float mBaseHeight;
        public float mBaseWidth;
        public int mChangingConfigurations;
        public Paint mFillPaint;
        public final Matrix mFinalPathMatrix;
        public Boolean mIsStateful;
        public final Path mPath;
        public PathMeasure mPathMeasure;
        public final Path mRenderPath;
        public int mRootAlpha;
        public final VGroup mRootGroup;
        public String mRootName;
        public Paint mStrokePaint;
        public final ArrayMap<String, Object> mVGTargetsMap;
        public float mViewportHeight;
        public float mViewportWidth;

        public VPathRenderer() {
            this.mFinalPathMatrix = new Matrix();
            this.mBaseWidth = 0.0f;
            this.mBaseHeight = 0.0f;
            this.mViewportWidth = 0.0f;
            this.mViewportHeight = 0.0f;
            this.mRootAlpha = KEYRecord.PROTOCOL_ANY;
            this.mRootName = null;
            this.mIsStateful = null;
            this.mVGTargetsMap = new ArrayMap<>();
            this.mRootGroup = new VGroup();
            this.mPath = new Path();
            this.mRenderPath = new Path();
        }

        /* JADX DEBUG: Multi-variable search result rejected for r13v11, resolved type: android.graphics.PathMeasure */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Type inference failed for: r11v0 */
        /* JADX WARN: Type inference failed for: r11v1, types: [boolean] */
        /* JADX WARN: Type inference failed for: r11v2 */
        /* JADX WARNING: Unknown variable types count: 1 */
        public final void drawGroupTree(VGroup vGroup, Matrix matrix, Canvas canvas, int i, int i2, ColorFilter colorFilter) {
            VPathRenderer vPathRenderer;
            VPathRenderer vPathRenderer2 = this;
            vGroup.mStackedMatrix.set(matrix);
            vGroup.mStackedMatrix.preConcat(vGroup.mLocalMatrix);
            canvas.save();
            ?? r11 = 0;
            int i3 = 0;
            while (i3 < vGroup.mChildren.size()) {
                VObject vObject = vGroup.mChildren.get(i3);
                if (vObject instanceof VGroup) {
                    drawGroupTree((VGroup) vObject, vGroup.mStackedMatrix, canvas, i, i2, colorFilter);
                } else if (vObject instanceof VPath) {
                    VPath vPath = (VPath) vObject;
                    float f = ((float) i) / vPathRenderer2.mViewportWidth;
                    float f2 = ((float) i2) / vPathRenderer2.mViewportHeight;
                    float min = Math.min(f, f2);
                    Matrix matrix2 = vGroup.mStackedMatrix;
                    vPathRenderer2.mFinalPathMatrix.set(matrix2);
                    vPathRenderer2.mFinalPathMatrix.postScale(f, f2);
                    float[] fArr = {0.0f, 1.0f, 1.0f, 0.0f};
                    matrix2.mapVectors(fArr);
                    char c = r11 == true ? 1 : 0;
                    char c2 = r11 == true ? 1 : 0;
                    char c3 = r11 == true ? 1 : 0;
                    float f3 = (fArr[r11] * fArr[3]) - (fArr[1] * fArr[2]);
                    float max = Math.max((float) Math.hypot((double) fArr[c], (double) fArr[1]), (float) Math.hypot((double) fArr[2], (double) fArr[3]));
                    float abs = max > 0.0f ? Math.abs(f3) / max : 0.0f;
                    if (abs == 0.0f) {
                        vPathRenderer = this;
                    } else {
                        vPathRenderer = this;
                        Path path = vPathRenderer.mPath;
                        Objects.requireNonNull(vPath);
                        path.reset();
                        PathParser$PathDataNode[] pathParser$PathDataNodeArr = vPath.mNodes;
                        if (pathParser$PathDataNodeArr != null) {
                            PathParser$PathDataNode.nodesToPath(pathParser$PathDataNodeArr, path);
                        }
                        Path path2 = vPathRenderer.mPath;
                        vPathRenderer.mRenderPath.reset();
                        if (vPath instanceof VClipPath) {
                            vPathRenderer.mRenderPath.setFillType(vPath.mFillRule == 0 ? Path.FillType.WINDING : Path.FillType.EVEN_ODD);
                            vPathRenderer.mRenderPath.addPath(path2, vPathRenderer.mFinalPathMatrix);
                            canvas.clipPath(vPathRenderer.mRenderPath);
                        } else {
                            VFullPath vFullPath = (VFullPath) vPath;
                            float f4 = vFullPath.mTrimPathStart;
                            if (!(f4 == 0.0f && vFullPath.mTrimPathEnd == 1.0f)) {
                                float f5 = vFullPath.mTrimPathOffset;
                                float f6 = (f4 + f5) % 1.0f;
                                float f7 = (vFullPath.mTrimPathEnd + f5) % 1.0f;
                                if (vPathRenderer.mPathMeasure == null) {
                                    vPathRenderer.mPathMeasure = new PathMeasure();
                                }
                                vPathRenderer.mPathMeasure.setPath(vPathRenderer.mPath, r11);
                                float length = vPathRenderer.mPathMeasure.getLength();
                                float f8 = f6 * length;
                                float f9 = f7 * length;
                                path2.reset();
                                if (f8 > f9) {
                                    vPathRenderer.mPathMeasure.getSegment(f8, length, path2, true);
                                    vPathRenderer.mPathMeasure.getSegment(0.0f, f9, path2, true);
                                } else {
                                    vPathRenderer.mPathMeasure.getSegment(f8, f9, path2, true);
                                }
                                path2.rLineTo(0.0f, 0.0f);
                            }
                            vPathRenderer.mRenderPath.addPath(path2, vPathRenderer.mFinalPathMatrix);
                            ComplexColorCompat complexColorCompat = vFullPath.mFillColor;
                            if (complexColorCompat.isGradient() || complexColorCompat.mColor != 0) {
                                ComplexColorCompat complexColorCompat2 = vFullPath.mFillColor;
                                if (vPathRenderer.mFillPaint == null) {
                                    Paint paint = new Paint(1);
                                    vPathRenderer.mFillPaint = paint;
                                    paint.setStyle(Paint.Style.FILL);
                                }
                                Paint paint2 = vPathRenderer.mFillPaint;
                                if (complexColorCompat2.isGradient()) {
                                    Shader shader = complexColorCompat2.mShader;
                                    shader.setLocalMatrix(vPathRenderer.mFinalPathMatrix);
                                    paint2.setShader(shader);
                                    paint2.setAlpha(Math.round(vFullPath.mFillAlpha * 255.0f));
                                } else {
                                    paint2.setShader(null);
                                    paint2.setAlpha(KEYRecord.PROTOCOL_ANY);
                                    int i4 = complexColorCompat2.mColor;
                                    float f10 = vFullPath.mFillAlpha;
                                    PorterDuff.Mode mode = VectorDrawableCompat.DEFAULT_TINT_MODE;
                                    paint2.setColor((i4 & 16777215) | (((int) (((float) Color.alpha(i4)) * f10)) << 24));
                                }
                                paint2.setColorFilter(colorFilter);
                                vPathRenderer.mRenderPath.setFillType(vFullPath.mFillRule == 0 ? Path.FillType.WINDING : Path.FillType.EVEN_ODD);
                                canvas.drawPath(vPathRenderer.mRenderPath, paint2);
                            }
                            ComplexColorCompat complexColorCompat3 = vFullPath.mStrokeColor;
                            if (complexColorCompat3.isGradient() || complexColorCompat3.mColor != 0) {
                                ComplexColorCompat complexColorCompat4 = vFullPath.mStrokeColor;
                                if (vPathRenderer.mStrokePaint == null) {
                                    Paint paint3 = new Paint(1);
                                    vPathRenderer.mStrokePaint = paint3;
                                    paint3.setStyle(Paint.Style.STROKE);
                                }
                                Paint paint4 = vPathRenderer.mStrokePaint;
                                Paint.Join join = vFullPath.mStrokeLineJoin;
                                if (join != null) {
                                    paint4.setStrokeJoin(join);
                                }
                                Paint.Cap cap = vFullPath.mStrokeLineCap;
                                if (cap != null) {
                                    paint4.setStrokeCap(cap);
                                }
                                paint4.setStrokeMiter(vFullPath.mStrokeMiterlimit);
                                if (complexColorCompat4.isGradient()) {
                                    Shader shader2 = complexColorCompat4.mShader;
                                    shader2.setLocalMatrix(vPathRenderer.mFinalPathMatrix);
                                    paint4.setShader(shader2);
                                    paint4.setAlpha(Math.round(vFullPath.mStrokeAlpha * 255.0f));
                                } else {
                                    paint4.setShader(null);
                                    paint4.setAlpha(KEYRecord.PROTOCOL_ANY);
                                    int i5 = complexColorCompat4.mColor;
                                    float f11 = vFullPath.mStrokeAlpha;
                                    PorterDuff.Mode mode2 = VectorDrawableCompat.DEFAULT_TINT_MODE;
                                    paint4.setColor((i5 & 16777215) | (((int) (((float) Color.alpha(i5)) * f11)) << 24));
                                }
                                paint4.setColorFilter(colorFilter);
                                paint4.setStrokeWidth(vFullPath.mStrokeWidth * abs * min);
                                canvas.drawPath(vPathRenderer.mRenderPath, paint4);
                            }
                        }
                    }
                    i3++;
                    vPathRenderer2 = vPathRenderer;
                    r11 = 0;
                }
                vPathRenderer = vPathRenderer2;
                i3++;
                vPathRenderer2 = vPathRenderer;
                r11 = 0;
            }
            canvas.restore();
        }

        public float getAlpha() {
            return ((float) getRootAlpha()) / 255.0f;
        }

        public int getRootAlpha() {
            return this.mRootAlpha;
        }

        public void setAlpha(float f) {
            setRootAlpha((int) (f * 255.0f));
        }

        public void setRootAlpha(int i) {
            this.mRootAlpha = i;
        }

        public VPathRenderer(VPathRenderer vPathRenderer) {
            this.mFinalPathMatrix = new Matrix();
            this.mBaseWidth = 0.0f;
            this.mBaseHeight = 0.0f;
            this.mViewportWidth = 0.0f;
            this.mViewportHeight = 0.0f;
            this.mRootAlpha = KEYRecord.PROTOCOL_ANY;
            this.mRootName = null;
            this.mIsStateful = null;
            ArrayMap<String, Object> arrayMap = new ArrayMap<>();
            this.mVGTargetsMap = arrayMap;
            this.mRootGroup = new VGroup(vPathRenderer.mRootGroup, arrayMap);
            this.mPath = new Path(vPathRenderer.mPath);
            this.mRenderPath = new Path(vPathRenderer.mRenderPath);
            this.mBaseWidth = vPathRenderer.mBaseWidth;
            this.mBaseHeight = vPathRenderer.mBaseHeight;
            this.mViewportWidth = vPathRenderer.mViewportWidth;
            this.mViewportHeight = vPathRenderer.mViewportHeight;
            this.mChangingConfigurations = vPathRenderer.mChangingConfigurations;
            this.mRootAlpha = vPathRenderer.mRootAlpha;
            this.mRootName = vPathRenderer.mRootName;
            String str = vPathRenderer.mRootName;
            if (str != null) {
                arrayMap.put(str, this);
            }
            this.mIsStateful = vPathRenderer.mIsStateful;
        }
    }

    public class VGroup extends VObject {
        public int mChangingConfigurations;
        public final ArrayList<VObject> mChildren;
        public String mGroupName;
        public final Matrix mLocalMatrix;
        public float mPivotX;
        public float mPivotY;
        public float mRotate;
        public float mScaleX;
        public float mScaleY;
        public final Matrix mStackedMatrix;
        public int[] mThemeAttrs;
        public float mTranslateX;
        public float mTranslateY;

        public VGroup(VGroup vGroup, ArrayMap<String, Object> arrayMap) {
            super(null);
            VPath vPath;
            this.mStackedMatrix = new Matrix();
            this.mChildren = new ArrayList<>();
            this.mRotate = 0.0f;
            this.mPivotX = 0.0f;
            this.mPivotY = 0.0f;
            this.mScaleX = 1.0f;
            this.mScaleY = 1.0f;
            this.mTranslateX = 0.0f;
            this.mTranslateY = 0.0f;
            Matrix matrix = new Matrix();
            this.mLocalMatrix = matrix;
            this.mGroupName = null;
            this.mRotate = vGroup.mRotate;
            this.mPivotX = vGroup.mPivotX;
            this.mPivotY = vGroup.mPivotY;
            this.mScaleX = vGroup.mScaleX;
            this.mScaleY = vGroup.mScaleY;
            this.mTranslateX = vGroup.mTranslateX;
            this.mTranslateY = vGroup.mTranslateY;
            this.mThemeAttrs = vGroup.mThemeAttrs;
            String str = vGroup.mGroupName;
            this.mGroupName = str;
            this.mChangingConfigurations = vGroup.mChangingConfigurations;
            if (str != null) {
                arrayMap.put(str, this);
            }
            matrix.set(vGroup.mLocalMatrix);
            ArrayList<VObject> arrayList = vGroup.mChildren;
            for (int i = 0; i < arrayList.size(); i++) {
                VObject vObject = arrayList.get(i);
                if (vObject instanceof VGroup) {
                    this.mChildren.add(new VGroup((VGroup) vObject, arrayMap));
                } else {
                    if (vObject instanceof VFullPath) {
                        vPath = new VFullPath((VFullPath) vObject);
                    } else if (vObject instanceof VClipPath) {
                        vPath = new VClipPath((VClipPath) vObject);
                    } else {
                        throw new IllegalStateException("Unknown object in the tree!");
                    }
                    this.mChildren.add(vPath);
                    String str2 = vPath.mPathName;
                    if (str2 != null) {
                        arrayMap.put(str2, vPath);
                    }
                }
            }
        }

        public String getGroupName() {
            return this.mGroupName;
        }

        public Matrix getLocalMatrix() {
            return this.mLocalMatrix;
        }

        public float getPivotX() {
            return this.mPivotX;
        }

        public float getPivotY() {
            return this.mPivotY;
        }

        public float getRotation() {
            return this.mRotate;
        }

        public float getScaleX() {
            return this.mScaleX;
        }

        public float getScaleY() {
            return this.mScaleY;
        }

        public float getTranslateX() {
            return this.mTranslateX;
        }

        public float getTranslateY() {
            return this.mTranslateY;
        }

        @Override // androidx.vectordrawable.graphics.drawable.VectorDrawableCompat.VObject
        public boolean isStateful() {
            for (int i = 0; i < this.mChildren.size(); i++) {
                if (this.mChildren.get(i).isStateful()) {
                    return true;
                }
            }
            return false;
        }

        @Override // androidx.vectordrawable.graphics.drawable.VectorDrawableCompat.VObject
        public boolean onStateChanged(int[] iArr) {
            boolean z = false;
            for (int i = 0; i < this.mChildren.size(); i++) {
                z |= this.mChildren.get(i).onStateChanged(iArr);
            }
            return z;
        }

        public void setPivotX(float f) {
            if (f != this.mPivotX) {
                this.mPivotX = f;
                updateLocalMatrix();
            }
        }

        public void setPivotY(float f) {
            if (f != this.mPivotY) {
                this.mPivotY = f;
                updateLocalMatrix();
            }
        }

        public void setRotation(float f) {
            if (f != this.mRotate) {
                this.mRotate = f;
                updateLocalMatrix();
            }
        }

        public void setScaleX(float f) {
            if (f != this.mScaleX) {
                this.mScaleX = f;
                updateLocalMatrix();
            }
        }

        public void setScaleY(float f) {
            if (f != this.mScaleY) {
                this.mScaleY = f;
                updateLocalMatrix();
            }
        }

        public void setTranslateX(float f) {
            if (f != this.mTranslateX) {
                this.mTranslateX = f;
                updateLocalMatrix();
            }
        }

        public void setTranslateY(float f) {
            if (f != this.mTranslateY) {
                this.mTranslateY = f;
                updateLocalMatrix();
            }
        }

        public final void updateLocalMatrix() {
            this.mLocalMatrix.reset();
            this.mLocalMatrix.postTranslate(-this.mPivotX, -this.mPivotY);
            this.mLocalMatrix.postScale(this.mScaleX, this.mScaleY);
            this.mLocalMatrix.postRotate(this.mRotate, 0.0f, 0.0f);
            this.mLocalMatrix.postTranslate(this.mTranslateX + this.mPivotX, this.mTranslateY + this.mPivotY);
        }

        public VGroup() {
            super(null);
            this.mStackedMatrix = new Matrix();
            this.mChildren = new ArrayList<>();
            this.mRotate = 0.0f;
            this.mPivotX = 0.0f;
            this.mPivotY = 0.0f;
            this.mScaleX = 1.0f;
            this.mScaleY = 1.0f;
            this.mTranslateX = 0.0f;
            this.mTranslateY = 0.0f;
            this.mLocalMatrix = new Matrix();
            this.mGroupName = null;
        }
    }
}
