package androidx.viewpager2.widget;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Rect;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.SparseArray;
import android.view.Gravity;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityNodeInfo;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import androidx.core.view.accessibility.AccessibilityViewCommand;
import androidx.fragment.app.Fragment;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.PagerSnapHelper;
import androidx.recyclerview.widget.RecyclerView;
import androidx.viewpager2.R$styleable;
import androidx.viewpager2.adapter.FragmentStateAdapter;
import androidx.viewpager2.adapter.StatefulAdapter;
import androidx.viewpager2.widget.ScrollEventAdapter;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.tencent.mm.opensdk.modelmsg.WXMediaMessage;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public final class ViewPager2 extends ViewGroup {
    public AccessibilityProvider mAccessibilityProvider;
    public int mCurrentItem;
    public RecyclerView.AdapterDataObserver mCurrentItemDataSetChangeObserver = new DataSetChangeObserver() {
        /* class androidx.viewpager2.widget.ViewPager2.AnonymousClass1 */

        @Override // androidx.recyclerview.widget.RecyclerView.AdapterDataObserver
        public void onChanged() {
            ViewPager2 viewPager2 = ViewPager2.this;
            viewPager2.mCurrentItemDirty = true;
            viewPager2.mScrollEventAdapter.mDataSetChangeHappened = true;
        }
    };
    public boolean mCurrentItemDirty = false;
    public CompositeOnPageChangeCallback mExternalPageChangeCallbacks = new CompositeOnPageChangeCallback(3);
    public FakeDrag mFakeDragger;
    public LinearLayoutManager mLayoutManager;
    public int mOffscreenPageLimit = -1;
    public CompositeOnPageChangeCallback mPageChangeEventDispatcher;
    public PageTransformerAdapter mPageTransformerAdapter;
    public PagerSnapHelper mPagerSnapHelper;
    public Parcelable mPendingAdapterState;
    public int mPendingCurrentItem = -1;
    public RecyclerView mRecyclerView;
    public RecyclerView.ItemAnimator mSavedItemAnimator = null;
    public boolean mSavedItemAnimatorPresent = false;
    public ScrollEventAdapter mScrollEventAdapter;
    public final Rect mTmpChildRect = new Rect();
    public final Rect mTmpContainerRect = new Rect();
    public boolean mUserInputEnabled = true;

    public abstract class AccessibilityProvider {
        public AccessibilityProvider(ViewPager2 viewPager2, AnonymousClass1 r2) {
        }

        public abstract void onInitialize(CompositeOnPageChangeCallback compositeOnPageChangeCallback, RecyclerView recyclerView);

        public abstract void onSetNewCurrentItem();
    }

    public static abstract class DataSetChangeObserver extends RecyclerView.AdapterDataObserver {
        public DataSetChangeObserver(AnonymousClass1 r1) {
        }

        @Override // androidx.recyclerview.widget.RecyclerView.AdapterDataObserver
        public final void onItemRangeChanged(int i, int i2, Object obj) {
            onChanged();
        }

        @Override // androidx.recyclerview.widget.RecyclerView.AdapterDataObserver
        public final void onItemRangeInserted(int i, int i2) {
            onChanged();
        }

        @Override // androidx.recyclerview.widget.RecyclerView.AdapterDataObserver
        public final void onItemRangeMoved(int i, int i2, int i3) {
            onChanged();
        }

        @Override // androidx.recyclerview.widget.RecyclerView.AdapterDataObserver
        public final void onItemRangeRemoved(int i, int i2) {
            onChanged();
        }
    }

    public class LinearLayoutManagerImpl extends LinearLayoutManager {
        public LinearLayoutManagerImpl(Context context) {
            super(1, false);
        }

        @Override // androidx.recyclerview.widget.LinearLayoutManager
        public void calculateExtraLayoutSpace(RecyclerView.State state, int[] iArr) {
            int offscreenPageLimit = ViewPager2.this.getOffscreenPageLimit();
            if (offscreenPageLimit == -1) {
                super.calculateExtraLayoutSpace(state, iArr);
                return;
            }
            int pageSize = ViewPager2.this.getPageSize() * offscreenPageLimit;
            iArr[0] = pageSize;
            iArr[1] = pageSize;
        }

        @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
        public void onInitializeAccessibilityNodeInfo(RecyclerView.Recycler recycler, RecyclerView.State state, AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
            super.onInitializeAccessibilityNodeInfo(recycler, state, accessibilityNodeInfoCompat);
            Objects.requireNonNull(ViewPager2.this.mAccessibilityProvider);
        }

        @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
        public boolean performAccessibilityAction(RecyclerView.Recycler recycler, RecyclerView.State state, int i, Bundle bundle) {
            Objects.requireNonNull(ViewPager2.this.mAccessibilityProvider);
            return super.performAccessibilityAction(recycler, state, i, bundle);
        }

        @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager
        public boolean requestChildRectangleOnScreen(RecyclerView recyclerView, View view, Rect rect, boolean z, boolean z2) {
            return false;
        }
    }

    public static abstract class OnPageChangeCallback {
        public void onPageScrollStateChanged(int i) {
        }

        public void onPageScrolled(int i, float f, int i2) {
        }

        public abstract void onPageSelected(int i);
    }

    public class PageAwareAccessibilityProvider extends AccessibilityProvider {
        public final AccessibilityViewCommand mActionPageBackward = new AccessibilityViewCommand() {
            /* class androidx.viewpager2.widget.ViewPager2.PageAwareAccessibilityProvider.AnonymousClass2 */

            @Override // androidx.core.view.accessibility.AccessibilityViewCommand
            public boolean perform(View view, AccessibilityViewCommand.CommandArguments commandArguments) {
                PageAwareAccessibilityProvider.this.setCurrentItemFromAccessibilityCommand(((ViewPager2) view).getCurrentItem() - 1);
                return true;
            }
        };
        public final AccessibilityViewCommand mActionPageForward = new AccessibilityViewCommand() {
            /* class androidx.viewpager2.widget.ViewPager2.PageAwareAccessibilityProvider.AnonymousClass1 */

            @Override // androidx.core.view.accessibility.AccessibilityViewCommand
            public boolean perform(View view, AccessibilityViewCommand.CommandArguments commandArguments) {
                PageAwareAccessibilityProvider.this.setCurrentItemFromAccessibilityCommand(((ViewPager2) view).getCurrentItem() + 1);
                return true;
            }
        };
        public RecyclerView.AdapterDataObserver mAdapterDataObserver;

        public PageAwareAccessibilityProvider() {
            super(ViewPager2.this, null);
        }

        @Override // androidx.viewpager2.widget.ViewPager2.AccessibilityProvider
        public void onInitialize(CompositeOnPageChangeCallback compositeOnPageChangeCallback, RecyclerView recyclerView) {
            AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
            recyclerView.setImportantForAccessibility(2);
            this.mAdapterDataObserver = new DataSetChangeObserver() {
                /* class androidx.viewpager2.widget.ViewPager2.PageAwareAccessibilityProvider.AnonymousClass3 */

                @Override // androidx.recyclerview.widget.RecyclerView.AdapterDataObserver
                public void onChanged() {
                    PageAwareAccessibilityProvider.this.updatePageAccessibilityActions();
                }
            };
            if (ViewPager2.this.getImportantForAccessibility() == 0) {
                ViewPager2.this.setImportantForAccessibility(1);
            }
        }

        @Override // androidx.viewpager2.widget.ViewPager2.AccessibilityProvider
        public void onSetNewCurrentItem() {
            updatePageAccessibilityActions();
        }

        public void setCurrentItemFromAccessibilityCommand(int i) {
            ViewPager2 viewPager2 = ViewPager2.this;
            if (viewPager2.mUserInputEnabled) {
                viewPager2.setCurrentItemInternal(i, true);
            }
        }

        public void updatePageAccessibilityActions() {
            int itemCount;
            ViewPager2 viewPager2 = ViewPager2.this;
            int i = 16908360;
            ViewCompat.removeAccessibilityAction(viewPager2, 16908360);
            ViewCompat.removeAccessibilityAction(viewPager2, 16908361);
            ViewCompat.removeAccessibilityAction(viewPager2, 16908358);
            ViewCompat.removeAccessibilityAction(viewPager2, 16908359);
            if (ViewPager2.this.getAdapter() != null && (itemCount = ViewPager2.this.getAdapter().getItemCount()) != 0) {
                ViewPager2 viewPager22 = ViewPager2.this;
                if (viewPager22.mUserInputEnabled) {
                    if (viewPager22.getOrientation() == 0) {
                        boolean isRtl = ViewPager2.this.isRtl();
                        int i2 = isRtl ? 16908360 : 16908361;
                        if (isRtl) {
                            i = 16908361;
                        }
                        if (ViewPager2.this.mCurrentItem < itemCount - 1) {
                            ViewCompat.replaceAccessibilityAction(viewPager2, new AccessibilityNodeInfoCompat.AccessibilityActionCompat(i2, null), null, this.mActionPageForward);
                        }
                        if (ViewPager2.this.mCurrentItem > 0) {
                            ViewCompat.replaceAccessibilityAction(viewPager2, new AccessibilityNodeInfoCompat.AccessibilityActionCompat(i, null), null, this.mActionPageBackward);
                            return;
                        }
                        return;
                    }
                    if (ViewPager2.this.mCurrentItem < itemCount - 1) {
                        ViewCompat.replaceAccessibilityAction(viewPager2, new AccessibilityNodeInfoCompat.AccessibilityActionCompat(16908359, null), null, this.mActionPageForward);
                    }
                    if (ViewPager2.this.mCurrentItem > 0) {
                        ViewCompat.replaceAccessibilityAction(viewPager2, new AccessibilityNodeInfoCompat.AccessibilityActionCompat(16908358, null), null, this.mActionPageBackward);
                    }
                }
            }
        }
    }

    public interface PageTransformer {
        void transformPage(View view, float f);
    }

    public class PagerSnapHelperImpl extends PagerSnapHelper {
        public PagerSnapHelperImpl() {
        }

        @Override // androidx.recyclerview.widget.PagerSnapHelper
        public View findSnapView(RecyclerView.LayoutManager layoutManager) {
            if (ViewPager2.this.mFakeDragger.mScrollEventAdapter.mFakeDragging) {
                return null;
            }
            return super.findSnapView(layoutManager);
        }
    }

    public class RecyclerViewImpl extends RecyclerView {
        public RecyclerViewImpl(Context context) {
            super(context);
        }

        @Override // androidx.recyclerview.widget.RecyclerView
        public CharSequence getAccessibilityClassName() {
            Objects.requireNonNull(ViewPager2.this.mAccessibilityProvider);
            return super.getAccessibilityClassName();
        }

        public void onInitializeAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
            super.onInitializeAccessibilityEvent(accessibilityEvent);
            accessibilityEvent.setFromIndex(ViewPager2.this.mCurrentItem);
            accessibilityEvent.setToIndex(ViewPager2.this.mCurrentItem);
            accessibilityEvent.setSource(ViewPager2.this);
            accessibilityEvent.setClassName("androidx.viewpager.widget.ViewPager");
        }

        @Override // androidx.recyclerview.widget.RecyclerView
        public boolean onInterceptTouchEvent(MotionEvent motionEvent) {
            return ViewPager2.this.mUserInputEnabled && super.onInterceptTouchEvent(motionEvent);
        }

        @Override // androidx.recyclerview.widget.RecyclerView
        @SuppressLint({"ClickableViewAccessibility"})
        public boolean onTouchEvent(MotionEvent motionEvent) {
            return ViewPager2.this.mUserInputEnabled && super.onTouchEvent(motionEvent);
        }
    }

    public static class SmoothScrollToPosition implements Runnable {
        public final int mPosition;
        public final RecyclerView mRecyclerView;

        public SmoothScrollToPosition(int i, RecyclerView recyclerView) {
            this.mPosition = i;
            this.mRecyclerView = recyclerView;
        }

        public void run() {
            this.mRecyclerView.smoothScrollToPosition(this.mPosition);
        }
    }

    public ViewPager2(Context context) {
        super(context);
        initialize(context, null);
    }

    public boolean canScrollHorizontally(int i) {
        return this.mRecyclerView.canScrollHorizontally(i);
    }

    public boolean canScrollVertically(int i) {
        return this.mRecyclerView.canScrollVertically(i);
    }

    @Override // android.view.View, android.view.ViewGroup
    public void dispatchRestoreInstanceState(SparseArray<Parcelable> sparseArray) {
        Parcelable parcelable = sparseArray.get(getId());
        if (parcelable instanceof SavedState) {
            int i = ((SavedState) parcelable).mRecyclerViewId;
            sparseArray.put(this.mRecyclerView.getId(), sparseArray.get(i));
            sparseArray.remove(i);
        }
        super.dispatchRestoreInstanceState(sparseArray);
        restorePendingState();
    }

    public CharSequence getAccessibilityClassName() {
        AccessibilityProvider accessibilityProvider = this.mAccessibilityProvider;
        Objects.requireNonNull(accessibilityProvider);
        if (!(accessibilityProvider instanceof PageAwareAccessibilityProvider)) {
            return super.getAccessibilityClassName();
        }
        Objects.requireNonNull(this.mAccessibilityProvider);
        return "androidx.viewpager.widget.ViewPager";
    }

    public RecyclerView.Adapter getAdapter() {
        return this.mRecyclerView.getAdapter();
    }

    public int getCurrentItem() {
        return this.mCurrentItem;
    }

    public int getItemDecorationCount() {
        return this.mRecyclerView.getItemDecorationCount();
    }

    public int getOffscreenPageLimit() {
        return this.mOffscreenPageLimit;
    }

    public int getOrientation() {
        return this.mLayoutManager.getOrientation();
    }

    public int getPageSize() {
        int i;
        int i2;
        RecyclerView recyclerView = this.mRecyclerView;
        if (getOrientation() == 0) {
            i = recyclerView.getWidth() - recyclerView.getPaddingLeft();
            i2 = recyclerView.getPaddingRight();
        } else {
            i = recyclerView.getHeight() - recyclerView.getPaddingTop();
            i2 = recyclerView.getPaddingBottom();
        }
        return i - i2;
    }

    public int getScrollState() {
        return this.mScrollEventAdapter.mScrollState;
    }

    /* JADX INFO: finally extract failed */
    public final void initialize(Context context, AttributeSet attributeSet) {
        this.mAccessibilityProvider = new PageAwareAccessibilityProvider();
        RecyclerViewImpl recyclerViewImpl = new RecyclerViewImpl(context);
        this.mRecyclerView = recyclerViewImpl;
        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
        recyclerViewImpl.setId(View.generateViewId());
        this.mRecyclerView.setDescendantFocusability(WXMediaMessage.MINI_PROGRAM__THUMB_LENGHT);
        LinearLayoutManagerImpl linearLayoutManagerImpl = new LinearLayoutManagerImpl(context);
        this.mLayoutManager = linearLayoutManagerImpl;
        this.mRecyclerView.setLayoutManager(linearLayoutManagerImpl);
        this.mRecyclerView.setScrollingTouchSlop(1);
        int[] iArr = R$styleable.ViewPager2;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, iArr);
        if (Build.VERSION.SDK_INT >= 29) {
            saveAttributeDataForStyleable(context, iArr, attributeSet, obtainStyledAttributes, 0, 0);
        }
        try {
            setOrientation(obtainStyledAttributes.getInt(R$styleable.ViewPager2_android_orientation, 0));
            obtainStyledAttributes.recycle();
            this.mRecyclerView.setLayoutParams(new ViewGroup.LayoutParams(-1, -1));
            this.mRecyclerView.addOnChildAttachStateChangeListener(new RecyclerView.OnChildAttachStateChangeListener(this) {
                /* class androidx.viewpager2.widget.ViewPager2.AnonymousClass4 */
            });
            ScrollEventAdapter scrollEventAdapter = new ScrollEventAdapter(this);
            this.mScrollEventAdapter = scrollEventAdapter;
            this.mFakeDragger = new FakeDrag(this, scrollEventAdapter, this.mRecyclerView);
            PagerSnapHelperImpl pagerSnapHelperImpl = new PagerSnapHelperImpl();
            this.mPagerSnapHelper = pagerSnapHelperImpl;
            pagerSnapHelperImpl.attachToRecyclerView(this.mRecyclerView);
            this.mRecyclerView.addOnScrollListener(this.mScrollEventAdapter);
            CompositeOnPageChangeCallback compositeOnPageChangeCallback = new CompositeOnPageChangeCallback(3);
            this.mPageChangeEventDispatcher = compositeOnPageChangeCallback;
            this.mScrollEventAdapter.mCallback = compositeOnPageChangeCallback;
            AnonymousClass2 r0 = new OnPageChangeCallback() {
                /* class androidx.viewpager2.widget.ViewPager2.AnonymousClass2 */

                @Override // androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback
                public void onPageScrollStateChanged(int i) {
                    if (i == 0) {
                        ViewPager2.this.updateCurrentItem();
                    }
                }

                @Override // androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback
                public void onPageSelected(int i) {
                    ViewPager2 viewPager2 = ViewPager2.this;
                    if (viewPager2.mCurrentItem != i) {
                        viewPager2.mCurrentItem = i;
                        viewPager2.mAccessibilityProvider.onSetNewCurrentItem();
                    }
                }
            };
            AnonymousClass3 r1 = new OnPageChangeCallback() {
                /* class androidx.viewpager2.widget.ViewPager2.AnonymousClass3 */

                @Override // androidx.viewpager2.widget.ViewPager2.OnPageChangeCallback
                public void onPageSelected(int i) {
                    ViewPager2.this.clearFocus();
                    if (ViewPager2.this.hasFocus()) {
                        ViewPager2.this.mRecyclerView.requestFocus(2);
                    }
                }
            };
            compositeOnPageChangeCallback.mCallbacks.add(r0);
            this.mPageChangeEventDispatcher.mCallbacks.add(r1);
            this.mAccessibilityProvider.onInitialize(this.mPageChangeEventDispatcher, this.mRecyclerView);
            CompositeOnPageChangeCallback compositeOnPageChangeCallback2 = this.mPageChangeEventDispatcher;
            compositeOnPageChangeCallback2.mCallbacks.add(this.mExternalPageChangeCallbacks);
            PageTransformerAdapter pageTransformerAdapter = new PageTransformerAdapter(this.mLayoutManager);
            this.mPageTransformerAdapter = pageTransformerAdapter;
            this.mPageChangeEventDispatcher.mCallbacks.add(pageTransformerAdapter);
            RecyclerView recyclerView = this.mRecyclerView;
            attachViewToParent(recyclerView, 0, recyclerView.getLayoutParams());
        } catch (Throwable th) {
            obtainStyledAttributes.recycle();
            throw th;
        }
    }

    public boolean isRtl() {
        return this.mLayoutManager.getLayoutDirection() == 1;
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0054  */
    /* JADX WARNING: Removed duplicated region for block: B:24:? A[RETURN, SYNTHETIC] */
    public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo accessibilityNodeInfo) {
        int i;
        int i2;
        RecyclerView.Adapter adapter;
        int itemCount;
        ViewPager2 viewPager2;
        super.onInitializeAccessibilityNodeInfo(accessibilityNodeInfo);
        PageAwareAccessibilityProvider pageAwareAccessibilityProvider = (PageAwareAccessibilityProvider) this.mAccessibilityProvider;
        if (ViewPager2.this.getAdapter() == null) {
            i2 = 0;
        } else if (ViewPager2.this.getOrientation() == 1) {
            i2 = ViewPager2.this.getAdapter().getItemCount();
        } else {
            i = ViewPager2.this.getAdapter().getItemCount();
            i2 = 0;
            accessibilityNodeInfo.setCollectionInfo((AccessibilityNodeInfo.CollectionInfo) AccessibilityNodeInfoCompat.CollectionInfoCompat.obtain(i2, i, false, 0).mInfo);
            adapter = ViewPager2.this.getAdapter();
            if (adapter != null && (itemCount = adapter.getItemCount()) != 0) {
                viewPager2 = ViewPager2.this;
                if (!viewPager2.mUserInputEnabled) {
                    if (viewPager2.mCurrentItem > 0) {
                        accessibilityNodeInfo.addAction(8192);
                    }
                    if (ViewPager2.this.mCurrentItem < itemCount - 1) {
                        accessibilityNodeInfo.addAction(4096);
                    }
                    accessibilityNodeInfo.setScrollable(true);
                    return;
                }
                return;
            }
            return;
        }
        i = 0;
        accessibilityNodeInfo.setCollectionInfo((AccessibilityNodeInfo.CollectionInfo) AccessibilityNodeInfoCompat.CollectionInfoCompat.obtain(i2, i, false, 0).mInfo);
        adapter = ViewPager2.this.getAdapter();
        if (adapter != null) {
            viewPager2 = ViewPager2.this;
            if (!viewPager2.mUserInputEnabled) {
            }
        }
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        int measuredWidth = this.mRecyclerView.getMeasuredWidth();
        int measuredHeight = this.mRecyclerView.getMeasuredHeight();
        this.mTmpContainerRect.left = getPaddingLeft();
        this.mTmpContainerRect.right = (i3 - i) - getPaddingRight();
        this.mTmpContainerRect.top = getPaddingTop();
        this.mTmpContainerRect.bottom = (i4 - i2) - getPaddingBottom();
        Gravity.apply(8388659, measuredWidth, measuredHeight, this.mTmpContainerRect, this.mTmpChildRect);
        RecyclerView recyclerView = this.mRecyclerView;
        Rect rect = this.mTmpChildRect;
        recyclerView.layout(rect.left, rect.top, rect.right, rect.bottom);
        if (this.mCurrentItemDirty) {
            updateCurrentItem();
        }
    }

    public void onMeasure(int i, int i2) {
        measureChild(this.mRecyclerView, i, i2);
        int measuredWidth = this.mRecyclerView.getMeasuredWidth();
        int measuredHeight = this.mRecyclerView.getMeasuredHeight();
        int measuredState = this.mRecyclerView.getMeasuredState();
        int paddingRight = getPaddingRight() + getPaddingLeft() + measuredWidth;
        int paddingTop = getPaddingTop();
        setMeasuredDimension(ViewGroup.resolveSizeAndState(Math.max(paddingRight, getSuggestedMinimumWidth()), i, measuredState), ViewGroup.resolveSizeAndState(Math.max(getPaddingBottom() + paddingTop + measuredHeight, getSuggestedMinimumHeight()), i2, measuredState << 16));
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (!(parcelable instanceof SavedState)) {
            super.onRestoreInstanceState(parcelable);
            return;
        }
        SavedState savedState = (SavedState) parcelable;
        super.onRestoreInstanceState(savedState.getSuperState());
        this.mPendingCurrentItem = savedState.mCurrentItem;
        this.mPendingAdapterState = savedState.mAdapterState;
    }

    public Parcelable onSaveInstanceState() {
        SavedState savedState = new SavedState(super.onSaveInstanceState());
        savedState.mRecyclerViewId = this.mRecyclerView.getId();
        int i = this.mPendingCurrentItem;
        if (i == -1) {
            i = this.mCurrentItem;
        }
        savedState.mCurrentItem = i;
        Parcelable parcelable = this.mPendingAdapterState;
        if (parcelable != null) {
            savedState.mAdapterState = parcelable;
        } else {
            RecyclerView.Adapter adapter = this.mRecyclerView.getAdapter();
            if (adapter instanceof StatefulAdapter) {
                FragmentStateAdapter fragmentStateAdapter = (FragmentStateAdapter) ((StatefulAdapter) adapter);
                Objects.requireNonNull(fragmentStateAdapter);
                Bundle bundle = new Bundle(fragmentStateAdapter.mSavedStates.size() + fragmentStateAdapter.mFragments.size());
                for (int i2 = 0; i2 < fragmentStateAdapter.mFragments.size(); i2++) {
                    long keyAt = fragmentStateAdapter.mFragments.keyAt(i2);
                    Fragment fragment = fragmentStateAdapter.mFragments.get(keyAt);
                    if (fragment != null && fragment.isAdded()) {
                        fragmentStateAdapter.mFragmentManager.putFragment(bundle, GeneratedOutlineSupport.outline14("f#", keyAt), fragment);
                    }
                }
                for (int i3 = 0; i3 < fragmentStateAdapter.mSavedStates.size(); i3++) {
                    long keyAt2 = fragmentStateAdapter.mSavedStates.keyAt(i3);
                    if (fragmentStateAdapter.containsItem(keyAt2)) {
                        bundle.putParcelable(GeneratedOutlineSupport.outline14("s#", keyAt2), fragmentStateAdapter.mSavedStates.get(keyAt2));
                    }
                }
                savedState.mAdapterState = bundle;
            }
        }
        return savedState;
    }

    public void onViewAdded(View view) {
        throw new IllegalStateException(ViewPager2.class.getSimpleName() + " does not support direct child views");
    }

    public boolean performAccessibilityAction(int i, Bundle bundle) {
        int i2;
        Objects.requireNonNull((PageAwareAccessibilityProvider) this.mAccessibilityProvider);
        boolean z = false;
        if (!(i == 8192 || i == 4096)) {
            return super.performAccessibilityAction(i, bundle);
        }
        PageAwareAccessibilityProvider pageAwareAccessibilityProvider = (PageAwareAccessibilityProvider) this.mAccessibilityProvider;
        Objects.requireNonNull(pageAwareAccessibilityProvider);
        if (i == 8192 || i == 4096) {
            z = true;
        }
        if (z) {
            if (i == 8192) {
                i2 = ViewPager2.this.getCurrentItem() - 1;
            } else {
                i2 = ViewPager2.this.getCurrentItem() + 1;
            }
            pageAwareAccessibilityProvider.setCurrentItemFromAccessibilityCommand(i2);
            return true;
        }
        throw new IllegalStateException();
    }

    public final void restorePendingState() {
        RecyclerView.Adapter adapter;
        if (!(this.mPendingCurrentItem == -1 || (adapter = getAdapter()) == null)) {
            Parcelable parcelable = this.mPendingAdapterState;
            if (parcelable != null) {
                if (adapter instanceof StatefulAdapter) {
                    FragmentStateAdapter fragmentStateAdapter = (FragmentStateAdapter) ((StatefulAdapter) adapter);
                    if (!fragmentStateAdapter.mSavedStates.isEmpty() || !fragmentStateAdapter.mFragments.isEmpty()) {
                        throw new IllegalStateException("Expected the adapter to be 'fresh' while restoring state.");
                    }
                    Bundle bundle = (Bundle) parcelable;
                    if (bundle.getClassLoader() == null) {
                        bundle.setClassLoader(fragmentStateAdapter.getClass().getClassLoader());
                    }
                    for (String str : bundle.keySet()) {
                        if (FragmentStateAdapter.isValidKey(str, "f#")) {
                            fragmentStateAdapter.mFragments.put(Long.parseLong(str.substring(2)), fragmentStateAdapter.mFragmentManager.getFragment(bundle, str));
                        } else if (FragmentStateAdapter.isValidKey(str, "s#")) {
                            long parseLong = Long.parseLong(str.substring(2));
                            Fragment.SavedState savedState = (Fragment.SavedState) bundle.getParcelable(str);
                            if (fragmentStateAdapter.containsItem(parseLong)) {
                                fragmentStateAdapter.mSavedStates.put(parseLong, savedState);
                            }
                        } else {
                            throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("Unexpected key in savedState: ", str));
                        }
                    }
                    if (!fragmentStateAdapter.mFragments.isEmpty()) {
                        fragmentStateAdapter.mHasStaleFragments = true;
                        fragmentStateAdapter.mIsInGracePeriod = true;
                        fragmentStateAdapter.gcFragments();
                        Handler handler = new Handler(Looper.getMainLooper());
                        FragmentStateAdapter.AnonymousClass4 r5 = 
                        /*  JADX ERROR: Method code generation error
                            jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x00b7: CONSTRUCTOR  (r5v8 'r5' androidx.viewpager2.adapter.FragmentStateAdapter$4) = (r4v4 'fragmentStateAdapter' androidx.viewpager2.adapter.FragmentStateAdapter) call: androidx.viewpager2.adapter.FragmentStateAdapter.4.<init>(androidx.viewpager2.adapter.FragmentStateAdapter):void type: CONSTRUCTOR in method: androidx.viewpager2.widget.ViewPager2.restorePendingState():void, file: classes.dex
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                            	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                            	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                            	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                            	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                            	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                            	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                            	at java.util.ArrayList.forEach(ArrayList.java:1259)
                            	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                            	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                            Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.viewpager2.adapter.FragmentStateAdapter, state: GENERATED_AND_UNLOADED
                            	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                            	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                            	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                            	... 40 more
                            */
                        /*
                        // Method dump skipped, instructions count: 246
                        */
                        throw new UnsupportedOperationException("Method not decompiled: androidx.viewpager2.widget.ViewPager2.restorePendingState():void");
                    }

                    public void setAdapter(RecyclerView.Adapter adapter) {
                        RecyclerView.Adapter adapter2 = this.mRecyclerView.getAdapter();
                        PageAwareAccessibilityProvider pageAwareAccessibilityProvider = (PageAwareAccessibilityProvider) this.mAccessibilityProvider;
                        Objects.requireNonNull(pageAwareAccessibilityProvider);
                        if (adapter2 != null) {
                            adapter2.unregisterAdapterDataObserver(pageAwareAccessibilityProvider.mAdapterDataObserver);
                        }
                        if (adapter2 != null) {
                            adapter2.unregisterAdapterDataObserver(this.mCurrentItemDataSetChangeObserver);
                        }
                        this.mRecyclerView.setAdapter(adapter);
                        this.mCurrentItem = 0;
                        restorePendingState();
                        PageAwareAccessibilityProvider pageAwareAccessibilityProvider2 = (PageAwareAccessibilityProvider) this.mAccessibilityProvider;
                        pageAwareAccessibilityProvider2.updatePageAccessibilityActions();
                        if (adapter != null) {
                            adapter.registerAdapterDataObserver(pageAwareAccessibilityProvider2.mAdapterDataObserver);
                        }
                        if (adapter != null) {
                            adapter.registerAdapterDataObserver(this.mCurrentItemDataSetChangeObserver);
                        }
                    }

                    public void setCurrentItem(int i) {
                        if (!this.mFakeDragger.mScrollEventAdapter.mFakeDragging) {
                            setCurrentItemInternal(i, true);
                            return;
                        }
                        throw new IllegalStateException("Cannot change current item when ViewPager2 is fake dragging");
                    }

                    public void setCurrentItemInternal(int i, boolean z) {
                        RecyclerView.Adapter adapter = getAdapter();
                        boolean z2 = false;
                        if (adapter == null) {
                            if (this.mPendingCurrentItem != -1) {
                                this.mPendingCurrentItem = Math.max(i, 0);
                            }
                        } else if (adapter.getItemCount() > 0) {
                            int min = Math.min(Math.max(i, 0), adapter.getItemCount() - 1);
                            int i2 = this.mCurrentItem;
                            if (min == i2) {
                                if (this.mScrollEventAdapter.mScrollState == 0) {
                                    return;
                                }
                            }
                            if (min != i2 || !z) {
                                double d = (double) i2;
                                this.mCurrentItem = min;
                                ((PageAwareAccessibilityProvider) this.mAccessibilityProvider).updatePageAccessibilityActions();
                                ScrollEventAdapter scrollEventAdapter = this.mScrollEventAdapter;
                                if (!(scrollEventAdapter.mScrollState == 0)) {
                                    scrollEventAdapter.updateScrollEventValues();
                                    ScrollEventAdapter.ScrollEventValues scrollEventValues = scrollEventAdapter.mScrollValues;
                                    d = ((double) scrollEventValues.mPosition) + ((double) scrollEventValues.mOffset);
                                }
                                ScrollEventAdapter scrollEventAdapter2 = this.mScrollEventAdapter;
                                scrollEventAdapter2.mAdapterState = z ? 2 : 3;
                                scrollEventAdapter2.mFakeDragging = false;
                                if (scrollEventAdapter2.mTarget != min) {
                                    z2 = true;
                                }
                                scrollEventAdapter2.mTarget = min;
                                scrollEventAdapter2.dispatchStateChanged(2);
                                if (z2) {
                                    scrollEventAdapter2.dispatchSelected(min);
                                }
                                if (!z) {
                                    this.mRecyclerView.scrollToPosition(min);
                                    return;
                                }
                                double d2 = (double) min;
                                if (Math.abs(d2 - d) > 3.0d) {
                                    this.mRecyclerView.scrollToPosition(d2 > d ? min - 3 : min + 3);
                                    RecyclerView recyclerView = this.mRecyclerView;
                                    recyclerView.post(new SmoothScrollToPosition(min, recyclerView));
                                    return;
                                }
                                this.mRecyclerView.smoothScrollToPosition(min);
                            }
                        }
                    }

                    public void setLayoutDirection(int i) {
                        super.setLayoutDirection(i);
                        ((PageAwareAccessibilityProvider) this.mAccessibilityProvider).updatePageAccessibilityActions();
                    }

                    public void setOffscreenPageLimit(int i) {
                        if (i >= 1 || i == -1) {
                            this.mOffscreenPageLimit = i;
                            this.mRecyclerView.requestLayout();
                            return;
                        }
                        throw new IllegalArgumentException("Offscreen page limit must be OFFSCREEN_PAGE_LIMIT_DEFAULT or a number > 0");
                    }

                    public void setOrientation(int i) {
                        this.mLayoutManager.setOrientation(i);
                        ((PageAwareAccessibilityProvider) this.mAccessibilityProvider).updatePageAccessibilityActions();
                    }

                    public void setPageTransformer(PageTransformer pageTransformer) {
                        if (pageTransformer != null) {
                            if (!this.mSavedItemAnimatorPresent) {
                                this.mSavedItemAnimator = this.mRecyclerView.getItemAnimator();
                                this.mSavedItemAnimatorPresent = true;
                            }
                            this.mRecyclerView.setItemAnimator(null);
                        } else if (this.mSavedItemAnimatorPresent) {
                            this.mRecyclerView.setItemAnimator(this.mSavedItemAnimator);
                            this.mSavedItemAnimator = null;
                            this.mSavedItemAnimatorPresent = false;
                        }
                        PageTransformerAdapter pageTransformerAdapter = this.mPageTransformerAdapter;
                        if (pageTransformer != pageTransformerAdapter.mPageTransformer) {
                            pageTransformerAdapter.mPageTransformer = pageTransformer;
                            if (pageTransformer != null) {
                                ScrollEventAdapter scrollEventAdapter = this.mScrollEventAdapter;
                                scrollEventAdapter.updateScrollEventValues();
                                ScrollEventAdapter.ScrollEventValues scrollEventValues = scrollEventAdapter.mScrollValues;
                                double d = ((double) scrollEventValues.mPosition) + ((double) scrollEventValues.mOffset);
                                int i = (int) d;
                                float f = (float) (d - ((double) i));
                                this.mPageTransformerAdapter.onPageScrolled(i, f, Math.round(((float) getPageSize()) * f));
                            }
                        }
                    }

                    public void setUserInputEnabled(boolean z) {
                        this.mUserInputEnabled = z;
                        ((PageAwareAccessibilityProvider) this.mAccessibilityProvider).updatePageAccessibilityActions();
                    }

                    public void updateCurrentItem() {
                        PagerSnapHelper pagerSnapHelper = this.mPagerSnapHelper;
                        if (pagerSnapHelper != null) {
                            View findSnapView = pagerSnapHelper.findSnapView(this.mLayoutManager);
                            if (findSnapView != null) {
                                int position = this.mLayoutManager.getPosition(findSnapView);
                                if (position != this.mCurrentItem && getScrollState() == 0) {
                                    this.mPageChangeEventDispatcher.onPageSelected(position);
                                }
                                this.mCurrentItemDirty = false;
                                return;
                            }
                            return;
                        }
                        throw new IllegalStateException("Design assumption violated.");
                    }

                    public static class SavedState extends View.BaseSavedState {
                        public static final Parcelable.Creator<SavedState> CREATOR = new Parcelable.ClassLoaderCreator<SavedState>() {
                            /* class androidx.viewpager2.widget.ViewPager2.SavedState.AnonymousClass1 */

                            @Override // android.os.Parcelable.Creator
                            public Object createFromParcel(Parcel parcel) {
                                return Build.VERSION.SDK_INT >= 24 ? new SavedState(parcel, null) : new SavedState(parcel);
                            }

                            @Override // android.os.Parcelable.Creator
                            public Object[] newArray(int i) {
                                return new SavedState[i];
                            }

                            /* Return type fixed from 'java.lang.Object' to match base method */
                            @Override // android.os.Parcelable.ClassLoaderCreator
                            public SavedState createFromParcel(Parcel parcel, ClassLoader classLoader) {
                                return Build.VERSION.SDK_INT >= 24 ? new SavedState(parcel, classLoader) : new SavedState(parcel);
                            }
                        };
                        public Parcelable mAdapterState;
                        public int mCurrentItem;
                        public int mRecyclerViewId;

                        public SavedState(Parcel parcel, ClassLoader classLoader) {
                            super(parcel, classLoader);
                            this.mRecyclerViewId = parcel.readInt();
                            this.mCurrentItem = parcel.readInt();
                            this.mAdapterState = parcel.readParcelable(classLoader);
                        }

                        public void writeToParcel(Parcel parcel, int i) {
                            super.writeToParcel(parcel, i);
                            parcel.writeInt(this.mRecyclerViewId);
                            parcel.writeInt(this.mCurrentItem);
                            parcel.writeParcelable(this.mAdapterState, i);
                        }

                        public SavedState(Parcel parcel) {
                            super(parcel);
                            this.mRecyclerViewId = parcel.readInt();
                            this.mCurrentItem = parcel.readInt();
                            this.mAdapterState = parcel.readParcelable(null);
                        }

                        public SavedState(Parcelable parcelable) {
                            super(parcelable);
                        }
                    }

                    public ViewPager2(Context context, AttributeSet attributeSet) {
                        super(context, attributeSet);
                        initialize(context, attributeSet);
                    }

                    public ViewPager2(Context context, AttributeSet attributeSet, int i) {
                        super(context, attributeSet, i);
                        initialize(context, attributeSet);
                    }
                }
