package androidx.work;

import java.util.concurrent.Executor;
import java.util.concurrent.Executors;

public final class Configuration {
    public final Executor mExecutor;
    public final InputMergerFactory$1 mInputMergerFactory;
    public final int mLoggingLevel;
    public final int mMaxJobSchedulerId;
    public final int mMaxSchedulerLimit;
    public final Executor mTaskExecutor;
    public final WorkerFactory$1 mWorkerFactory;

    public static final class Builder {
        public Executor mExecutor;
        public Executor mTaskExecutor;
    }

    public Configuration(Builder builder) {
        Executor executor = builder.mExecutor;
        if (executor == null) {
            this.mExecutor = createDefaultExecutor();
        } else {
            this.mExecutor = executor;
        }
        Executor executor2 = builder.mTaskExecutor;
        if (executor2 == null) {
            this.mTaskExecutor = createDefaultExecutor();
        } else {
            this.mTaskExecutor = executor2;
        }
        this.mWorkerFactory = new WorkerFactory$1();
        this.mInputMergerFactory = new InputMergerFactory$1();
        this.mLoggingLevel = 4;
        this.mMaxJobSchedulerId = Integer.MAX_VALUE;
        this.mMaxSchedulerLimit = 20;
    }

    public final Executor createDefaultExecutor() {
        return Executors.newFixedThreadPool(Math.max(2, Math.min(Runtime.getRuntime().availableProcessors() - 1, 4)));
    }
}
