package androidx.work;

import android.annotation.SuppressLint;
import android.content.Context;
import androidx.annotation.Keep;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.common.util.concurrent.ListenableFuture;

public abstract class ListenableWorker {
    public Context mAppContext;
    public boolean mUsed;
    public WorkerParameters mWorkerParams;

    @Keep
    @SuppressLint({"BanKeepAnnotation"})
    public ListenableWorker(Context context, WorkerParameters workerParameters) {
        if (context == null) {
            throw new IllegalArgumentException("Application Context is null");
        } else if (workerParameters != null) {
            this.mAppContext = context;
            this.mWorkerParams = workerParameters;
        } else {
            throw new IllegalArgumentException("WorkerParameters is null");
        }
    }

    public void onStopped() {
    }

    public abstract ListenableFuture<Result> startWork();

    public final void stop() {
        onStopped();
    }

    public static abstract class Result {

        public final class Failure extends Result {
            public final Data mOutputData = Data.EMPTY;

            public boolean equals(Object obj) {
                if (this == obj) {
                    return true;
                }
                if (obj == null || Failure.class != obj.getClass()) {
                    return false;
                }
                return this.mOutputData.equals(((Failure) obj).mOutputData);
            }

            public int hashCode() {
                return this.mOutputData.hashCode() + 846803280;
            }

            public String toString() {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failure {mOutputData=");
                outline25.append(this.mOutputData);
                outline25.append('}');
                return outline25.toString();
            }
        }

        public final class Retry extends Result {
            public boolean equals(Object obj) {
                if (this == obj) {
                    return true;
                }
                return obj != null && Retry.class == obj.getClass();
            }

            public int hashCode() {
                return 25945934;
            }

            public String toString() {
                return "Retry";
            }
        }

        public final class Success extends Result {
            public final Data mOutputData;

            public Success() {
                this.mOutputData = Data.EMPTY;
            }

            public boolean equals(Object obj) {
                if (this == obj) {
                    return true;
                }
                if (obj == null || Success.class != obj.getClass()) {
                    return false;
                }
                return this.mOutputData.equals(((Success) obj).mOutputData);
            }

            public int hashCode() {
                return this.mOutputData.hashCode() - 1876823561;
            }

            public String toString() {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("Success {mOutputData=");
                outline25.append(this.mOutputData);
                outline25.append('}');
                return outline25.toString();
            }

            public Success(Data data) {
                this.mOutputData = data;
            }
        }
    }
}
