package androidx.work.impl.background.systemalarm;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.WorkManagerImpl;

public class RescheduleReceiver extends BroadcastReceiver {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("RescheduleReceiver");

    public void onReceive(Context context, Intent intent) {
        Logger$LogcatLogger.get().debug(TAG, String.format("Received intent %s", intent), new Throwable[0]);
        if (Build.VERSION.SDK_INT >= 23) {
            try {
                WorkManagerImpl instance = WorkManagerImpl.getInstance(context);
                BroadcastReceiver.PendingResult goAsync = goAsync();
                synchronized (WorkManagerImpl.sLock) {
                    instance.mRescheduleReceiverResult = goAsync;
                    if (instance.mForceStopRunnableCompleted) {
                        goAsync.finish();
                        instance.mRescheduleReceiverResult = null;
                    }
                }
            } catch (IllegalStateException unused) {
                Logger$LogcatLogger.get().error(TAG, "Cannot reschedule jobs. WorkManager needs to be initialized via a ContentProvider#onCreate() or an Application#onCreate().", new Throwable[0]);
            }
        } else {
            String str = CommandHandler.TAG;
            Intent intent2 = new Intent(context, SystemAlarmService.class);
            intent2.setAction("ACTION_RESCHEDULE");
            context.startService(intent2);
        }
    }
}
