package androidx.work.impl.background.systemalarm;

import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.os.Looper;
import android.os.PowerManager;
import android.text.TextUtils;
import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.ExecutionListener;
import androidx.work.impl.Processor;
import androidx.work.impl.WorkManagerImpl;
import androidx.work.impl.utils.SerialExecutor;
import androidx.work.impl.utils.WakeLocks;
import androidx.work.impl.utils.WorkTimer;
import androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

public class SystemAlarmDispatcher implements ExecutionListener {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("SystemAlarmDispatcher");
    public final CommandHandler mCommandHandler;
    public CommandsCompletedListener mCompletedListener;
    public final Context mContext;
    public Intent mCurrentIntent;
    public final List<Intent> mIntents;
    public final Handler mMainHandler;
    public final Processor mProcessor;
    public final WorkManagerTaskExecutor mTaskExecutor;
    public final WorkManagerImpl mWorkManager;
    public final WorkTimer mWorkTimer = new WorkTimer();

    public class AddRunnable implements Runnable {
        public final SystemAlarmDispatcher mDispatcher;
        public final Intent mIntent;
        public final int mStartId;

        public AddRunnable(SystemAlarmDispatcher systemAlarmDispatcher, Intent intent, int i) {
            this.mDispatcher = systemAlarmDispatcher;
            this.mIntent = intent;
            this.mStartId = i;
        }

        public void run() {
            this.mDispatcher.add(this.mIntent, this.mStartId);
        }
    }

    public interface CommandsCompletedListener {
    }

    public class DequeueAndCheckForCompletion implements Runnable {
        public final SystemAlarmDispatcher mDispatcher;

        public DequeueAndCheckForCompletion(SystemAlarmDispatcher systemAlarmDispatcher) {
            this.mDispatcher = systemAlarmDispatcher;
        }

        public void run() {
            boolean z;
            SystemAlarmDispatcher systemAlarmDispatcher = this.mDispatcher;
            Objects.requireNonNull(systemAlarmDispatcher);
            Logger$LogcatLogger logger$LogcatLogger = Logger$LogcatLogger.get();
            String str = SystemAlarmDispatcher.TAG;
            logger$LogcatLogger.debug(str, "Checking if commands are complete.", new Throwable[0]);
            systemAlarmDispatcher.assertMainThread();
            synchronized (systemAlarmDispatcher.mIntents) {
                boolean z2 = true;
                if (systemAlarmDispatcher.mCurrentIntent != null) {
                    Logger$LogcatLogger.get().debug(str, String.format("Removing command %s", systemAlarmDispatcher.mCurrentIntent), new Throwable[0]);
                    if (systemAlarmDispatcher.mIntents.remove(0).equals(systemAlarmDispatcher.mCurrentIntent)) {
                        systemAlarmDispatcher.mCurrentIntent = null;
                    } else {
                        throw new IllegalStateException("Dequeue-d command is not the first.");
                    }
                }
                SerialExecutor serialExecutor = systemAlarmDispatcher.mTaskExecutor.mBackgroundExecutor;
                CommandHandler commandHandler = systemAlarmDispatcher.mCommandHandler;
                synchronized (commandHandler.mLock) {
                    z = !commandHandler.mPendingDelayMet.isEmpty();
                }
                if (!z && systemAlarmDispatcher.mIntents.isEmpty()) {
                    synchronized (serialExecutor.mLock) {
                        if (serialExecutor.mTasks.isEmpty()) {
                            z2 = false;
                        }
                    }
                    if (!z2) {
                        Logger$LogcatLogger.get().debug(str, "No more commands & intents.", new Throwable[0]);
                        CommandsCompletedListener commandsCompletedListener = systemAlarmDispatcher.mCompletedListener;
                        if (commandsCompletedListener != null) {
                            ((SystemAlarmService) commandsCompletedListener).onAllCommandsCompleted();
                        }
                    }
                }
                if (!systemAlarmDispatcher.mIntents.isEmpty()) {
                    systemAlarmDispatcher.processCommand();
                }
            }
        }
    }

    public SystemAlarmDispatcher(Context context) {
        Context applicationContext = context.getApplicationContext();
        this.mContext = applicationContext;
        this.mCommandHandler = new CommandHandler(applicationContext);
        WorkManagerImpl instance = WorkManagerImpl.getInstance(context);
        this.mWorkManager = instance;
        Processor processor = instance.mProcessor;
        this.mProcessor = processor;
        this.mTaskExecutor = instance.mWorkTaskExecutor;
        processor.addExecutionListener(this);
        this.mIntents = new ArrayList();
        this.mCurrentIntent = null;
        this.mMainHandler = new Handler(Looper.getMainLooper());
    }

    public boolean add(Intent intent, int i) {
        boolean z;
        Logger$LogcatLogger logger$LogcatLogger = Logger$LogcatLogger.get();
        String str = TAG;
        boolean z2 = false;
        logger$LogcatLogger.debug(str, String.format("Adding command %s (%s)", intent, Integer.valueOf(i)), new Throwable[0]);
        assertMainThread();
        String action = intent.getAction();
        if (TextUtils.isEmpty(action)) {
            Logger$LogcatLogger.get().warning(str, "Unknown command. Ignoring", new Throwable[0]);
            return false;
        }
        if ("ACTION_CONSTRAINTS_CHANGED".equals(action)) {
            assertMainThread();
            synchronized (this.mIntents) {
                Iterator<Intent> it = this.mIntents.iterator();
                while (true) {
                    if (it.hasNext()) {
                        if ("ACTION_CONSTRAINTS_CHANGED".equals(it.next().getAction())) {
                            z = true;
                            break;
                        }
                    } else {
                        z = false;
                        break;
                    }
                }
            }
            if (z) {
                return false;
            }
        }
        intent.putExtra("KEY_START_ID", i);
        synchronized (this.mIntents) {
            if (!this.mIntents.isEmpty()) {
                z2 = true;
            }
            this.mIntents.add(intent);
            if (!z2) {
                processCommand();
            }
        }
        return true;
    }

    public final void assertMainThread() {
        if (this.mMainHandler.getLooper().getThread() != Thread.currentThread()) {
            throw new IllegalStateException("Needs to be invoked on the main thread.");
        }
    }

    public void onDestroy() {
        Logger$LogcatLogger.get().debug(TAG, "Destroying SystemAlarmDispatcher", new Throwable[0]);
        this.mProcessor.removeExecutionListener(this);
        WorkTimer workTimer = this.mWorkTimer;
        if (!workTimer.mExecutorService.isShutdown()) {
            workTimer.mExecutorService.shutdownNow();
        }
        this.mCompletedListener = null;
    }

    @Override // androidx.work.impl.ExecutionListener
    public void onExecuted(String str, boolean z) {
        Context context = this.mContext;
        String str2 = CommandHandler.TAG;
        Intent intent = new Intent(context, SystemAlarmService.class);
        intent.setAction("ACTION_EXECUTION_COMPLETED");
        intent.putExtra("KEY_WORKSPEC_ID", str);
        intent.putExtra("KEY_NEEDS_RESCHEDULE", z);
        this.mMainHandler.post(new AddRunnable(this, intent, 0));
    }

    public final void processCommand() {
        assertMainThread();
        PowerManager.WakeLock newWakeLock = WakeLocks.newWakeLock(this.mContext, "ProcessCommand");
        try {
            newWakeLock.acquire();
            WorkManagerTaskExecutor workManagerTaskExecutor = this.mWorkManager.mWorkTaskExecutor;
            workManagerTaskExecutor.mBackgroundExecutor.execute(new Runnable() {
                /* class androidx.work.impl.background.systemalarm.SystemAlarmDispatcher.AnonymousClass1 */

                public void run() {
                    SystemAlarmDispatcher systemAlarmDispatcher;
                    DequeueAndCheckForCompletion dequeueAndCheckForCompletion;
                    synchronized (SystemAlarmDispatcher.this.mIntents) {
                        SystemAlarmDispatcher systemAlarmDispatcher2 = SystemAlarmDispatcher.this;
                        systemAlarmDispatcher2.mCurrentIntent = systemAlarmDispatcher2.mIntents.get(0);
                    }
                    Intent intent = SystemAlarmDispatcher.this.mCurrentIntent;
                    if (intent != null) {
                        String action = intent.getAction();
                        int intExtra = SystemAlarmDispatcher.this.mCurrentIntent.getIntExtra("KEY_START_ID", 0);
                        Logger$LogcatLogger logger$LogcatLogger = Logger$LogcatLogger.get();
                        String str = SystemAlarmDispatcher.TAG;
                        logger$LogcatLogger.debug(str, String.format("Processing command %s, %s", SystemAlarmDispatcher.this.mCurrentIntent, Integer.valueOf(intExtra)), new Throwable[0]);
                        PowerManager.WakeLock newWakeLock = WakeLocks.newWakeLock(SystemAlarmDispatcher.this.mContext, String.format("%s (%s)", action, Integer.valueOf(intExtra)));
                        try {
                            Logger$LogcatLogger.get().debug(str, String.format("Acquiring operation wake lock (%s) %s", action, newWakeLock), new Throwable[0]);
                            newWakeLock.acquire();
                            SystemAlarmDispatcher systemAlarmDispatcher3 = SystemAlarmDispatcher.this;
                            systemAlarmDispatcher3.mCommandHandler.onHandleIntent(systemAlarmDispatcher3.mCurrentIntent, intExtra, systemAlarmDispatcher3);
                            Logger$LogcatLogger.get().debug(str, String.format("Releasing operation wake lock (%s) %s", action, newWakeLock), new Throwable[0]);
                            newWakeLock.release();
                            systemAlarmDispatcher = SystemAlarmDispatcher.this;
                            dequeueAndCheckForCompletion = new DequeueAndCheckForCompletion(systemAlarmDispatcher);
                        } catch (Throwable th) {
                            Logger$LogcatLogger.get().debug(SystemAlarmDispatcher.TAG, String.format("Releasing operation wake lock (%s) %s", action, newWakeLock), new Throwable[0]);
                            newWakeLock.release();
                            SystemAlarmDispatcher systemAlarmDispatcher4 = SystemAlarmDispatcher.this;
                            systemAlarmDispatcher4.mMainHandler.post(new DequeueAndCheckForCompletion(systemAlarmDispatcher4));
                            throw th;
                        }
                        systemAlarmDispatcher.mMainHandler.post(dequeueAndCheckForCompletion);
                    }
                }
            });
        } finally {
            newWakeLock.release();
        }
    }
}
