package androidx.work.impl.constraints.controllers;

import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.constraints.WorkConstraintsCallback;
import androidx.work.impl.constraints.WorkConstraintsTracker;
import androidx.work.impl.constraints.trackers.ConstraintTracker;
import androidx.work.impl.model.WorkSpec;
import java.util.ArrayList;
import java.util.List;

public abstract class ConstraintController<T> {
    public OnConstraintUpdatedCallback mCallback;
    public T mCurrentValue;
    public final List<String> mMatchingWorkSpecIds = new ArrayList();
    public ConstraintTracker<T> mTracker;

    public interface OnConstraintUpdatedCallback {
    }

    public ConstraintController(ConstraintTracker<T> constraintTracker) {
        this.mTracker = constraintTracker;
    }

    public abstract boolean hasConstraint(WorkSpec workSpec);

    public abstract boolean isConstrained(T t);

    public void replace(Iterable<WorkSpec> iterable) {
        this.mMatchingWorkSpecIds.clear();
        for (WorkSpec workSpec : iterable) {
            if (hasConstraint(workSpec)) {
                this.mMatchingWorkSpecIds.add(workSpec.id);
            }
        }
        if (this.mMatchingWorkSpecIds.isEmpty()) {
            this.mTracker.removeListener(this);
        } else {
            ConstraintTracker<T> constraintTracker = this.mTracker;
            synchronized (constraintTracker.mLock) {
                if (constraintTracker.mListeners.add(this)) {
                    if (constraintTracker.mListeners.size() == 1) {
                        constraintTracker.mCurrentState = constraintTracker.getInitialState();
                        Logger$LogcatLogger.get().debug(ConstraintTracker.TAG, String.format("%s: initial state = %s", constraintTracker.getClass().getSimpleName(), constraintTracker.mCurrentState), new Throwable[0]);
                        constraintTracker.startTracking();
                    }
                    this.mCurrentValue = constraintTracker.mCurrentState;
                    updateCallback();
                }
            }
        }
        updateCallback();
    }

    public final void updateCallback() {
        if (!(this.mMatchingWorkSpecIds.isEmpty() || this.mCallback == null)) {
            T t = this.mCurrentValue;
            if (t == null || isConstrained(t)) {
                OnConstraintUpdatedCallback onConstraintUpdatedCallback = this.mCallback;
                List<String> list = this.mMatchingWorkSpecIds;
                WorkConstraintsTracker workConstraintsTracker = (WorkConstraintsTracker) onConstraintUpdatedCallback;
                synchronized (workConstraintsTracker.mLock) {
                    WorkConstraintsCallback workConstraintsCallback = workConstraintsTracker.mCallback;
                    if (workConstraintsCallback != null) {
                        workConstraintsCallback.onAllConstraintsNotMet(list);
                    }
                }
                return;
            }
            OnConstraintUpdatedCallback onConstraintUpdatedCallback2 = this.mCallback;
            List<String> list2 = this.mMatchingWorkSpecIds;
            WorkConstraintsTracker workConstraintsTracker2 = (WorkConstraintsTracker) onConstraintUpdatedCallback2;
            synchronized (workConstraintsTracker2.mLock) {
                ArrayList arrayList = new ArrayList();
                for (String str : list2) {
                    if (workConstraintsTracker2.areAllConstraintsMet(str)) {
                        Logger$LogcatLogger.get().debug(WorkConstraintsTracker.TAG, String.format("Constraints met for %s", str), new Throwable[0]);
                        arrayList.add(str);
                    }
                }
                WorkConstraintsCallback workConstraintsCallback2 = workConstraintsTracker2.mCallback;
                if (workConstraintsCallback2 != null) {
                    workConstraintsCallback2.onAllConstraintsMet(arrayList);
                }
            }
        }
    }
}
