package androidx.work.impl.constraints.trackers;

import android.content.Context;
import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.constraints.controllers.ConstraintController;
import androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor;
import java.util.ArrayList;
import java.util.LinkedHashSet;
import java.util.Set;

public abstract class ConstraintTracker<T> {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("ConstraintTracker");
    public final Context mAppContext;
    public T mCurrentState;
    public final Set<ConstraintController<T>> mListeners = new LinkedHashSet();
    public final Object mLock = new Object();
    public final WorkManagerTaskExecutor mTaskExecutor;

    public ConstraintTracker(Context context, WorkManagerTaskExecutor workManagerTaskExecutor) {
        this.mAppContext = context.getApplicationContext();
        this.mTaskExecutor = workManagerTaskExecutor;
    }

    public abstract T getInitialState();

    public void removeListener(ConstraintController<T> constraintController) {
        synchronized (this.mLock) {
            if (this.mListeners.remove(constraintController) && this.mListeners.isEmpty()) {
                stopTracking();
            }
        }
    }

    public void setState(T t) {
        synchronized (this.mLock) {
            T t2 = this.mCurrentState;
            if (t2 != t) {
                if (t2 == null || !t2.equals(t)) {
                    this.mCurrentState = t;
                    final ArrayList arrayList = new ArrayList(this.mListeners);
                    this.mTaskExecutor.mMainThreadExecutor.execute(new Runnable() {
                        /* class androidx.work.impl.constraints.trackers.ConstraintTracker.AnonymousClass1 */

                        public void run() {
                            for (ConstraintController constraintController : arrayList) {
                                constraintController.mCurrentValue = ConstraintTracker.this.mCurrentState;
                                constraintController.updateCallback();
                            }
                        }
                    });
                }
            }
        }
    }

    public abstract void startTracking();

    public abstract void stopTracking();
}
