package androidx.work.impl.foreground;

import android.content.Context;
import androidx.work.ForegroundInfo;
import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.ExecutionListener;
import androidx.work.impl.WorkManagerImpl;
import androidx.work.impl.constraints.WorkConstraintsCallback;
import androidx.work.impl.constraints.WorkConstraintsTracker;
import androidx.work.impl.model.WorkSpec;
import androidx.work.impl.utils.StopWorkRunnable;
import androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class SystemForegroundDispatcher implements WorkConstraintsCallback, ExecutionListener {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("SystemFgDispatcher");
    public Callback mCallback;
    public final WorkConstraintsTracker mConstraintsTracker;
    public Context mContext;
    public String mCurrentForegroundWorkSpecId;
    public final Map<String, ForegroundInfo> mForegroundInfoById;
    public ForegroundInfo mLastForegroundInfo;
    public final Object mLock = new Object();
    public final WorkManagerTaskExecutor mTaskExecutor;
    public final Set<WorkSpec> mTrackedWorkSpecs;
    public WorkManagerImpl mWorkManagerImpl;
    public final Map<String, WorkSpec> mWorkSpecById;

    public interface Callback {
    }

    public SystemForegroundDispatcher(Context context) {
        this.mContext = context;
        WorkManagerImpl instance = WorkManagerImpl.getInstance(this.mContext);
        this.mWorkManagerImpl = instance;
        WorkManagerTaskExecutor workManagerTaskExecutor = instance.mWorkTaskExecutor;
        this.mTaskExecutor = workManagerTaskExecutor;
        this.mCurrentForegroundWorkSpecId = null;
        this.mLastForegroundInfo = null;
        this.mForegroundInfoById = new LinkedHashMap();
        this.mTrackedWorkSpecs = new HashSet();
        this.mWorkSpecById = new HashMap();
        this.mConstraintsTracker = new WorkConstraintsTracker(this.mContext, workManagerTaskExecutor, this);
        this.mWorkManagerImpl.mProcessor.addExecutionListener(this);
    }

    @Override // androidx.work.impl.constraints.WorkConstraintsCallback
    public void onAllConstraintsMet(List<String> list) {
    }

    @Override // androidx.work.impl.constraints.WorkConstraintsCallback
    public void onAllConstraintsNotMet(List<String> list) {
        if (!list.isEmpty()) {
            for (String str : list) {
                Logger$LogcatLogger.get().debug(TAG, String.format("Constraints unmet for WorkSpec %s", str), new Throwable[0]);
                WorkManagerImpl workManagerImpl = this.mWorkManagerImpl;
                WorkManagerTaskExecutor workManagerTaskExecutor = workManagerImpl.mWorkTaskExecutor;
                workManagerTaskExecutor.mBackgroundExecutor.execute(new StopWorkRunnable(workManagerImpl, str, true));
            }
        }
    }

    @Override // androidx.work.impl.ExecutionListener
    public void onExecuted(String str, boolean z) {
        boolean remove;
        Map.Entry<String, ForegroundInfo> entry;
        synchronized (this.mLock) {
            WorkSpec remove2 = this.mWorkSpecById.remove(str);
            remove = remove2 != null ? this.mTrackedWorkSpecs.remove(remove2) : false;
        }
        if (remove) {
            this.mConstraintsTracker.replace(this.mTrackedWorkSpecs);
        }
        this.mLastForegroundInfo = this.mForegroundInfoById.remove(str);
        if (str.equals(this.mCurrentForegroundWorkSpecId) && this.mForegroundInfoById.size() > 0) {
            Iterator<Map.Entry<String, ForegroundInfo>> it = this.mForegroundInfoById.entrySet().iterator();
            Map.Entry<String, ForegroundInfo> next = it.next();
            while (true) {
                entry = next;
                if (!it.hasNext()) {
                    break;
                }
                next = it.next();
            }
            this.mCurrentForegroundWorkSpecId = entry.getKey();
            if (this.mCallback != null) {
                ForegroundInfo value = entry.getValue();
                ((SystemForegroundService) this.mCallback).startForeground(value.mNotificationId, value.mForegroundServiceType, value.mNotification);
                ((SystemForegroundService) this.mCallback).cancelNotification(value.mNotificationId);
                ((SystemForegroundService) this.mCallback).cancelNotification(this.mLastForegroundInfo.mNotificationId);
            }
        }
    }
}
