package androidx.work.impl.foreground;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Intent;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import androidx.lifecycle.LifecycleService;
import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.WorkDatabase;
import androidx.work.impl.foreground.SystemForegroundDispatcher;
import androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor;
import java.util.Objects;

public class SystemForegroundService extends LifecycleService implements SystemForegroundDispatcher.Callback {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("SystemFgService");
    public SystemForegroundDispatcher mDispatcher;
    public Handler mHandler;
    public boolean mIsShutdown;
    public NotificationManager mNotificationManager;

    public void cancelNotification(final int i) {
        this.mHandler.post(new Runnable() {
            /* class androidx.work.impl.foreground.SystemForegroundService.AnonymousClass3 */

            public void run() {
                SystemForegroundService.this.mNotificationManager.cancel(i);
            }
        });
    }

    public final void initializeDispatcher() {
        this.mHandler = new Handler(Looper.getMainLooper());
        this.mNotificationManager = (NotificationManager) getApplicationContext().getSystemService("notification");
        SystemForegroundDispatcher systemForegroundDispatcher = new SystemForegroundDispatcher(getApplicationContext());
        this.mDispatcher = systemForegroundDispatcher;
        if (systemForegroundDispatcher.mCallback != null) {
            Logger$LogcatLogger.get().error(SystemForegroundDispatcher.TAG, "A callback already exists.", new Throwable[0]);
        } else {
            systemForegroundDispatcher.mCallback = this;
        }
    }

    @Override // androidx.lifecycle.LifecycleService
    public void onCreate() {
        super.onCreate();
        initializeDispatcher();
    }

    @Override // androidx.lifecycle.LifecycleService
    public void onDestroy() {
        super.onDestroy();
        SystemForegroundDispatcher systemForegroundDispatcher = this.mDispatcher;
        systemForegroundDispatcher.mCallback = null;
        systemForegroundDispatcher.mConstraintsTracker.reset();
        systemForegroundDispatcher.mWorkManagerImpl.mProcessor.removeExecutionListener(systemForegroundDispatcher);
    }

    @Override // androidx.lifecycle.LifecycleService
    public int onStartCommand(Intent intent, int i, int i2) {
        super.onStartCommand(intent, i, i2);
        int i3 = 0;
        if (this.mIsShutdown) {
            Logger$LogcatLogger.get().info(TAG, "Re-initializing SystemForegroundService after a request to shut-down.", new Throwable[0]);
            SystemForegroundDispatcher systemForegroundDispatcher = this.mDispatcher;
            systemForegroundDispatcher.mCallback = null;
            systemForegroundDispatcher.mConstraintsTracker.reset();
            systemForegroundDispatcher.mWorkManagerImpl.mProcessor.removeExecutionListener(systemForegroundDispatcher);
            initializeDispatcher();
            this.mIsShutdown = false;
        }
        if (intent != null) {
            SystemForegroundDispatcher systemForegroundDispatcher2 = this.mDispatcher;
            Objects.requireNonNull(systemForegroundDispatcher2);
            String action = intent.getAction();
            if ("ACTION_START_FOREGROUND".equals(action)) {
                Logger$LogcatLogger.get().info(SystemForegroundDispatcher.TAG, String.format("Started foreground service %s", intent), new Throwable[0]);
                String stringExtra = intent.getStringExtra("KEY_WORKSPEC_ID");
                WorkDatabase workDatabase = systemForegroundDispatcher2.mWorkManagerImpl.mWorkDatabase;
                WorkManagerTaskExecutor workManagerTaskExecutor = systemForegroundDispatcher2.mTaskExecutor;
                workManagerTaskExecutor.mBackgroundExecutor.execute(
                /*  JADX ERROR: Method code generation error
                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0068: INVOKE  
                      (wrap: androidx.work.impl.utils.SerialExecutor : 0x0066: IGET  (r10v22 androidx.work.impl.utils.SerialExecutor) = (r0v10 'workManagerTaskExecutor' androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor) androidx.work.impl.utils.taskexecutor.WorkManagerTaskExecutor.mBackgroundExecutor androidx.work.impl.utils.SerialExecutor)
                      (wrap: androidx.work.impl.foreground.SystemForegroundDispatcher$1 : 0x0063: CONSTRUCTOR  (r2v9 androidx.work.impl.foreground.SystemForegroundDispatcher$1) = 
                      (r1v0 'systemForegroundDispatcher2' androidx.work.impl.foreground.SystemForegroundDispatcher)
                      (r12v25 'workDatabase' androidx.work.impl.WorkDatabase)
                      (r10v21 'stringExtra' java.lang.String)
                     call: androidx.work.impl.foreground.SystemForegroundDispatcher.1.<init>(androidx.work.impl.foreground.SystemForegroundDispatcher, androidx.work.impl.WorkDatabase, java.lang.String):void type: CONSTRUCTOR)
                     type: VIRTUAL call: androidx.work.impl.utils.SerialExecutor.execute(java.lang.Runnable):void in method: androidx.work.impl.foreground.SystemForegroundService.onStartCommand(android.content.Intent, int, int):int, file: classes.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                    Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0063: CONSTRUCTOR  (r2v9 androidx.work.impl.foreground.SystemForegroundDispatcher$1) = 
                      (r1v0 'systemForegroundDispatcher2' androidx.work.impl.foreground.SystemForegroundDispatcher)
                      (r12v25 'workDatabase' androidx.work.impl.WorkDatabase)
                      (r10v21 'stringExtra' java.lang.String)
                     call: androidx.work.impl.foreground.SystemForegroundDispatcher.1.<init>(androidx.work.impl.foreground.SystemForegroundDispatcher, androidx.work.impl.WorkDatabase, java.lang.String):void type: CONSTRUCTOR in method: androidx.work.impl.foreground.SystemForegroundService.onStartCommand(android.content.Intent, int, int):int, file: classes.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                    	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                    	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                    	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                    	... 24 more
                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.work.impl.foreground.SystemForegroundDispatcher, state: GENERATED_AND_UNLOADED
                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                    	... 30 more
                    */
                /*
                // Method dump skipped, instructions count: 430
                */
                throw new UnsupportedOperationException("Method not decompiled: androidx.work.impl.foreground.SystemForegroundService.onStartCommand(android.content.Intent, int, int):int");
            }

            public void startForeground(final int i, final int i2, final Notification notification) {
                this.mHandler.post(new Runnable() {
                    /* class androidx.work.impl.foreground.SystemForegroundService.AnonymousClass1 */

                    public void run() {
                        if (Build.VERSION.SDK_INT >= 29) {
                            SystemForegroundService.this.startForeground(i, notification, i2);
                        } else {
                            SystemForegroundService.this.startForeground(i, notification);
                        }
                    }
                });
            }
        }
