package androidx.work.impl.utils;

import androidx.work.Logger$LogcatLogger;
import androidx.work.impl.background.systemalarm.DelayMetCommandHandler;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;

public class WorkTimer {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("WorkTimer");
    public final ThreadFactory mBackgroundThreadFactory;
    public final ScheduledExecutorService mExecutorService;
    public final Map<String, TimeLimitExceededListener> mListeners = new HashMap();
    public final Object mLock = new Object();
    public final Map<String, WorkTimerRunnable> mTimerMap = new HashMap();

    public interface TimeLimitExceededListener {
    }

    public class WorkTimerRunnable implements Runnable {
        public final String mWorkSpecId;
        public final WorkTimer mWorkTimer;

        public WorkTimerRunnable(WorkTimer workTimer, String str) {
            this.mWorkTimer = workTimer;
            this.mWorkSpecId = str;
        }

        public void run() {
            synchronized (this.mWorkTimer.mLock) {
                if (this.mWorkTimer.mTimerMap.remove(this.mWorkSpecId) != null) {
                    TimeLimitExceededListener remove = this.mWorkTimer.mListeners.remove(this.mWorkSpecId);
                    if (remove != null) {
                        String str = this.mWorkSpecId;
                        Logger$LogcatLogger.get().debug(DelayMetCommandHandler.TAG, String.format("Exceeded time limits on execution for %s", str), new Throwable[0]);
                        ((DelayMetCommandHandler) remove).stopWork();
                    }
                } else {
                    Logger$LogcatLogger.get().debug("WrkTimerRunnable", String.format("Timer with %s is already marked as complete.", this.mWorkSpecId), new Throwable[0]);
                }
            }
        }
    }

    public WorkTimer() {
        AnonymousClass1 r0 = new ThreadFactory(this) {
            /* class androidx.work.impl.utils.WorkTimer.AnonymousClass1 */
            public int mThreadsCreated = 0;

            public Thread newThread(Runnable runnable) {
                Thread newThread = Executors.defaultThreadFactory().newThread(runnable);
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("WorkManager-WorkTimer-thread-");
                outline25.append(this.mThreadsCreated);
                newThread.setName(outline25.toString());
                this.mThreadsCreated++;
                return newThread;
            }
        };
        this.mBackgroundThreadFactory = r0;
        this.mExecutorService = Executors.newSingleThreadScheduledExecutor(r0);
    }

    public void startTimer(String str, long j, TimeLimitExceededListener timeLimitExceededListener) {
        synchronized (this.mLock) {
            Logger$LogcatLogger.get().debug(TAG, String.format("Starting timer for %s", str), new Throwable[0]);
            stopTimer(str);
            WorkTimerRunnable workTimerRunnable = new WorkTimerRunnable(this, str);
            this.mTimerMap.put(str, workTimerRunnable);
            this.mListeners.put(str, timeLimitExceededListener);
            this.mExecutorService.schedule(workTimerRunnable, j, TimeUnit.MILLISECONDS);
        }
    }

    public void stopTimer(String str) {
        synchronized (this.mLock) {
            if (this.mTimerMap.remove(str) != null) {
                Logger$LogcatLogger.get().debug(TAG, String.format("Stopping timer for %s", str), new Throwable[0]);
                this.mListeners.remove(str);
            }
        }
    }
}
