package com.allpayx.sdk.activity;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import com.allpayx.sdk.AllPayEngine;
import com.allpayx.sdk.constants.AllPayConst;
import com.allpayx.sdk.module.PayModule;
import com.allpayx.sdk.util.HttpUtil;
import com.allpayx.sdk.util.JsonUtil;
import com.allpayx.sdk.util.NetworkUtils;
import com.allpayx.sdk.util.ResultJson;
import com.allpayx.sdk.util.ServerUtil;
import com.allpayx.sdk.view.LoadView;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.HashMap;

public class AllPayActivity extends Activity {
    private final String TAG = "AllPayActivity";
    private long firstTime = 0;
    private Context mContext;
    private Intent mIntent;
    private LoadView mLoadView;
    private String mOrderNum;
    private String mParameter;
    private PayModule mPayModule;
    private String mPaymentSchema;
    private ResultJson mResultJson;
    private String mTn;

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void returnResult(String str, String str2) {
        this.mResultJson.putString("state", str);
        this.mResultJson.putString("errorDetail", str2);
        this.mResultJson.putString("orderNum", this.mOrderNum);
        this.mResultJson.putString("paymentSchema", this.mPaymentSchema);
        this.mIntent.putExtra("pay_result", this.mResultJson.getJson().toString());
        setResult(AllPayConst.VTPAY_PAY_RESULT_CODE, this.mIntent);
        finish();
    }

    public void onActivityResult(int i, int i2, Intent intent) {
        PayModule payModule = this.mPayModule;
        if (payModule != null) {
            payModule.onActivityResult(i, i2, intent);
        }
    }

    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        this.mContext = this;
        this.mResultJson = new ResultJson();
        Intent intent = getIntent();
        this.mIntent = intent;
        this.mTn = intent.getStringExtra("tn");
        LoadView loadView = new LoadView(this.mContext);
        this.mLoadView = loadView;
        setContentView(loadView.getLoadingView());
        this.mLoadView.startLoading();
        this.firstTime = System.currentTimeMillis();
        if (!NetworkUtils.isConnected(this.mContext)) {
            returnResult(AllPayConst.VTPAY_PAY_RESULT_FAIL, "Network error");
        } else {
            new Thread(new Runnable() {
                /* class com.allpayx.sdk.activity.AllPayActivity.AnonymousClass1 */

                public void run() {
                    String str = Build.MODEL;
                    String str2 = Build.VERSION.RELEASE;
                    Log.i("AllPayActivity", "phoneModel:" + str + "\nsystemVersion" + str2 + "\nsdkVersion:" + "5.0.0");
                    HashMap hashMap = new HashMap();
                    hashMap.put("tn", AllPayActivity.this.mTn);
                    hashMap.put("phoneModel", str);
                    hashMap.put("systemVersion", str2);
                    hashMap.put("sdkVersion", "5.0.0");
                    hashMap.put("terminalId", "");
                    String str3 = AllPayEngine.isDebug ? ServerUtil.SERVER_URL_TEST : ServerUtil.SERVER_URL;
                    String reqStr = HttpUtil.reqStr(str3 + "/api/getPayment", hashMap, HttpUtil.METHOD_POST);
                    if (!JsonUtil.getParam(reqStr, "RespCode").equals("00")) {
                        AllPayActivity.this.returnResult(AllPayConst.VTPAY_PAY_RESULT_FAIL, JsonUtil.getParam(reqStr, "RespMsg"));
                        return;
                    }
                    AllPayActivity.this.mPaymentSchema = JsonUtil.getParam(reqStr, "paymentSchema");
                    AllPayActivity.this.mTn = JsonUtil.getParam(reqStr, "tn");
                    AllPayActivity.this.mParameter = JsonUtil.getParam(reqStr, "Parameter");
                    AllPayActivity.this.mOrderNum = JsonUtil.getParam(reqStr, "orderNum");
                    String param = JsonUtil.getParam(reqStr, "module");
                    try {
                        AllPayActivity.this.mPayModule = (PayModule) Class.forName(GeneratedOutlineSupport.outline18("com.allpayx.sdk.module.", param)).newInstance();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                    if (AllPayActivity.this.mPayModule == null) {
                        AllPayActivity allPayActivity = AllPayActivity.this;
                        allPayActivity.returnResult(AllPayConst.VTPAY_PAY_RESULT_FAIL, param + " is not addded");
                        return;
                    }
                    AllPayActivity.this.runOnUiThread(new Runnable() {
                        /* class com.allpayx.sdk.activity.AllPayActivity.AnonymousClass1.AnonymousClass1 */

                        public void run() {
                            PayModule payModule = AllPayActivity.this.mPayModule;
                            AllPayActivity allPayActivity = AllPayActivity.this;
                            payModule.pay(allPayActivity, allPayActivity.mOrderNum, AllPayActivity.this.mPaymentSchema, AllPayActivity.this.mParameter);
                        }
                    });
                }
            }).start();
        }
    }

    public void onDestroy() {
        PayModule payModule = this.mPayModule;
        if (payModule != null) {
            payModule.onDestroy();
        }
        super.onDestroy();
    }

    public boolean onKeyDown(int i, KeyEvent keyEvent) {
        if (i == 4) {
            long currentTimeMillis = System.currentTimeMillis();
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("secondTime - firstTime:");
            outline25.append(currentTimeMillis - this.firstTime);
            Log.e("AllPayActivity", outline25.toString());
            if (currentTimeMillis - this.firstTime < 6000) {
                return false;
            }
        }
        return super.onKeyDown(i, keyEvent);
    }

    public void onPause() {
        super.onPause();
        this.mLoadView.endLoading();
        PayModule payModule = this.mPayModule;
        if (payModule != null) {
            payModule.onPause();
        }
    }

    public void onResume() {
        super.onResume();
        PayModule payModule = this.mPayModule;
        if (payModule != null) {
            payModule.onResume();
        }
    }
}
