package com.allpayx.sdk.view;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.view.animation.TranslateAnimation;
import android.widget.ScrollView;

public class ReboundScrollView extends ScrollView {
    private static final int ANIM_TIME = 300;
    private static final float MOVE_FACTOR = 0.5f;
    private static final String TAG = "ElasticScrollView";
    private boolean canPullDown = false;
    private boolean canPullUp = false;
    private View contentView;
    private boolean isMoved = false;
    private Rect originalRect = new Rect();
    private float startY;

    public ReboundScrollView(Context context) {
        super(context);
    }

    private boolean isCanPullDown() {
        if (getScrollY() != 0) {
            return this.contentView.getHeight() < getScrollY() + getHeight();
        }
    }

    private boolean isCanPullUp() {
        return this.contentView.getHeight() <= getScrollY() + getHeight();
    }

    public boolean dispatchTouchEvent(MotionEvent motionEvent) {
        boolean z;
        if (this.contentView == null) {
            return super.dispatchTouchEvent(motionEvent);
        }
        int action = motionEvent.getAction();
        if (action != 0) {
            boolean z2 = false;
            if (action != 1) {
                if (action == 2) {
                    if (this.canPullDown || this.canPullUp) {
                        int y = (int) (motionEvent.getY() - this.startY);
                        boolean z3 = this.canPullDown;
                        if ((z3 && y > 0) || (((z = this.canPullUp) && y < 0) || (z && z3))) {
                            z2 = true;
                        }
                        if (z2) {
                            int i = (int) (((float) y) * 0.5f);
                            View view = this.contentView;
                            Rect rect = this.originalRect;
                            view.layout(rect.left, rect.top + i, rect.right, rect.bottom + i);
                            this.isMoved = true;
                        }
                    } else {
                        this.startY = motionEvent.getY();
                        this.canPullDown = isCanPullDown();
                        this.canPullUp = isCanPullUp();
                    }
                }
            } else if (this.isMoved) {
                TranslateAnimation translateAnimation = new TranslateAnimation(0.0f, 0.0f, (float) this.contentView.getTop(), (float) this.originalRect.top);
                translateAnimation.setDuration(300);
                this.contentView.startAnimation(translateAnimation);
                View view2 = this.contentView;
                Rect rect2 = this.originalRect;
                view2.layout(rect2.left, rect2.top, rect2.right, rect2.bottom);
                this.canPullDown = false;
                this.canPullUp = false;
                this.isMoved = false;
            }
        } else {
            this.canPullDown = isCanPullDown();
            this.canPullUp = isCanPullUp();
            this.startY = motionEvent.getY();
        }
        return super.dispatchTouchEvent(motionEvent);
    }

    public void onFinishInflate() {
        if (getChildCount() > 0) {
            this.contentView = getChildAt(0);
        }
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        View view = this.contentView;
        if (view != null) {
            this.originalRect.set(view.getLeft(), this.contentView.getTop(), this.contentView.getRight(), this.contentView.getBottom());
        }
    }

    public ReboundScrollView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
    }
}
