package com.audio.view;

import android.app.Dialog;
import android.content.Context;
import android.graphics.drawable.AnimationDrawable;
import android.media.AudioRecord;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.appcompat.widget.AppCompatButton;
import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.audio.record.AudioRecorder;
import java.util.Objects;
import net.xfkefu.sdk.R;
import net.xfkefu.sdk.a.DateHelper;
import net.xfkefu.sdk.a.PermissionHelper;

public class AudioRecorderButton extends AppCompatButton {
    public boolean isRecording;
    public final AudioRecorder mAudioRecorder;
    public final AudioDialogManager mDialogManager;
    public final Runnable mGetVoiceLevelRunnable;
    public final Handler mHandler;
    public boolean mReady;
    public int mState;
    public float mTime;
    public AudioRecorderListener onAudioRecorderListener;
    public float shortTime;

    public interface AudioRecorderListener {
        void noPermission();

        void onFinish(float f, String str);
    }

    public AudioRecorderButton(Context context) {
        this(context, null);
    }

    public final void changeState(int i) {
        AudioDialogManager audioDialogManager;
        Dialog dialog;
        if (this.mState != i) {
            this.mState = i;
            if (i == 1) {
                setBackgroundResource(R.drawable.kefu_audio_btn_recorder);
                setText(R.string.kefu_audio_recorder_normal);
            } else if (i == 2) {
                setBackgroundResource(R.drawable.kefu_audio_btn_recording);
                setText(R.string.kefu_audio_recorder_recording);
                if (this.isRecording && (dialog = (audioDialogManager = this.mDialogManager).mDialog) != null && dialog.isShowing()) {
                    audioDialogManager.mIcon.setVisibility(0);
                    audioDialogManager.mVoice.setVisibility(0);
                    audioDialogManager.mLabel.setVisibility(0);
                    audioDialogManager.mIcon.setImageResource(R.drawable.kefu_audio_recorder);
                    audioDialogManager.mLabel.setText("手指上滑，取消发送");
                    AnimationDrawable animationDrawable = (AnimationDrawable) audioDialogManager.mVoice.getBackground();
                    if (!animationDrawable.isRunning()) {
                        animationDrawable.start();
                    }
                }
            } else if (i == 3) {
                setBackgroundResource(R.drawable.kefu_audio_btn_recording);
                setText(R.string.kefu_audio_recorder_want_cancel);
                AudioDialogManager audioDialogManager2 = this.mDialogManager;
                Dialog dialog2 = audioDialogManager2.mDialog;
                if (dialog2 != null && dialog2.isShowing()) {
                    audioDialogManager2.mIcon.setVisibility(0);
                    audioDialogManager2.mVoice.setVisibility(8);
                    audioDialogManager2.mLabel.setVisibility(0);
                    audioDialogManager2.mIcon.setImageResource(R.drawable.kefu_audio_cancel);
                    audioDialogManager2.mLabel.setText("松开手指，取消发送");
                    AnimationDrawable animationDrawable2 = (AnimationDrawable) audioDialogManager2.mVoice.getBackground();
                    if (animationDrawable2.isRunning()) {
                        animationDrawable2.stop();
                    }
                }
            }
        }
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        int action = motionEvent.getAction();
        int x = (int) motionEvent.getX();
        int y = (int) motionEvent.getY();
        if (action != 0) {
            boolean z = false;
            if (action != 1) {
                if (action == 2 && this.isRecording) {
                    if (x < 0 || x > getWidth() || y < -50 || y > getWidth() + 50) {
                        z = true;
                    }
                    if (z) {
                        changeState(3);
                    } else {
                        changeState(2);
                    }
                }
            } else if (!this.mReady) {
                this.isRecording = false;
                this.mTime = 0.0f;
                this.mReady = false;
                changeState(1);
                return super.onTouchEvent(motionEvent);
            } else if (!this.isRecording || this.mTime < this.shortTime) {
                AudioDialogManager audioDialogManager = this.mDialogManager;
                Dialog dialog = audioDialogManager.mDialog;
                if (dialog != null && dialog.isShowing()) {
                    audioDialogManager.mIcon.setVisibility(0);
                    audioDialogManager.mVoice.setVisibility(8);
                    audioDialogManager.mLabel.setVisibility(0);
                    audioDialogManager.mIcon.setImageResource(R.drawable.kefu_audio_to_short);
                    audioDialogManager.mLabel.setText("录音时间过短");
                }
                AudioRecorder audioRecorder = this.mAudioRecorder;
                audioRecorder.pcmFiles.clear();
                AudioRecord audioRecord = audioRecorder.audioRecord;
                if (audioRecord != null) {
                    audioRecord.release();
                    audioRecorder.audioRecord = null;
                }
                audioRecorder.status = AudioRecorder.Status.STATUS_NO_READY;
                this.mHandler.sendEmptyMessageDelayed(274, 1300);
            } else {
                int i = this.mState;
                if (i == 2) {
                    this.mDialogManager.dismissDialog();
                    AudioRecorder audioRecorder2 = this.mAudioRecorder;
                    Objects.requireNonNull(audioRecorder2);
                    Log.d("AudioRecorder", "===stopRecord===");
                    AudioRecorder.Status status = audioRecorder2.status;
                    AudioRecorder.Status status2 = AudioRecorder.Status.STATUS_NO_READY;
                    if (status == status2 || status == AudioRecorder.Status.STATUS_READY) {
                        throw new IllegalStateException("录音尚未开始");
                    }
                    audioRecorder2.status = AudioRecorder.Status.STATUS_STOP;
                    audioRecorder2.audioRecord.stop();
                    Log.d("AudioRecorder", "===release===");
                    AudioRecord audioRecord2 = audioRecorder2.audioRecord;
                    if (audioRecord2 != null) {
                        audioRecord2.release();
                        audioRecorder2.audioRecord = null;
                    }
                    audioRecorder2.status = status2;
                } else if (i == 3) {
                    this.mDialogManager.dismissDialog();
                    AudioRecorder audioRecorder3 = this.mAudioRecorder;
                    audioRecorder3.pcmFiles.clear();
                    AudioRecord audioRecord3 = audioRecorder3.audioRecord;
                    if (audioRecord3 != null) {
                        audioRecord3.release();
                        audioRecorder3.audioRecord = null;
                    }
                    audioRecorder3.status = AudioRecorder.Status.STATUS_NO_READY;
                }
            }
        } else {
            changeState(2);
        }
        return super.onTouchEvent(motionEvent);
    }

    public void setOnAudioRecorderListener(AudioRecorderListener audioRecorderListener) {
        this.onAudioRecorderListener = audioRecorderListener;
    }

    public AudioRecorderButton(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.mState = 1;
        this.isRecording = false;
        this.shortTime = 1.0f;
        this.mGetVoiceLevelRunnable = new Runnable() {
            /* class com.audio.view.AudioRecorderButton.AnonymousClass2 */

            public void run() {
                while (AudioRecorderButton.this.isRecording) {
                    try {
                        Thread.sleep(100);
                        AudioRecorderButton audioRecorderButton = AudioRecorderButton.this;
                        audioRecorderButton.mTime += 0.1f;
                        audioRecorderButton.mHandler.sendEmptyMessage(273);
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }
            }
        };
        this.mHandler = new Handler(Looper.getMainLooper()) {
            /* class com.audio.view.AudioRecorderButton.AnonymousClass3 */

            public void handleMessage(Message message) {
                switch (message.what) {
                    case 272:
                        AudioDialogManager audioDialogManager = AudioRecorderButton.this.mDialogManager;
                        Objects.requireNonNull(audioDialogManager);
                        audioDialogManager.mDialog = new Dialog(audioDialogManager.mContext, R.style.Kefu_AudioDialog_Theme);
                        audioDialogManager.mDialog.setContentView(LayoutInflater.from(audioDialogManager.mContext).inflate(R.layout.kefu_dialog_audio, (ViewGroup) null));
                        audioDialogManager.mIcon = (ImageView) audioDialogManager.mDialog.findViewById(R.id.id_recorder_dialog_icon);
                        audioDialogManager.mVoice = (ImageView) audioDialogManager.mDialog.findViewById(R.id.id_recorder_dialog_voice);
                        audioDialogManager.mLabel = (TextView) audioDialogManager.mDialog.findViewById(R.id.id_recorder_dialog_label);
                        audioDialogManager.mDialog.show();
                        ((AnimationDrawable) audioDialogManager.mVoice.getBackground()).start();
                        AudioRecorderButton.this.isRecording = true;
                        new Thread(AudioRecorderButton.this.mGetVoiceLevelRunnable).start();
                        break;
                    case 273:
                        Objects.requireNonNull(AudioRecorderButton.this.mDialogManager);
                        break;
                    case 274:
                        AudioRecorderButton.this.mDialogManager.dismissDialog();
                        break;
                }
                super.handleMessage(message);
            }
        };
        this.mDialogManager = new AudioDialogManager(context);
        if (ViewGroupUtilsApi14.instance == null) {
            ViewGroupUtilsApi14.instance = new AudioRecorder(context, null);
        }
        AudioRecorder audioRecorder = ViewGroupUtilsApi14.instance;
        this.mAudioRecorder = audioRecorder;
        audioRecorder.mStateListener = new AudioRecorder.StateListener() {
            /* class com.audio.view.AudioRecorderButton.AnonymousClass1 */
        };
        setOnLongClickListener(new View.OnLongClickListener(context) {
            /* class com.audio.view.$$Lambda$AudioRecorderButton$QoE3zZ6A2NljwjAAvGD7f8XZ_o */
            public final /* synthetic */ Context f$1;

            {
                this.f$1 = r2;
            }

            public final boolean onLongClick(View view) {
                AudioRecorderButton audioRecorderButton = AudioRecorderButton.this;
                Context context = this.f$1;
                Objects.requireNonNull(audioRecorderButton);
                if (PermissionHelper.hasPermissions(context, new String[]{"android.permission.RECORD_AUDIO", "android.permission.WRITE_EXTERNAL_STORAGE", "android.permission.READ_EXTERNAL_STORAGE"})) {
                    audioRecorderButton.mReady = true;
                    AudioRecorder audioRecorder = audioRecorderButton.mAudioRecorder;
                    Objects.requireNonNull(audioRecorder);
                    audioRecorder.bufferSizeInBytes = AudioRecord.getMinBufferSize(8000, 16, 2);
                    audioRecorder.audioRecord = new AudioRecord(1, 8000, 16, 2, audioRecorder.bufferSizeInBytes);
                    audioRecorder.outputFile = context.getCacheDir() + "/audios/" + DateHelper.currentTimeMillis();
                    audioRecorder.status = AudioRecorder.Status.STATUS_READY;
                    AudioRecorder audioRecorder2 = audioRecorderButton.mAudioRecorder;
                    if (audioRecorder2.status == AudioRecorder.Status.STATUS_NO_READY || TextUtils.isEmpty(audioRecorder2.outputFile)) {
                        throw new IllegalStateException("录音尚未初始化,请检查是否禁止了录音权限~");
                    } else if (audioRecorder2.status != AudioRecorder.Status.STATUS_START) {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("===startRecord===");
                        outline25.append(audioRecorder2.audioRecord.getState());
                        Log.d("AudioRecorder", outline25.toString());
                        audioRecorder2.audioRecord.startRecording();
                        AudioRecorder.StateListener stateListener = audioRecorder2.mStateListener;
                        if (stateListener != null) {
                            AudioRecorderButton.this.mHandler.sendEmptyMessage(272);
                        }
                        new Thread(
                        /*  JADX ERROR: Method code generation error
                            jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x00a8: INVOKE  
                              (wrap: java.lang.Thread : 0x00a5: CONSTRUCTOR  (r0v16 java.lang.Thread) = 
                              (wrap: com.audio.record.AudioRecorder$1 : 0x00a2: CONSTRUCTOR  (r1v11 com.audio.record.AudioRecorder$1) = (r10v4 'audioRecorder2' com.audio.record.AudioRecorder) call: com.audio.record.AudioRecorder.1.<init>(com.audio.record.AudioRecorder):void type: CONSTRUCTOR)
                             call: java.lang.Thread.<init>(java.lang.Runnable):void type: CONSTRUCTOR)
                             type: VIRTUAL call: java.lang.Thread.start():void in method: com.audio.view.-$$Lambda$AudioRecorderButton$QoE-3zZ6A2NljwjAAvGD7f8XZ_o.onLongClick(android.view.View):boolean, file: classes.dex
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                            	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.connectElseIf(RegionGen.java:176)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:153)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                            	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                            	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                            	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                            	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                            	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                            	at java.util.ArrayList.forEach(ArrayList.java:1259)
                            	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                            	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                            Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x00a5: CONSTRUCTOR  (r0v16 java.lang.Thread) = 
                              (wrap: com.audio.record.AudioRecorder$1 : 0x00a2: CONSTRUCTOR  (r1v11 com.audio.record.AudioRecorder$1) = (r10v4 'audioRecorder2' com.audio.record.AudioRecorder) call: com.audio.record.AudioRecorder.1.<init>(com.audio.record.AudioRecorder):void type: CONSTRUCTOR)
                             call: java.lang.Thread.<init>(java.lang.Runnable):void type: CONSTRUCTOR in method: com.audio.view.-$$Lambda$AudioRecorderButton$QoE-3zZ6A2NljwjAAvGD7f8XZ_o.onLongClick(android.view.View):boolean, file: classes.dex
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                            	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                            	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                            	at jadx.core.codegen.InsnGen.addArgDot(InsnGen.java:87)
                            	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:715)
                            	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                            	... 26 more
                            Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x00a2: CONSTRUCTOR  (r1v11 com.audio.record.AudioRecorder$1) = (r10v4 'audioRecorder2' com.audio.record.AudioRecorder) call: com.audio.record.AudioRecorder.1.<init>(com.audio.record.AudioRecorder):void type: CONSTRUCTOR in method: com.audio.view.-$$Lambda$AudioRecorderButton$QoE-3zZ6A2NljwjAAvGD7f8XZ_o.onLongClick(android.view.View):boolean, file: classes.dex
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                            	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                            	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                            	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                            	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:663)
                            	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                            	... 32 more
                            Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: com.audio.record.AudioRecorder, state: GENERATED_AND_UNLOADED
                            	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                            	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                            	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                            	... 38 more
                            */
                        /*
                        // Method dump skipped, instructions count: 195
                        */
                        throw new UnsupportedOperationException("Method not decompiled: com.audio.view.$$Lambda$AudioRecorderButton$QoE3zZ6A2NljwjAAvGD7f8XZ_o.onLongClick(android.view.View):boolean");
                    }
                });
            }
        }
