package com.bumptech.glide;

import android.content.ComponentCallbacks2;
import android.content.ContentResolver;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.content.res.AssetFileDescriptor;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import android.os.ParcelFileDescriptor;
import android.text.TextUtils;
import android.util.Log;
import androidx.fragment.app.FragmentActivity;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.GlideBuilder;
import com.bumptech.glide.GlideExperiments;
import com.bumptech.glide.gifdecoder.GifDecoder;
import com.bumptech.glide.load.ImageHeaderParser;
import com.bumptech.glide.load.ResourceDecoder;
import com.bumptech.glide.load.ResourceEncoder;
import com.bumptech.glide.load.data.InputStreamRewinder;
import com.bumptech.glide.load.data.ParcelFileDescriptorRewinder;
import com.bumptech.glide.load.engine.Engine;
import com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool;
import com.bumptech.glide.load.engine.bitmap_recycle.BitmapPoolAdapter;
import com.bumptech.glide.load.engine.bitmap_recycle.LruArrayPool;
import com.bumptech.glide.load.engine.bitmap_recycle.LruBitmapPool;
import com.bumptech.glide.load.engine.cache.InternalCacheDiskCacheFactory;
import com.bumptech.glide.load.engine.cache.LruResourceCache;
import com.bumptech.glide.load.engine.cache.MemorySizeCalculator;
import com.bumptech.glide.load.engine.executor.GlideExecutor;
import com.bumptech.glide.load.model.AssetUriLoader;
import com.bumptech.glide.load.model.ByteArrayLoader;
import com.bumptech.glide.load.model.ByteBufferEncoder;
import com.bumptech.glide.load.model.ByteBufferFileLoader;
import com.bumptech.glide.load.model.DataUrlLoader;
import com.bumptech.glide.load.model.FileLoader;
import com.bumptech.glide.load.model.GlideUrl;
import com.bumptech.glide.load.model.MediaStoreFileLoader;
import com.bumptech.glide.load.model.ResourceLoader;
import com.bumptech.glide.load.model.StreamEncoder;
import com.bumptech.glide.load.model.StringLoader;
import com.bumptech.glide.load.model.UnitModelLoader;
import com.bumptech.glide.load.model.UriLoader;
import com.bumptech.glide.load.model.UrlUriLoader;
import com.bumptech.glide.load.model.stream.HttpGlideUrlLoader;
import com.bumptech.glide.load.model.stream.MediaStoreImageThumbLoader;
import com.bumptech.glide.load.model.stream.MediaStoreVideoThumbLoader;
import com.bumptech.glide.load.model.stream.QMediaStoreUriLoader;
import com.bumptech.glide.load.model.stream.UrlLoader;
import com.bumptech.glide.load.resource.bitmap.BitmapDrawableDecoder;
import com.bumptech.glide.load.resource.bitmap.BitmapDrawableEncoder;
import com.bumptech.glide.load.resource.bitmap.BitmapEncoder;
import com.bumptech.glide.load.resource.bitmap.ByteBufferBitmapDecoder;
import com.bumptech.glide.load.resource.bitmap.ByteBufferBitmapImageDecoderResourceDecoder;
import com.bumptech.glide.load.resource.bitmap.DefaultImageHeaderParser;
import com.bumptech.glide.load.resource.bitmap.Downsampler;
import com.bumptech.glide.load.resource.bitmap.ExifInterfaceImageHeaderParser;
import com.bumptech.glide.load.resource.bitmap.InputStreamBitmapImageDecoderResourceDecoder;
import com.bumptech.glide.load.resource.bitmap.ParcelFileDescriptorBitmapDecoder;
import com.bumptech.glide.load.resource.bitmap.ResourceBitmapDecoder;
import com.bumptech.glide.load.resource.bitmap.StreamBitmapDecoder;
import com.bumptech.glide.load.resource.bitmap.UnitBitmapDecoder;
import com.bumptech.glide.load.resource.bitmap.VideoDecoder;
import com.bumptech.glide.load.resource.bytes.ByteBufferRewinder;
import com.bumptech.glide.load.resource.drawable.ResourceDrawableDecoder;
import com.bumptech.glide.load.resource.drawable.UnitDrawableDecoder;
import com.bumptech.glide.load.resource.file.FileDecoder;
import com.bumptech.glide.load.resource.gif.ByteBufferGifDecoder;
import com.bumptech.glide.load.resource.gif.GifDrawable;
import com.bumptech.glide.load.resource.gif.GifDrawableEncoder;
import com.bumptech.glide.load.resource.gif.GifFrameResourceDecoder;
import com.bumptech.glide.load.resource.gif.StreamGifDecoder;
import com.bumptech.glide.load.resource.transcode.BitmapBytesTranscoder;
import com.bumptech.glide.load.resource.transcode.BitmapDrawableTranscoder;
import com.bumptech.glide.load.resource.transcode.DrawableBytesTranscoder;
import com.bumptech.glide.load.resource.transcode.GifDrawableBytesTranscoder;
import com.bumptech.glide.manager.DefaultConnectivityMonitorFactory;
import com.bumptech.glide.manager.RequestManagerRetriever;
import com.bumptech.glide.module.GlideModule;
import com.bumptech.glide.module.ManifestParser;
import com.bumptech.glide.provider.ImageHeaderParserRegistry;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.target.ImageViewTargetFactory;
import com.bumptech.glide.util.Util;
import java.io.File;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.net.URL;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.concurrent.PriorityBlockingQueue;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

public class Glide implements ComponentCallbacks2 {
    public static volatile Glide glide;
    public static volatile boolean isInitializing;
    public final LruArrayPool arrayPool;
    public final BitmapPool bitmapPool;
    public final DefaultConnectivityMonitorFactory connectivityMonitorFactory;
    public final GlideContext glideContext;
    public final List<RequestManager> managers = new ArrayList();
    public final LruResourceCache memoryCache;
    public final Registry registry;
    public final RequestManagerRetriever requestManagerRetriever;

    public Glide(Context context, Engine engine, LruResourceCache lruResourceCache, BitmapPool bitmapPool2, LruArrayPool lruArrayPool, RequestManagerRetriever requestManagerRetriever2, DefaultConnectivityMonitorFactory defaultConnectivityMonitorFactory, int i, GlideBuilder.AnonymousClass1 r35, Map<Class<?>, GenericTransitionOptions<?, ?>> map, List<RequestListener<Object>> list, GlideExperiments glideExperiments) {
        ResourceDecoder resourceDecoder;
        ResourceDecoder resourceDecoder2;
        this.bitmapPool = bitmapPool2;
        this.arrayPool = lruArrayPool;
        this.memoryCache = lruResourceCache;
        this.requestManagerRetriever = requestManagerRetriever2;
        this.connectivityMonitorFactory = defaultConnectivityMonitorFactory;
        Resources resources = context.getResources();
        Registry registry2 = new Registry();
        this.registry = registry2;
        DefaultImageHeaderParser defaultImageHeaderParser = new DefaultImageHeaderParser();
        ImageHeaderParserRegistry imageHeaderParserRegistry = registry2.imageHeaderParserRegistry;
        synchronized (imageHeaderParserRegistry) {
            imageHeaderParserRegistry.parsers.add(defaultImageHeaderParser);
        }
        int i2 = Build.VERSION.SDK_INT;
        if (i2 >= 27) {
            ExifInterfaceImageHeaderParser exifInterfaceImageHeaderParser = new ExifInterfaceImageHeaderParser();
            ImageHeaderParserRegistry imageHeaderParserRegistry2 = registry2.imageHeaderParserRegistry;
            synchronized (imageHeaderParserRegistry2) {
                imageHeaderParserRegistry2.parsers.add(exifInterfaceImageHeaderParser);
            }
        }
        List<ImageHeaderParser> imageHeaderParsers = registry2.getImageHeaderParsers();
        ByteBufferGifDecoder byteBufferGifDecoder = new ByteBufferGifDecoder(context, imageHeaderParsers, bitmapPool2, lruArrayPool);
        VideoDecoder videoDecoder = new VideoDecoder(bitmapPool2, new VideoDecoder.ParcelFileDescriptorInitializer());
        Downsampler downsampler = new Downsampler(registry2.getImageHeaderParsers(), resources.getDisplayMetrics(), bitmapPool2, lruArrayPool);
        if (!glideExperiments.experiments.containsKey(GlideBuilder.EnableImageDecoderForBitmaps.class) || i2 < 28) {
            resourceDecoder = new ByteBufferBitmapDecoder(downsampler);
            resourceDecoder2 = new StreamBitmapDecoder(downsampler, lruArrayPool);
        } else {
            resourceDecoder2 = new InputStreamBitmapImageDecoderResourceDecoder();
            resourceDecoder = new ByteBufferBitmapImageDecoderResourceDecoder();
        }
        ResourceDrawableDecoder resourceDrawableDecoder = new ResourceDrawableDecoder(context);
        ResourceLoader.StreamFactory streamFactory = new ResourceLoader.StreamFactory(resources);
        ResourceLoader.UriFactory uriFactory = new ResourceLoader.UriFactory(resources);
        ResourceLoader.FileDescriptorFactory fileDescriptorFactory = new ResourceLoader.FileDescriptorFactory(resources);
        ResourceLoader.AssetFileDescriptorFactory assetFileDescriptorFactory = new ResourceLoader.AssetFileDescriptorFactory(resources);
        BitmapEncoder bitmapEncoder = new BitmapEncoder(lruArrayPool);
        BitmapBytesTranscoder bitmapBytesTranscoder = new BitmapBytesTranscoder();
        GifDrawableBytesTranscoder gifDrawableBytesTranscoder = new GifDrawableBytesTranscoder();
        ContentResolver contentResolver = context.getContentResolver();
        registry2.append(ByteBuffer.class, new ByteBufferEncoder());
        registry2.append(InputStream.class, new StreamEncoder(lruArrayPool));
        registry2.append("Bitmap", ByteBuffer.class, Bitmap.class, resourceDecoder);
        registry2.append("Bitmap", InputStream.class, Bitmap.class, resourceDecoder2);
        registry2.append("Bitmap", ParcelFileDescriptor.class, Bitmap.class, new ParcelFileDescriptorBitmapDecoder(downsampler));
        registry2.append("Bitmap", ParcelFileDescriptor.class, Bitmap.class, videoDecoder);
        registry2.append("Bitmap", AssetFileDescriptor.class, Bitmap.class, new VideoDecoder(bitmapPool2, new VideoDecoder.AssetFileDescriptorInitializer(null)));
        UnitModelLoader.Factory<?> factory = UnitModelLoader.Factory.FACTORY;
        registry2.append(Bitmap.class, Bitmap.class, factory);
        registry2.append("Bitmap", Bitmap.class, Bitmap.class, new UnitBitmapDecoder());
        registry2.append(Bitmap.class, (ResourceEncoder) bitmapEncoder);
        registry2.append("BitmapDrawable", ByteBuffer.class, BitmapDrawable.class, new BitmapDrawableDecoder(resources, resourceDecoder));
        registry2.append("BitmapDrawable", InputStream.class, BitmapDrawable.class, new BitmapDrawableDecoder(resources, resourceDecoder2));
        registry2.append("BitmapDrawable", ParcelFileDescriptor.class, BitmapDrawable.class, new BitmapDrawableDecoder(resources, videoDecoder));
        registry2.append(BitmapDrawable.class, (ResourceEncoder) new BitmapDrawableEncoder(bitmapPool2, bitmapEncoder));
        registry2.append("Gif", InputStream.class, GifDrawable.class, new StreamGifDecoder(imageHeaderParsers, byteBufferGifDecoder, lruArrayPool));
        registry2.append("Gif", ByteBuffer.class, GifDrawable.class, byteBufferGifDecoder);
        registry2.append(GifDrawable.class, (ResourceEncoder) new GifDrawableEncoder());
        registry2.append(GifDecoder.class, GifDecoder.class, factory);
        registry2.append("Bitmap", GifDecoder.class, Bitmap.class, new GifFrameResourceDecoder(bitmapPool2));
        registry2.append("legacy_append", Uri.class, Drawable.class, resourceDrawableDecoder);
        registry2.append("legacy_append", Uri.class, Bitmap.class, new ResourceBitmapDecoder(resourceDrawableDecoder, bitmapPool2));
        registry2.register(new ByteBufferRewinder.Factory());
        registry2.append(File.class, ByteBuffer.class, new ByteBufferFileLoader.Factory());
        registry2.append(File.class, InputStream.class, new FileLoader.StreamFactory());
        registry2.append("legacy_append", File.class, File.class, new FileDecoder());
        registry2.append(File.class, ParcelFileDescriptor.class, new FileLoader.FileDescriptorFactory());
        registry2.append(File.class, File.class, factory);
        registry2.register(new InputStreamRewinder.Factory(lruArrayPool));
        registry2.register(new ParcelFileDescriptorRewinder.Factory());
        Class cls = Integer.TYPE;
        registry2.append(cls, InputStream.class, streamFactory);
        registry2.append(cls, ParcelFileDescriptor.class, fileDescriptorFactory);
        registry2.append(Integer.class, InputStream.class, streamFactory);
        registry2.append(Integer.class, ParcelFileDescriptor.class, fileDescriptorFactory);
        registry2.append(Integer.class, Uri.class, uriFactory);
        registry2.append(cls, AssetFileDescriptor.class, assetFileDescriptorFactory);
        registry2.append(Integer.class, AssetFileDescriptor.class, assetFileDescriptorFactory);
        registry2.append(cls, Uri.class, uriFactory);
        registry2.append(String.class, InputStream.class, new DataUrlLoader.StreamFactory());
        registry2.append(Uri.class, InputStream.class, new DataUrlLoader.StreamFactory());
        registry2.append(String.class, InputStream.class, new StringLoader.StreamFactory());
        registry2.append(String.class, ParcelFileDescriptor.class, new StringLoader.FileDescriptorFactory());
        registry2.append(String.class, AssetFileDescriptor.class, new StringLoader.AssetFileDescriptorFactory());
        registry2.append(Uri.class, InputStream.class, new AssetUriLoader.StreamFactory(context.getAssets()));
        registry2.append(Uri.class, ParcelFileDescriptor.class, new AssetUriLoader.FileDescriptorFactory(context.getAssets()));
        registry2.append(Uri.class, InputStream.class, new MediaStoreImageThumbLoader.Factory(context));
        registry2.append(Uri.class, InputStream.class, new MediaStoreVideoThumbLoader.Factory(context));
        if (i2 >= 29) {
            registry2.append(Uri.class, InputStream.class, new QMediaStoreUriLoader.InputStreamFactory(context));
            registry2.append(Uri.class, ParcelFileDescriptor.class, new QMediaStoreUriLoader.FileDescriptorFactory(context));
        }
        registry2.append(Uri.class, InputStream.class, new UriLoader.StreamFactory(contentResolver));
        registry2.append(Uri.class, ParcelFileDescriptor.class, new UriLoader.FileDescriptorFactory(contentResolver));
        registry2.append(Uri.class, AssetFileDescriptor.class, new UriLoader.AssetFileDescriptorFactory(contentResolver));
        registry2.append(Uri.class, InputStream.class, new UrlUriLoader.StreamFactory());
        registry2.append(URL.class, InputStream.class, new UrlLoader.StreamFactory());
        registry2.append(Uri.class, File.class, new MediaStoreFileLoader.Factory(context));
        registry2.append(GlideUrl.class, InputStream.class, new HttpGlideUrlLoader.Factory());
        registry2.append(byte[].class, ByteBuffer.class, new ByteArrayLoader.ByteBufferFactory());
        registry2.append(byte[].class, InputStream.class, new ByteArrayLoader.StreamFactory());
        registry2.append(Uri.class, Uri.class, factory);
        registry2.append(Drawable.class, Drawable.class, factory);
        registry2.append("legacy_append", Drawable.class, Drawable.class, new UnitDrawableDecoder());
        registry2.register(Bitmap.class, BitmapDrawable.class, new BitmapDrawableTranscoder(resources));
        registry2.register(Bitmap.class, byte[].class, bitmapBytesTranscoder);
        registry2.register(Drawable.class, byte[].class, new DrawableBytesTranscoder(bitmapPool2, bitmapBytesTranscoder, gifDrawableBytesTranscoder));
        registry2.register(GifDrawable.class, byte[].class, gifDrawableBytesTranscoder);
        if (i2 >= 23) {
            VideoDecoder videoDecoder2 = new VideoDecoder(bitmapPool2, new VideoDecoder.ByteBufferInitializer());
            registry2.append("legacy_append", ByteBuffer.class, Bitmap.class, videoDecoder2);
            registry2.append("legacy_append", ByteBuffer.class, BitmapDrawable.class, new BitmapDrawableDecoder(resources, videoDecoder2));
        }
        this.glideContext = new GlideContext(context, lruArrayPool, registry2, new ImageViewTargetFactory(), r35, map, list, engine, glideExperiments, i);
    }

    public static void checkAndInitializeGlide(Context context, GeneratedAppGlideModule generatedAppGlideModule) {
        if (!isInitializing) {
            isInitializing = true;
            GlideBuilder glideBuilder = new GlideBuilder();
            Context applicationContext = context.getApplicationContext();
            Collections.emptyList();
            if (Log.isLoggable("ManifestParser", 3)) {
                Log.d("ManifestParser", "Loading Glide modules");
            }
            ArrayList arrayList = new ArrayList();
            try {
                ApplicationInfo applicationInfo = applicationContext.getPackageManager().getApplicationInfo(applicationContext.getPackageName(), 128);
                if (applicationInfo.metaData != null) {
                    if (Log.isLoggable("ManifestParser", 2)) {
                        Log.v("ManifestParser", "Got app info metadata: " + applicationInfo.metaData);
                    }
                    for (String str : applicationInfo.metaData.keySet()) {
                        if ("GlideModule".equals(applicationInfo.metaData.get(str))) {
                            ManifestParser.parseModule(str);
                            throw null;
                        }
                    }
                    if (Log.isLoggable("ManifestParser", 3)) {
                        Log.d("ManifestParser", "Finished loading Glide modules");
                    }
                } else if (Log.isLoggable("ManifestParser", 3)) {
                    Log.d("ManifestParser", "Got null app info metadata");
                }
                if (generatedAppGlideModule != null && !generatedAppGlideModule.getExcludedModuleClasses().isEmpty()) {
                    Set<Class<?>> excludedModuleClasses = generatedAppGlideModule.getExcludedModuleClasses();
                    Iterator it = arrayList.iterator();
                    while (it.hasNext()) {
                        GlideModule glideModule = (GlideModule) it.next();
                        if (excludedModuleClasses.contains(glideModule.getClass())) {
                            if (Log.isLoggable("Glide", 3)) {
                                Log.d("Glide", "AppGlideModule excludes manifest GlideModule: " + glideModule);
                            }
                            it.remove();
                        }
                    }
                }
                if (Log.isLoggable("Glide", 3)) {
                    Iterator it2 = arrayList.iterator();
                    while (it2.hasNext()) {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Discovered GlideModule from manifest: ");
                        outline25.append(((GlideModule) it2.next()).getClass());
                        Log.d("Glide", outline25.toString());
                    }
                }
                glideBuilder.requestManagerFactory = null;
                Iterator it3 = arrayList.iterator();
                while (it3.hasNext()) {
                    ((GlideModule) it3.next()).applyOptions(applicationContext, glideBuilder);
                }
                if (glideBuilder.sourceExecutor == null) {
                    int calculateBestThreadCount = GlideExecutor.calculateBestThreadCount();
                    if (!TextUtils.isEmpty("source")) {
                        glideBuilder.sourceExecutor = new GlideExecutor(new ThreadPoolExecutor(calculateBestThreadCount, calculateBestThreadCount, 0, TimeUnit.MILLISECONDS, new PriorityBlockingQueue(), new GlideExecutor.DefaultThreadFactory("source", GlideExecutor.UncaughtThrowableStrategy.DEFAULT, false)));
                    } else {
                        throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("Name must be non-null and non-empty, but given: ", "source"));
                    }
                }
                if (glideBuilder.diskCacheExecutor == null) {
                    int i = GlideExecutor.bestThreadCount;
                    if (!TextUtils.isEmpty("disk-cache")) {
                        glideBuilder.diskCacheExecutor = new GlideExecutor(new ThreadPoolExecutor(1, 1, 0, TimeUnit.MILLISECONDS, new PriorityBlockingQueue(), new GlideExecutor.DefaultThreadFactory("disk-cache", GlideExecutor.UncaughtThrowableStrategy.DEFAULT, true)));
                    } else {
                        throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("Name must be non-null and non-empty, but given: ", "disk-cache"));
                    }
                }
                if (glideBuilder.animationExecutor == null) {
                    int i2 = GlideExecutor.calculateBestThreadCount() >= 4 ? 2 : 1;
                    if (!TextUtils.isEmpty("animation")) {
                        glideBuilder.animationExecutor = new GlideExecutor(new ThreadPoolExecutor(i2, i2, 0, TimeUnit.MILLISECONDS, new PriorityBlockingQueue(), new GlideExecutor.DefaultThreadFactory("animation", GlideExecutor.UncaughtThrowableStrategy.DEFAULT, true)));
                    } else {
                        throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("Name must be non-null and non-empty, but given: ", "animation"));
                    }
                }
                if (glideBuilder.memorySizeCalculator == null) {
                    glideBuilder.memorySizeCalculator = new MemorySizeCalculator(new MemorySizeCalculator.Builder(applicationContext));
                }
                if (glideBuilder.connectivityMonitorFactory == null) {
                    glideBuilder.connectivityMonitorFactory = new DefaultConnectivityMonitorFactory();
                }
                if (glideBuilder.bitmapPool == null) {
                    int i3 = glideBuilder.memorySizeCalculator.bitmapPoolSize;
                    if (i3 > 0) {
                        glideBuilder.bitmapPool = new LruBitmapPool((long) i3);
                    } else {
                        glideBuilder.bitmapPool = new BitmapPoolAdapter();
                    }
                }
                if (glideBuilder.arrayPool == null) {
                    glideBuilder.arrayPool = new LruArrayPool(glideBuilder.memorySizeCalculator.arrayPoolSize);
                }
                if (glideBuilder.memoryCache == null) {
                    glideBuilder.memoryCache = new LruResourceCache((long) glideBuilder.memorySizeCalculator.memoryCacheSize);
                }
                if (glideBuilder.diskCacheFactory == null) {
                    glideBuilder.diskCacheFactory = new InternalCacheDiskCacheFactory(applicationContext);
                }
                if (glideBuilder.engine == null) {
                    glideBuilder.engine = new Engine(glideBuilder.memoryCache, glideBuilder.diskCacheFactory, glideBuilder.diskCacheExecutor, glideBuilder.sourceExecutor, new GlideExecutor(new ThreadPoolExecutor(0, Integer.MAX_VALUE, GlideExecutor.KEEP_ALIVE_TIME_MS, TimeUnit.MILLISECONDS, new SynchronousQueue(), new GlideExecutor.DefaultThreadFactory("source-unlimited", GlideExecutor.UncaughtThrowableStrategy.DEFAULT, false))), glideBuilder.animationExecutor, false);
                }
                List<RequestListener<Object>> list = glideBuilder.defaultRequestListeners;
                if (list == null) {
                    glideBuilder.defaultRequestListeners = Collections.emptyList();
                } else {
                    glideBuilder.defaultRequestListeners = Collections.unmodifiableList(list);
                }
                GlideExperiments.Builder builder = glideBuilder.glideExperimentsBuilder;
                Objects.requireNonNull(builder);
                GlideExperiments glideExperiments = new GlideExperiments(builder);
                Glide glide2 = new Glide(applicationContext, glideBuilder.engine, glideBuilder.memoryCache, glideBuilder.bitmapPool, glideBuilder.arrayPool, new RequestManagerRetriever(glideBuilder.requestManagerFactory, glideExperiments), glideBuilder.connectivityMonitorFactory, glideBuilder.logLevel, glideBuilder.defaultRequestOptionsFactory, glideBuilder.defaultTransitionOptions, glideBuilder.defaultRequestListeners, glideExperiments);
                Iterator it4 = arrayList.iterator();
                while (it4.hasNext()) {
                    GlideModule glideModule2 = (GlideModule) it4.next();
                    try {
                        glideModule2.registerComponents(applicationContext, glide2, glide2.registry);
                    } catch (AbstractMethodError e) {
                        StringBuilder outline252 = GeneratedOutlineSupport.outline25("Attempting to register a Glide v3 module. If you see this, you or one of your dependencies may be including Glide v3 even though you're using Glide v4. You'll need to find and remove (or update) the offending dependency. The v3 module name is: ");
                        outline252.append(glideModule2.getClass().getName());
                        throw new IllegalStateException(outline252.toString(), e);
                    }
                }
                applicationContext.registerComponentCallbacks(glide2);
                glide = glide2;
                isInitializing = false;
            } catch (PackageManager.NameNotFoundException e2) {
                throw new RuntimeException("Unable to find metadata to parse GlideModules", e2);
            }
        } else {
            throw new IllegalStateException("You cannot call Glide.get() in registerComponents(), use the provided Glide instance instead");
        }
    }

    public static Glide get(Context context) {
        if (glide == null) {
            Context applicationContext = context.getApplicationContext();
            GeneratedAppGlideModule generatedAppGlideModule = null;
            try {
                generatedAppGlideModule = (GeneratedAppGlideModule) Class.forName("com.bumptech.glide.GeneratedAppGlideModuleImpl").getDeclaredConstructor(Context.class).newInstance(applicationContext.getApplicationContext());
            } catch (ClassNotFoundException unused) {
                if (Log.isLoggable("Glide", 5)) {
                    Log.w("Glide", "Failed to find GeneratedAppGlideModule. You should include an annotationProcessor compile dependency on com.github.bumptech.glide:compiler in your application and a @GlideModule annotated AppGlideModule implementation or LibraryGlideModules will be silently ignored");
                }
            } catch (InstantiationException e) {
                throwIncorrectGlideModule(e);
                throw null;
            } catch (IllegalAccessException e2) {
                throwIncorrectGlideModule(e2);
                throw null;
            } catch (NoSuchMethodException e3) {
                throwIncorrectGlideModule(e3);
                throw null;
            } catch (InvocationTargetException e4) {
                throwIncorrectGlideModule(e4);
                throw null;
            }
            synchronized (Glide.class) {
                if (glide == null) {
                    checkAndInitializeGlide(context, generatedAppGlideModule);
                }
            }
        }
        return glide;
    }

    public static void throwIncorrectGlideModule(Exception exc) {
        throw new IllegalStateException("GeneratedAppGlideModuleImpl is implemented incorrectly. If you've manually implemented this class, remove your implementation. The Annotation processor will generate a correct implementation.", exc);
    }

    public static RequestManager with(Context context) {
        Objects.requireNonNull(context, "You cannot start a load on a not yet attached View or a Fragment where getActivity() returns null (which usually occurs when getActivity() is called before the Fragment is attached or after the Fragment is destroyed).");
        return get(context).requestManagerRetriever.get(context);
    }

    public void onConfigurationChanged(Configuration configuration) {
    }

    public void onLowMemory() {
        Util.assertMainThread();
        this.memoryCache.trimToSize(0);
        this.bitmapPool.clearMemory();
        LruArrayPool lruArrayPool = this.arrayPool;
        synchronized (lruArrayPool) {
            lruArrayPool.evictToSize(0);
        }
    }

    public void onTrimMemory(int i) {
        long j;
        Util.assertMainThread();
        synchronized (this.managers) {
            for (RequestManager requestManager : this.managers) {
                Objects.requireNonNull(requestManager);
            }
        }
        LruResourceCache lruResourceCache = this.memoryCache;
        Objects.requireNonNull(lruResourceCache);
        if (i >= 40) {
            lruResourceCache.trimToSize(0);
        } else if (i >= 20 || i == 15) {
            synchronized (lruResourceCache) {
                j = lruResourceCache.maxSize;
            }
            lruResourceCache.trimToSize(j / 2);
        }
        this.bitmapPool.trimMemory(i);
        LruArrayPool lruArrayPool = this.arrayPool;
        synchronized (lruArrayPool) {
            if (i >= 40) {
                synchronized (lruArrayPool) {
                    lruArrayPool.evictToSize(0);
                }
            } else if (i >= 20 || i == 15) {
                lruArrayPool.evictToSize(lruArrayPool.maxSize / 2);
            }
        }
    }

    public static RequestManager with(FragmentActivity fragmentActivity) {
        Objects.requireNonNull(fragmentActivity, "You cannot start a load on a not yet attached View or a Fragment where getActivity() returns null (which usually occurs when getActivity() is called before the Fragment is attached or after the Fragment is destroyed).");
        return get(fragmentActivity).requestManagerRetriever.get(fragmentActivity);
    }
}
