package com.bumptech.glide.gifdecoder;

import android.graphics.Bitmap;
import android.util.Log;
import com.bumptech.glide.load.engine.bitmap_recycle.LruArrayPool;
import com.bumptech.glide.load.resource.gif.GifBitmapProvider;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.Arrays;
import java.util.Iterator;
import org.xbill.DNS.KEYRecord;

public class StandardGifDecoder implements GifDecoder {
    public int[] act;
    public Bitmap.Config bitmapConfig = Bitmap.Config.ARGB_8888;
    public final GifBitmapProvider bitmapProvider;
    public byte[] block;
    public int downsampledHeight;
    public int downsampledWidth;
    public int framePointer;
    public GifHeader header;
    public Boolean isFirstFrameTransparent;
    public byte[] mainPixels;
    public int[] mainScratch;
    public final int[] pct = new int[256];
    public byte[] pixelStack;
    public short[] prefix;
    public Bitmap previousImage;
    public ByteBuffer rawData;
    public int sampleSize;
    public boolean savePrevious;
    public int status;
    public byte[] suffix;

    public StandardGifDecoder(GifBitmapProvider gifBitmapProvider, GifHeader gifHeader, ByteBuffer byteBuffer, int i) {
        int[] iArr;
        this.bitmapProvider = gifBitmapProvider;
        this.header = new GifHeader();
        synchronized (this) {
            if (i > 0) {
                int highestOneBit = Integer.highestOneBit(i);
                this.status = 0;
                this.header = gifHeader;
                this.framePointer = -1;
                ByteBuffer asReadOnlyBuffer = byteBuffer.asReadOnlyBuffer();
                this.rawData = asReadOnlyBuffer;
                asReadOnlyBuffer.position(0);
                this.rawData.order(ByteOrder.LITTLE_ENDIAN);
                this.savePrevious = false;
                Iterator<GifFrame> it = gifHeader.frames.iterator();
                while (true) {
                    if (it.hasNext()) {
                        if (it.next().dispose == 3) {
                            this.savePrevious = true;
                            break;
                        }
                    } else {
                        break;
                    }
                }
                this.sampleSize = highestOneBit;
                int i2 = gifHeader.width;
                this.downsampledWidth = i2 / highestOneBit;
                int i3 = gifHeader.height;
                this.downsampledHeight = i3 / highestOneBit;
                this.mainPixels = this.bitmapProvider.obtainByteArray(i2 * i3);
                GifBitmapProvider gifBitmapProvider2 = this.bitmapProvider;
                int i4 = this.downsampledWidth * this.downsampledHeight;
                LruArrayPool lruArrayPool = gifBitmapProvider2.arrayPool;
                if (lruArrayPool == null) {
                    iArr = new int[i4];
                } else {
                    iArr = (int[]) lruArrayPool.get(i4, int[].class);
                }
                this.mainScratch = iArr;
            } else {
                throw new IllegalArgumentException("Sample size must be >=0, not: " + i);
            }
        }
    }

    public final Bitmap getNextBitmap() {
        Boolean bool = this.isFirstFrameTransparent;
        Bitmap.Config config = (bool == null || bool.booleanValue()) ? Bitmap.Config.ARGB_8888 : this.bitmapConfig;
        Bitmap dirty = this.bitmapProvider.bitmapPool.getDirty(this.downsampledWidth, this.downsampledHeight, config);
        dirty.setHasAlpha(true);
        return dirty;
    }

    public synchronized Bitmap getNextFrame() {
        if (this.header.frameCount <= 0 || this.framePointer < 0) {
            if (Log.isLoggable("StandardGifDecoder", 3)) {
                Log.d("StandardGifDecoder", "Unable to decode frame, frameCount=" + this.header.frameCount + ", framePointer=" + this.framePointer);
            }
            this.status = 1;
        }
        int i = this.status;
        if (i != 1) {
            if (i != 2) {
                this.status = 0;
                if (this.block == null) {
                    this.block = this.bitmapProvider.obtainByteArray(KEYRecord.PROTOCOL_ANY);
                }
                GifFrame gifFrame = this.header.frames.get(this.framePointer);
                int i2 = this.framePointer - 1;
                GifFrame gifFrame2 = i2 >= 0 ? this.header.frames.get(i2) : null;
                int[] iArr = gifFrame.lct;
                if (iArr == null) {
                    iArr = this.header.gct;
                }
                this.act = iArr;
                if (iArr == null) {
                    if (Log.isLoggable("StandardGifDecoder", 3)) {
                        Log.d("StandardGifDecoder", "No valid color table found for frame #" + this.framePointer);
                    }
                    this.status = 1;
                    return null;
                }
                if (gifFrame.transparency) {
                    System.arraycopy(iArr, 0, this.pct, 0, iArr.length);
                    int[] iArr2 = this.pct;
                    this.act = iArr2;
                    iArr2[gifFrame.transIndex] = 0;
                    if (gifFrame.dispose == 2 && this.framePointer == 0) {
                        this.isFirstFrameTransparent = Boolean.TRUE;
                    }
                }
                return setPixels(gifFrame, gifFrame2);
            }
        }
        if (Log.isLoggable("StandardGifDecoder", 3)) {
            Log.d("StandardGifDecoder", "Unable to decode frame, status=" + this.status);
        }
        return null;
    }

    public void setDefaultBitmapConfig(Bitmap.Config config) {
        if (config == Bitmap.Config.ARGB_8888 || config == Bitmap.Config.RGB_565) {
            this.bitmapConfig = config;
            return;
        }
        throw new IllegalArgumentException("Unsupported format: " + config + ", must be one of " + Bitmap.Config.ARGB_8888 + " or " + Bitmap.Config.RGB_565);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:23:0x0043, code lost:
        if (r3.bgIndex == r36.transIndex) goto L_0x0045;
     */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x005e  */
    public final Bitmap setPixels(GifFrame gifFrame, GifFrame gifFrame2) {
        int[] iArr;
        int i;
        boolean z;
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        short s;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        short s2;
        int i17;
        Bitmap bitmap;
        int i18;
        int i19;
        int i20;
        int[] iArr2 = this.mainScratch;
        if (gifFrame2 == null) {
            Bitmap bitmap2 = this.previousImage;
            if (bitmap2 != null) {
                this.bitmapProvider.bitmapPool.put(bitmap2);
            }
            this.previousImage = null;
            Arrays.fill(iArr2, 0);
        }
        if (gifFrame2 != null && gifFrame2.dispose == 3 && this.previousImage == null) {
            Arrays.fill(iArr2, 0);
        }
        if (gifFrame2 != null && (i17 = gifFrame2.dispose) > 0) {
            if (i17 == 2) {
                if (!gifFrame.transparency) {
                    GifHeader gifHeader = this.header;
                    i18 = gifHeader.bgColor;
                    if (gifFrame.lct != null) {
                    }
                    int i21 = gifFrame2.ih;
                    int i22 = this.sampleSize;
                    int i23 = i21 / i22;
                    int i24 = gifFrame2.iy / i22;
                    int i25 = gifFrame2.iw / i22;
                    int i26 = gifFrame2.ix / i22;
                    int i27 = this.downsampledWidth;
                    i19 = (i24 * i27) + i26;
                    i20 = (i23 * i27) + i19;
                    while (i19 < i20) {
                        int i28 = i19 + i25;
                        for (int i29 = i19; i29 < i28; i29++) {
                            iArr2[i29] = i18;
                        }
                        i19 += this.downsampledWidth;
                    }
                }
                i18 = 0;
                int i212 = gifFrame2.ih;
                int i222 = this.sampleSize;
                int i232 = i212 / i222;
                int i242 = gifFrame2.iy / i222;
                int i252 = gifFrame2.iw / i222;
                int i262 = gifFrame2.ix / i222;
                int i272 = this.downsampledWidth;
                i19 = (i242 * i272) + i262;
                i20 = (i232 * i272) + i19;
                while (i19 < i20) {
                }
            } else if (i17 == 3 && (bitmap = this.previousImage) != null) {
                int i30 = this.downsampledWidth;
                bitmap.getPixels(iArr2, 0, i30, 0, 0, i30, this.downsampledHeight);
            }
        }
        this.rawData.position(gifFrame.bufferFrameStart);
        int i31 = gifFrame.iw * gifFrame.ih;
        byte[] bArr = this.mainPixels;
        if (bArr == null || bArr.length < i31) {
            this.mainPixels = this.bitmapProvider.obtainByteArray(i31);
        }
        byte[] bArr2 = this.mainPixels;
        if (this.prefix == null) {
            this.prefix = new short[4096];
        }
        short[] sArr = this.prefix;
        if (this.suffix == null) {
            this.suffix = new byte[4096];
        }
        byte[] bArr3 = this.suffix;
        if (this.pixelStack == null) {
            this.pixelStack = new byte[4097];
        }
        byte[] bArr4 = this.pixelStack;
        int i32 = this.rawData.get() & 255;
        int i33 = 1 << i32;
        int i34 = i33 + 1;
        int i35 = i33 + 2;
        int i36 = i32 + 1;
        int i37 = (1 << i36) - 1;
        for (int i38 = 0; i38 < i33; i38++) {
            sArr[i38] = 0;
            bArr3[i38] = (byte) i38;
        }
        byte[] bArr5 = this.block;
        StandardGifDecoder standardGifDecoder = this;
        int i39 = i36;
        int i40 = i35;
        int i41 = i37;
        int i42 = 0;
        short s3 = -1;
        int i43 = 0;
        int i44 = 0;
        int i45 = 0;
        int i46 = 0;
        int i47 = 0;
        int i48 = 0;
        int i49 = 0;
        while (true) {
            if (i42 >= i31) {
                iArr = iArr2;
                break;
            }
            if (i43 == 0) {
                int i50 = standardGifDecoder.rawData.get() & 255;
                if (i50 <= 0) {
                    i13 = i36;
                    i12 = i42;
                    iArr = iArr2;
                    s = s3;
                } else {
                    i13 = i36;
                    ByteBuffer byteBuffer = standardGifDecoder.rawData;
                    i12 = i42;
                    s = s3;
                    iArr = iArr2;
                    byteBuffer.get(standardGifDecoder.block, 0, Math.min(i50, byteBuffer.remaining()));
                }
                if (i50 <= 0) {
                    standardGifDecoder.status = 3;
                    break;
                }
                i43 = i50;
                i44 = 0;
            } else {
                i13 = i36;
                i12 = i42;
                iArr = iArr2;
                s = s3;
            }
            i46 += (bArr5[i44] & 255) << i45;
            i44++;
            i43--;
            int i51 = i45 + 8;
            int i52 = i40;
            int i53 = i39;
            i42 = i12;
            s3 = s;
            int i54 = i47;
            while (true) {
                if (i51 < i53) {
                    i14 = i54;
                    standardGifDecoder = this;
                    break;
                }
                int i55 = i46 & i41;
                i46 >>= i53;
                i51 -= i53;
                if (i55 == i33) {
                    i15 = i51;
                    i52 = i35;
                    i41 = i37;
                    standardGifDecoder = standardGifDecoder;
                    i53 = i13;
                    s3 = -1;
                    i16 = i54;
                } else if (i55 == i34) {
                    standardGifDecoder = standardGifDecoder;
                    i14 = i54;
                    break;
                } else {
                    i15 = i51;
                    if (s3 == -1) {
                        bArr2[i48] = bArr3[i55];
                        i48++;
                        i42++;
                        i16 = i55;
                    } else {
                        if (i55 >= i52) {
                            bArr4[i49] = (byte) i54;
                            i49++;
                            s2 = s3;
                        } else {
                            s2 = i55;
                        }
                        while (s2 >= i33) {
                            bArr4[i49] = bArr3[s2];
                            i49++;
                            s2 = sArr[s2];
                        }
                        int i56 = bArr3[s2] & 255;
                        byte b = (byte) i56;
                        bArr2[i48] = b;
                        while (true) {
                            i48++;
                            i42++;
                            if (i49 <= 0) {
                                break;
                            }
                            i49--;
                            bArr2[i48] = bArr4[i49];
                        }
                        i16 = i56;
                        if (i52 < 4096) {
                            sArr[i52] = (short) s3;
                            bArr3[i52] = b;
                            i52++;
                            if ((i52 & i41) == 0 && i52 < 4096) {
                                i53++;
                                i41 += i52;
                            }
                        }
                    }
                    s3 = i55;
                    standardGifDecoder = this;
                }
                i54 = i16;
                i51 = i15;
            }
            i39 = i53;
            bArr5 = bArr5;
            i47 = i14;
            i36 = i13;
            i45 = i51;
            i40 = i52;
            iArr2 = iArr;
        }
        Arrays.fill(bArr2, i48, i31, (byte) 0);
        if (gifFrame.interlace || this.sampleSize != 1) {
            int[] iArr3 = this.mainScratch;
            int i57 = gifFrame.ih;
            int i58 = this.sampleSize;
            int i59 = i57 / i58;
            int i60 = gifFrame.iy / i58;
            int i61 = gifFrame.iw / i58;
            int i62 = gifFrame.ix / i58;
            boolean z2 = this.framePointer == 0;
            int i63 = this.downsampledWidth;
            int i64 = this.downsampledHeight;
            byte[] bArr6 = this.mainPixels;
            int[] iArr4 = this.act;
            Boolean bool = this.isFirstFrameTransparent;
            int i65 = 0;
            int i66 = 0;
            int i67 = 1;
            int i68 = 8;
            while (i65 < i59) {
                if (gifFrame.interlace) {
                    if (i66 >= i59) {
                        int i69 = i67 + 1;
                        i2 = i59;
                        if (i69 == 2) {
                            i67 = i69;
                            i66 = 4;
                        } else if (i69 != 3) {
                            i67 = i69;
                            if (i69 == 4) {
                                i66 = 1;
                                i68 = 2;
                            }
                        } else {
                            i67 = i69;
                            i66 = 2;
                            i68 = 4;
                        }
                    } else {
                        i2 = i59;
                    }
                    i3 = i66 + i68;
                } else {
                    i2 = i59;
                    i3 = i66;
                    i66 = i65;
                }
                int i70 = i66 + i60;
                boolean z3 = i58 == 1;
                if (i70 < i64) {
                    int i71 = i70 * i63;
                    int i72 = i71 + i62;
                    i9 = i3;
                    int i73 = i72 + i61;
                    int i74 = i71 + i63;
                    if (i74 < i73) {
                        i73 = i74;
                    }
                    i8 = i60;
                    int i75 = i65 * i58 * gifFrame.iw;
                    if (z3) {
                        bool = bool;
                        int i76 = i72;
                        while (true) {
                            i7 = i61;
                            if (i76 >= i73) {
                                break;
                            }
                            int i77 = iArr4[bArr6[i75] & 255];
                            if (i77 != 0) {
                                iArr3[i76] = i77;
                            } else if (z2 && bool == null) {
                                bool = Boolean.TRUE;
                            }
                            i75 += i58;
                            i76++;
                            i61 = i7;
                        }
                    } else {
                        i7 = i61;
                        int i78 = ((i73 - i72) * i58) + i75;
                        bool = bool;
                        int i79 = i72;
                        while (i79 < i73) {
                            int i80 = gifFrame.iw;
                            int i81 = i75;
                            int i82 = 0;
                            int i83 = 0;
                            int i84 = 0;
                            int i85 = 0;
                            int i86 = 0;
                            while (true) {
                                if (i81 >= this.sampleSize + i75) {
                                    i10 = i64;
                                    break;
                                }
                                byte[] bArr7 = this.mainPixels;
                                i10 = i64;
                                if (i81 >= bArr7.length || i81 >= i78) {
                                    break;
                                }
                                int i87 = this.act[bArr7[i81] & 255];
                                if (i87 != 0) {
                                    i82 += (i87 >> 24) & KEYRecord.PROTOCOL_ANY;
                                    i83 += (i87 >> 16) & KEYRecord.PROTOCOL_ANY;
                                    i84 += (i87 >> 8) & KEYRecord.PROTOCOL_ANY;
                                    i85 += i87 & KEYRecord.PROTOCOL_ANY;
                                    i86++;
                                }
                                i81++;
                                i64 = i10;
                            }
                            int i88 = i80 + i75;
                            for (int i89 = i88; i89 < this.sampleSize + i88; i89++) {
                                byte[] bArr8 = this.mainPixels;
                                if (i89 >= bArr8.length || i89 >= i78) {
                                    break;
                                }
                                int i90 = this.act[bArr8[i89] & 255];
                                if (i90 != 0) {
                                    i82 += (i90 >> 24) & KEYRecord.PROTOCOL_ANY;
                                    i83 += (i90 >> 16) & KEYRecord.PROTOCOL_ANY;
                                    i84 += (i90 >> 8) & KEYRecord.PROTOCOL_ANY;
                                    i85 += i90 & KEYRecord.PROTOCOL_ANY;
                                    i86++;
                                }
                            }
                            if (i86 == 0) {
                                i11 = 0;
                            } else {
                                i11 = ((i82 / i86) << 24) | ((i83 / i86) << 16) | ((i84 / i86) << 8) | (i85 / i86);
                            }
                            if (i11 != 0) {
                                iArr3[i79] = i11;
                            } else if (z2 && bool == null) {
                                bool = Boolean.TRUE;
                            }
                            i75 += i58;
                            i79++;
                            i73 = i73;
                            i62 = i62;
                            i63 = i63;
                            i64 = i10;
                        }
                    }
                    i6 = i62;
                    i5 = i63;
                    i4 = i64;
                } else {
                    i9 = i3;
                    i8 = i60;
                    i7 = i61;
                    i6 = i62;
                    i5 = i63;
                    i4 = i64;
                    bool = bool;
                }
                i65++;
                i59 = i2;
                i66 = i9;
                i60 = i8;
                i61 = i7;
                i62 = i6;
                i63 = i5;
                i64 = i4;
            }
            if (this.isFirstFrameTransparent == null) {
                if (bool == null) {
                    z = false;
                } else {
                    z = bool.booleanValue();
                }
                this.isFirstFrameTransparent = Boolean.valueOf(z);
            }
        } else {
            int[] iArr5 = this.mainScratch;
            int i91 = gifFrame.ih;
            int i92 = gifFrame.iy;
            int i93 = gifFrame.iw;
            int i94 = gifFrame.ix;
            boolean z4 = this.framePointer == 0;
            int i95 = this.downsampledWidth;
            byte[] bArr9 = this.mainPixels;
            int[] iArr6 = this.act;
            byte b2 = -1;
            for (int i96 = 0; i96 < i91; i96++) {
                int i97 = (i96 + i92) * i95;
                int i98 = i97 + i94;
                int i99 = i98 + i93;
                int i100 = i97 + i95;
                if (i100 < i99) {
                    i99 = i100;
                }
                int i101 = gifFrame.iw * i96;
                while (i98 < i99) {
                    byte b3 = bArr9[i101];
                    int i102 = b3 & 255;
                    if (i102 != b2) {
                        int i103 = iArr6[i102];
                        if (i103 != 0) {
                            iArr5[i98] = i103;
                        } else {
                            b2 = b3;
                        }
                    }
                    i101++;
                    i98++;
                    i91 = i91;
                    i92 = i92;
                }
            }
            Boolean bool2 = this.isFirstFrameTransparent;
            this.isFirstFrameTransparent = Boolean.valueOf((bool2 != null && bool2.booleanValue()) || (this.isFirstFrameTransparent == null && z4 && b2 != -1));
        }
        if (this.savePrevious && ((i = gifFrame.dispose) == 0 || i == 1)) {
            if (this.previousImage == null) {
                this.previousImage = getNextBitmap();
            }
            Bitmap bitmap3 = this.previousImage;
            int i104 = this.downsampledWidth;
            bitmap3.setPixels(iArr, 0, i104, 0, 0, i104, this.downsampledHeight);
        }
        Bitmap nextBitmap = getNextBitmap();
        int i105 = this.downsampledWidth;
        nextBitmap.setPixels(iArr, 0, i105, 0, 0, i105, this.downsampledHeight);
        return nextBitmap;
    }
}
