package com.bumptech.glide.load;

import androidx.collection.ArrayMap;
import androidx.collection.SimpleArrayMap;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.load.Option;
import com.bumptech.glide.util.CachedHashCodeArrayMap;
import java.security.MessageDigest;

public final class Options implements Key {
    public final ArrayMap<Option<?>, Object> values = new CachedHashCodeArrayMap();

    @Override // com.bumptech.glide.load.Key
    public boolean equals(Object obj) {
        if (obj instanceof Options) {
            return this.values.equals(((Options) obj).values);
        }
        return false;
    }

    public <T> T get(Option<T> option) {
        return this.values.indexOfKey(option) >= 0 ? (T) this.values.getOrDefault(option, null) : option.defaultValue;
    }

    @Override // com.bumptech.glide.load.Key
    public int hashCode() {
        return this.values.hashCode();
    }

    public void putAll(Options options) {
        this.values.putAll((SimpleArrayMap<? extends Option<?>, ? extends Object>) options.values);
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Options{values=");
        outline25.append(this.values);
        outline25.append('}');
        return outline25.toString();
    }

    @Override // com.bumptech.glide.load.Key
    public void updateDiskCacheKey(MessageDigest messageDigest) {
        int i = 0;
        while (true) {
            ArrayMap<Option<?>, Object> arrayMap = this.values;
            if (i < arrayMap.mSize) {
                Option<?> keyAt = arrayMap.keyAt(i);
                Object valueAt = this.values.valueAt(i);
                Option.CacheKeyUpdater<T> cacheKeyUpdater = keyAt.cacheKeyUpdater;
                if (keyAt.keyBytes == null) {
                    keyAt.keyBytes = keyAt.key.getBytes(Key.CHARSET);
                }
                cacheKeyUpdater.update(keyAt.keyBytes, valueAt, messageDigest);
                i++;
            } else {
                return;
            }
        }
    }
}
