package com.bumptech.glide.load.data;

import android.os.SystemClock;
import android.text.TextUtils;
import android.util.Log;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.Priority;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.HttpException;
import com.bumptech.glide.load.data.DataFetcher;
import com.bumptech.glide.load.model.GlideUrl;
import com.bumptech.glide.util.ContentLengthInputStream;
import com.bumptech.glide.util.LogTime;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.Map;
import java.util.Objects;

public class HttpUrlFetcher implements DataFetcher<InputStream> {
    public static final DefaultHttpUrlConnectionFactory DEFAULT_CONNECTION_FACTORY = new DefaultHttpUrlConnectionFactory();
    public final DefaultHttpUrlConnectionFactory connectionFactory;
    public final GlideUrl glideUrl;
    public volatile boolean isCancelled;
    public InputStream stream;
    public final int timeout;
    public HttpURLConnection urlConnection;

    public class DefaultHttpUrlConnectionFactory {
    }

    public HttpUrlFetcher(GlideUrl glideUrl2, int i) {
        DefaultHttpUrlConnectionFactory defaultHttpUrlConnectionFactory = DEFAULT_CONNECTION_FACTORY;
        this.glideUrl = glideUrl2;
        this.timeout = i;
        this.connectionFactory = defaultHttpUrlConnectionFactory;
    }

    public static int getHttpStatusCodeOrInvalid(HttpURLConnection httpURLConnection) {
        try {
            return httpURLConnection.getResponseCode();
        } catch (IOException e) {
            if (!Log.isLoggable("HttpUrlFetcher", 3)) {
                return -1;
            }
            Log.d("HttpUrlFetcher", "Failed to get a response code", e);
            return -1;
        }
    }

    @Override // com.bumptech.glide.load.data.DataFetcher
    public void cancel() {
        this.isCancelled = true;
    }

    @Override // com.bumptech.glide.load.data.DataFetcher
    public void cleanup() {
        InputStream inputStream = this.stream;
        if (inputStream != null) {
            try {
                inputStream.close();
            } catch (IOException unused) {
            }
        }
        HttpURLConnection httpURLConnection = this.urlConnection;
        if (httpURLConnection != null) {
            httpURLConnection.disconnect();
        }
        this.urlConnection = null;
    }

    @Override // com.bumptech.glide.load.data.DataFetcher
    public Class<InputStream> getDataClass() {
        return InputStream.class;
    }

    @Override // com.bumptech.glide.load.data.DataFetcher
    public DataSource getDataSource() {
        return DataSource.REMOTE;
    }

    @Override // com.bumptech.glide.load.data.DataFetcher
    public void loadData(Priority priority, DataFetcher.DataCallback<? super InputStream> dataCallback) {
        StringBuilder sb;
        int i = LogTime.$r8$clinit;
        long elapsedRealtimeNanos = SystemClock.elapsedRealtimeNanos();
        try {
            dataCallback.onDataReady(loadDataWithRedirects(this.glideUrl.toURL(), 0, null, this.glideUrl.headers.getHeaders()));
            if (Log.isLoggable("HttpUrlFetcher", 2)) {
                sb = new StringBuilder();
                sb.append("Finished http url fetcher fetch in ");
                sb.append(LogTime.getElapsedMillis(elapsedRealtimeNanos));
                Log.v("HttpUrlFetcher", sb.toString());
            }
        } catch (IOException e) {
            if (Log.isLoggable("HttpUrlFetcher", 3)) {
                Log.d("HttpUrlFetcher", "Failed to load data for url", e);
            }
            dataCallback.onLoadFailed(e);
            if (Log.isLoggable("HttpUrlFetcher", 2)) {
                sb = new StringBuilder();
            }
        } catch (Throwable th) {
            if (Log.isLoggable("HttpUrlFetcher", 2)) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("Finished http url fetcher fetch in ");
                outline25.append(LogTime.getElapsedMillis(elapsedRealtimeNanos));
                Log.v("HttpUrlFetcher", outline25.toString());
            }
            throw th;
        }
    }

    public final InputStream loadDataWithRedirects(URL url, int i, URL url2, Map<String, String> map) {
        if (i < 5) {
            if (url2 != null) {
                try {
                    if (url.toURI().equals(url2.toURI())) {
                        throw new HttpException("In re-direct loop", -1);
                    }
                } catch (URISyntaxException unused) {
                }
            }
            boolean z = false;
            try {
                Objects.requireNonNull(this.connectionFactory);
                HttpURLConnection httpURLConnection = (HttpURLConnection) url.openConnection();
                for (Map.Entry<String, String> entry : map.entrySet()) {
                    httpURLConnection.addRequestProperty(entry.getKey(), entry.getValue());
                }
                httpURLConnection.setConnectTimeout(this.timeout);
                httpURLConnection.setReadTimeout(this.timeout);
                httpURLConnection.setUseCaches(false);
                httpURLConnection.setDoInput(true);
                httpURLConnection.setInstanceFollowRedirects(false);
                this.urlConnection = httpURLConnection;
                try {
                    httpURLConnection.connect();
                    this.stream = this.urlConnection.getInputStream();
                    if (this.isCancelled) {
                        return null;
                    }
                    int httpStatusCodeOrInvalid = getHttpStatusCodeOrInvalid(this.urlConnection);
                    int i2 = httpStatusCodeOrInvalid / 100;
                    if (i2 == 2) {
                        HttpURLConnection httpURLConnection2 = this.urlConnection;
                        try {
                            if (TextUtils.isEmpty(httpURLConnection2.getContentEncoding())) {
                                this.stream = new ContentLengthInputStream(httpURLConnection2.getInputStream(), (long) httpURLConnection2.getContentLength());
                            } else {
                                if (Log.isLoggable("HttpUrlFetcher", 3)) {
                                    Log.d("HttpUrlFetcher", "Got non empty content encoding: " + httpURLConnection2.getContentEncoding());
                                }
                                this.stream = httpURLConnection2.getInputStream();
                            }
                            return this.stream;
                        } catch (IOException e) {
                            throw new HttpException("Failed to obtain InputStream", getHttpStatusCodeOrInvalid(httpURLConnection2), e);
                        }
                    } else {
                        if (i2 == 3) {
                            z = true;
                        }
                        if (z) {
                            String headerField = this.urlConnection.getHeaderField("Location");
                            if (!TextUtils.isEmpty(headerField)) {
                                try {
                                    URL url3 = new URL(url, headerField);
                                    cleanup();
                                    return loadDataWithRedirects(url3, i + 1, url, map);
                                } catch (MalformedURLException e2) {
                                    throw new HttpException(GeneratedOutlineSupport.outline18("Bad redirect url: ", headerField), httpStatusCodeOrInvalid, e2);
                                }
                            } else {
                                throw new HttpException("Received empty or null redirect url", httpStatusCodeOrInvalid);
                            }
                        } else if (httpStatusCodeOrInvalid == -1) {
                            throw new HttpException(httpStatusCodeOrInvalid);
                        } else {
                            try {
                                throw new HttpException(this.urlConnection.getResponseMessage(), httpStatusCodeOrInvalid);
                            } catch (IOException e3) {
                                throw new HttpException("Failed to get a response message", httpStatusCodeOrInvalid, e3);
                            }
                        }
                    }
                } catch (IOException e4) {
                    throw new HttpException("Failed to connect or obtain data", getHttpStatusCodeOrInvalid(this.urlConnection), e4);
                }
            } catch (IOException e5) {
                throw new HttpException("URL.openConnection threw", 0, e5);
            }
        } else {
            throw new HttpException("Too many (> 5) redirects!", -1);
        }
    }
}
