package com.bumptech.glide.load.engine;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.Transformation;
import java.security.MessageDigest;
import java.util.Map;
import java.util.Objects;

public class EngineKey implements Key {
    public int hashCode;
    public final int height;
    public final Object model;
    public final Options options;
    public final Class<?> resourceClass;
    public final Key signature;
    public final Class<?> transcodeClass;
    public final Map<Class<?>, Transformation<?>> transformations;
    public final int width;

    public EngineKey(Object obj, Key key, int i, int i2, Map<Class<?>, Transformation<?>> map, Class<?> cls, Class<?> cls2, Options options2) {
        Objects.requireNonNull(obj, "Argument must not be null");
        this.model = obj;
        Objects.requireNonNull(key, "Signature must not be null");
        this.signature = key;
        this.width = i;
        this.height = i2;
        Objects.requireNonNull(map, "Argument must not be null");
        this.transformations = map;
        Objects.requireNonNull(cls, "Resource class must not be null");
        this.resourceClass = cls;
        Objects.requireNonNull(cls2, "Transcode class must not be null");
        this.transcodeClass = cls2;
        Objects.requireNonNull(options2, "Argument must not be null");
        this.options = options2;
    }

    @Override // com.bumptech.glide.load.Key
    public boolean equals(Object obj) {
        if (!(obj instanceof EngineKey)) {
            return false;
        }
        EngineKey engineKey = (EngineKey) obj;
        if (!this.model.equals(engineKey.model) || !this.signature.equals(engineKey.signature) || this.height != engineKey.height || this.width != engineKey.width || !this.transformations.equals(engineKey.transformations) || !this.resourceClass.equals(engineKey.resourceClass) || !this.transcodeClass.equals(engineKey.transcodeClass) || !this.options.equals(engineKey.options)) {
            return false;
        }
        return true;
    }

    @Override // com.bumptech.glide.load.Key
    public int hashCode() {
        if (this.hashCode == 0) {
            int hashCode2 = this.model.hashCode();
            this.hashCode = hashCode2;
            int hashCode3 = this.signature.hashCode() + (hashCode2 * 31);
            this.hashCode = hashCode3;
            int i = (hashCode3 * 31) + this.width;
            this.hashCode = i;
            int i2 = (i * 31) + this.height;
            this.hashCode = i2;
            int hashCode4 = this.transformations.hashCode() + (i2 * 31);
            this.hashCode = hashCode4;
            int hashCode5 = this.resourceClass.hashCode() + (hashCode4 * 31);
            this.hashCode = hashCode5;
            int hashCode6 = this.transcodeClass.hashCode() + (hashCode5 * 31);
            this.hashCode = hashCode6;
            this.hashCode = this.options.hashCode() + (hashCode6 * 31);
        }
        return this.hashCode;
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("EngineKey{model=");
        outline25.append(this.model);
        outline25.append(", width=");
        outline25.append(this.width);
        outline25.append(", height=");
        outline25.append(this.height);
        outline25.append(", resourceClass=");
        outline25.append(this.resourceClass);
        outline25.append(", transcodeClass=");
        outline25.append(this.transcodeClass);
        outline25.append(", signature=");
        outline25.append(this.signature);
        outline25.append(", hashCode=");
        outline25.append(this.hashCode);
        outline25.append(", transformations=");
        outline25.append(this.transformations);
        outline25.append(", options=");
        outline25.append(this.options);
        outline25.append('}');
        return outline25.toString();
    }

    @Override // com.bumptech.glide.load.Key
    public void updateDiskCacheKey(MessageDigest messageDigest) {
        throw new UnsupportedOperationException();
    }
}
