package com.bumptech.glide.load.engine;

import androidx.core.util.Pools$Pool;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.data.DataRewinder;
import com.bumptech.glide.load.engine.DecodePath;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;

public class LoadPath<Data, ResourceType, Transcode> {
    public final List<? extends DecodePath<Data, ResourceType, Transcode>> decodePaths;
    public final String failureMessage;
    public final Pools$Pool<List<Throwable>> listPool;

    public LoadPath(Class<Data> cls, Class<ResourceType> cls2, Class<Transcode> cls3, List<DecodePath<Data, ResourceType, Transcode>> list, Pools$Pool<List<Throwable>> pools$Pool) {
        this.listPool = pools$Pool;
        if (!list.isEmpty()) {
            this.decodePaths = list;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed LoadPath{");
            outline25.append(cls.getSimpleName());
            outline25.append("->");
            outline25.append(cls2.getSimpleName());
            outline25.append("->");
            outline25.append(cls3.getSimpleName());
            outline25.append("}");
            this.failureMessage = outline25.toString();
            return;
        }
        throw new IllegalArgumentException("Must not be empty.");
    }

    public Resource<Transcode> load(DataRewinder<Data> dataRewinder, Options options, int i, int i2, DecodePath.DecodeCallback<ResourceType> decodeCallback) {
        List<Throwable> acquire = this.listPool.acquire();
        Objects.requireNonNull(acquire, "Argument must not be null");
        List<Throwable> list = acquire;
        try {
            int size = this.decodePaths.size();
            Resource<Transcode> resource = null;
            for (int i3 = 0; i3 < size; i3++) {
                try {
                    resource = ((DecodePath) this.decodePaths.get(i3)).decode(dataRewinder, i, i2, options, decodeCallback);
                } catch (GlideException e) {
                    list.add(e);
                }
                if (resource != null) {
                    break;
                }
            }
            if (resource != null) {
                return resource;
            }
            throw new GlideException(this.failureMessage, new ArrayList(list));
        } finally {
            this.listPool.release(list);
        }
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("LoadPath{decodePaths=");
        outline25.append(Arrays.toString(this.decodePaths.toArray()));
        outline25.append('}');
        return outline25.toString();
    }
}
