package com.bumptech.glide.load.engine.cache;

import android.app.ActivityManager;
import android.content.Context;
import android.os.Build;
import android.text.format.Formatter;
import android.util.DisplayMetrics;
import android.util.Log;
import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.buffer.AbstractByteBufAllocator;

public final class MemorySizeCalculator {
    public final int arrayPoolSize;
    public final int bitmapPoolSize;
    public final Context context;
    public final int memoryCacheSize;

    public final class Builder {
        public static final int BITMAP_POOL_TARGET_SCREENS = (Build.VERSION.SDK_INT < 26 ? 4 : 1);
        public ActivityManager activityManager;
        public float bitmapPoolScreens = ((float) BITMAP_POOL_TARGET_SCREENS);
        public final Context context;
        public DisplayMetricsScreenDimensions screenDimensions;

        public Builder(Context context2) {
            this.context = context2;
            this.activityManager = (ActivityManager) context2.getSystemService("activity");
            this.screenDimensions = new DisplayMetricsScreenDimensions(context2.getResources().getDisplayMetrics());
            if (Build.VERSION.SDK_INT >= 26 && this.activityManager.isLowRamDevice()) {
                this.bitmapPoolScreens = 0.0f;
            }
        }
    }

    public final class DisplayMetricsScreenDimensions {
        public final DisplayMetrics displayMetrics;

        public DisplayMetricsScreenDimensions(DisplayMetrics displayMetrics2) {
            this.displayMetrics = displayMetrics2;
        }
    }

    public MemorySizeCalculator(Builder builder) {
        this.context = builder.context;
        int i = builder.activityManager.isLowRamDevice() ? 2097152 : AbstractByteBufAllocator.CALCULATE_THRESHOLD;
        this.arrayPoolSize = i;
        ActivityManager activityManager = builder.activityManager;
        int round = Math.round(((float) (activityManager.getMemoryClass() * 1024 * 1024)) * (activityManager.isLowRamDevice() ? 0.33f : 0.4f));
        DisplayMetrics displayMetrics = builder.screenDimensions.displayMetrics;
        float f = (float) (displayMetrics.widthPixels * displayMetrics.heightPixels * 4);
        int round2 = Math.round(builder.bitmapPoolScreens * f);
        int round3 = Math.round(f * 2.0f);
        int i2 = round - i;
        int i3 = round3 + round2;
        if (i3 <= i2) {
            this.memoryCacheSize = round3;
            this.bitmapPoolSize = round2;
        } else {
            float f2 = ((float) i2) / (builder.bitmapPoolScreens + 2.0f);
            this.memoryCacheSize = Math.round(2.0f * f2);
            this.bitmapPoolSize = Math.round(f2 * builder.bitmapPoolScreens);
        }
        if (Log.isLoggable("MemorySizeCalculator", 3)) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Calculation complete, Calculated memory cache size: ");
            outline25.append(toMb(this.memoryCacheSize));
            outline25.append(", pool size: ");
            outline25.append(toMb(this.bitmapPoolSize));
            outline25.append(", byte array size: ");
            outline25.append(toMb(i));
            outline25.append(", memory class limited? ");
            outline25.append(i3 > round);
            outline25.append(", max size: ");
            outline25.append(toMb(round));
            outline25.append(", memoryClass: ");
            outline25.append(builder.activityManager.getMemoryClass());
            outline25.append(", isLowMemoryDevice: ");
            outline25.append(builder.activityManager.isLowRamDevice());
            Log.d("MemorySizeCalculator", outline25.toString());
        }
    }

    public final String toMb(int i) {
        return Formatter.formatFileSize(this.context, (long) i);
    }
}
