package com.bumptech.glide.load.model;

import android.text.TextUtils;
import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public final class LazyHeaders implements Headers {
    public volatile Map<String, String> combinedHeaders;
    public final Map<String, List<StringHeaderFactory>> headers;

    public final class Builder {
        public static final Map<String, List<StringHeaderFactory>> DEFAULT_HEADERS;
        public static final String DEFAULT_USER_AGENT;
        public Map<String, List<StringHeaderFactory>> headers = DEFAULT_HEADERS;

        static {
            String property = System.getProperty("http.agent");
            if (!TextUtils.isEmpty(property)) {
                int length = property.length();
                StringBuilder sb = new StringBuilder(property.length());
                for (int i = 0; i < length; i++) {
                    char charAt = property.charAt(i);
                    if ((charAt > 31 || charAt == '\t') && charAt < 127) {
                        sb.append(charAt);
                    } else {
                        sb.append('?');
                    }
                }
                property = sb.toString();
            }
            DEFAULT_USER_AGENT = property;
            HashMap hashMap = new HashMap(2);
            if (!TextUtils.isEmpty(property)) {
                hashMap.put("User-Agent", Collections.singletonList(new StringHeaderFactory(property)));
            }
            DEFAULT_HEADERS = Collections.unmodifiableMap(hashMap);
        }
    }

    public final class StringHeaderFactory {
        public final String value;

        public StringHeaderFactory(String str) {
            this.value = str;
        }

        public boolean equals(Object obj) {
            if (obj instanceof StringHeaderFactory) {
                return this.value.equals(((StringHeaderFactory) obj).value);
            }
            return false;
        }

        public int hashCode() {
            return this.value.hashCode();
        }

        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("StringHeaderFactory{value='");
            outline25.append(this.value);
            outline25.append('\'');
            outline25.append('}');
            return outline25.toString();
        }
    }

    public LazyHeaders(Map<String, List<StringHeaderFactory>> map) {
        this.headers = Collections.unmodifiableMap(map);
    }

    public boolean equals(Object obj) {
        if (obj instanceof LazyHeaders) {
            return this.headers.equals(((LazyHeaders) obj).headers);
        }
        return false;
    }

    public final Map<String, String> generateHeaders() {
        HashMap hashMap = new HashMap();
        for (Map.Entry<String, List<StringHeaderFactory>> entry : this.headers.entrySet()) {
            List<StringHeaderFactory> value = entry.getValue();
            StringBuilder sb = new StringBuilder();
            int size = value.size();
            for (int i = 0; i < size; i++) {
                String str = value.get(i).value;
                if (!TextUtils.isEmpty(str)) {
                    sb.append(str);
                    if (i != value.size() - 1) {
                        sb.append(StringUtil.COMMA);
                    }
                }
            }
            String sb2 = sb.toString();
            if (!TextUtils.isEmpty(sb2)) {
                hashMap.put(entry.getKey(), sb2);
            }
        }
        return hashMap;
    }

    @Override // com.bumptech.glide.load.model.Headers
    public Map<String, String> getHeaders() {
        if (this.combinedHeaders == null) {
            synchronized (this) {
                if (this.combinedHeaders == null) {
                    this.combinedHeaders = Collections.unmodifiableMap(generateHeaders());
                }
            }
        }
        return this.combinedHeaders;
    }

    public int hashCode() {
        return this.headers.hashCode();
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("LazyHeaders{headers=");
        outline25.append(this.headers);
        outline25.append('}');
        return outline25.toString();
    }
}
