package com.bumptech.glide.load.resource.gif;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.SystemClock;
import android.util.Log;
import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.gifdecoder.GifHeader;
import com.bumptech.glide.gifdecoder.GifHeaderParser;
import com.bumptech.glide.gifdecoder.StandardGifDecoder;
import com.bumptech.glide.load.DecodeFormat;
import com.bumptech.glide.load.ImageHeaderParser;
import com.bumptech.glide.load.ImageHeaderParserUtils$2;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.ResourceDecoder;
import com.bumptech.glide.load.engine.Resource;
import com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool;
import com.bumptech.glide.load.engine.bitmap_recycle.LruArrayPool;
import com.bumptech.glide.load.resource.UnitTransformation;
import com.bumptech.glide.util.LogTime;
import com.bumptech.glide.util.Util;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayDeque;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;
import java.util.Queue;

public class ByteBufferGifDecoder implements ResourceDecoder<ByteBuffer, GifDrawable> {
    public static final GifDecoderFactory GIF_DECODER_FACTORY = new GifDecoderFactory();
    public static final GifHeaderParserPool PARSER_POOL = new GifHeaderParserPool();
    public final Context context;
    public final GifDecoderFactory gifDecoderFactory;
    public final GifHeaderParserPool parserPool;
    public final List<ImageHeaderParser> parsers;
    public final GifBitmapProvider provider;

    public class GifDecoderFactory {
    }

    public class GifHeaderParserPool {
        public final Queue<GifHeaderParser> pool = new ArrayDeque(0);

        public GifHeaderParserPool() {
            char[] cArr = Util.HEX_CHAR_ARRAY;
        }

        public synchronized void release(GifHeaderParser gifHeaderParser) {
            gifHeaderParser.rawData = null;
            gifHeaderParser.header = null;
            this.pool.offer(gifHeaderParser);
        }
    }

    public ByteBufferGifDecoder(Context context2, List<ImageHeaderParser> list, BitmapPool bitmapPool, LruArrayPool lruArrayPool) {
        GifHeaderParserPool gifHeaderParserPool = PARSER_POOL;
        GifDecoderFactory gifDecoderFactory2 = GIF_DECODER_FACTORY;
        this.context = context2.getApplicationContext();
        this.parsers = list;
        this.gifDecoderFactory = gifDecoderFactory2;
        this.provider = new GifBitmapProvider(bitmapPool, lruArrayPool);
        this.parserPool = gifHeaderParserPool;
    }

    public static int getSampleSize(GifHeader gifHeader, int i, int i2) {
        int i3;
        int min = Math.min(gifHeader.height / i2, gifHeader.width / i);
        if (min == 0) {
            i3 = 0;
        } else {
            i3 = Integer.highestOneBit(min);
        }
        int max = Math.max(1, i3);
        if (Log.isLoggable("BufferGifDecoder", 2) && max > 1) {
            StringBuilder outline27 = GeneratedOutlineSupport.outline27("Downsampling GIF, sampleSize: ", max, ", target dimens: [", i, "x");
            outline27.append(i2);
            outline27.append("], actual dimens: [");
            outline27.append(gifHeader.width);
            outline27.append("x");
            outline27.append(gifHeader.height);
            outline27.append("]");
            Log.v("BufferGifDecoder", outline27.toString());
        }
        return max;
    }

    public final GifDrawableResource decode(ByteBuffer byteBuffer, int i, int i2, GifHeaderParser gifHeaderParser, Options options) {
        Bitmap.Config config;
        int i3 = LogTime.$r8$clinit;
        long elapsedRealtimeNanos = SystemClock.elapsedRealtimeNanos();
        try {
            GifHeader parseHeader = gifHeaderParser.parseHeader();
            if (parseHeader.frameCount > 0) {
                if (parseHeader.status == 0) {
                    if (options.get(GifOptions.DECODE_FORMAT) == DecodeFormat.PREFER_RGB_565) {
                        config = Bitmap.Config.RGB_565;
                    } else {
                        config = Bitmap.Config.ARGB_8888;
                    }
                    int sampleSize = getSampleSize(parseHeader, i, i2);
                    GifDecoderFactory gifDecoderFactory2 = this.gifDecoderFactory;
                    GifBitmapProvider gifBitmapProvider = this.provider;
                    Objects.requireNonNull(gifDecoderFactory2);
                    StandardGifDecoder standardGifDecoder = new StandardGifDecoder(gifBitmapProvider, parseHeader, byteBuffer, sampleSize);
                    standardGifDecoder.setDefaultBitmapConfig(config);
                    standardGifDecoder.framePointer = (standardGifDecoder.framePointer + 1) % standardGifDecoder.header.frameCount;
                    Bitmap nextFrame = standardGifDecoder.getNextFrame();
                    if (nextFrame == null) {
                        if (Log.isLoggable("BufferGifDecoder", 2)) {
                            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Decoded GIF from stream in ");
                            outline25.append(LogTime.getElapsedMillis(elapsedRealtimeNanos));
                            Log.v("BufferGifDecoder", outline25.toString());
                        }
                        return null;
                    }
                    GifDrawableResource gifDrawableResource = new GifDrawableResource(new GifDrawable(this.context, standardGifDecoder, (UnitTransformation) UnitTransformation.TRANSFORMATION, i, i2, nextFrame));
                    if (Log.isLoggable("BufferGifDecoder", 2)) {
                        StringBuilder outline252 = GeneratedOutlineSupport.outline25("Decoded GIF from stream in ");
                        outline252.append(LogTime.getElapsedMillis(elapsedRealtimeNanos));
                        Log.v("BufferGifDecoder", outline252.toString());
                    }
                    return gifDrawableResource;
                }
            }
            return null;
        } finally {
            if (Log.isLoggable("BufferGifDecoder", 2)) {
                StringBuilder outline253 = GeneratedOutlineSupport.outline25("Decoded GIF from stream in ");
                outline253.append(LogTime.getElapsedMillis(elapsedRealtimeNanos));
                Log.v("BufferGifDecoder", outline253.toString());
            }
        }
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, com.bumptech.glide.load.Options] */
    @Override // com.bumptech.glide.load.ResourceDecoder
    public boolean handles(ByteBuffer byteBuffer, Options options) {
        ImageHeaderParser.ImageType imageType;
        ByteBuffer byteBuffer2 = byteBuffer;
        if (!((Boolean) options.get(GifOptions.DISABLE_ANIMATION)).booleanValue()) {
            List<ImageHeaderParser> list = this.parsers;
            if (byteBuffer2 == null) {
                imageType = ImageHeaderParser.ImageType.UNKNOWN;
            } else {
                imageType = ViewGroupUtilsApi14.getTypeInternal(list, new ImageHeaderParserUtils$2(byteBuffer2));
            }
            if (imageType == ImageHeaderParser.ImageType.GIF) {
                return true;
            }
        }
        return false;
    }

    /* Return type fixed from 'com.bumptech.glide.load.engine.Resource' to match base method */
    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, int, int, com.bumptech.glide.load.Options] */
    @Override // com.bumptech.glide.load.ResourceDecoder
    public Resource<GifDrawable> decode(ByteBuffer byteBuffer, int i, int i2, Options options) {
        GifHeaderParser poll;
        ByteBuffer byteBuffer2 = byteBuffer;
        GifHeaderParserPool gifHeaderParserPool = this.parserPool;
        synchronized (gifHeaderParserPool) {
            poll = gifHeaderParserPool.pool.poll();
            if (poll == null) {
                poll = new GifHeaderParser();
            }
            poll.rawData = null;
            Arrays.fill(poll.block, (byte) 0);
            poll.header = new GifHeader();
            poll.blockSize = 0;
            ByteBuffer asReadOnlyBuffer = byteBuffer2.asReadOnlyBuffer();
            poll.rawData = asReadOnlyBuffer;
            asReadOnlyBuffer.position(0);
            poll.rawData.order(ByteOrder.LITTLE_ENDIAN);
        }
        try {
            return decode(byteBuffer2, i, i2, poll, options);
        } finally {
            this.parserPool.release(poll);
        }
    }
}
