package com.bumptech.glide.load.resource.gif;

import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.os.SystemClock;
import androidx.recyclerview.widget.LinearLayoutManager;
import com.bumptech.glide.Glide;
import com.bumptech.glide.RequestBuilder;
import com.bumptech.glide.RequestManager;
import com.bumptech.glide.gifdecoder.GifDecoder;
import com.bumptech.glide.gifdecoder.GifHeader;
import com.bumptech.glide.gifdecoder.StandardGifDecoder;
import com.bumptech.glide.load.Transformation;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.load.engine.bitmap_recycle.BitmapPool;
import com.bumptech.glide.request.BaseRequestOptions;
import com.bumptech.glide.request.RequestOptions;
import com.bumptech.glide.request.target.CustomTarget;
import com.bumptech.glide.request.transition.Transition;
import com.bumptech.glide.signature.ObjectKey;
import com.bumptech.glide.util.Executors;
import com.bumptech.glide.util.Util;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

public class GifFrameLoader {
    public final BitmapPool bitmapPool;
    public final List<FrameCallback> callbacks = new ArrayList();
    public DelayTarget current;
    public Bitmap firstFrame;
    public int firstFrameSize;
    public final GifDecoder gifDecoder;
    public final Handler handler;
    public int height;
    public boolean isCleared;
    public boolean isLoadPending;
    public boolean isRunning;
    public DelayTarget next;
    public OnEveryFrameListener onEveryFrameListener;
    public DelayTarget pendingTarget;
    public RequestBuilder<Bitmap> requestBuilder;
    public final RequestManager requestManager;
    public int width;

    public class DelayTarget extends CustomTarget<Bitmap> {
        public final Handler handler;
        public final int index;
        public Bitmap resource;
        public final long targetTime;

        public DelayTarget(Handler handler2, int i, long j) {
            super(LinearLayoutManager.INVALID_OFFSET, LinearLayoutManager.INVALID_OFFSET);
            this.handler = handler2;
            this.index = i;
            this.targetTime = j;
        }

        @Override // com.bumptech.glide.request.target.Target
        public void onLoadCleared(Drawable drawable) {
            this.resource = null;
        }

        @Override // com.bumptech.glide.request.target.Target
        public void onResourceReady(Object obj, Transition transition) {
            this.resource = (Bitmap) obj;
            this.handler.sendMessageAtTime(this.handler.obtainMessage(1, this), this.targetTime);
        }
    }

    public interface FrameCallback {
    }

    public class FrameLoaderCallback implements Handler.Callback {
        public FrameLoaderCallback() {
        }

        public boolean handleMessage(Message message) {
            int i = message.what;
            if (i == 1) {
                GifFrameLoader.this.onFrameReady((DelayTarget) message.obj);
                return true;
            } else if (i != 2) {
                return false;
            } else {
                GifFrameLoader.this.requestManager.clear((DelayTarget) message.obj);
                return false;
            }
        }
    }

    public interface OnEveryFrameListener {
        void onFrameReady();
    }

    public GifFrameLoader(Glide glide, GifDecoder gifDecoder2, int i, int i2, Transformation<Bitmap> transformation, Bitmap bitmap) {
        BitmapPool bitmapPool2 = glide.bitmapPool;
        RequestManager with = Glide.with(glide.glideContext.getBaseContext());
        RequestManager with2 = Glide.with(glide.glideContext.getBaseContext());
        Objects.requireNonNull(with2);
        RequestBuilder<Bitmap> apply = with2.as(Bitmap.class).apply((BaseRequestOptions<?>) RequestManager.DECODE_TYPE_BITMAP).apply(((RequestOptions) ((RequestOptions) ((RequestOptions) new RequestOptions().diskCacheStrategy(DiskCacheStrategy.NONE)).useAnimationPool(true)).skipMemoryCache(true)).override(i, i2));
        this.requestManager = with;
        Handler handler2 = new Handler(Looper.getMainLooper(), new FrameLoaderCallback());
        this.bitmapPool = bitmapPool2;
        this.handler = handler2;
        this.requestBuilder = apply;
        this.gifDecoder = gifDecoder2;
        setFrameTransformation(transformation, bitmap);
    }

    public final void loadNextFrame() {
        int i;
        if (this.isRunning && !this.isLoadPending) {
            int i2 = -1;
            int i3 = 0;
            DelayTarget delayTarget = this.pendingTarget;
            if (delayTarget != null) {
                this.pendingTarget = null;
                onFrameReady(delayTarget);
                return;
            }
            this.isLoadPending = true;
            StandardGifDecoder standardGifDecoder = (StandardGifDecoder) this.gifDecoder;
            GifHeader gifHeader = standardGifDecoder.header;
            int i4 = gifHeader.frameCount;
            if (i4 > 0 && (i = standardGifDecoder.framePointer) >= 0) {
                if (i >= 0 && i < i4) {
                    i2 = gifHeader.frames.get(i).delay;
                }
                i3 = i2;
            }
            long uptimeMillis = SystemClock.uptimeMillis() + ((long) i3);
            StandardGifDecoder standardGifDecoder2 = (StandardGifDecoder) this.gifDecoder;
            int i5 = (standardGifDecoder2.framePointer + 1) % standardGifDecoder2.header.frameCount;
            standardGifDecoder2.framePointer = i5;
            this.next = new DelayTarget(this.handler, i5, uptimeMillis);
            RequestBuilder<Bitmap> loadGeneric = this.requestBuilder.apply((BaseRequestOptions<?>) ((RequestOptions) new RequestOptions().signature(new ObjectKey(Double.valueOf(Math.random()))))).loadGeneric(this.gifDecoder);
            loadGeneric.into(this.next, null, loadGeneric, Executors.MAIN_THREAD_EXECUTOR);
        }
    }

    public void onFrameReady(DelayTarget delayTarget) {
        OnEveryFrameListener onEveryFrameListener2 = this.onEveryFrameListener;
        if (onEveryFrameListener2 != null) {
            onEveryFrameListener2.onFrameReady();
        }
        this.isLoadPending = false;
        if (this.isCleared) {
            this.handler.obtainMessage(2, delayTarget).sendToTarget();
        } else if (!this.isRunning) {
            this.pendingTarget = delayTarget;
        } else {
            if (delayTarget.resource != null) {
                Bitmap bitmap = this.firstFrame;
                if (bitmap != null) {
                    this.bitmapPool.put(bitmap);
                    this.firstFrame = null;
                }
                DelayTarget delayTarget2 = this.current;
                this.current = delayTarget;
                for (int size = this.callbacks.size() - 1; size >= 0; size--) {
                    GifDrawable gifDrawable = (GifDrawable) this.callbacks.get(size);
                    Drawable.Callback callback = gifDrawable.getCallback();
                    while (callback instanceof Drawable) {
                        callback = ((Drawable) callback).getCallback();
                    }
                    if (callback == null) {
                        gifDrawable.stop();
                        gifDrawable.invalidateSelf();
                    } else {
                        gifDrawable.invalidateSelf();
                        GifFrameLoader gifFrameLoader = gifDrawable.state.frameLoader;
                        DelayTarget delayTarget3 = gifFrameLoader.current;
                        if ((delayTarget3 != null ? delayTarget3.index : -1) == ((StandardGifDecoder) gifFrameLoader.gifDecoder).header.frameCount - 1) {
                            gifDrawable.loopCount++;
                        }
                        int i = gifDrawable.maxLoopCount;
                        if (i != -1 && gifDrawable.loopCount >= i) {
                            gifDrawable.stop();
                        }
                    }
                }
                if (delayTarget2 != null) {
                    this.handler.obtainMessage(2, delayTarget2).sendToTarget();
                }
            }
            loadNextFrame();
        }
    }

    public void setFrameTransformation(Transformation<Bitmap> transformation, Bitmap bitmap) {
        Objects.requireNonNull(transformation, "Argument must not be null");
        Objects.requireNonNull(bitmap, "Argument must not be null");
        this.firstFrame = bitmap;
        this.requestBuilder = this.requestBuilder.apply(new RequestOptions().transform(transformation, true));
        this.firstFrameSize = Util.getBitmapByteSize(bitmap);
        this.width = bitmap.getWidth();
        this.height = bitmap.getHeight();
    }

    public void setOnEveryFrameReadyListener(OnEveryFrameListener onEveryFrameListener2) {
        this.onEveryFrameListener = onEveryFrameListener2;
    }
}
