package com.bumptech.glide.manager;

import android.app.Activity;
import android.app.Application;
import android.app.Fragment;
import android.app.FragmentManager;
import android.content.Context;
import android.content.ContextWrapper;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.util.Log;
import androidx.fragment.app.BackStackRecord;
import androidx.fragment.app.FragmentActivity;
import com.bumptech.glide.Glide;
import com.bumptech.glide.GlideBuilder;
import com.bumptech.glide.GlideExperiments;
import com.bumptech.glide.RequestManager;
import com.bumptech.glide.load.resource.bitmap.HardwareConfigState;
import com.bumptech.glide.util.Util;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

public class RequestManagerRetriever implements Handler.Callback {
    public static final RequestManagerFactory DEFAULT_FACTORY = new RequestManagerFactory() {
        /* class com.bumptech.glide.manager.RequestManagerRetriever.AnonymousClass1 */
    };
    public volatile RequestManager applicationManager;
    public final RequestManagerFactory factory;
    public final FrameWaiter frameWaiter;
    public final Handler handler;
    public final Map<FragmentManager, RequestManagerFragment> pendingRequestManagerFragments = new HashMap();
    public final Map<androidx.fragment.app.FragmentManager, SupportRequestManagerFragment> pendingSupportRequestManagerFragments = new HashMap();

    public interface RequestManagerFactory {
    }

    public RequestManagerRetriever(RequestManagerFactory requestManagerFactory, GlideExperiments glideExperiments) {
        FrameWaiter frameWaiter2;
        new Bundle();
        this.factory = requestManagerFactory == null ? DEFAULT_FACTORY : requestManagerFactory;
        this.handler = new Handler(Looper.getMainLooper(), this);
        if (!HardwareConfigState.HARDWARE_BITMAPS_SUPPORTED || !HardwareConfigState.BLOCK_HARDWARE_BITMAPS_WHEN_GL_CONTEXT_MIGHT_NOT_BE_INITIALIZED) {
            frameWaiter2 = new DoNothingFirstFrameWaiter();
        } else if (glideExperiments.experiments.containsKey(GlideBuilder.WaitForFramesAfterTrimMemory.class)) {
            frameWaiter2 = new FirstFrameAndAfterTrimMemoryWaiter();
        } else {
            frameWaiter2 = new FirstFrameWaiter();
        }
        this.frameWaiter = frameWaiter2;
    }

    public static Activity findActivity(Context context) {
        if (context instanceof Activity) {
            return (Activity) context;
        }
        if (context instanceof ContextWrapper) {
            return findActivity(((ContextWrapper) context).getBaseContext());
        }
        return null;
    }

    public static boolean isActivityVisible(Context context) {
        Activity findActivity = findActivity(context);
        return findActivity == null || !findActivity.isFinishing();
    }

    public RequestManager get(Context context) {
        if (context != null) {
            if (Util.isOnMainThread() && !(context instanceof Application)) {
                if (context instanceof FragmentActivity) {
                    return get((FragmentActivity) context);
                }
                if (context instanceof Activity) {
                    return get((Activity) context);
                }
                if (context instanceof ContextWrapper) {
                    ContextWrapper contextWrapper = (ContextWrapper) context;
                    if (contextWrapper.getBaseContext().getApplicationContext() != null) {
                        return get(contextWrapper.getBaseContext());
                    }
                }
            }
            if (this.applicationManager == null) {
                synchronized (this) {
                    if (this.applicationManager == null) {
                        Glide glide = Glide.get(context.getApplicationContext());
                        RequestManagerFactory requestManagerFactory = this.factory;
                        ApplicationLifecycle applicationLifecycle = new ApplicationLifecycle();
                        EmptyRequestManagerTreeNode emptyRequestManagerTreeNode = new EmptyRequestManagerTreeNode();
                        Context applicationContext = context.getApplicationContext();
                        Objects.requireNonNull((AnonymousClass1) requestManagerFactory);
                        this.applicationManager = new RequestManager(glide, applicationLifecycle, emptyRequestManagerTreeNode, applicationContext);
                    }
                }
            }
            return this.applicationManager;
        }
        throw new IllegalArgumentException("You cannot start a load on a null Context");
    }

    public final RequestManagerFragment getRequestManagerFragment(FragmentManager fragmentManager, Fragment fragment) {
        RequestManagerFragment requestManagerFragment = (RequestManagerFragment) fragmentManager.findFragmentByTag("com.bumptech.glide.manager");
        if (requestManagerFragment == null && (requestManagerFragment = this.pendingRequestManagerFragments.get(fragmentManager)) == null) {
            requestManagerFragment = new RequestManagerFragment();
            requestManagerFragment.parentFragmentHint = fragment;
            if (!(fragment == null || fragment.getActivity() == null)) {
                requestManagerFragment.registerFragmentWithRoot(fragment.getActivity());
            }
            this.pendingRequestManagerFragments.put(fragmentManager, requestManagerFragment);
            fragmentManager.beginTransaction().add(requestManagerFragment, "com.bumptech.glide.manager").commitAllowingStateLoss();
            this.handler.obtainMessage(1, fragmentManager).sendToTarget();
        }
        return requestManagerFragment;
    }

    public final SupportRequestManagerFragment getSupportRequestManagerFragment(androidx.fragment.app.FragmentManager fragmentManager, androidx.fragment.app.Fragment fragment) {
        SupportRequestManagerFragment supportRequestManagerFragment = (SupportRequestManagerFragment) fragmentManager.findFragmentByTag("com.bumptech.glide.manager");
        if (supportRequestManagerFragment == null && (supportRequestManagerFragment = this.pendingSupportRequestManagerFragments.get(fragmentManager)) == null) {
            supportRequestManagerFragment = new SupportRequestManagerFragment();
            supportRequestManagerFragment.parentFragmentHint = fragment;
            if (!(fragment == null || fragment.getContext() == null)) {
                androidx.fragment.app.Fragment fragment2 = fragment;
                while (fragment2.getParentFragment() != null) {
                    fragment2 = fragment2.getParentFragment();
                }
                androidx.fragment.app.FragmentManager fragmentManager2 = fragment2.getFragmentManager();
                if (fragmentManager2 != null) {
                    supportRequestManagerFragment.registerFragmentWithRoot(fragment.getContext(), fragmentManager2);
                }
            }
            this.pendingSupportRequestManagerFragments.put(fragmentManager, supportRequestManagerFragment);
            BackStackRecord backStackRecord = new BackStackRecord(fragmentManager);
            backStackRecord.doAddOp(0, supportRequestManagerFragment, "com.bumptech.glide.manager", 1);
            backStackRecord.commitInternal(true);
            this.handler.obtainMessage(2, fragmentManager).sendToTarget();
        }
        return supportRequestManagerFragment;
    }

    public boolean handleMessage(Message message) {
        Object obj;
        Object obj2;
        Object obj3;
        int i = message.what;
        Object obj4 = null;
        boolean z = true;
        if (i == 1) {
            obj3 = (FragmentManager) message.obj;
            obj2 = this.pendingRequestManagerFragments.remove(obj3);
        } else if (i != 2) {
            z = false;
            obj = null;
            if (z && obj4 == null && Log.isLoggable("RMRetriever", 5)) {
                Log.w("RMRetriever", "Failed to remove expected request manager fragment, manager: " + obj);
            }
            return z;
        } else {
            obj3 = (androidx.fragment.app.FragmentManager) message.obj;
            obj2 = this.pendingSupportRequestManagerFragments.remove(obj3);
        }
        obj4 = obj2;
        obj = obj3;
        Log.w("RMRetriever", "Failed to remove expected request manager fragment, manager: " + obj);
        return z;
    }

    public RequestManager get(FragmentActivity fragmentActivity) {
        if (Util.isOnBackgroundThread()) {
            return get(fragmentActivity.getApplicationContext());
        }
        if (!fragmentActivity.isDestroyed()) {
            this.frameWaiter.registerSelf(fragmentActivity);
            androidx.fragment.app.FragmentManager supportFragmentManager = fragmentActivity.getSupportFragmentManager();
            boolean isActivityVisible = isActivityVisible(fragmentActivity);
            SupportRequestManagerFragment supportRequestManagerFragment = getSupportRequestManagerFragment(supportFragmentManager, null);
            RequestManager requestManager = supportRequestManagerFragment.requestManager;
            if (requestManager != null) {
                return requestManager;
            }
            Glide glide = Glide.get(fragmentActivity);
            RequestManagerFactory requestManagerFactory = this.factory;
            ActivityFragmentLifecycle activityFragmentLifecycle = supportRequestManagerFragment.lifecycle;
            RequestManagerTreeNode requestManagerTreeNode = supportRequestManagerFragment.requestManagerTreeNode;
            Objects.requireNonNull((AnonymousClass1) requestManagerFactory);
            RequestManager requestManager2 = new RequestManager(glide, activityFragmentLifecycle, requestManagerTreeNode, fragmentActivity);
            if (isActivityVisible) {
                requestManager2.onStart();
            }
            supportRequestManagerFragment.requestManager = requestManager2;
            return requestManager2;
        }
        throw new IllegalArgumentException("You cannot start a load for a destroyed activity");
    }

    public RequestManager get(Activity activity) {
        if (Util.isOnBackgroundThread()) {
            return get(activity.getApplicationContext());
        }
        if (activity instanceof FragmentActivity) {
            return get((FragmentActivity) activity);
        }
        if (!activity.isDestroyed()) {
            this.frameWaiter.registerSelf(activity);
            FragmentManager fragmentManager = activity.getFragmentManager();
            boolean isActivityVisible = isActivityVisible(activity);
            RequestManagerFragment requestManagerFragment = getRequestManagerFragment(fragmentManager, null);
            RequestManager requestManager = requestManagerFragment.requestManager;
            if (requestManager != null) {
                return requestManager;
            }
            Glide glide = Glide.get(activity);
            RequestManagerFactory requestManagerFactory = this.factory;
            ActivityFragmentLifecycle activityFragmentLifecycle = requestManagerFragment.lifecycle;
            RequestManagerTreeNode requestManagerTreeNode = requestManagerFragment.requestManagerTreeNode;
            Objects.requireNonNull((AnonymousClass1) requestManagerFactory);
            RequestManager requestManager2 = new RequestManager(glide, activityFragmentLifecycle, requestManagerTreeNode, activity);
            if (isActivityVisible) {
                requestManager2.onStart();
            }
            requestManagerFragment.requestManager = requestManager2;
            return requestManager2;
        }
        throw new IllegalArgumentException("You cannot start a load for a destroyed activity");
    }
}
