package com.bumptech.glide.request;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.drawable.Drawable;
import android.os.SystemClock;
import android.util.Log;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.GlideBuilder;
import com.bumptech.glide.GlideContext;
import com.bumptech.glide.Priority;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.engine.Engine;
import com.bumptech.glide.load.engine.GlideException;
import com.bumptech.glide.load.engine.Resource;
import com.bumptech.glide.load.resource.drawable.DrawableDecoderCompat;
import com.bumptech.glide.request.target.SizeReadyCallback;
import com.bumptech.glide.request.target.Target;
import com.bumptech.glide.request.transition.NoTransition;
import com.bumptech.glide.util.LogTime;
import com.bumptech.glide.util.Util;
import com.bumptech.glide.util.pool.StateVerifier$DefaultStateVerifier;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.Executor;

public final class SingleRequest<R> implements Request, SizeReadyCallback, ResourceCallback {
    public static final boolean IS_VERBOSE_LOGGABLE = Log.isLoggable("Request", 2);
    public final NoTransition.NoAnimationFactory<? super R> animationFactory;
    public final Executor callbackExecutor;
    public final Context context;
    public volatile Engine engine;
    public Drawable errorDrawable;
    public Drawable fallbackDrawable;
    public final GlideContext glideContext;
    public int height;
    public boolean isCallingCallbacks;
    public Engine.LoadStatus loadStatus;
    public final Object model;
    public final int overrideHeight;
    public final int overrideWidth;
    public Drawable placeholderDrawable;
    public final Priority priority;
    public final RequestCoordinator requestCoordinator;
    public final List<RequestListener<R>> requestListeners;
    public final Object requestLock;
    public final BaseRequestOptions<?> requestOptions;
    public RuntimeException requestOrigin;
    public Resource<R> resource;
    public long startTime;
    public final StateVerifier$DefaultStateVerifier stateVerifier;
    public Status status;
    public final String tag;
    public final Target<R> target;
    public final RequestListener<R> targetListener;
    public final Class<R> transcodeClass;
    public int width;

    public enum Status {
        PENDING,
        RUNNING,
        WAITING_FOR_SIZE,
        COMPLETE,
        FAILED,
        CLEARED
    }

    public SingleRequest(Context context2, GlideContext glideContext2, Object obj, Object obj2, Class<R> cls, BaseRequestOptions<?> baseRequestOptions, int i, int i2, Priority priority2, Target<R> target2, RequestListener<R> requestListener, List<RequestListener<R>> list, RequestCoordinator requestCoordinator2, Engine engine2, NoTransition.NoAnimationFactory<? super R> noAnimationFactory, Executor executor) {
        this.tag = IS_VERBOSE_LOGGABLE ? String.valueOf(hashCode()) : null;
        this.stateVerifier = new StateVerifier$DefaultStateVerifier();
        this.requestLock = obj;
        this.context = context2;
        this.glideContext = glideContext2;
        this.model = obj2;
        this.transcodeClass = cls;
        this.requestOptions = baseRequestOptions;
        this.overrideWidth = i;
        this.overrideHeight = i2;
        this.priority = priority2;
        this.target = target2;
        this.targetListener = requestListener;
        this.requestListeners = list;
        this.requestCoordinator = requestCoordinator2;
        this.engine = engine2;
        this.animationFactory = noAnimationFactory;
        this.callbackExecutor = executor;
        this.status = Status.PENDING;
        if (this.requestOrigin == null && glideContext2.experiments.experiments.containsKey(GlideBuilder.LogRequestOrigins.class)) {
            this.requestOrigin = new RuntimeException("Glide request origin trace");
        }
    }

    public final void assertNotCallingCallbacks() {
        if (this.isCallingCallbacks) {
            throw new IllegalStateException("You can't start or clear loads in RequestListener or Target callbacks. If you're trying to start a fallback request when a load fails, use RequestBuilder#error(RequestBuilder). Otherwise consider posting your into() or clear() calls to the main thread using a Handler instead.");
        }
    }

    @Override // com.bumptech.glide.request.Request
    public void begin() {
        synchronized (this.requestLock) {
            assertNotCallingCallbacks();
            this.stateVerifier.throwIfRecycled();
            int i = LogTime.$r8$clinit;
            this.startTime = SystemClock.elapsedRealtimeNanos();
            if (this.model == null) {
                if (Util.isValidDimensions(this.overrideWidth, this.overrideHeight)) {
                    this.width = this.overrideWidth;
                    this.height = this.overrideHeight;
                }
                onLoadFailed(new GlideException("Received null model"), getFallbackDrawable() == null ? 5 : 3);
                return;
            }
            Status status2 = this.status;
            Status status3 = Status.RUNNING;
            if (status2 != status3) {
                boolean z = false;
                if (status2 == Status.COMPLETE) {
                    onResourceReady((Resource<?>) this.resource, DataSource.MEMORY_CACHE, false);
                    return;
                }
                Status status4 = Status.WAITING_FOR_SIZE;
                this.status = status4;
                if (Util.isValidDimensions(this.overrideWidth, this.overrideHeight)) {
                    onSizeReady(this.overrideWidth, this.overrideHeight);
                } else {
                    this.target.getSize(this);
                }
                Status status5 = this.status;
                if (status5 == status3 || status5 == status4) {
                    RequestCoordinator requestCoordinator2 = this.requestCoordinator;
                    if (requestCoordinator2 == null || requestCoordinator2.canNotifyStatusChanged(this)) {
                        z = true;
                    }
                    if (z) {
                        this.target.onLoadStarted(getPlaceholderDrawable());
                    }
                }
                if (IS_VERBOSE_LOGGABLE) {
                    logV("finished run method in " + LogTime.getElapsedMillis(this.startTime));
                }
                return;
            }
            throw new IllegalArgumentException("Cannot restart a running request");
        }
    }

    public final void cancel() {
        assertNotCallingCallbacks();
        this.stateVerifier.throwIfRecycled();
        this.target.removeCallback(this);
        Engine.LoadStatus loadStatus2 = this.loadStatus;
        if (loadStatus2 != null) {
            synchronized (Engine.this) {
                loadStatus2.engineJob.removeCallback(loadStatus2.cb);
            }
            this.loadStatus = null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:22:0x003b, code lost:
        if (r1 == null) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x003d, code lost:
        r5.engine.release(r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:?, code lost:
        return;
     */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x002f  */
    @Override // com.bumptech.glide.request.Request
    public void clear() {
        boolean z;
        synchronized (this.requestLock) {
            assertNotCallingCallbacks();
            this.stateVerifier.throwIfRecycled();
            Status status2 = this.status;
            Status status3 = Status.CLEARED;
            if (status2 != status3) {
                cancel();
                Resource<R> resource2 = this.resource;
                if (resource2 != null) {
                    this.resource = null;
                } else {
                    resource2 = null;
                }
                RequestCoordinator requestCoordinator2 = this.requestCoordinator;
                if (requestCoordinator2 != null) {
                    if (!requestCoordinator2.canNotifyCleared(this)) {
                        z = false;
                        if (z) {
                            this.target.onLoadCleared(getPlaceholderDrawable());
                        }
                        this.status = status3;
                    }
                }
                z = true;
                if (z) {
                }
                this.status = status3;
            }
        }
    }

    public final Drawable getFallbackDrawable() {
        int i;
        if (this.fallbackDrawable == null) {
            BaseRequestOptions<?> baseRequestOptions = this.requestOptions;
            Drawable drawable = baseRequestOptions.fallbackDrawable;
            this.fallbackDrawable = drawable;
            if (drawable == null && (i = baseRequestOptions.fallbackId) > 0) {
                this.fallbackDrawable = loadDrawable(i);
            }
        }
        return this.fallbackDrawable;
    }

    public final Drawable getPlaceholderDrawable() {
        int i;
        if (this.placeholderDrawable == null) {
            BaseRequestOptions<?> baseRequestOptions = this.requestOptions;
            Drawable drawable = baseRequestOptions.placeholderDrawable;
            this.placeholderDrawable = drawable;
            if (drawable == null && (i = baseRequestOptions.placeholderId) > 0) {
                this.placeholderDrawable = loadDrawable(i);
            }
        }
        return this.placeholderDrawable;
    }

    @Override // com.bumptech.glide.request.Request
    public boolean isAnyResourceSet() {
        boolean z;
        synchronized (this.requestLock) {
            z = this.status == Status.COMPLETE;
        }
        return z;
    }

    @Override // com.bumptech.glide.request.Request
    public boolean isCleared() {
        boolean z;
        synchronized (this.requestLock) {
            z = this.status == Status.CLEARED;
        }
        return z;
    }

    @Override // com.bumptech.glide.request.Request
    public boolean isComplete() {
        boolean z;
        synchronized (this.requestLock) {
            z = this.status == Status.COMPLETE;
        }
        return z;
    }

    @Override // com.bumptech.glide.request.Request
    public boolean isEquivalentTo(Request request) {
        int i;
        int i2;
        Object obj;
        Class<R> cls;
        BaseRequestOptions<?> baseRequestOptions;
        Priority priority2;
        int size;
        int i3;
        int i4;
        Object obj2;
        Class<R> cls2;
        BaseRequestOptions<?> baseRequestOptions2;
        Priority priority3;
        int size2;
        boolean z;
        if (!(request instanceof SingleRequest)) {
            return false;
        }
        synchronized (this.requestLock) {
            i = this.overrideWidth;
            i2 = this.overrideHeight;
            obj = this.model;
            cls = this.transcodeClass;
            baseRequestOptions = this.requestOptions;
            priority2 = this.priority;
            List<RequestListener<R>> list = this.requestListeners;
            size = list != null ? list.size() : 0;
        }
        SingleRequest singleRequest = (SingleRequest) request;
        synchronized (singleRequest.requestLock) {
            i3 = singleRequest.overrideWidth;
            i4 = singleRequest.overrideHeight;
            obj2 = singleRequest.model;
            cls2 = singleRequest.transcodeClass;
            baseRequestOptions2 = singleRequest.requestOptions;
            priority3 = singleRequest.priority;
            List<RequestListener<R>> list2 = singleRequest.requestListeners;
            size2 = list2 != null ? list2.size() : 0;
        }
        if (i == i3 && i2 == i4) {
            char[] cArr = Util.HEX_CHAR_ARRAY;
            if (obj == null) {
                z = obj2 == null;
            } else {
                z = obj.equals(obj2);
            }
            return z && cls.equals(cls2) && baseRequestOptions.equals(baseRequestOptions2) && priority2 == priority3 && size == size2;
        }
    }

    public final boolean isFirstReadyResource() {
        RequestCoordinator requestCoordinator2 = this.requestCoordinator;
        return requestCoordinator2 == null || !requestCoordinator2.getRoot().isAnyResourceSet();
    }

    @Override // com.bumptech.glide.request.Request
    public boolean isRunning() {
        boolean z;
        synchronized (this.requestLock) {
            Status status2 = this.status;
            if (status2 != Status.RUNNING) {
                if (status2 != Status.WAITING_FOR_SIZE) {
                    z = false;
                }
            }
            z = true;
        }
        return z;
    }

    public final Drawable loadDrawable(int i) {
        Resources.Theme theme = this.requestOptions.theme;
        if (theme == null) {
            theme = this.context.getTheme();
        }
        GlideContext glideContext2 = this.glideContext;
        return DrawableDecoderCompat.getDrawable(glideContext2, glideContext2, i, theme);
    }

    public final void logV(String str) {
        StringBuilder outline28 = GeneratedOutlineSupport.outline28(str, " this: ");
        outline28.append(this.tag);
        Log.v("Request", outline28.toString());
    }

    /* JADX INFO: finally extract failed */
    public final void onLoadFailed(GlideException glideException, int i) {
        boolean z;
        this.stateVerifier.throwIfRecycled();
        synchronized (this.requestLock) {
            glideException.setOrigin(this.requestOrigin);
            int i2 = this.glideContext.logLevel;
            if (i2 <= i) {
                Log.w("Glide", "Load failed for " + this.model + " with size [" + this.width + "x" + this.height + "]", glideException);
                if (i2 <= 4) {
                    glideException.logRootCauses("Glide");
                }
            }
            this.loadStatus = null;
            this.status = Status.FAILED;
            boolean z2 = true;
            this.isCallingCallbacks = true;
            try {
                List<RequestListener<R>> list = this.requestListeners;
                if (list != null) {
                    z = false;
                    for (RequestListener<R> requestListener : list) {
                        z |= requestListener.onLoadFailed(glideException, this.model, this.target, isFirstReadyResource());
                    }
                } else {
                    z = false;
                }
                RequestListener<R> requestListener2 = this.targetListener;
                if (requestListener2 == null || !requestListener2.onLoadFailed(glideException, this.model, this.target, isFirstReadyResource())) {
                    z2 = false;
                }
                if (!z && !z2) {
                    setErrorPlaceholder();
                }
                this.isCallingCallbacks = false;
                RequestCoordinator requestCoordinator2 = this.requestCoordinator;
                if (requestCoordinator2 != null) {
                    requestCoordinator2.onRequestFailed(this);
                }
            } catch (Throwable th) {
                this.isCallingCallbacks = false;
                throw th;
            }
        }
    }

    public void onResourceReady(Resource<?> resource2, DataSource dataSource, boolean z) {
        Throwable th;
        this.stateVerifier.throwIfRecycled();
        try {
            synchronized (this.requestLock) {
                try {
                    this.loadStatus = null;
                    if (resource2 == null) {
                        onLoadFailed(new GlideException("Expected to receive a Resource<R> with an object of " + this.transcodeClass + " inside, but instead got null."), 5);
                        return;
                    }
                    Object obj = resource2.get();
                    if (obj != null) {
                        if (this.transcodeClass.isAssignableFrom(obj.getClass())) {
                            RequestCoordinator requestCoordinator2 = this.requestCoordinator;
                            if (!(requestCoordinator2 == null || requestCoordinator2.canSetImage(this))) {
                                try {
                                    this.resource = null;
                                    this.status = Status.COMPLETE;
                                    this.engine.release(resource2);
                                    return;
                                } catch (Throwable th2) {
                                    th = th2;
                                    throw th;
                                }
                            } else {
                                onResourceReady(resource2, obj, dataSource);
                                return;
                            }
                        }
                    }
                    this.resource = null;
                    StringBuilder sb = new StringBuilder();
                    sb.append("Expected to receive an object of ");
                    sb.append(this.transcodeClass);
                    sb.append(" but instead got ");
                    sb.append(obj != null ? obj.getClass() : "");
                    sb.append("{");
                    sb.append(obj);
                    sb.append("} inside Resource{");
                    sb.append(resource2);
                    sb.append("}.");
                    sb.append(obj != null ? "" : " To indicate failure return a null Resource object, rather than a Resource object containing null data.");
                    onLoadFailed(new GlideException(sb.toString()), 5);
                    this.engine.release(resource2);
                } catch (Throwable th3) {
                    th = th3;
                    throw th;
                }
            }
        } catch (Throwable th4) {
            if (0 != 0) {
                this.engine.release(null);
            }
            throw th4;
        }
    }

    public void onSizeReady(int i, int i2) {
        Object obj;
        Throwable th;
        int i3;
        int i4 = i;
        this.stateVerifier.throwIfRecycled();
        Object obj2 = this.requestLock;
        synchronized (obj2) {
            try {
                boolean z = IS_VERBOSE_LOGGABLE;
                if (z) {
                    logV("Got onSizeReady in " + LogTime.getElapsedMillis(this.startTime));
                }
                if (this.status == Status.WAITING_FOR_SIZE) {
                    Status status2 = Status.RUNNING;
                    this.status = status2;
                    float f = this.requestOptions.sizeMultiplier;
                    if (i4 != Integer.MIN_VALUE) {
                        i4 = Math.round(((float) i4) * f);
                    }
                    this.width = i4;
                    if (i2 == Integer.MIN_VALUE) {
                        i3 = i2;
                    } else {
                        i3 = Math.round(f * ((float) i2));
                    }
                    this.height = i3;
                    if (z) {
                        logV("finished setup for calling load in " + LogTime.getElapsedMillis(this.startTime));
                    }
                    Engine engine2 = this.engine;
                    GlideContext glideContext2 = this.glideContext;
                    Object obj3 = this.model;
                    BaseRequestOptions<?> baseRequestOptions = this.requestOptions;
                    try {
                        obj = obj2;
                    } catch (Throwable th2) {
                        th = th2;
                        obj = obj2;
                        while (true) {
                            try {
                                break;
                            } catch (Throwable th3) {
                                th = th3;
                            }
                        }
                        throw th;
                    }
                    try {
                    } catch (Throwable th4) {
                        th = th4;
                        while (true) {
                            break;
                        }
                        throw th;
                    }
                    try {
                        this.loadStatus = engine2.load(glideContext2, obj3, baseRequestOptions.signature, this.width, this.height, baseRequestOptions.resourceClass, this.transcodeClass, this.priority, baseRequestOptions.diskCacheStrategy, baseRequestOptions.transformations, baseRequestOptions.isTransformationRequired, baseRequestOptions.isScaleOnlyOrNoTransform, baseRequestOptions.options, baseRequestOptions.isCacheable, baseRequestOptions.useUnlimitedSourceGeneratorsPool, baseRequestOptions.useAnimationPool, baseRequestOptions.onlyRetrieveFromCache, this, this.callbackExecutor);
                        if (this.status != status2) {
                            this.loadStatus = null;
                        }
                        if (z) {
                            logV("finished onSizeReady in " + LogTime.getElapsedMillis(this.startTime));
                        }
                    } catch (Throwable th5) {
                        th = th5;
                        while (true) {
                            break;
                        }
                        throw th;
                    }
                }
            } catch (Throwable th6) {
                th = th6;
                obj = obj2;
                while (true) {
                    break;
                }
                throw th;
            }
        }
    }

    @Override // com.bumptech.glide.request.Request
    public void pause() {
        synchronized (this.requestLock) {
            if (isRunning()) {
                clear();
            }
        }
    }

    public final void setErrorPlaceholder() {
        int i;
        RequestCoordinator requestCoordinator2 = this.requestCoordinator;
        if (requestCoordinator2 == null || requestCoordinator2.canNotifyStatusChanged(this)) {
            Drawable drawable = null;
            if (this.model == null) {
                drawable = getFallbackDrawable();
            }
            if (drawable == null) {
                if (this.errorDrawable == null) {
                    BaseRequestOptions<?> baseRequestOptions = this.requestOptions;
                    Drawable drawable2 = baseRequestOptions.errorPlaceholder;
                    this.errorDrawable = drawable2;
                    if (drawable2 == null && (i = baseRequestOptions.errorId) > 0) {
                        this.errorDrawable = loadDrawable(i);
                    }
                }
                drawable = this.errorDrawable;
            }
            if (drawable == null) {
                drawable = getPlaceholderDrawable();
            }
            this.target.onLoadFailed(drawable);
        }
    }

    /* JADX WARN: Incorrect args count in method signature: (Lcom/bumptech/glide/load/engine/Resource<TR;>;TR;Lcom/bumptech/glide/load/DataSource;Z)V */
    /* JADX INFO: finally extract failed */
    public final void onResourceReady(Resource resource2, Object obj, DataSource dataSource) {
        boolean z;
        boolean isFirstReadyResource = isFirstReadyResource();
        this.status = Status.COMPLETE;
        this.resource = resource2;
        if (this.glideContext.logLevel <= 3) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Finished loading ");
            outline25.append(obj.getClass().getSimpleName());
            outline25.append(" from ");
            outline25.append(dataSource);
            outline25.append(" for ");
            outline25.append(this.model);
            outline25.append(" with size [");
            outline25.append(this.width);
            outline25.append("x");
            outline25.append(this.height);
            outline25.append("] in ");
            outline25.append(LogTime.getElapsedMillis(this.startTime));
            outline25.append(" ms");
            Log.d("Glide", outline25.toString());
        }
        boolean z2 = true;
        this.isCallingCallbacks = true;
        try {
            List<RequestListener<R>> list = this.requestListeners;
            if (list != null) {
                z = false;
                for (RequestListener<R> requestListener : list) {
                    z |= requestListener.onResourceReady(obj, this.model, this.target, dataSource, isFirstReadyResource);
                }
            } else {
                z = false;
            }
            RequestListener<R> requestListener2 = this.targetListener;
            if (requestListener2 == null || !requestListener2.onResourceReady(obj, this.model, this.target, dataSource, isFirstReadyResource)) {
                z2 = false;
            }
            if (!z2 && !z) {
                Objects.requireNonNull(this.animationFactory);
                this.target.onResourceReady(obj, NoTransition.NO_ANIMATION);
            }
            this.isCallingCallbacks = false;
            RequestCoordinator requestCoordinator2 = this.requestCoordinator;
            if (requestCoordinator2 != null) {
                requestCoordinator2.onRequestSuccess(this);
            }
        } catch (Throwable th) {
            this.isCallingCallbacks = false;
            throw th;
        }
    }
}
