package com.bumptech.glide.request.target;

import android.content.Context;
import android.graphics.Point;
import android.util.Log;
import android.view.Display;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.view.WindowManager;
import com.bumptech.glide.request.SingleRequest;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

public final class ViewTarget$SizeDeterminer {
    public static Integer maxDisplayLength;
    public final List<SizeReadyCallback> cbs = new ArrayList();
    public SizeDeterminerLayoutListener layoutListener;
    public final View view;

    public final class SizeDeterminerLayoutListener implements ViewTreeObserver.OnPreDrawListener {
        public final WeakReference<ViewTarget$SizeDeterminer> sizeDeterminerRef;

        public SizeDeterminerLayoutListener(ViewTarget$SizeDeterminer viewTarget$SizeDeterminer) {
            this.sizeDeterminerRef = new WeakReference<>(viewTarget$SizeDeterminer);
        }

        public boolean onPreDraw() {
            if (Log.isLoggable("ViewTarget", 2)) {
                Log.v("ViewTarget", "OnGlobalLayoutListener called attachStateListener=" + this);
            }
            ViewTarget$SizeDeterminer viewTarget$SizeDeterminer = this.sizeDeterminerRef.get();
            if (viewTarget$SizeDeterminer == null || viewTarget$SizeDeterminer.cbs.isEmpty()) {
                return true;
            }
            int targetWidth = viewTarget$SizeDeterminer.getTargetWidth();
            int targetHeight = viewTarget$SizeDeterminer.getTargetHeight();
            if (!viewTarget$SizeDeterminer.isViewStateAndSizeValid(targetWidth, targetHeight)) {
                return true;
            }
            Iterator it = new ArrayList(viewTarget$SizeDeterminer.cbs).iterator();
            while (it.hasNext()) {
                ((SingleRequest) ((SizeReadyCallback) it.next())).onSizeReady(targetWidth, targetHeight);
            }
            viewTarget$SizeDeterminer.clearCallbacksAndListener();
            return true;
        }
    }

    public ViewTarget$SizeDeterminer(View view2) {
        this.view = view2;
    }

    public void clearCallbacksAndListener() {
        ViewTreeObserver viewTreeObserver = this.view.getViewTreeObserver();
        if (viewTreeObserver.isAlive()) {
            viewTreeObserver.removeOnPreDrawListener(this.layoutListener);
        }
        this.layoutListener = null;
        this.cbs.clear();
    }

    public final int getTargetDimen(int i, int i2, int i3) {
        int i4 = i2 - i3;
        if (i4 > 0) {
            return i4;
        }
        int i5 = i - i3;
        if (i5 > 0) {
            return i5;
        }
        if (this.view.isLayoutRequested() || i2 != -2) {
            return 0;
        }
        if (Log.isLoggable("ViewTarget", 4)) {
            Log.i("ViewTarget", "Glide treats LayoutParams.WRAP_CONTENT as a request for an image the size of this device's screen dimensions. If you want to load the original image and are ok with the corresponding memory cost and OOMs (depending on the input size), use override(Target.SIZE_ORIGINAL). Otherwise, use LayoutParams.MATCH_PARENT, set layout_width and layout_height to fixed dimension, or use .override() with fixed dimensions.");
        }
        Context context = this.view.getContext();
        if (maxDisplayLength == null) {
            WindowManager windowManager = (WindowManager) context.getSystemService("window");
            Objects.requireNonNull(windowManager, "Argument must not be null");
            Display defaultDisplay = windowManager.getDefaultDisplay();
            Point point = new Point();
            defaultDisplay.getSize(point);
            maxDisplayLength = Integer.valueOf(Math.max(point.x, point.y));
        }
        return maxDisplayLength.intValue();
    }

    public final int getTargetHeight() {
        int paddingBottom = this.view.getPaddingBottom() + this.view.getPaddingTop();
        ViewGroup.LayoutParams layoutParams = this.view.getLayoutParams();
        return getTargetDimen(this.view.getHeight(), layoutParams != null ? layoutParams.height : 0, paddingBottom);
    }

    public final int getTargetWidth() {
        int paddingRight = this.view.getPaddingRight() + this.view.getPaddingLeft();
        ViewGroup.LayoutParams layoutParams = this.view.getLayoutParams();
        return getTargetDimen(this.view.getWidth(), layoutParams != null ? layoutParams.width : 0, paddingRight);
    }

    public final boolean isViewStateAndSizeValid(int i, int i2) {
        if (i > 0 || i == Integer.MIN_VALUE) {
            if (i2 > 0 || i2 == Integer.MIN_VALUE) {
                return true;
            }
        }
        return false;
    }
}
