package com.bumptech.glide.util.pool;

import android.util.Log;
import androidx.core.util.Pools$Pool;
import androidx.core.util.Pools$SynchronizedPool;
import com.android.tools.r8.GeneratedOutlineSupport;

public abstract class FactoryPools {
    public static final Resetter<Object> EMPTY_RESETTER = new Resetter<Object>() {
        /* class com.bumptech.glide.util.pool.FactoryPools.AnonymousClass1 */

        @Override // com.bumptech.glide.util.pool.FactoryPools.Resetter
        public void reset(Object obj) {
        }
    };

    public interface Factory<T> {
        T create();
    }

    public final class FactoryPool<T> implements Pools$Pool<T> {
        public final Factory<T> factory;
        public final Pools$Pool<T> pool;
        public final Resetter<T> resetter;

        public FactoryPool(Pools$Pool<T> pools$Pool, Factory<T> factory2, Resetter<T> resetter2) {
            this.pool = pools$Pool;
            this.factory = factory2;
            this.resetter = resetter2;
        }

        @Override // androidx.core.util.Pools$Pool
        public T acquire() {
            T acquire = this.pool.acquire();
            if (acquire == null) {
                acquire = this.factory.create();
                if (Log.isLoggable("FactoryPools", 2)) {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Created new ");
                    outline25.append(acquire.getClass());
                    Log.v("FactoryPools", outline25.toString());
                }
            }
            if (acquire instanceof Poolable) {
                acquire.getVerifier().isReleased = false;
            }
            return acquire;
        }

        @Override // androidx.core.util.Pools$Pool
        public boolean release(T t) {
            if (t instanceof Poolable) {
                t.getVerifier().isReleased = true;
            }
            this.resetter.reset(t);
            return this.pool.release(t);
        }
    }

    public interface Poolable {
        StateVerifier$DefaultStateVerifier getVerifier();
    }

    public interface Resetter<T> {
        void reset(T t);
    }

    public static <T extends Poolable> Pools$Pool<T> threadSafe(int i, Factory<T> factory) {
        return new FactoryPool(new Pools$SynchronizedPool(i), factory, EMPTY_RESETTER);
    }
}
