package com.faster.cheetah.customerview;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.CornerPathEffect;
import android.graphics.Paint;
import android.graphics.Path;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.view.View;
import android.view.WindowManager;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.faster.cheetah.R$styleable;
import java.util.List;
import java.util.Objects;

public class TriangleViewPagerIndicator extends LinearLayout {
    public static final int COLOR_TEXT_NORMAL = Color.parseColor("#FFFFFF");
    public final int DIMENSION_TRIANGLE_WIDTH_MAX;
    public int mInitTranslationX;
    public Paint mPaint;
    public Path mPath;
    public int mTabVisibleCount;
    public List<String> mTitles;
    public int mTriangleHeight;
    public int mTriangleWidth;

    public interface PageOnChangeListener {
    }

    static {
        Color.parseColor("#FFFFFF");
    }

    public TriangleViewPagerIndicator(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.DIMENSION_TRIANGLE_WIDTH_MAX = (int) (((float) (getScreenWidth() / 3)) * 0.16666667f);
    }

    private int getScreenWidth() {
        DisplayMetrics displayMetrics = new DisplayMetrics();
        ((WindowManager) getContext().getSystemService("window")).getDefaultDisplay().getMetrics(displayMetrics);
        return displayMetrics.widthPixels;
    }

    public void dispatchDraw(Canvas canvas) {
        super.dispatchDraw(canvas);
        canvas.save();
        canvas.translate((float) (this.mInitTranslationX + 0), (float) (getHeight() + 2));
        canvas.drawPath(this.mPath, this.mPaint);
        canvas.restore();
    }

    public void onFinishInflate() {
        super.onFinishInflate();
        int childCount = getChildCount();
        if (childCount != 0) {
            for (int i = 0; i < childCount; i++) {
                View childAt = getChildAt(i);
                LinearLayout.LayoutParams layoutParams = (LinearLayout.LayoutParams) childAt.getLayoutParams();
                layoutParams.weight = 0.0f;
                layoutParams.width = getScreenWidth() / this.mTabVisibleCount;
                childAt.setLayoutParams(layoutParams);
            }
            setItemClickEvent();
        }
    }

    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        int i5 = (int) (((float) (i / this.mTabVisibleCount)) * 0.16666667f);
        this.mTriangleWidth = i5;
        int min = Math.min(i5, this.DIMENSION_TRIANGLE_WIDTH_MAX);
        this.mTriangleWidth = min;
        this.mInitTranslationX = ((i / this.mTabVisibleCount) / 2) - (min / 2);
        this.mTriangleHeight = (int) (Math.tan(0.5235987755982988d) * ((double) (min / 2)));
        Path path = new Path();
        this.mPath = path;
        path.moveTo(0.0f, 0.0f);
        this.mPath.lineTo((float) this.mTriangleWidth, 0.0f);
        this.mPath.lineTo((float) (this.mTriangleWidth / 2), (float) (-this.mTriangleHeight));
        this.mPath.close();
    }

    public final void setItemClickEvent() {
        int childCount = getChildCount();
        for (final int i = 0; i < childCount; i++) {
            getChildAt(i).setOnClickListener(new View.OnClickListener() {
                /* class com.faster.cheetah.customerview.TriangleViewPagerIndicator.AnonymousClass2 */

                public void onClick(View view) {
                    TriangleViewPagerIndicator triangleViewPagerIndicator = TriangleViewPagerIndicator.this;
                    int i = TriangleViewPagerIndicator.COLOR_TEXT_NORMAL;
                    Objects.requireNonNull(triangleViewPagerIndicator);
                    throw null;
                }
            });
        }
    }

    public void setTabItemTitles(List<String> list) {
        if (list != null && list.size() > 0) {
            removeAllViews();
            this.mTitles = list;
            for (String str : list) {
                TextView textView = new TextView(getContext());
                LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(-1, -1);
                layoutParams.weight = 1.0f;
                textView.setText(str);
                textView.setGravity(17);
                textView.setTextSize(2, 16.0f);
                textView.setTextColor(COLOR_TEXT_NORMAL);
                textView.setLayoutParams(layoutParams);
                addView(textView);
            }
            setItemClickEvent();
        }
    }

    public void setViewPagerOnPageChangeListener(PageOnChangeListener pageOnChangeListener) {
    }

    public void setVisibleTabCount(int i) {
        this.mTabVisibleCount = i;
    }

    public TriangleViewPagerIndicator(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.DIMENSION_TRIANGLE_WIDTH_MAX = (int) (((float) (getScreenWidth() / 3)) * 0.16666667f);
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.TriangleViewPagerIndicator);
        int i = obtainStyledAttributes.getInt(0, 4);
        this.mTabVisibleCount = i;
        if (i < 0) {
            this.mTabVisibleCount = 4;
        }
        obtainStyledAttributes.recycle();
        Paint paint = new Paint();
        this.mPaint = paint;
        paint.setAntiAlias(true);
        this.mPaint.setColor(Color.parseColor("#ffffff"));
        this.mPaint.setStyle(Paint.Style.FILL);
        this.mPaint.setPathEffect(new CornerPathEffect(3.0f));
    }

    public TriangleViewPagerIndicator(Context context) {
        this(context, null);
    }
}
