package com.faster.cheetah.sdk.shadowsocks.core;

import android.app.PendingIntent;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.VpnService;
import android.os.Build;
import android.os.Handler;
import android.os.ParcelFileDescriptor;
import com.faster.cheetah.MainActivity;
import com.faster.cheetah.sdk.shadowsocks.core.ProxyConfig;
import com.faster.cheetah.sdk.shadowsocks.dns.DnsPacket;
import com.faster.cheetah.sdk.shadowsocks.tcpip.CommonMethods;
import com.faster.cheetah.sdk.shadowsocks.tcpip.IPHeader;
import com.faster.cheetah.sdk.shadowsocks.tcpip.TCPHeader;
import com.faster.cheetah.sdk.shadowsocks.tcpip.UDPHeader;
import com.zfast.xyz.R;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

public class LocalVpnService extends VpnService implements Runnable {
    private static int ID = 0;
    public static LocalVpnService Instance = null;
    public static boolean IsRunning = false;
    private static int LOCAL_IP;
    public static String ProxyUrl;
    private static ConcurrentHashMap<onStatusChangedListener, Object> m_OnStatusChangedListeners = new ConcurrentHashMap<>();
    private ByteBuffer m_DNSBuffer;
    private DnsProxy m_DnsProxy;
    private Handler m_Handler = new Handler();
    private IPHeader m_IPHeader;
    private byte[] m_Packet;
    private long m_ReceivedBytes;
    private long m_SentBytes;
    private TCPHeader m_TCPHeader;
    private TcpProxyServer m_TcpProxyServer;
    private UDPHeader m_UDPHeader;
    private ParcelFileDescriptor m_VPNInterface;
    private FileOutputStream m_VPNOutputStream;
    private Thread m_VPNThread;

    public interface onStatusChangedListener {
        void onLogReceived(String str);

        void onStatusChanged(String str, Boolean bool);
    }

    public LocalVpnService() {
        ID++;
        byte[] bArr = new byte[20000];
        this.m_Packet = bArr;
        this.m_IPHeader = new IPHeader(bArr, 0);
        this.m_TCPHeader = new TCPHeader(this.m_Packet, 20);
        this.m_UDPHeader = new UDPHeader(this.m_Packet, 20);
        this.m_DNSBuffer = ((ByteBuffer) ByteBuffer.wrap(this.m_Packet).position(28)).slice();
        Instance = this;
        System.out.printf("New VPNService(%d)\n", Integer.valueOf(ID));
    }

    public static void addOnStatusChangedListener(onStatusChangedListener onstatuschangedlistener) {
        if (!m_OnStatusChangedListeners.containsKey(onstatuschangedlistener)) {
            m_OnStatusChangedListeners.put(onstatuschangedlistener, 1);
        }
    }

    private synchronized void dispose() {
        disconnectVPN();
        TcpProxyServer tcpProxyServer = this.m_TcpProxyServer;
        if (tcpProxyServer != null) {
            tcpProxyServer.stop();
            this.m_TcpProxyServer = null;
            writeLog("LocalTcpServer stopped.", new Object[0]);
        }
        DnsProxy dnsProxy = this.m_DnsProxy;
        if (dnsProxy != null) {
            dnsProxy.stop();
            this.m_DnsProxy = null;
            writeLog("LocalDnsProxy stopped.", new Object[0]);
        }
        stopSelf();
        IsRunning = false;
        System.exit(0);
    }

    private ParcelFileDescriptor establishVPN() {
        VpnService.Builder builder = new VpnService.Builder(this);
        ProxyConfig proxyConfig = ProxyConfig.Instance;
        builder.setMtu(proxyConfig.getMTU());
        ProxyConfig.IPAddress defaultLocalIP = proxyConfig.getDefaultLocalIP();
        LOCAL_IP = CommonMethods.ipStringToInt(defaultLocalIP.Address);
        builder.addAddress(defaultLocalIP.Address, defaultLocalIP.PrefixLength);
        Iterator<ProxyConfig.IPAddress> it = proxyConfig.getDnsList().iterator();
        while (it.hasNext()) {
            builder.addDnsServer(it.next().Address);
        }
        ProxyConfig proxyConfig2 = ProxyConfig.Instance;
        if (proxyConfig2.getRouteList().size() > 0) {
            Iterator<ProxyConfig.IPAddress> it2 = proxyConfig2.getRouteList().iterator();
            while (it2.hasNext()) {
                ProxyConfig.IPAddress next = it2.next();
                builder.addRoute(next.Address, next.PrefixLength);
            }
            builder.addRoute(CommonMethods.ipIntToString(ProxyConfig.FAKE_NETWORK_IP), 16);
        } else {
            builder.addRoute("0.0.0.0", 0);
        }
        Method method = Class.forName("android.os.SystemProperties").getMethod("get", String.class);
        ArrayList arrayList = new ArrayList();
        String[] strArr = {"net.dns1", "net.dns2", "net.dns3", "net.dns4"};
        for (int i = 0; i < 4; i++) {
            String str = (String) method.invoke(null, strArr[i]);
            if (str != null && !"".equals(str) && !arrayList.contains(str)) {
                arrayList.add(str);
                if (str.replaceAll("\\d", "").equals("...")) {
                    builder.addRoute(str, 32);
                } else {
                    builder.addRoute(str, 128);
                }
            }
        }
        builder.setConfigureIntent(PendingIntent.getActivity(this, 0, new Intent(this, MainActivity.class), 0));
        ProxyConfig proxyConfig3 = ProxyConfig.Instance;
        builder.setSession(proxyConfig3.getSessionName());
        ParcelFileDescriptor establish = builder.establish();
        onStatusChanged(proxyConfig3.getSessionName() + getString(R.string.status_connected), true);
        return establish;
    }

    private void onStatusChanged(final String str, final boolean z) {
        this.m_Handler.post(new Runnable() {
            /* class com.faster.cheetah.sdk.shadowsocks.core.LocalVpnService.AnonymousClass1 */

            public void run() {
                for (Map.Entry entry : LocalVpnService.m_OnStatusChangedListeners.entrySet()) {
                    ((onStatusChangedListener) entry.getKey()).onStatusChanged(str, Boolean.valueOf(z));
                }
            }
        });
    }

    public static void removeOnStatusChangedListener(onStatusChangedListener onstatuschangedlistener) {
        if (m_OnStatusChangedListeners.containsKey(onstatuschangedlistener)) {
            m_OnStatusChangedListeners.remove(onstatuschangedlistener);
        }
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(3:19|20|21) */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x004e, code lost:
        throw new java.lang.Exception("LocalServer stopped.");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0055, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x005c, code lost:
        throw new java.lang.Exception("LocalServer stopped.");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x005d, code lost:
        r1.close();
        disconnectVPN();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x0063, code lost:
        throw r0;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0057 */
    private void runVPN() {
        this.m_VPNInterface = establishVPN();
        this.m_VPNOutputStream = new FileOutputStream(this.m_VPNInterface.getFileDescriptor());
        FileInputStream fileInputStream = new FileInputStream(this.m_VPNInterface.getFileDescriptor());
        int i = 0;
        loop0:
        while (i != -1) {
            if (!IsRunning) {
                break;
            }
            while (true) {
                i = fileInputStream.read(this.m_Packet);
                if (i <= 0 || !IsRunning) {
                    Thread.sleep(20);
                } else if (this.m_DnsProxy.Stopped || this.m_TcpProxyServer.Stopped) {
                    fileInputStream.close();
                } else {
                    onIPPacketReceived(this.m_IPHeader, i);
                }
            }
            Thread.sleep(20);
        }
        fileInputStream.close();
        disconnectVPN();
    }

    private void waitUntilPreapred() {
        while (VpnService.prepare(this) != null) {
            try {
                Thread.sleep(100);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
    }

    public void disconnectVPN() {
        try {
            ParcelFileDescriptor parcelFileDescriptor = this.m_VPNInterface;
            if (parcelFileDescriptor != null) {
                parcelFileDescriptor.close();
                this.m_VPNInterface = null;
            }
        } catch (Exception unused) {
        }
        onStatusChanged(ProxyConfig.Instance.getSessionName() + getString(R.string.status_disconnected), false);
        this.m_VPNOutputStream = null;
    }

    public String getAppInstallID() {
        SharedPreferences sharedPreferences = getSharedPreferences("SmartProxy", 0);
        String string = sharedPreferences.getString("AppInstallID", null);
        if (string != null && !string.isEmpty()) {
            return string;
        }
        String uuid = UUID.randomUUID().toString();
        SharedPreferences.Editor edit = sharedPreferences.edit();
        edit.putString("AppInstallID", uuid);
        edit.apply();
        return uuid;
    }

    public String getVersionName() {
        try {
            return getPackageManager().getPackageInfo(getPackageName(), 0).versionName;
        } catch (Exception unused) {
            return "0.0";
        }
    }

    public void onCreate() {
        System.out.printf("VPNService(%s) created.\n", Integer.valueOf(ID));
        Thread thread = new Thread(this, "VPNServiceThread");
        this.m_VPNThread = thread;
        thread.start();
        super.onCreate();
    }

    public void onDestroy() {
        System.out.printf("VPNService(%s) destoried.\n", Integer.valueOf(ID));
        Thread thread = this.m_VPNThread;
        if (thread != null) {
            thread.interrupt();
        }
    }

    public void onIPPacketReceived(IPHeader iPHeader, int i) {
        byte protocol = iPHeader.getProtocol();
        if (protocol == 6) {
            TCPHeader tCPHeader = this.m_TCPHeader;
            System.out.println(this.m_IPHeader);
            tCPHeader.m_Offset = iPHeader.getHeaderLength();
            if (iPHeader.getSourceIP() != LOCAL_IP) {
                return;
            }
            if (tCPHeader.getSourcePort() == this.m_TcpProxyServer.Port) {
                NatSession session = NatSessionManager.getSession(tCPHeader.getDestinationPort());
                if (session != null) {
                    iPHeader.setSourceIP(iPHeader.getDestinationIP());
                    tCPHeader.setSourcePort(session.RemotePort);
                    iPHeader.setDestinationIP(LOCAL_IP);
                    CommonMethods.ComputeTCPChecksum(iPHeader, tCPHeader);
                    this.m_VPNOutputStream.write(iPHeader.m_Data, iPHeader.m_Offset, i);
                    this.m_ReceivedBytes += (long) i;
                    return;
                }
                System.out.printf("NoSession: %s %s\n", iPHeader.toString(), tCPHeader.toString());
                return;
            }
            short sourcePort = tCPHeader.getSourcePort();
            NatSession session2 = NatSessionManager.getSession(sourcePort);
            if (!(session2 != null && session2.RemoteIP == iPHeader.getDestinationIP() && session2.RemotePort == tCPHeader.getDestinationPort())) {
                session2 = NatSessionManager.createSession(sourcePort, iPHeader.getDestinationIP(), tCPHeader.getDestinationPort());
            }
            session2.LastNanoTime = System.nanoTime();
            session2.PacketSent++;
            int dataLength = iPHeader.getDataLength() - tCPHeader.getHeaderLength();
            if (session2.PacketSent != 2 || dataLength != 0) {
                if (session2.BytesSent == 0 && dataLength > 10) {
                    String parseHost = HttpHostHeaderParser.parseHost(tCPHeader.m_Data, tCPHeader.getHeaderLength() + tCPHeader.m_Offset, dataLength);
                    if (parseHost != null) {
                        session2.RemoteHost = parseHost;
                    } else {
                        System.out.printf("No host name found: %s", session2.RemoteHost);
                    }
                }
                iPHeader.setSourceIP(iPHeader.getDestinationIP());
                iPHeader.setDestinationIP(LOCAL_IP);
                tCPHeader.setDestinationPort(this.m_TcpProxyServer.Port);
                CommonMethods.ComputeTCPChecksum(iPHeader, tCPHeader);
                this.m_VPNOutputStream.write(iPHeader.m_Data, iPHeader.m_Offset, i);
                session2.BytesSent += dataLength;
                this.m_SentBytes += (long) i;
            }
        } else if (protocol == 17) {
            UDPHeader uDPHeader = this.m_UDPHeader;
            uDPHeader.m_Offset = iPHeader.getHeaderLength();
            if (iPHeader.getSourceIP() == LOCAL_IP && uDPHeader.getDestinationPort() == 53) {
                this.m_DNSBuffer.clear();
                this.m_DNSBuffer.limit(iPHeader.getDataLength() - 8);
                DnsPacket FromBytes = DnsPacket.FromBytes(this.m_DNSBuffer);
                if (FromBytes != null && FromBytes.Header.QuestionCount > 0) {
                    this.m_DnsProxy.onDnsRequestReceived(iPHeader, uDPHeader, FromBytes);
                }
            }
        }
    }

    public int onStartCommand(Intent intent, int i, int i2) {
        IsRunning = true;
        return super.onStartCommand(intent, i, i2);
    }

    public synchronized void run() {
        String str;
        try {
            System.out.printf("VPNService(%s) work thread is runing...\n", Integer.valueOf(ID));
            ProxyConfig.AppInstallID = getAppInstallID();
            ProxyConfig.AppVersion = getVersionName();
            System.out.printf("AppInstallID: %s\n", ProxyConfig.AppInstallID);
            writeLog("Android version: %s", Build.VERSION.RELEASE);
            writeLog("App version: %s", ProxyConfig.AppVersion);
            ChinaIpMaskManager.loadFromFile(getResources().openRawResource(R.raw.ipmask));
            waitUntilPreapred();
            writeLog("Load config from file ...", new Object[0]);
            try {
                ProxyConfig.Instance.loadFromFile(getResources().openRawResource(R.raw.config));
                writeLog("Load done", new Object[0]);
            } catch (Exception e) {
                String message = e.getMessage();
                if (message == null || message.isEmpty()) {
                    message = e.toString();
                }
                writeLog("Load failed with error: %s", message);
            }
            while (true) {
                if (IsRunning) {
                    TcpProxyServer tcpProxyServer = new TcpProxyServer(0);
                    this.m_TcpProxyServer = tcpProxyServer;
                    tcpProxyServer.start();
                    writeLog("LocalTcpServer started.", new Object[0]);
                    DnsProxy dnsProxy = new DnsProxy();
                    this.m_DnsProxy = dnsProxy;
                    dnsProxy.start();
                    writeLog("LocalDnsProxy started.", new Object[0]);
                    writeLog("set shadowsocks/(http proxy)", new Object[0]);
                    try {
                        ProxyConfig proxyConfig = ProxyConfig.Instance;
                        proxyConfig.m_ProxyList.clear();
                        proxyConfig.addProxyToList(ProxyUrl);
                        writeLog("Proxy is: %s", proxyConfig.getDefaultProxy());
                        String welcomeInfo = proxyConfig.getWelcomeInfo();
                        if (welcomeInfo != null && !welcomeInfo.isEmpty()) {
                            writeLog("%s", proxyConfig.getWelcomeInfo());
                        }
                        StringBuilder sb = new StringBuilder();
                        sb.append("Global mode is ");
                        sb.append(proxyConfig.globalMode ? "on" : "off");
                        writeLog(sb.toString(), new Object[0]);
                        try {
                            runVPN();
                            TcpProxyServer tcpProxyServer2 = this.m_TcpProxyServer;
                            if (tcpProxyServer2 != null) {
                                tcpProxyServer2.stop();
                                this.m_TcpProxyServer = null;
                                writeLog("LocalTcpServer stopped.", new Object[0]);
                            }
                            DnsProxy dnsProxy2 = this.m_DnsProxy;
                            if (dnsProxy2 != null) {
                                dnsProxy2.stop();
                                this.m_DnsProxy = null;
                                writeLog("LocalDnsProxy stopped.", new Object[0]);
                            }
                            IsRunning = false;
                            str = proxyConfig.getSessionName() + getString(R.string.status_disconnected);
                        } catch (Exception e2) {
                            e2.printStackTrace();
                            if (this.m_TcpProxyServer != null) {
                                this.m_TcpProxyServer.stop();
                                this.m_TcpProxyServer = null;
                                writeLog("LocalTcpServer stopped.", new Object[0]);
                            }
                            DnsProxy dnsProxy3 = this.m_DnsProxy;
                            if (dnsProxy3 != null) {
                                dnsProxy3.stop();
                                this.m_DnsProxy = null;
                                writeLog("LocalDnsProxy stopped.", new Object[0]);
                            }
                            IsRunning = false;
                            str = ProxyConfig.Instance.getSessionName() + getString(R.string.status_disconnected);
                        } catch (Throwable th) {
                            TcpProxyServer tcpProxyServer3 = this.m_TcpProxyServer;
                            if (tcpProxyServer3 != null) {
                                tcpProxyServer3.stop();
                                this.m_TcpProxyServer = null;
                                writeLog("LocalTcpServer stopped.", new Object[0]);
                            }
                            DnsProxy dnsProxy4 = this.m_DnsProxy;
                            if (dnsProxy4 != null) {
                                dnsProxy4.stop();
                                this.m_DnsProxy = null;
                                writeLog("LocalDnsProxy stopped.", new Object[0]);
                            }
                            IsRunning = false;
                            onStatusChanged(ProxyConfig.Instance.getSessionName() + getString(R.string.status_disconnected), false);
                            throw th;
                        }
                        onStatusChanged(str, false);
                    } catch (Exception e3) {
                        String message2 = e3.getMessage();
                        if (message2 == null || message2.isEmpty()) {
                            message2 = e3.toString();
                        }
                        IsRunning = false;
                        onStatusChanged(message2, false);
                    }
                } else {
                    Thread.sleep(100);
                }
            }
        } catch (InterruptedException e4) {
            System.out.println(e4);
            writeLog("App terminated.", new Object[0]);
        } catch (Exception e5) {
            e5.printStackTrace();
            writeLog("Fatal error: %s", e5.toString());
            writeLog("App terminated.", new Object[0]);
        } catch (Throwable th2) {
            writeLog("App terminated.", new Object[0]);
            dispose();
            throw th2;
        }
        dispose();
    }

    public void sendUDPPacket(IPHeader iPHeader, UDPHeader uDPHeader) {
        try {
            CommonMethods.ComputeUDPChecksum(iPHeader, uDPHeader);
            this.m_VPNOutputStream.write(iPHeader.m_Data, iPHeader.m_Offset, iPHeader.getTotalLength());
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void writeLog(String str, Object... objArr) {
        final String format = String.format(str, objArr);
        System.out.println(format);
        this.m_Handler.post(new Runnable() {
            /* class com.faster.cheetah.sdk.shadowsocks.core.LocalVpnService.AnonymousClass2 */

            public void run() {
                for (Map.Entry entry : LocalVpnService.m_OnStatusChangedListeners.entrySet()) {
                    ((onStatusChangedListener) entry.getKey()).onLogReceived(format);
                }
            }
        });
    }
}
