package com.faster.cheetah.sdk.shadowsocks.core;

import android.annotation.SuppressLint;
import android.os.Build;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.shadowsocks.tcpip.CommonMethods;
import com.faster.cheetah.sdk.shadowsocks.tunnel.Config;
import com.faster.cheetah.sdk.shadowsocks.tunnel.httpconnect.HttpConnectConfig;
import com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ShadowsocksConfig;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import com.squareup.okhttp.internal.DiskLruCache;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Timer;
import java.util.TimerTask;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;

public class ProxyConfig {
    public static String AppInstallID = null;
    public static String AppVersion = null;
    public static final int FAKE_NETWORK_IP = CommonMethods.ipStringToInt("172.25.0.0");
    public static final int FAKE_NETWORK_MASK = CommonMethods.ipStringToInt("255.255.0.0");
    public static final boolean IS_DEBUG = false;
    public static final ProxyConfig Instance = new ProxyConfig();
    public static List<String> listFilterIP = null;
    public static boolean needTurn = false;
    public boolean globalMode = false;
    public ArrayList<IPAddress> m_DnsList = new ArrayList<>();
    public HashMap<String, Boolean> m_DomainMap = new HashMap<>();
    public ArrayList<IPAddress> m_IpList = new ArrayList<>();
    public ArrayList<Config> m_ProxyList = new ArrayList<>();
    public ArrayList<IPAddress> m_RouteList = new ArrayList<>();
    public TimerTask m_Task = new TimerTask() {
        /* class com.faster.cheetah.sdk.shadowsocks.core.ProxyConfig.AnonymousClass1 */

        public void refreshProxyServer() {
            for (int i = 0; i < ProxyConfig.this.m_ProxyList.size(); i++) {
                try {
                    try {
                        Config config = ProxyConfig.this.m_ProxyList.get(0);
                        InetAddress byName = InetAddress.getByName(config.ServerAddress.getHostName());
                        if (byName != null && !byName.equals(config.ServerAddress.getAddress())) {
                            config.ServerAddress = new InetSocketAddress(byName, config.ServerAddress.getPort());
                        }
                    } catch (Exception unused) {
                    }
                } catch (Exception unused2) {
                    return;
                }
            }
        }

        public void run() {
            refreshProxyServer();
        }
    };
    public Timer m_Timer;
    public int m_dns_ttl;
    public boolean m_isolate_http_host_header = true;
    public int m_mtu;
    public boolean m_outside_china_use_proxy = true;
    public String m_session_name;
    public String m_user_agent;
    public String m_welcome_info;

    public ProxyConfig() {
        Timer timer = new Timer();
        this.m_Timer = timer;
        timer.schedule(this.m_Task, 120000, 120000);
    }

    private void addDomainToHashMap(String[] strArr, int i, Boolean bool) {
        while (i < strArr.length) {
            String trim = strArr[i].toLowerCase().trim();
            if (trim.charAt(0) == '.') {
                trim = trim.substring(1);
            }
            this.m_DomainMap.put(trim, bool);
            i++;
        }
    }

    private void addIPAddressToList(String[] strArr, int i, ArrayList<IPAddress> arrayList) {
        while (i < strArr.length) {
            String lowerCase = strArr[i].trim().toLowerCase();
            if (!lowerCase.startsWith("#")) {
                IPAddress iPAddress = new IPAddress(lowerCase);
                if (!arrayList.contains(iPAddress)) {
                    arrayList.add(iPAddress);
                }
                i++;
            } else {
                return;
            }
        }
    }

    private boolean convertToBool(String str) {
        if (str == null || str.isEmpty()) {
            return false;
        }
        String trim = str.toLowerCase(Locale.ENGLISH).trim();
        if (trim.equals("on") || trim.equals(DiskLruCache.VERSION_1) || trim.equals("true") || trim.equals("yes")) {
            return true;
        }
        return false;
    }

    private String[] downloadConfig(String str) {
        try {
            DefaultHttpClient defaultHttpClient = new DefaultHttpClient();
            HttpGet httpGet = new HttpGet(str);
            httpGet.addHeader("X-Android-MODEL", Build.MODEL);
            httpGet.addHeader("X-Android-SDK_INT", Integer.toString(Build.VERSION.SDK_INT));
            httpGet.addHeader("X-Android-RELEASE", Build.VERSION.RELEASE);
            httpGet.addHeader("X-App-Version", AppVersion);
            httpGet.addHeader("X-App-Install-ID", AppInstallID);
            httpGet.setHeader("User-Agent", System.getProperty("http.agent"));
            return EntityUtils.toString(defaultHttpClient.execute(httpGet).getEntity(), "UTF-8").split("\\n");
        } catch (Exception unused) {
            throw new Exception(String.format("Download config file from %s failed.", str));
        }
    }

    private Boolean getDomainState(String str) {
        String lowerCase = str.toLowerCase();
        while (lowerCase.length() > 0) {
            Boolean bool = this.m_DomainMap.get(lowerCase);
            if (bool == null) {
                int indexOf = lowerCase.indexOf(46) + 1;
                if (indexOf <= 0 || indexOf >= lowerCase.length()) {
                    break;
                }
                lowerCase = lowerCase.substring(indexOf);
            } else {
                return bool;
            }
        }
        return null;
    }

    public static boolean isFakeIP(int i) {
        return (i & FAKE_NETWORK_MASK) == FAKE_NETWORK_IP;
    }

    private boolean isFilterIP(String str, int i) {
        List<String> list = listFilterIP;
        if (list == null) {
            return false;
        }
        if (list.contains(str)) {
            return true;
        }
        if (i == 0 || !listFilterIP.contains(CommonMethods.ipIntToString(i))) {
            return false;
        }
        return true;
    }

    private boolean myNeedProxy(String str, int i) {
        Boolean domainState;
        if (isFilterIP(str, i)) {
            return false;
        }
        if (this.globalMode) {
            return true;
        }
        if (str != null && (domainState = getDomainState(str)) != null) {
            return domainState.booleanValue();
        }
        if (isFakeIP(i)) {
            return true;
        }
        if (!this.m_outside_china_use_proxy || i == 0) {
            return false;
        }
        if (needTurn) {
            return ChinaIpMaskManager.isIPInChina(i);
        }
        return !ChinaIpMaskManager.isIPInChina(i);
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(5:15|14|17|18|19) */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0034, code lost:
        r8 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:?, code lost:
        r3.close();
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0036 */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0049 A[SYNTHETIC, Splitter:B:21:0x0049] */
    private String[] readConfigFromFile(String str) {
        StringBuilder sb = new StringBuilder();
        FileInputStream fileInputStream = null;
        byte[] bArr = new byte[8192];
        FileInputStream fileInputStream2 = new FileInputStream(str);
        while (true) {
            try {
                int read = fileInputStream2.read(bArr);
                if (read <= 0) {
                    break;
                }
                sb.append(new String(bArr, 0, read, "UTF-8"));
            } catch (Exception unused) {
                fileInputStream = fileInputStream2;
                throw new Exception(String.format("Can't read config file: %s", str));
            } catch (Throwable th) {
                Throwable th2 = th;
                fileInputStream = fileInputStream2;
                if (fileInputStream != null) {
                }
                throw th2;
            }
        }
        String[] split = sb.toString().split("\\n");
        try {
            fileInputStream2.close();
        } catch (Exception unused2) {
        }
        return split;
    }

    private void tryAddProxy(String[] strArr) {
        for (String str : strArr) {
            Matcher matcher = Pattern.compile("proxy\\s+([^:]+):(\\d+)", 2).matcher(str);
            while (matcher.find()) {
                HttpConnectConfig httpConnectConfig = new HttpConnectConfig();
                httpConnectConfig.ServerAddress = new InetSocketAddress(matcher.group(1), Integer.parseInt(matcher.group(2)));
                if (!this.m_ProxyList.contains(httpConnectConfig)) {
                    this.m_ProxyList.add(httpConnectConfig);
                    this.m_DomainMap.put(httpConnectConfig.ServerAddress.getHostName(), Boolean.FALSE);
                }
            }
        }
    }

    public void addProxyToList(String str) {
        Config config;
        if (str.startsWith("ss://")) {
            config = ShadowsocksConfig.parse(str);
        } else {
            if (!str.toLowerCase().startsWith("http://")) {
                str = GeneratedOutlineSupport.outline18("http://", str);
            }
            config = HttpConnectConfig.parse(str);
        }
        if (!this.m_ProxyList.contains(config)) {
            this.m_ProxyList.add(config);
            this.m_DomainMap.put(config.ServerAddress.getHostName(), Boolean.FALSE);
        }
    }

    public IPAddress getDefaultLocalIP() {
        if (this.m_IpList.size() > 0) {
            return this.m_IpList.get(0);
        }
        return new IPAddress("10.8.0.2", 32);
    }

    public Config getDefaultProxy() {
        if (this.m_ProxyList.size() > 0) {
            return this.m_ProxyList.get(0);
        }
        return null;
    }

    public Config getDefaultTunnelConfig(InetSocketAddress inetSocketAddress) {
        return getDefaultProxy();
    }

    public ArrayList<IPAddress> getDnsList() {
        return this.m_DnsList;
    }

    public int getDnsTTL() {
        if (this.m_dns_ttl < 30) {
            this.m_dns_ttl = 30;
        }
        return this.m_dns_ttl;
    }

    public int getMTU() {
        int i = this.m_mtu;
        if (i <= 1400 || i > 20000) {
            return 20000;
        }
        return i;
    }

    public ArrayList<IPAddress> getRouteList() {
        return this.m_RouteList;
    }

    public String getSessionName() {
        if (this.m_session_name == null) {
            this.m_session_name = getDefaultProxy().ServerAddress.getHostName();
        }
        return this.m_session_name;
    }

    public String getUserAgent() {
        String str = this.m_user_agent;
        if (str == null || str.isEmpty()) {
            this.m_user_agent = System.getProperty("http.agent");
        }
        return this.m_user_agent;
    }

    public String getWelcomeInfo() {
        return this.m_welcome_info;
    }

    public boolean isIsolateHttpHostHeader() {
        return this.m_isolate_http_host_header;
    }

    public void loadFromFile(InputStream inputStream) {
        byte[] bArr = new byte[inputStream.available()];
        inputStream.read(bArr);
        loadFromLines(new String(bArr).split("\\r?\\n"));
    }

    public void loadFromLines(String[] strArr) {
        this.m_IpList.clear();
        this.m_DnsList.clear();
        this.m_RouteList.clear();
        this.m_ProxyList.clear();
        this.m_DomainMap.clear();
        int i = 0;
        for (String str : strArr) {
            i++;
            String[] split = str.split("\\s+");
            if (split.length >= 2) {
                String trim = split[0].toLowerCase(Locale.ENGLISH).trim();
                try {
                    if (!trim.startsWith("#")) {
                        if (trim.equals("ip")) {
                            addIPAddressToList(split, 1, this.m_IpList);
                        } else if (trim.equals("dns")) {
                            addIPAddressToList(split, 1, this.m_DnsList);
                        } else if (trim.equals("route")) {
                            addIPAddressToList(split, 1, this.m_RouteList);
                        } else if (trim.equals("proxy")) {
                            addProxyToList(split, 1);
                        } else if (trim.equals("direct_domain")) {
                            addDomainToHashMap(split, 1, Boolean.FALSE);
                        } else if (trim.equals("proxy_domain")) {
                            addDomainToHashMap(split, 1, Boolean.TRUE);
                        } else if (trim.equals("dns_ttl")) {
                            this.m_dns_ttl = Integer.parseInt(split[1]);
                        } else if (trim.equals("welcome_info")) {
                            this.m_welcome_info = str.substring(str.indexOf(" ")).trim();
                        } else if (trim.equals("session_name")) {
                            this.m_session_name = split[1];
                        } else if (trim.equals("user_agent")) {
                            this.m_user_agent = str.substring(str.indexOf(" ")).trim();
                        } else if (trim.equals("outside_china_use_proxy")) {
                            this.m_outside_china_use_proxy = convertToBool(split[1]);
                        } else if (trim.equals("isolate_http_host_header")) {
                            this.m_isolate_http_host_header = convertToBool(split[1]);
                        } else if (trim.equals(VpnProfileDataSource.KEY_MTU)) {
                            this.m_mtu = Integer.parseInt(split[1]);
                        }
                    }
                } catch (Exception e) {
                    throw new Exception(String.format("config file parse error: line:%d, tag:%s, error:%s", Integer.valueOf(i), trim, e));
                }
            }
        }
        if (this.m_ProxyList.size() == 0) {
            tryAddProxy(strArr);
        }
    }

    public void loadFromUrl(String str) {
        String[] strArr;
        if (str.charAt(0) == '/') {
            strArr = readConfigFromFile(str);
        } else {
            strArr = downloadConfig(str);
        }
        loadFromLines(strArr);
    }

    public boolean needProxy(String str, int i) {
        return myNeedProxy(str, i);
    }

    public class IPAddress {
        public final String Address;
        public final int PrefixLength;

        public IPAddress(String str, int i) {
            this.Address = str;
            this.PrefixLength = i;
        }

        public boolean equals(Object obj) {
            if (obj == null) {
                return false;
            }
            return toString().equals(obj.toString());
        }

        @SuppressLint({"DefaultLocale"})
        public String toString() {
            return String.format("%s/%d", this.Address, Integer.valueOf(this.PrefixLength));
        }

        public IPAddress(String str) {
            String[] split = str.split("/");
            String str2 = split[0];
            int parseInt = split.length > 1 ? Integer.parseInt(split[1]) : 32;
            this.Address = str2;
            this.PrefixLength = parseInt;
        }
    }

    private void addProxyToList(String[] strArr, int i) {
        while (i < strArr.length) {
            addProxyToList(strArr[i].trim());
            i++;
        }
    }
}
