package com.faster.cheetah.sdk.shadowsocks.core;

import com.faster.cheetah.sdk.shadowsocks.tunnel.Config;
import com.faster.cheetah.sdk.shadowsocks.tunnel.RawTunnel;
import com.faster.cheetah.sdk.shadowsocks.tunnel.Tunnel;
import com.faster.cheetah.sdk.shadowsocks.tunnel.httpconnect.HttpConnectConfig;
import com.faster.cheetah.sdk.shadowsocks.tunnel.httpconnect.HttpConnectTunnel;
import com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ShadowsocksConfig;
import com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ShadowsocksTunnel;
import java.net.InetSocketAddress;
import java.nio.channels.Selector;
import java.nio.channels.SocketChannel;

public class TunnelFactory {
    public static Tunnel createTunnelByConfig(InetSocketAddress inetSocketAddress, Selector selector) {
        if (!inetSocketAddress.isUnresolved()) {
            return new RawTunnel(inetSocketAddress, selector);
        }
        Config defaultTunnelConfig = ProxyConfig.Instance.getDefaultTunnelConfig(inetSocketAddress);
        if (defaultTunnelConfig instanceof HttpConnectConfig) {
            return new HttpConnectTunnel((HttpConnectConfig) defaultTunnelConfig, selector);
        }
        if (defaultTunnelConfig instanceof ShadowsocksConfig) {
            return new ShadowsocksTunnel((ShadowsocksConfig) defaultTunnelConfig, selector);
        }
        throw new Exception("The config is unknow.");
    }

    public static Tunnel wrap(SocketChannel socketChannel, Selector selector) {
        return new RawTunnel(socketChannel, selector);
    }
}
