package com.faster.cheetah.sdk.shadowsocks.tunnel;

import android.annotation.SuppressLint;
import com.faster.cheetah.sdk.shadowsocks.core.LocalVpnService;
import java.net.InetSocketAddress;
import java.nio.ByteBuffer;
import java.nio.channels.SelectionKey;
import java.nio.channels.Selector;
import java.nio.channels.SocketChannel;

public abstract class Tunnel {
    public static final ByteBuffer GL_BUFFER = ByteBuffer.allocate(20000);
    public static long SessionCount;
    private Tunnel m_BrotherTunnel;
    public InetSocketAddress m_DestAddress;
    private boolean m_Disposed;
    private SocketChannel m_InnerChannel;
    private Selector m_Selector;
    private ByteBuffer m_SendRemainBuffer;
    private InetSocketAddress m_ServerEP;

    public Tunnel(SocketChannel socketChannel, Selector selector) {
        this.m_InnerChannel = socketChannel;
        this.m_Selector = selector;
        SessionCount++;
    }

    public abstract void afterReceived(ByteBuffer byteBuffer);

    public abstract void beforeSend(ByteBuffer byteBuffer);

    public void beginReceive() {
        if (this.m_InnerChannel.isBlocking()) {
            this.m_InnerChannel.configureBlocking(false);
        }
        this.m_InnerChannel.register(this.m_Selector, 1, this);
    }

    public void connect(InetSocketAddress inetSocketAddress) {
        if (LocalVpnService.Instance.protect(this.m_InnerChannel.socket())) {
            this.m_DestAddress = inetSocketAddress;
            this.m_InnerChannel.register(this.m_Selector, 8, this);
            this.m_InnerChannel.connect(this.m_ServerEP);
            return;
        }
        throw new Exception("VPN protect socket failed.");
    }

    public void dispose() {
        disposeInternal(true);
    }

    public void disposeInternal(boolean z) {
        if (!this.m_Disposed) {
            try {
                this.m_InnerChannel.close();
            } catch (Exception unused) {
            }
            Tunnel tunnel = this.m_BrotherTunnel;
            if (tunnel != null && z) {
                tunnel.disposeInternal(false);
            }
            this.m_InnerChannel = null;
            this.m_SendRemainBuffer = null;
            this.m_Selector = null;
            this.m_BrotherTunnel = null;
            this.m_Disposed = true;
            SessionCount--;
            onDispose();
        }
    }

    public abstract boolean isTunnelEstablished();

    @SuppressLint({"DefaultLocale"})
    public void onConnectable() {
        try {
            if (this.m_InnerChannel.finishConnect()) {
                onConnected(GL_BUFFER);
                return;
            }
            LocalVpnService.Instance.writeLog("Error: connect to %s failed.", this.m_ServerEP);
            dispose();
        } catch (Exception e) {
            LocalVpnService.Instance.writeLog("Error: connect to %s failed: %s", this.m_ServerEP, e);
            dispose();
        }
    }

    public abstract void onConnected(ByteBuffer byteBuffer);

    public abstract void onDispose();

    public void onReadable(SelectionKey selectionKey) {
        try {
            ByteBuffer byteBuffer = GL_BUFFER;
            byteBuffer.clear();
            int read = this.m_InnerChannel.read(byteBuffer);
            if (read > 0) {
                byteBuffer.flip();
                afterReceived(byteBuffer);
                if (isTunnelEstablished() && byteBuffer.hasRemaining()) {
                    this.m_BrotherTunnel.beforeSend(byteBuffer);
                    if (!this.m_BrotherTunnel.write(byteBuffer, true)) {
                        selectionKey.cancel();
                    }
                }
            } else if (read < 0) {
                dispose();
            }
        } catch (Exception e) {
            e.printStackTrace();
            dispose();
        }
    }

    public void onTunnelEstablished() {
        beginReceive();
        this.m_BrotherTunnel.beginReceive();
    }

    public void onWritable(SelectionKey selectionKey) {
        try {
            beforeSend(this.m_SendRemainBuffer);
            if (write(this.m_SendRemainBuffer, false)) {
                selectionKey.cancel();
                if (isTunnelEstablished()) {
                    this.m_BrotherTunnel.beginReceive();
                } else {
                    beginReceive();
                }
            }
        } catch (Exception unused) {
            dispose();
        }
    }

    public void setBrotherTunnel(Tunnel tunnel) {
        this.m_BrotherTunnel = tunnel;
    }

    /* JADX WARNING: Removed duplicated region for block: B:2:0x0006  */
    public boolean write(ByteBuffer byteBuffer, boolean z) {
        while (byteBuffer.hasRemaining() && this.m_InnerChannel.write(byteBuffer) != 0) {
            while (byteBuffer.hasRemaining()) {
                while (byteBuffer.hasRemaining()) {
                }
            }
        }
        if (!byteBuffer.hasRemaining()) {
            return true;
        }
        if (!z) {
            return false;
        }
        if (this.m_SendRemainBuffer == null) {
            this.m_SendRemainBuffer = ByteBuffer.allocate(byteBuffer.capacity());
        }
        this.m_SendRemainBuffer.clear();
        this.m_SendRemainBuffer.put(byteBuffer);
        this.m_SendRemainBuffer.flip();
        this.m_InnerChannel.register(this.m_Selector, 4, this);
        return false;
    }

    public Tunnel(InetSocketAddress inetSocketAddress, Selector selector) {
        SocketChannel open = SocketChannel.open();
        open.configureBlocking(false);
        this.m_InnerChannel = open;
        this.m_Selector = selector;
        this.m_ServerEP = inetSocketAddress;
        SessionCount++;
    }
}
