package com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks;

import java.io.ByteArrayOutputStream;
import java.security.InvalidAlgorithmParameterException;
import java.util.HashMap;
import java.util.Map;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import org.bouncycastle.crypto.StreamBlockCipher;
import org.bouncycastle.crypto.engines.AESFastEngine;
import org.bouncycastle.crypto.modes.CFBBlockCipher;
import org.bouncycastle.crypto.modes.OFBBlockCipher;

public class AesCrypt extends CryptBase {
    public static final String CIPHER_AES_128_CFB = "aes-128-cfb";
    public static final String CIPHER_AES_128_OFB = "aes-128-ofb";
    public static final String CIPHER_AES_192_CFB = "aes-192-cfb";
    public static final String CIPHER_AES_192_OFB = "aes-192-ofb";
    public static final String CIPHER_AES_256_CFB = "aes-256-cfb";
    public static final String CIPHER_AES_256_OFB = "aes-256-ofb";

    public AesCrypt(String str, String str2) {
        super(str, str2);
    }

    public static Map<String, String> getCiphers() {
        HashMap hashMap = new HashMap();
        hashMap.put(CIPHER_AES_128_CFB, AesCrypt.class.getName());
        hashMap.put(CIPHER_AES_192_CFB, AesCrypt.class.getName());
        hashMap.put(CIPHER_AES_256_CFB, AesCrypt.class.getName());
        hashMap.put(CIPHER_AES_128_OFB, AesCrypt.class.getName());
        hashMap.put(CIPHER_AES_192_OFB, AesCrypt.class.getName());
        hashMap.put(CIPHER_AES_256_OFB, AesCrypt.class.getName());
        return hashMap;
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public void _decrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr2 = new byte[bArr.length];
        byteArrayOutputStream.write(bArr2, 0, this.decCipher.processBytes(bArr, 0, bArr.length, bArr2, 0));
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public void _encrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr2 = new byte[bArr.length];
        byteArrayOutputStream.write(bArr2, 0, this.encCipher.processBytes(bArr, 0, bArr.length, bArr2, 0));
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public int getIVLength() {
        return 16;
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public SecretKey getKey() {
        return new SecretKeySpec(this._ssKey.getEncoded(), "AES");
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public int getKeyLength() {
        if (this._name.equals(CIPHER_AES_128_CFB) || this._name.equals(CIPHER_AES_128_OFB)) {
            return 16;
        }
        if (this._name.equals(CIPHER_AES_192_CFB) || this._name.equals(CIPHER_AES_192_OFB)) {
            return 24;
        }
        return (this._name.equals(CIPHER_AES_256_CFB) || this._name.equals(CIPHER_AES_256_OFB)) ? 32 : 0;
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public StreamBlockCipher getCipher(boolean z) {
        AESFastEngine aESFastEngine = new AESFastEngine();
        if (this._name.equals(CIPHER_AES_128_CFB)) {
            return new CFBBlockCipher(aESFastEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_AES_192_CFB)) {
            return new CFBBlockCipher(aESFastEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_AES_256_CFB)) {
            return new CFBBlockCipher(aESFastEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_AES_128_OFB)) {
            return new OFBBlockCipher(aESFastEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_AES_192_OFB)) {
            return new OFBBlockCipher(aESFastEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_AES_256_OFB)) {
            return new OFBBlockCipher(aESFastEngine, getIVLength() * 8);
        }
        throw new InvalidAlgorithmParameterException(this._name);
    }
}
