package com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks;

import java.io.ByteArrayOutputStream;
import java.security.InvalidAlgorithmParameterException;
import java.util.HashMap;
import java.util.Map;
import javax.crypto.SecretKey;
import javax.crypto.spec.SecretKeySpec;
import org.bouncycastle.crypto.StreamBlockCipher;
import org.bouncycastle.crypto.engines.CamelliaEngine;
import org.bouncycastle.crypto.modes.CFBBlockCipher;

public class CamelliaCrypt extends CryptBase {
    public static final String CIPHER_CAMELLIA_128_CFB = "camellia-128-cfb";
    public static final String CIPHER_CAMELLIA_192_CFB = "camellia-192-cfb";
    public static final String CIPHER_CAMELLIA_256_CFB = "camellia-256-cfb";

    public CamelliaCrypt(String str, String str2) {
        super(str, str2);
    }

    public static Map<String, String> getCiphers() {
        HashMap hashMap = new HashMap();
        hashMap.put(CIPHER_CAMELLIA_128_CFB, CamelliaCrypt.class.getName());
        hashMap.put(CIPHER_CAMELLIA_192_CFB, CamelliaCrypt.class.getName());
        hashMap.put(CIPHER_CAMELLIA_256_CFB, CamelliaCrypt.class.getName());
        return hashMap;
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public void _decrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr2 = new byte[bArr.length];
        byteArrayOutputStream.write(bArr2, 0, this.decCipher.processBytes(bArr, 0, bArr.length, bArr2, 0));
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public void _encrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr2 = new byte[bArr.length];
        byteArrayOutputStream.write(bArr2, 0, this.encCipher.processBytes(bArr, 0, bArr.length, bArr2, 0));
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public int getIVLength() {
        return 16;
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public SecretKey getKey() {
        return new SecretKeySpec(this._ssKey.getEncoded(), "AES");
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public int getKeyLength() {
        if (this._name.equals(CIPHER_CAMELLIA_128_CFB)) {
            return 16;
        }
        if (this._name.equals(CIPHER_CAMELLIA_192_CFB)) {
            return 24;
        }
        return this._name.equals(CIPHER_CAMELLIA_256_CFB) ? 32 : 0;
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.CryptBase
    public StreamBlockCipher getCipher(boolean z) {
        CamelliaEngine camelliaEngine = new CamelliaEngine();
        if (this._name.equals(CIPHER_CAMELLIA_128_CFB)) {
            return new CFBBlockCipher(camelliaEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_CAMELLIA_192_CFB)) {
            return new CFBBlockCipher(camelliaEngine, getIVLength() * 8);
        }
        if (this._name.equals(CIPHER_CAMELLIA_256_CFB)) {
            return new CFBBlockCipher(camelliaEngine, getIVLength() * 8);
        }
        throw new InvalidAlgorithmParameterException(this._name);
    }
}
