package com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.security.InvalidAlgorithmParameterException;
import java.security.MessageDigest;
import java.security.SecureRandom;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;
import java.util.logging.Logger;
import javax.crypto.SecretKey;
import org.bouncycastle.crypto.CipherParameters;
import org.bouncycastle.crypto.StreamCipher;
import org.bouncycastle.crypto.params.KeyParameter;
import org.bouncycastle.crypto.params.ParametersWithIV;

public abstract class CryptBase implements ICrypt {
    public byte[] _decryptIV;
    public boolean _decryptIVSet;
    public byte[] _encryptIV;
    public boolean _encryptIVSet;
    public final int _ivLength;
    public final SecretKey _key;
    public final int _keyLength;
    public final String _name;
    public final ShadowSocksKey _ssKey;
    public StreamCipher decCipher;
    public final Lock decLock = new ReentrantLock();
    public StreamCipher encCipher;
    public final Lock encLock = new ReentrantLock();
    private Logger logger = Logger.getLogger(CryptBase.class.getName());

    public CryptBase(String str, String str2) {
        this._name = str.toLowerCase();
        this._ivLength = getIVLength();
        int keyLength = getKeyLength();
        this._keyLength = keyLength;
        this._ssKey = new ShadowSocksKey(str2, keyLength);
        this._key = getKey();
    }

    public static byte[] md5Digest(byte[] bArr) {
        try {
            return MessageDigest.getInstance("MD5").digest(bArr);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public abstract void _decrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream);

    public abstract void _encrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream);

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public byte[] decrypt(byte[] bArr) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        decrypt(bArr, byteArrayOutputStream);
        return byteArrayOutputStream.toByteArray();
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public byte[] encrypt(byte[] bArr) {
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        encrypt(bArr, byteArrayOutputStream);
        return byteArrayOutputStream.toByteArray();
    }

    public abstract StreamCipher getCipher(boolean z);

    public CipherParameters getCipherParameters(byte[] bArr) {
        int i = this._ivLength;
        byte[] bArr2 = new byte[i];
        this._decryptIV = bArr2;
        System.arraycopy(bArr, 0, bArr2, 0, i);
        return new ParametersWithIV(new KeyParameter(this._key.getEncoded()), this._decryptIV);
    }

    public abstract SecretKey getKey();

    public void setIV(byte[] bArr, boolean z) {
        int i = this._ivLength;
        if (i != 0) {
            if (z) {
                CipherParameters cipherParameters = getCipherParameters(bArr);
                try {
                    this.encCipher = getCipher(z);
                } catch (InvalidAlgorithmParameterException e) {
                    this.logger.info(e.toString());
                }
                this.encCipher.init(z, cipherParameters);
                return;
            }
            byte[] bArr2 = new byte[i];
            this._decryptIV = bArr2;
            System.arraycopy(bArr, 0, bArr2, 0, i);
            CipherParameters cipherParameters2 = getCipherParameters(bArr);
            try {
                this.decCipher = getCipher(z);
            } catch (InvalidAlgorithmParameterException e2) {
                this.logger.info(e2.toString());
            }
            this.decCipher.init(z, cipherParameters2);
        }
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public void decrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        synchronized (this.decLock) {
            byteArrayOutputStream.reset();
            if (!this._decryptIVSet) {
                this._decryptIVSet = true;
                setIV(bArr, false);
                int length = bArr.length;
                int i = this._ivLength;
                byte[] bArr2 = new byte[(length - i)];
                System.arraycopy(bArr, i, bArr2, 0, bArr.length - i);
                bArr = bArr2;
            }
            _decrypt(bArr, byteArrayOutputStream);
        }
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public void encrypt(byte[] bArr, ByteArrayOutputStream byteArrayOutputStream) {
        synchronized (this.encLock) {
            byteArrayOutputStream.reset();
            if (!this._encryptIVSet) {
                this._encryptIVSet = true;
                byte[] bArr2 = new byte[this._ivLength];
                new SecureRandom().nextBytes(bArr2);
                setIV(bArr2, true);
                try {
                    byteArrayOutputStream.write(bArr2);
                } catch (IOException e) {
                    this.logger.info(e.toString());
                }
            }
            _encrypt(bArr, byteArrayOutputStream);
        }
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public void decrypt(byte[] bArr, int i, ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr2 = new byte[i];
        System.arraycopy(bArr, 0, bArr2, 0, i);
        decrypt(bArr2, byteArrayOutputStream);
    }

    @Override // com.faster.cheetah.sdk.shadowsocks.tunnel.shadowsocks.ICrypt
    public void encrypt(byte[] bArr, int i, ByteArrayOutputStream byteArrayOutputStream) {
        byte[] bArr2 = new byte[i];
        System.arraycopy(bArr, 0, bArr2, 0, i);
        encrypt(bArr2, byteArrayOutputStream);
    }
}
