package com.faster.cheetah.sdk.strongswan.data;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.database.MatrixCursor;
import android.net.Uri;
import android.os.ParcelFileDescriptor;
import android.os.SystemClock;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.logic.CharonVpnService;
import java.io.File;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.concurrent.ConcurrentHashMap;

public class LogContentProvider extends ContentProvider {
    private static final String AUTHORITY = "com.zfast.xyz.sdk.strongswan.content.log";
    private static final long URI_VALIDITY = 1800000;
    private static ConcurrentHashMap<Uri, Long> mUris = new ConcurrentHashMap<>();
    private File mLogFile;

    public static Uri createContentUri() {
        try {
            SecureRandom instance = SecureRandom.getInstance("SHA1PRNG");
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("content://com.zfast.xyz.sdk.strongswan.content.log/");
            outline25.append(instance.nextLong());
            Uri parse = Uri.parse(outline25.toString());
            mUris.put(parse, Long.valueOf(SystemClock.uptimeMillis()));
            return parse;
        } catch (NoSuchAlgorithmException unused) {
            return null;
        }
    }

    public int delete(Uri uri, String str, String[] strArr) {
        return 0;
    }

    public String getType(Uri uri) {
        return "text/plain";
    }

    public Uri insert(Uri uri, ContentValues contentValues) {
        return null;
    }

    public boolean onCreate() {
        this.mLogFile = new File(getContext().getFilesDir(), CharonVpnService.LOG_FILE);
        return true;
    }

    @Override // android.content.ContentProvider
    public ParcelFileDescriptor openFile(Uri uri, String str) {
        Long l = mUris.get(uri);
        if (l != null) {
            long uptimeMillis = SystemClock.uptimeMillis() - l.longValue();
            if (uptimeMillis > 0 && uptimeMillis < URI_VALIDITY) {
                return ParcelFileDescriptor.open(this.mLogFile, 402653184);
            }
            mUris.remove(uri);
        }
        return super.openFile(uri, str);
    }

    public Cursor query(Uri uri, String[] strArr, String str, String[] strArr2, String str2) {
        if (strArr == null || strArr.length < 1 || mUris.get(uri) == null) {
            return null;
        }
        MatrixCursor matrixCursor = new MatrixCursor(strArr, 1);
        if ("_display_name".equals(matrixCursor.getColumnName(0))) {
            matrixCursor.newRow().add(CharonVpnService.LOG_FILE);
        } else {
            if ("_size".equals(matrixCursor.getColumnName(0))) {
                matrixCursor.newRow().add(Long.valueOf(this.mLogFile.length()));
            }
            return null;
        }
        return matrixCursor;
    }

    public int update(Uri uri, ContentValues contentValues, String str, String[] strArr) {
        return 0;
    }
}
