package com.faster.cheetah.sdk.strongswan.security;

import android.content.Context;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.utils.Utils;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Date;
import java.util.regex.Pattern;

public class LocalCertificateStore {
    private static final Pattern ALIAS_PATTERN = Pattern.compile("^local:[0-9a-f]{40}$");
    private static final String ALIAS_PREFIX = "local:";
    private static final String FILE_PREFIX = "certificate-";

    private String getKeyId(Certificate certificate) {
        try {
            return Utils.bytesToHex(MessageDigest.getInstance("SHA1").digest(certificate.getPublicKey().getEncoded()));
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
            return null;
        }
    }

    public boolean addCertificate(Certificate certificate) {
        String keyId;
        if (!(certificate instanceof X509Certificate) || (keyId = getKeyId(certificate)) == null) {
            return false;
        }
        try {
            Context context = LocalCertificateKeyStoreProvider.context;
            FileOutputStream openFileOutput = context.openFileOutput(FILE_PREFIX + keyId, 0);
            try {
                openFileOutput.write(certificate.getEncoded());
                try {
                    openFileOutput.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                return true;
            } catch (CertificateEncodingException e2) {
                e2.printStackTrace();
                try {
                    openFileOutput.close();
                } catch (IOException e3) {
                    e = e3;
                }
                return false;
            } catch (IOException e4) {
                e4.printStackTrace();
                try {
                    openFileOutput.close();
                } catch (IOException e5) {
                    e = e5;
                }
                return false;
            } catch (Throwable th) {
                try {
                    openFileOutput.close();
                } catch (IOException e6) {
                    e6.printStackTrace();
                }
                throw th;
            }
        } catch (FileNotFoundException e7) {
            e7.printStackTrace();
            return false;
        }
        e.printStackTrace();
        return false;
    }

    public ArrayList<String> aliases() {
        ArrayList<String> arrayList = new ArrayList<>();
        String[] fileList = LocalCertificateKeyStoreProvider.context.fileList();
        for (String str : fileList) {
            if (str.startsWith(FILE_PREFIX)) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25(ALIAS_PREFIX);
                outline25.append(str.substring(12));
                arrayList.add(outline25.toString());
            }
        }
        return arrayList;
    }

    public boolean containsAlias(String str) {
        return getCreationDate(str) != null;
    }

    public void deleteCertificate(String str) {
        if (ALIAS_PATTERN.matcher(str).matches()) {
            String substring = str.substring(6);
            Context context = LocalCertificateKeyStoreProvider.context;
            context.deleteFile(FILE_PREFIX + substring);
        }
    }

    public X509Certificate getCertificate(String str) {
        if (!ALIAS_PATTERN.matcher(str).matches()) {
            return null;
        }
        String substring = str.substring(6);
        try {
            Context context = LocalCertificateKeyStoreProvider.context;
            FileInputStream openFileInput = context.openFileInput(FILE_PREFIX + substring);
            try {
                X509Certificate x509Certificate = (X509Certificate) CertificateFactory.getInstance("X.509").generateCertificate(openFileInput);
                try {
                    openFileInput.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
                return x509Certificate;
            } catch (CertificateException e2) {
                e2.printStackTrace();
                try {
                    openFileInput.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
            } catch (Throwable th) {
                try {
                    openFileInput.close();
                } catch (IOException e4) {
                    e4.printStackTrace();
                }
                throw th;
            }
        } catch (FileNotFoundException e5) {
            e5.printStackTrace();
            return null;
        }
    }

    public String getCertificateAlias(Certificate certificate) {
        String keyId = getKeyId(certificate);
        if (keyId != null) {
            return GeneratedOutlineSupport.outline18(ALIAS_PREFIX, keyId);
        }
        return null;
    }

    public Date getCreationDate(String str) {
        if (!ALIAS_PATTERN.matcher(str).matches()) {
            return null;
        }
        String substring = str.substring(6);
        Context context = LocalCertificateKeyStoreProvider.context;
        File fileStreamPath = context.getFileStreamPath(FILE_PREFIX + substring);
        if (fileStreamPath.exists()) {
            return new Date(fileStreamPath.lastModified());
        }
        return null;
    }
}
