package com.faster.cheetah.sdk.strongswan.utils;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.TreeSet;

public class IPRangeSet implements Iterable<IPRange> {
    private TreeSet<IPRange> mRanges = new TreeSet<>();

    public static IPRangeSet fromString(String str) {
        IPRangeSet iPRangeSet = new IPRangeSet();
        if (str != null) {
            for (String str2 : str.split("\\s+")) {
                try {
                    iPRangeSet.add(new IPRange(str2));
                } catch (Exception unused) {
                    return null;
                }
            }
        }
        return iPRangeSet;
    }

    public void add(IPRange iPRange) {
        if (!this.mRanges.contains(iPRange)) {
            while (true) {
                Iterator<IPRange> it = this.mRanges.iterator();
                while (it.hasNext()) {
                    IPRange merge = it.next().merge(iPRange);
                    if (merge != null) {
                        it.remove();
                        iPRange = merge;
                    }
                }
                this.mRanges.add(iPRange);
                return;
            }
        }
    }

    public void addAll(Collection<? extends IPRange> collection) {
        for (IPRange iPRange : collection) {
            add(iPRange);
        }
    }

    @Override // java.lang.Iterable
    public Iterator<IPRange> iterator() {
        return this.mRanges.iterator();
    }

    public void remove(IPRange iPRange) {
        ArrayList arrayList = new ArrayList();
        Iterator<IPRange> it = this.mRanges.iterator();
        while (it.hasNext()) {
            IPRange next = it.next();
            List<IPRange> remove = next.remove(iPRange);
            if (remove.size() == 0) {
                it.remove();
            } else if (!remove.get(0).equals(next)) {
                it.remove();
                arrayList.addAll(remove);
            }
        }
        this.mRanges.addAll(arrayList);
    }

    public int size() {
        return this.mRanges.size();
    }

    public Iterable<IPRange> subnets() {
        return new Iterable<IPRange>() {
            /* class com.faster.cheetah.sdk.strongswan.utils.IPRangeSet.AnonymousClass1 */

            @Override // java.lang.Iterable
            public Iterator<IPRange> iterator() {
                return new Iterator<IPRange>() {
                    /* class com.faster.cheetah.sdk.strongswan.utils.IPRangeSet.AnonymousClass1.AnonymousClass1 */
                    private Iterator<IPRange> mIterator;
                    private List<IPRange> mSubnets;

                    {
                        this.mIterator = IPRangeSet.this.mRanges.iterator();
                    }

                    public boolean hasNext() {
                        List<IPRange> list = this.mSubnets;
                        return (list != null && list.size() > 0) || this.mIterator.hasNext();
                    }

                    public void remove() {
                        throw new UnsupportedOperationException();
                    }

                    @Override // java.util.Iterator
                    public IPRange next() {
                        List<IPRange> list = this.mSubnets;
                        if (list == null || list.size() == 0) {
                            this.mSubnets = this.mIterator.next().toSubnets();
                        }
                        return this.mSubnets.remove(0);
                    }
                };
            }
        };
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        Iterator<IPRange> it = this.mRanges.iterator();
        while (it.hasNext()) {
            IPRange next = it.next();
            if (sb.length() > 0) {
                sb.append(" ");
            }
            sb.append(next.toString());
        }
        return sb.toString();
    }

    public void add(IPRangeSet iPRangeSet) {
        if (iPRangeSet != this) {
            Iterator<IPRange> it = iPRangeSet.mRanges.iterator();
            while (it.hasNext()) {
                add(it.next());
            }
        }
    }

    public void remove(IPRangeSet iPRangeSet) {
        if (iPRangeSet == this) {
            this.mRanges.clear();
            return;
        }
        Iterator<IPRange> it = iPRangeSet.mRanges.iterator();
        while (it.hasNext()) {
            remove(it.next());
        }
    }
}
