package com.github.shadowsocks;

import android.app.Application;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.database.sqlite.SQLiteCantOpenDatabaseException;
import android.net.ConnectivityManager;
import android.os.Build;
import android.util.Log;
import androidx.core.content.ContextCompat;
import androidx.transition.ViewGroupUtilsApi14;
import com.github.shadowsocks.bg.ProxyService;
import com.github.shadowsocks.bg.TransproxyService;
import com.github.shadowsocks.bg.VpnService;
import com.github.shadowsocks.core.R$string;
import com.github.shadowsocks.database.PrivateDatabase;
import com.github.shadowsocks.database.Profile;
import com.github.shadowsocks.database.ProfileDao_Impl;
import com.github.shadowsocks.preference.DataStore;
import com.github.shadowsocks.utils.DirectBoot;
import com.github.shadowsocks.utils.UtilsKt;
import java.io.IOException;
import java.sql.SQLException;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.Pair;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.PropertyReference1Impl;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KProperty;

/* compiled from: Core.kt */
public final class Core {
    public static final /* synthetic */ KProperty[] $$delegatedProperties;
    public static final Core INSTANCE = new Core();
    public static final Lazy activity$delegate = ViewGroupUtilsApi14.lazy(Core$activity$2.INSTANCE);
    public static Application app;
    public static Function1<? super Context, PendingIntent> configureIntent;
    public static final Lazy connectivity$delegate = ViewGroupUtilsApi14.lazy(Core$connectivity$2.INSTANCE);
    public static final Lazy deviceStorage$delegate = ViewGroupUtilsApi14.lazy(Core$deviceStorage$2.INSTANCE);
    public static final Lazy directBootSupported$delegate = ViewGroupUtilsApi14.lazy(Core$directBootSupported$2.INSTANCE);
    public static final Lazy notification$delegate = ViewGroupUtilsApi14.lazy(Core$notification$2.INSTANCE);
    public static final Lazy packageInfo$delegate = ViewGroupUtilsApi14.lazy(Core$packageInfo$2.INSTANCE);

    static {
        PropertyReference1Impl propertyReference1Impl = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Core.class), "activity", "getActivity()Landroid/app/ActivityManager;");
        Objects.requireNonNull(Reflection.factory);
        $$delegatedProperties = new KProperty[]{propertyReference1Impl, new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Core.class), "connectivity", "getConnectivity()Landroid/net/ConnectivityManager;"), new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Core.class), "notification", "getNotification()Landroid/app/NotificationManager;"), new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Core.class), "packageInfo", "getPackageInfo()Landroid/content/pm/PackageInfo;"), new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Core.class), "deviceStorage", "getDeviceStorage()Landroid/app/Application;"), new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Core.class), "directBootSupported", "getDirectBootSupported()Z")};
    }

    public final Application getApp() {
        Application application = app;
        if (application != null) {
            return application;
        }
        Intrinsics.throwUninitializedPropertyAccessException("app");
        throw null;
    }

    public final ConnectivityManager getConnectivity() {
        Lazy lazy = connectivity$delegate;
        KProperty kProperty = $$delegatedProperties[1];
        return (ConnectivityManager) lazy.getValue();
    }

    public final Pair<Profile, Profile> getCurrentProfile() {
        Profile profile;
        Pair<Profile, Profile> deviceProfile;
        if (DataStore.INSTANCE.getDirectBootAware() && (deviceProfile = DirectBoot.INSTANCE.getDeviceProfile()) != null) {
            return deviceProfile;
        }
        Long l = DataStore.publicStore.getLong("profileId");
        Profile profile2 = null;
        try {
            profile = ((ProfileDao_Impl) PrivateDatabase.Companion.getProfileDao()).get(l != null ? l.longValue() : 0);
        } catch (SQLiteCantOpenDatabaseException e) {
            throw new IOException(e);
        } catch (SQLException e2) {
            KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
            Intrinsics.checkParameterIsNotNull(e2, "t");
            Log.e("", "", e2);
            e2.printStackTrace();
            profile = null;
        }
        if (profile == null) {
            return null;
        }
        Intrinsics.checkParameterIsNotNull(profile, "profile");
        Long udpFallback = profile.getUdpFallback();
        if (udpFallback != null) {
            try {
                profile2 = ((ProfileDao_Impl) PrivateDatabase.Companion.getProfileDao()).get(udpFallback.longValue());
            } catch (SQLiteCantOpenDatabaseException e3) {
                throw new IOException(e3);
            } catch (SQLException e4) {
                KProperty[] kPropertyArr2 = UtilsKt.$$delegatedProperties;
                Intrinsics.checkParameterIsNotNull(e4, "t");
                Log.e("", "", e4);
                e4.printStackTrace();
            }
        }
        return new Pair<>(profile, profile2);
    }

    public final Application getDeviceStorage() {
        Lazy lazy = deviceStorage$delegate;
        KProperty kProperty = $$delegatedProperties[4];
        return (Application) lazy.getValue();
    }

    public final PackageInfo getPackageInfo() {
        Lazy lazy = packageInfo$delegate;
        KProperty kProperty = $$delegatedProperties[3];
        return (PackageInfo) lazy.getValue();
    }

    public final PackageInfo getPackageInfo(String str) {
        Intrinsics.checkParameterIsNotNull(str, "packageName");
        Application application = app;
        if (application != null) {
            PackageInfo packageInfo = application.getPackageManager().getPackageInfo(str, Build.VERSION.SDK_INT >= 28 ? 134217728 : 64);
            if (packageInfo != null) {
                return packageInfo;
            }
            Intrinsics.throwNpe();
            throw null;
        }
        Intrinsics.throwUninitializedPropertyAccessException("app");
        throw null;
    }

    public final void startService() {
        Class cls;
        Application application = app;
        if (application != null) {
            Application application2 = app;
            if (application2 != null) {
                String serviceMode = DataStore.INSTANCE.getServiceMode();
                int hashCode = serviceMode.hashCode();
                if (hashCode == -1717747514) {
                    if (serviceMode.equals("transproxy")) {
                        cls = TransproxyService.class;
                    }
                    throw new UnknownError();
                } else if (hashCode != 116980) {
                    if (hashCode == 106941038 && serviceMode.equals("proxy")) {
                        cls = ProxyService.class;
                    }
                    throw new UnknownError();
                } else {
                    if (serviceMode.equals("vpn")) {
                        cls = VpnService.class;
                    }
                    throw new UnknownError();
                }
                Intent intent = new Intent(application2, cls);
                Object obj = ContextCompat.sLock;
                if (Build.VERSION.SDK_INT >= 26) {
                    application.startForegroundService(intent);
                } else {
                    application.startService(intent);
                }
            } else {
                Intrinsics.throwUninitializedPropertyAccessException("app");
                throw null;
            }
        } else {
            Intrinsics.throwUninitializedPropertyAccessException("app");
            throw null;
        }
    }

    public final void stopService() {
        Application application = app;
        if (application != null) {
            Intent intent = new Intent("com.github.shadowsocks.CLOSE");
            Application application2 = app;
            if (application2 != null) {
                application.sendBroadcast(intent.setPackage(application2.getPackageName()));
            } else {
                Intrinsics.throwUninitializedPropertyAccessException("app");
                throw null;
            }
        } else {
            Intrinsics.throwUninitializedPropertyAccessException("app");
            throw null;
        }
    }

    public final void updateNotificationChannels() {
        int i = Build.VERSION.SDK_INT;
        if (i >= 26) {
            Lazy lazy = notification$delegate;
            KProperty[] kPropertyArr = $$delegatedProperties;
            KProperty kProperty = kPropertyArr[2];
            NotificationManager notificationManager = (NotificationManager) lazy.getValue();
            NotificationChannel[] notificationChannelArr = new NotificationChannel[3];
            Application application = app;
            if (application != null) {
                notificationChannelArr[0] = new NotificationChannel("service-vpn", application.getText(R$string.service_vpn), i >= 28 ? 1 : 2);
                Application application2 = app;
                if (application2 != null) {
                    notificationChannelArr[1] = new NotificationChannel("service-proxy", application2.getText(R$string.service_proxy), 2);
                    Application application3 = app;
                    if (application3 != null) {
                        notificationChannelArr[2] = new NotificationChannel("service-transproxy", application3.getText(R$string.service_transproxy), 2);
                        notificationManager.createNotificationChannels(ArraysKt___ArraysKt.listOf(notificationChannelArr));
                        KProperty kProperty2 = kPropertyArr[2];
                        ((NotificationManager) lazy.getValue()).deleteNotificationChannel("service-nat");
                        return;
                    }
                    Intrinsics.throwUninitializedPropertyAccessException("app");
                    throw null;
                }
                Intrinsics.throwUninitializedPropertyAccessException("app");
                throw null;
            }
            Intrinsics.throwUninitializedPropertyAccessException("app");
            throw null;
        }
    }
}
