package com.github.shadowsocks.aidl;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.os.Handler;
import android.os.IBinder;
import android.os.IInterface;
import android.os.RemoteException;
import com.faster.cheetah.MainActivity;
import com.github.shadowsocks.aidl.IShadowsocksService;
import com.github.shadowsocks.bg.BaseService$State;
import com.github.shadowsocks.bg.ProxyService;
import com.github.shadowsocks.bg.TransproxyService;
import com.github.shadowsocks.bg.VpnService;
import com.github.shadowsocks.preference.DataStore;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;

/* compiled from: ShadowsocksConnection.kt */
public final class ShadowsocksConnection implements ServiceConnection, IBinder.DeathRecipient {
    public IBinder binder;
    public Callback callback;
    public boolean callbackRegistered;
    public boolean connectionActive;
    public final Handler handler;
    public boolean listenForDeath;
    public IShadowsocksService service;
    public final ShadowsocksConnection$serviceCallback$1 serviceCallback = new ShadowsocksConnection$serviceCallback$1(this);

    /* compiled from: ShadowsocksConnection.kt */
    public interface Callback {
    }

    public ShadowsocksConnection(Handler handler2, boolean z) {
        Intrinsics.checkParameterIsNotNull(handler2, "handler");
        this.handler = handler2;
        this.listenForDeath = z;
    }

    public void binderDied() {
        this.service = null;
        this.callbackRegistered = false;
        Callback callback2 = this.callback;
        if (callback2 != null) {
            this.handler.post(new ShadowsocksConnection$sam$i$java_lang_Runnable$0(new ShadowsocksConnection$binderDied$1$1(callback2)));
        }
    }

    public final void connect(Context context, Callback callback2) {
        Class cls;
        Intrinsics.checkParameterIsNotNull(context, "context");
        Intrinsics.checkParameterIsNotNull(callback2, "callback");
        if (!this.connectionActive) {
            this.connectionActive = true;
            if (this.callback == null) {
                this.callback = callback2;
                String serviceMode = DataStore.INSTANCE.getServiceMode();
                int hashCode = serviceMode.hashCode();
                if (hashCode == -1717747514) {
                    if (serviceMode.equals("transproxy")) {
                        cls = TransproxyService.class;
                    }
                    throw new UnknownError();
                } else if (hashCode != 116980) {
                    if (hashCode == 106941038 && serviceMode.equals("proxy")) {
                        cls = ProxyService.class;
                    }
                    throw new UnknownError();
                } else {
                    if (serviceMode.equals("vpn")) {
                        cls = VpnService.class;
                    }
                    throw new UnknownError();
                }
                Intent action = new Intent(context, cls).setAction("com.github.shadowsocks.SERVICE");
                Intrinsics.checkExpressionValueIsNotNull(action, "Intent(context, serviceC…setAction(Action.SERVICE)");
                context.bindService(action, this, 1);
                return;
            }
            throw new IllegalStateException("Check failed.".toString());
        }
    }

    public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
        IShadowsocksService iShadowsocksService;
        BaseService$State baseService$State;
        Intrinsics.checkParameterIsNotNull(iBinder, "binder");
        this.binder = iBinder;
        int i = IShadowsocksService.Stub.$r8$clinit;
        IInterface queryLocalInterface = iBinder.queryLocalInterface("com.github.shadowsocks.aidl.IShadowsocksService");
        if (queryLocalInterface == null || !(queryLocalInterface instanceof IShadowsocksService)) {
            iShadowsocksService = new IShadowsocksService.Stub.Proxy(iBinder);
        } else {
            iShadowsocksService = (IShadowsocksService) queryLocalInterface;
        }
        if (iShadowsocksService != null) {
            this.service = iShadowsocksService;
            try {
                if (this.listenForDeath) {
                    iBinder.linkToDeath(this, 0);
                }
                if (!this.callbackRegistered) {
                    iShadowsocksService.registerCallback(this.serviceCallback);
                    this.callbackRegistered = true;
                    Callback callback2 = this.callback;
                    if (callback2 != null) {
                        MainActivity mainActivity = (MainActivity) callback2;
                        Objects.requireNonNull(mainActivity);
                        Intrinsics.checkParameterIsNotNull(iShadowsocksService, "service");
                        try {
                            baseService$State = BaseService$State.values()[iShadowsocksService.getState()];
                        } catch (RemoteException unused) {
                            baseService$State = BaseService$State.Idle;
                        }
                        mainActivity.changeState(baseService$State, null);
                        return;
                    }
                    Intrinsics.throwNpe();
                    throw null;
                }
                throw new IllegalStateException("Check failed.".toString());
            } catch (RemoteException unused2) {
            }
        } else {
            Intrinsics.throwNpe();
            throw null;
        }
    }

    public void onServiceDisconnected(ComponentName componentName) {
        IShadowsocksService iShadowsocksService = this.service;
        if (iShadowsocksService != null && this.callbackRegistered) {
            try {
                iShadowsocksService.unregisterCallback(this.serviceCallback);
            } catch (RemoteException unused) {
            }
        }
        this.callbackRegistered = false;
        Callback callback2 = this.callback;
        if (callback2 != null) {
            ((MainActivity) callback2).changeState(BaseService$State.Idle, null);
        }
        this.service = null;
        this.binder = null;
    }
}
