package com.github.shadowsocks.bg;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.net.DnsResolver;
import android.net.LinkProperties;
import android.net.Network;
import android.net.RouteInfo;
import android.os.Build;
import android.os.CancellationSignal;
import android.os.Looper;
import android.system.ErrnoException;
import android.system.Os;
import android.system.OsConstants;
import android.util.Log;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.allpayx.sdk.util.AvenuesParams;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.github.shadowsocks.Core;
import com.github.shadowsocks.utils.UtilsKt;
import java.io.FileDescriptor;
import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.net.InetAddress;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.Executor;
import kotlin.Lazy;
import kotlin.TypeCastException;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.PropertyReference1Impl;
import kotlin.jvm.internal.Reflection;
import kotlin.jvm.internal.ReflectionFactory;
import kotlin.reflect.KProperty;
import kotlinx.coroutines.CancellableContinuationImpl;
import kotlinx.coroutines.CoroutineDispatcher;
import kotlinx.coroutines.DeferredCoroutine;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.GlobalScope;

/* compiled from: DnsResolverCompat.kt */
public abstract class DnsResolverCompat {
    public static final Companion Companion = new Companion(null);
    public static final InetAddress address4;
    public static final InetAddress address6;
    public static final Lazy instance$delegate = ViewGroupUtilsApi14.lazy(DnsResolverCompat$Companion$instance$2.INSTANCE);

    @SuppressLint({"PrivateApi"})
    /* compiled from: DnsResolverCompat.kt */
    public abstract class DnsResolverCompat21 extends DnsResolverCompat {
        public static final /* synthetic */ KProperty[] $$delegatedProperties;
        public final Lazy bindSocketToNetwork$delegate = ViewGroupUtilsApi14.lazy(DnsResolverCompat$DnsResolverCompat21$bindSocketToNetwork$2.INSTANCE);
        public final Lazy netId$delegate = ViewGroupUtilsApi14.lazy(DnsResolverCompat$DnsResolverCompat21$netId$2.INSTANCE);
        public final Lazy unboundedIO$delegate = ViewGroupUtilsApi14.lazy(DnsResolverCompat$DnsResolverCompat21$unboundedIO$2.INSTANCE);

        static {
            PropertyReference1Impl propertyReference1Impl = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(DnsResolverCompat21.class), "bindSocketToNetwork", "getBindSocketToNetwork()Ljava/lang/reflect/Method;");
            ReflectionFactory reflectionFactory = Reflection.factory;
            Objects.requireNonNull(reflectionFactory);
            PropertyReference1Impl propertyReference1Impl2 = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(DnsResolverCompat21.class), "netId", "getNetId()Ljava/lang/reflect/Field;");
            Objects.requireNonNull(reflectionFactory);
            PropertyReference1Impl propertyReference1Impl3 = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(DnsResolverCompat21.class), "unboundedIO", "getUnboundedIO()Lkotlinx/coroutines/CoroutineDispatcher;");
            Objects.requireNonNull(reflectionFactory);
            $$delegatedProperties = new KProperty[]{propertyReference1Impl, propertyReference1Impl2, propertyReference1Impl3};
        }

        public DnsResolverCompat21() {
            super(null);
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public void bindSocket(Network network, FileDescriptor fileDescriptor) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            Intrinsics.checkParameterIsNotNull(fileDescriptor, "socket");
            Lazy lazy = this.netId$delegate;
            KProperty[] kPropertyArr = $$delegatedProperties;
            KProperty kProperty = kPropertyArr[1];
            Object obj = ((Field) lazy.getValue()).get(network);
            if (obj != null) {
                Lazy lazy2 = this.bindSocketToNetwork$delegate;
                KProperty kProperty2 = kPropertyArr[0];
                Object invoke = ((Method) lazy2.getValue()).invoke(null, Integer.valueOf(UtilsKt.getInt(fileDescriptor)), obj);
                if (invoke != null) {
                    int intValue = ((Integer) invoke).intValue();
                    if (intValue != 0) {
                        String outline17 = GeneratedOutlineSupport.outline17("Binding socket to network ", obj);
                        throw new IOException(outline17, new ErrnoException(outline17, -intValue));
                    }
                    return;
                }
                throw new TypeCastException("null cannot be cast to non-null type kotlin.Int");
            }
            Intrinsics.throwNpe();
            throw null;
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object connectUdp$ss_core_release(FileDescriptor fileDescriptor, InetAddress inetAddress, int i, Continuation<? super Unit> continuation) {
            Looper mainLooper = Looper.getMainLooper();
            Intrinsics.checkExpressionValueIsNotNull(mainLooper, "Looper.getMainLooper()");
            if (Intrinsics.areEqual(mainLooper.getThread(), Thread.currentThread())) {
                Object withContext = ViewGroupUtilsApi14.withContext(Dispatchers.IO, new DnsResolverCompat$DnsResolverCompat21$connectUdp$2(this, fileDescriptor, inetAddress, i, null), continuation);
                if (withContext == CoroutineSingletons.COROUTINE_SUSPENDED) {
                    return withContext;
                }
            } else {
                Os.connect(fileDescriptor, inetAddress, i);
                Unit unit = Unit.INSTANCE;
                if (unit == CoroutineSingletons.COROUTINE_SUSPENDED) {
                    return unit;
                }
            }
            return Unit.INSTANCE;
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object resolve(Network network, String str, Continuation<? super InetAddress[]> continuation) {
            GlobalScope globalScope = GlobalScope.INSTANCE;
            Lazy lazy = this.unboundedIO$delegate;
            KProperty kProperty = $$delegatedProperties[2];
            return DeferredCoroutine.await$suspendImpl((DeferredCoroutine) ViewGroupUtilsApi14.async$default(globalScope, (CoroutineDispatcher) lazy.getValue(), null, new DnsResolverCompat$DnsResolverCompat21$resolve$2(network, str, null), 2, null), continuation);
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object resolveOnActiveNetwork(String str, Continuation<? super InetAddress[]> continuation) {
            GlobalScope globalScope = GlobalScope.INSTANCE;
            Lazy lazy = this.unboundedIO$delegate;
            KProperty kProperty = $$delegatedProperties[2];
            return DeferredCoroutine.await$suspendImpl((DeferredCoroutine) ViewGroupUtilsApi14.async$default(globalScope, (CoroutineDispatcher) lazy.getValue(), null, new DnsResolverCompat$DnsResolverCompat21$resolveOnActiveNetwork$2(str, null), 2, null), continuation);
        }
    }

    @TargetApi(22)
    /* compiled from: DnsResolverCompat.kt */
    public final class DnsResolverCompat22 extends DnsResolverCompat21 {
        public static final /* synthetic */ KProperty[] $$delegatedProperties;
        public static final DnsResolverCompat22 INSTANCE = new DnsResolverCompat22();
        public static final Lazy bindSocketFd$delegate = ViewGroupUtilsApi14.lazy(DnsResolverCompat$DnsResolverCompat22$bindSocketFd$2.INSTANCE);

        static {
            PropertyReference1Impl propertyReference1Impl = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(DnsResolverCompat22.class), "bindSocketFd", "getBindSocketFd()Ljava/lang/reflect/Method;");
            Objects.requireNonNull(Reflection.factory);
            $$delegatedProperties = new KProperty[]{propertyReference1Impl};
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat, com.github.shadowsocks.bg.DnsResolverCompat.DnsResolverCompat21
        public void bindSocket(Network network, FileDescriptor fileDescriptor) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            Intrinsics.checkParameterIsNotNull(fileDescriptor, "socket");
            try {
                Lazy lazy = bindSocketFd$delegate;
                KProperty kProperty = $$delegatedProperties[0];
                ((Method) lazy.getValue()).invoke(network, fileDescriptor);
            } catch (ReflectiveOperationException e) {
                try {
                    super.bindSocket(network, fileDescriptor);
                } catch (ReflectiveOperationException e2) {
                    e2.addSuppressed(e);
                    throw e2;
                }
            }
        }
    }

    @TargetApi(23)
    /* compiled from: DnsResolverCompat.kt */
    public final class DnsResolverCompat23 extends DnsResolverCompat21 {
        public static final DnsResolverCompat23 INSTANCE = new DnsResolverCompat23();

        @Override // com.github.shadowsocks.bg.DnsResolverCompat, com.github.shadowsocks.bg.DnsResolverCompat.DnsResolverCompat21
        public void bindSocket(Network network, FileDescriptor fileDescriptor) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            Intrinsics.checkParameterIsNotNull(fileDescriptor, "socket");
            network.bindSocket(fileDescriptor);
        }
    }

    @TargetApi(29)
    /* compiled from: DnsResolverCompat.kt */
    public final class DnsResolverCompat29 extends DnsResolverCompat implements Executor {
        public static final DnsResolverCompat29 INSTANCE = new DnsResolverCompat29();

        public DnsResolverCompat29() {
            super(null);
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public void bindSocket(Network network, FileDescriptor fileDescriptor) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            Intrinsics.checkParameterIsNotNull(fileDescriptor, "socket");
            network.bindSocket(fileDescriptor);
        }

        public void execute(Runnable runnable) {
            Intrinsics.checkParameterIsNotNull(runnable, AvenuesParams.COMMAND);
            runnable.run();
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object resolve(Network network, String str, Continuation<? super InetAddress[]> continuation) {
            CancellableContinuationImpl cancellableContinuationImpl = new CancellableContinuationImpl(ViewGroupUtilsApi14.intercepted(continuation), 1);
            CancellationSignal cancellationSignal = new CancellationSignal();
            cancellableContinuationImpl.invokeOnCancellation(new DnsResolverCompat$DnsResolverCompat29$resolve$2$1(cancellationSignal));
            DnsResolver.getInstance().query(network, str, 1, INSTANCE, cancellationSignal, new DnsResolverCompat$DnsResolverCompat29$resolve$2$2(cancellableContinuationImpl));
            Object result = cancellableContinuationImpl.getResult();
            if (result == CoroutineSingletons.COROUTINE_SUSPENDED) {
                Intrinsics.checkNotNullParameter(continuation, "frame");
            }
            return result;
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object resolveOnActiveNetwork(String str, Continuation<? super InetAddress[]> continuation) {
            Network activeNetwork = Core.INSTANCE.getConnectivity().getActiveNetwork();
            return activeNetwork != null ? resolve(activeNetwork, str, continuation) : new InetAddress[0];
        }
    }

    static {
        InetAddress parseNumericAddress = UtilsKt.parseNumericAddress("8.8.8.8");
        if (parseNumericAddress != null) {
            address4 = parseNumericAddress;
            InetAddress parseNumericAddress2 = UtilsKt.parseNumericAddress("2000::");
            if (parseNumericAddress2 != null) {
                address6 = parseNumericAddress2;
            } else {
                Intrinsics.throwNpe();
                throw null;
            }
        } else {
            Intrinsics.throwNpe();
            throw null;
        }
    }

    public DnsResolverCompat(DefaultConstructorMarker defaultConstructorMarker) {
    }

    public abstract void bindSocket(Network network, FileDescriptor fileDescriptor);

    public Object connectUdp$ss_core_release(FileDescriptor fileDescriptor, InetAddress inetAddress, int i, Continuation<? super Unit> continuation) {
        Os.connect(fileDescriptor, inetAddress, i);
        return Unit.INSTANCE;
    }

    public abstract Object resolve(Network network, String str, Continuation<? super InetAddress[]> continuation);

    public abstract Object resolveOnActiveNetwork(String str, Continuation<? super InetAddress[]> continuation);

    /* compiled from: DnsResolverCompat.kt */
    public final class Companion extends DnsResolverCompat {
        public static final /* synthetic */ KProperty[] $$delegatedProperties;

        static {
            PropertyReference1Impl propertyReference1Impl = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(Companion.class), "instance", "getInstance()Lcom/github/shadowsocks/bg/DnsResolverCompat;");
            Objects.requireNonNull(Reflection.factory);
            $$delegatedProperties = new KProperty[]{propertyReference1Impl};
        }

        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
            super(null);
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public void bindSocket(Network network, FileDescriptor fileDescriptor) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            Intrinsics.checkParameterIsNotNull(fileDescriptor, "socket");
            getInstance().bindSocket(network, fileDescriptor);
        }

        /* JADX WARNING: Code restructure failed: missing block: B:36:0x0097, code lost:
            r9 = e;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:37:0x0099, code lost:
            r9 = e;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:42:0x00a7, code lost:
            r5 = true;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:44:0x00aa, code lost:
            r12 = com.github.shadowsocks.utils.UtilsKt.$$delegatedProperties;
            kotlin.jvm.internal.Intrinsics.checkParameterIsNotNull(r9, "t");
            android.util.Log.e("", "", r9);
            r9.printStackTrace();
            r5 = r0.checkConnectivity(r11, r10);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:46:0x00c9, code lost:
            throw new java.lang.IllegalStateException("Check failed.".toString());
         */
        /* JADX WARNING: Code restructure failed: missing block: B:51:0x00d8, code lost:
            r9 = null;
         */
        /* JADX WARNING: Exception block dominator not found, dom blocks: [B:23:0x0076, B:32:0x0093] */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Removed duplicated region for block: B:15:0x0046  */
        /* JADX WARNING: Removed duplicated region for block: B:36:0x0097 A[ExcHandler: ReflectiveOperationException (e java.lang.ReflectiveOperationException), PHI: r0 r10 r11 
          PHI: (r0v5 com.github.shadowsocks.bg.DnsResolverCompat$Companion) = (r0v6 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v6 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion) binds: [B:32:0x0093, B:33:?, B:23:0x0076, B:24:?, B:25:0x007e, B:26:?] A[DONT_GENERATE, DONT_INLINE]
          PHI: (r10v6 java.net.InetAddress) = (r10v7 java.net.InetAddress), (r10v7 java.net.InetAddress), (r10v8 java.net.InetAddress), (r10v8 java.net.InetAddress), (r10v8 java.net.InetAddress), (r10v8 java.net.InetAddress) binds: [B:32:0x0093, B:33:?, B:23:0x0076, B:24:?, B:25:0x007e, B:26:?] A[DONT_GENERATE, DONT_INLINE]
          PHI: (r11v4 android.net.Network) = (r11v5 android.net.Network), (r11v5 android.net.Network), (r11v6 android.net.Network), (r11v6 android.net.Network), (r11v6 android.net.Network), (r11v6 android.net.Network) binds: [B:32:0x0093, B:33:?, B:23:0x0076, B:24:?, B:25:0x007e, B:26:?] A[DONT_GENERATE, DONT_INLINE], Splitter:B:23:0x0076] */
        /* JADX WARNING: Removed duplicated region for block: B:37:0x0099 A[ExcHandler: IOException (e java.io.IOException), PHI: r0 r10 r11 
          PHI: (r0v4 com.github.shadowsocks.bg.DnsResolverCompat$Companion) = (r0v6 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v6 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion), (r0v7 com.github.shadowsocks.bg.DnsResolverCompat$Companion) binds: [B:32:0x0093, B:33:?, B:23:0x0076, B:24:?, B:25:0x007e, B:26:?] A[DONT_GENERATE, DONT_INLINE]
          PHI: (r10v5 java.net.InetAddress) = (r10v7 java.net.InetAddress), (r10v7 java.net.InetAddress), (r10v8 java.net.InetAddress), (r10v8 java.net.InetAddress), (r10v8 java.net.InetAddress), (r10v8 java.net.InetAddress) binds: [B:32:0x0093, B:33:?, B:23:0x0076, B:24:?, B:25:0x007e, B:26:?] A[DONT_GENERATE, DONT_INLINE]
          PHI: (r11v3 android.net.Network) = (r11v5 android.net.Network), (r11v5 android.net.Network), (r11v6 android.net.Network), (r11v6 android.net.Network), (r11v6 android.net.Network), (r11v6 android.net.Network) binds: [B:32:0x0093, B:33:?, B:23:0x0076, B:24:?, B:25:0x007e, B:26:?] A[DONT_GENERATE, DONT_INLINE], Splitter:B:23:0x0076] */
        /* JADX WARNING: Removed duplicated region for block: B:42:0x00a7  */
        /* JADX WARNING: Removed duplicated region for block: B:44:0x00aa  */
        /* JADX WARNING: Removed duplicated region for block: B:45:0x00be  */
        /* JADX WARNING: Removed duplicated region for block: B:51:0x00d8  */
        /* JADX WARNING: Removed duplicated region for block: B:58:? A[ExcHandler: ErrnoException (unused android.system.ErrnoException), SYNTHETIC, Splitter:B:16:0x0049] */
        /* JADX WARNING: Removed duplicated region for block: B:8:0x0026  */
        public final Object checkConnectivity(Network network, int i, InetAddress inetAddress, Continuation<? super Boolean> continuation) {
            DnsResolverCompat$Companion$checkConnectivity$1 dnsResolverCompat$Companion$checkConnectivity$1;
            int i2;
            Network network2;
            InetAddress inetAddress2;
            Companion companion;
            Throwable th;
            FileDescriptor fileDescriptor;
            if (continuation instanceof DnsResolverCompat$Companion$checkConnectivity$1) {
                dnsResolverCompat$Companion$checkConnectivity$1 = (DnsResolverCompat$Companion$checkConnectivity$1) continuation;
                int i3 = dnsResolverCompat$Companion$checkConnectivity$1.label;
                if ((i3 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                    dnsResolverCompat$Companion$checkConnectivity$1.label = i3 - LinearLayoutManager.INVALID_OFFSET;
                    Object obj = dnsResolverCompat$Companion$checkConnectivity$1.result;
                    CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                    i2 = dnsResolverCompat$Companion$checkConnectivity$1.label;
                    boolean z = false;
                    if (i2 != 0) {
                        ViewGroupUtilsApi14.throwOnFailure(obj);
                        try {
                            FileDescriptor socket = Os.socket(i, OsConstants.SOCK_DGRAM, OsConstants.IPPROTO_UDP);
                            try {
                                DnsResolverCompat instance = getInstance();
                                Intrinsics.checkExpressionValueIsNotNull(socket, "socket");
                                instance.bindSocket(network, socket);
                                DnsResolverCompat instance2 = getInstance();
                                dnsResolverCompat$Companion$checkConnectivity$1.L$0 = this;
                                dnsResolverCompat$Companion$checkConnectivity$1.L$1 = network;
                                dnsResolverCompat$Companion$checkConnectivity$1.I$0 = i;
                                dnsResolverCompat$Companion$checkConnectivity$1.L$2 = inetAddress;
                                dnsResolverCompat$Companion$checkConnectivity$1.L$3 = socket;
                                dnsResolverCompat$Companion$checkConnectivity$1.label = 1;
                                if (instance2.connectUdp$ss_core_release(socket, inetAddress, 0, dnsResolverCompat$Companion$checkConnectivity$1) == coroutineSingletons) {
                                    return coroutineSingletons;
                                }
                                companion = this;
                                inetAddress2 = inetAddress;
                                network2 = network;
                                fileDescriptor = socket;
                            } catch (Throwable th2) {
                                companion = this;
                                network2 = network;
                                fileDescriptor = socket;
                                th = th2;
                                inetAddress2 = inetAddress;
                                Intrinsics.checkExpressionValueIsNotNull(fileDescriptor, "socket");
                                KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
                                Intrinsics.checkParameterIsNotNull(fileDescriptor, "$this$closeQuietly");
                                Os.close(fileDescriptor);
                                throw th;
                            }
                        } catch (IOException e) {
                            companion = this;
                            network2 = network;
                            IOException e2 = e;
                            inetAddress2 = inetAddress;
                            Throwable cause = e2.getCause();
                            if (!(cause instanceof ErrnoException)) {
                            }
                            ErrnoException errnoException = (ErrnoException) cause;
                            z = companion.checkConnectivity(network2, inetAddress2);
                        } catch (ErrnoException unused) {
                        } catch (ReflectiveOperationException e3) {
                            companion = this;
                            network2 = network;
                            ReflectiveOperationException e4 = e3;
                            inetAddress2 = inetAddress;
                            if (Build.VERSION.SDK_INT < 23) {
                            }
                            if (!z) {
                            }
                        }
                    } else if (i2 == 1) {
                        fileDescriptor = (FileDescriptor) dnsResolverCompat$Companion$checkConnectivity$1.L$3;
                        inetAddress2 = (InetAddress) dnsResolverCompat$Companion$checkConnectivity$1.L$2;
                        network2 = (Network) dnsResolverCompat$Companion$checkConnectivity$1.L$1;
                        companion = (Companion) dnsResolverCompat$Companion$checkConnectivity$1.L$0;
                        try {
                            ViewGroupUtilsApi14.throwOnFailure(obj);
                        } catch (Throwable th3) {
                            th = th3;
                        }
                    } else {
                        throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                    }
                    Intrinsics.checkExpressionValueIsNotNull(fileDescriptor, "socket");
                    KProperty[] kPropertyArr2 = UtilsKt.$$delegatedProperties;
                    Intrinsics.checkParameterIsNotNull(fileDescriptor, "$this$closeQuietly");
                    Os.close(fileDescriptor);
                    z = true;
                    return Boolean.valueOf(z);
                }
            }
            dnsResolverCompat$Companion$checkConnectivity$1 = new DnsResolverCompat$Companion$checkConnectivity$1(this, continuation);
            Object obj2 = dnsResolverCompat$Companion$checkConnectivity$1.result;
            CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
            i2 = dnsResolverCompat$Companion$checkConnectivity$1.label;
            boolean z2 = false;
            if (i2 != 0) {
            }
            try {
                Intrinsics.checkExpressionValueIsNotNull(fileDescriptor, "socket");
                KProperty[] kPropertyArr22 = UtilsKt.$$delegatedProperties;
                Intrinsics.checkParameterIsNotNull(fileDescriptor, "$this$closeQuietly");
                Os.close(fileDescriptor);
            } catch (ErrnoException unused2) {
            } catch (IOException e5) {
            } catch (ReflectiveOperationException e6) {
            }
            z2 = true;
            return Boolean.valueOf(z2);
        }

        public final DnsResolverCompat getInstance() {
            Lazy lazy = DnsResolverCompat.instance$delegate;
            KProperty kProperty = $$delegatedProperties[0];
            return (DnsResolverCompat) lazy.getValue();
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object resolve(Network network, String str, Continuation<? super InetAddress[]> continuation) {
            return getInstance().resolve(network, str, continuation);
        }

        @Override // com.github.shadowsocks.bg.DnsResolverCompat
        public Object resolveOnActiveNetwork(String str, Continuation<? super InetAddress[]> continuation) {
            return getInstance().resolveOnActiveNetwork(str, continuation);
        }

        public final boolean checkConnectivity(Network network, InetAddress inetAddress) {
            List<RouteInfo> routes;
            boolean z;
            boolean z2;
            LinkProperties linkProperties = Core.INSTANCE.getConnectivity().getLinkProperties(network);
            if (!(linkProperties == null || (routes = linkProperties.getRoutes()) == null)) {
                if (!routes.isEmpty()) {
                    Iterator<T> it = routes.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            break;
                        }
                        try {
                            z2 = it.next().matches(inetAddress);
                            continue;
                        } catch (RuntimeException e) {
                            KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
                            Intrinsics.checkParameterIsNotNull(e, "t");
                            Log.e("", "", e);
                            e.printStackTrace();
                            z2 = false;
                            continue;
                        }
                        if (z2) {
                            z = true;
                            break;
                        }
                    }
                }
                z = false;
                if (z) {
                    return true;
                }
            }
            return false;
        }
    }
}
