package com.github.shadowsocks.bg;

import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.net.LocalSocket;
import android.net.LocalSocketAddress;
import android.net.Network;
import android.net.VpnService;
import android.os.Build;
import android.os.IBinder;
import android.os.ParcelFileDescriptor;
import android.system.ErrnoException;
import android.system.Os;
import android.system.OsConstants;
import android.util.Log;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.utils.Constants;
import com.github.shadowsocks.Core;
import com.github.shadowsocks.VpnRequestActivity;
import com.github.shadowsocks.bg.DnsResolverCompat;
import com.github.shadowsocks.bg.LocalDnsService;
import com.github.shadowsocks.core.R$array;
import com.github.shadowsocks.core.R$string;
import com.github.shadowsocks.database.Profile;
import com.github.shadowsocks.net.ConcurrentLocalSocketListener;
import com.github.shadowsocks.net.DefaultNetworkListener;
import com.github.shadowsocks.net.HostsFile;
import com.github.shadowsocks.net.Subnet;
import com.github.shadowsocks.preference.DataStore;
import com.github.shadowsocks.utils.UtilsKt;
import java.io.File;
import java.io.FileDescriptor;
import java.io.IOException;
import java.io.OutputStream;
import java.net.InetAddress;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.Objects;
import kotlin.Unit;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.reflect.KProperty;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.CoroutineScope;

/* compiled from: VpnService.kt */
public final class VpnService extends android.net.VpnService implements LocalDnsService.Interface {
    public boolean active;
    public ParcelFileDescriptor conn;
    public final BaseService$Data data = new BaseService$Data(this);
    public boolean metered;
    public Network underlyingNetwork;
    public ProtectWorker worker;

    /* compiled from: VpnService.kt */
    public final class NullConnectionException extends NullPointerException implements BaseService$ExpectedException {
        public NullConnectionException() {
        }

        public String getLocalizedMessage() {
            String string = VpnService.this.getString(R$string.reboot_required);
            Intrinsics.checkExpressionValueIsNotNull(string, "getString(R.string.reboot_required)");
            return string;
        }
    }

    /* compiled from: VpnService.kt */
    public final class ProtectWorker extends ConcurrentLocalSocketListener {
        public ProtectWorker() {
            super("ShadowsocksVpnThread", new File(Core.INSTANCE.getDeviceStorage().getNoBackupFilesDir(), "protect_path"));
        }

        @Override // com.github.shadowsocks.net.LocalSocketListener
        public void acceptInternal(LocalSocket localSocket) {
            Intrinsics.checkParameterIsNotNull(localSocket, "socket");
            localSocket.getInputStream().read();
            FileDescriptor[] ancillaryFileDescriptors = localSocket.getAncillaryFileDescriptors();
            Integer num = null;
            if (ancillaryFileDescriptors != null) {
                Intrinsics.checkNotNullParameter(ancillaryFileDescriptors, "$this$single");
                int length = ancillaryFileDescriptors.length;
                if (length == 0) {
                    throw new NoSuchElementException("Array is empty.");
                } else if (length == 1) {
                    boolean z = false;
                    char c = 0;
                    z = false;
                    FileDescriptor fileDescriptor = ancillaryFileDescriptors[0];
                    if (fileDescriptor != null) {
                        try {
                            OutputStream outputStream = localSocket.getOutputStream();
                            Network network = VpnService.this.underlyingNetwork;
                            if (network != null) {
                                try {
                                    DnsResolverCompat.Companion.bindSocket(network, fileDescriptor);
                                    z = true;
                                } catch (IOException e) {
                                    Throwable cause = e.getCause();
                                    if (!(cause instanceof ErrnoException)) {
                                        cause = null;
                                    }
                                    ErrnoException errnoException = (ErrnoException) cause;
                                    if (errnoException != null) {
                                        num = Integer.valueOf(errnoException.errno);
                                    }
                                    int i = OsConstants.EPERM;
                                    if ((num != null && num.intValue() == i) || (num != null && num.intValue() == 64)) {
                                        e.printStackTrace();
                                    } else {
                                        KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
                                        Intrinsics.checkParameterIsNotNull(e, "t");
                                        Log.e("", "", e);
                                        e.printStackTrace();
                                    }
                                } catch (ReflectiveOperationException e2) {
                                    if (Build.VERSION.SDK_INT < 23) {
                                        c = 1;
                                    }
                                    if (c != 0) {
                                        KProperty[] kPropertyArr2 = UtilsKt.$$delegatedProperties;
                                        Intrinsics.checkParameterIsNotNull(e2, "t");
                                        Log.e("", "", e2);
                                        e2.printStackTrace();
                                    } else {
                                        throw new IllegalStateException("Check failed.".toString());
                                    }
                                }
                                outputStream.write(!z ? 1 : 0);
                            }
                            z = VpnService.this.protect(UtilsKt.getInt(fileDescriptor));
                            outputStream.write(!z ? 1 : 0);
                        } finally {
                            KProperty[] kPropertyArr3 = UtilsKt.$$delegatedProperties;
                            Intrinsics.checkParameterIsNotNull(fileDescriptor, "$this$closeQuietly");
                            try {
                                Os.close(fileDescriptor);
                            } catch (ErrnoException unused) {
                            }
                        }
                    } else {
                        Intrinsics.throwNpe();
                        throw null;
                    }
                } else {
                    throw new IllegalArgumentException("Array has more than one element.");
                }
            } else {
                Intrinsics.throwNpe();
                throw null;
            }
        }
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public ArrayList<String> buildAdditionalArguments(ArrayList<String> arrayList) {
        Intrinsics.checkParameterIsNotNull(arrayList, "cmd");
        arrayList.add("-V");
        return arrayList;
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public ServiceNotification createNotification(String str) {
        Intrinsics.checkParameterIsNotNull(str, "profileName");
        return new ServiceNotification(this, str, "service-vpn", false);
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public void forceLoad() {
        ViewGroupUtilsApi14.forceLoad(this);
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public Object getActiveNetwork(Continuation<? super Network> continuation) {
        return DefaultNetworkListener.INSTANCE.get(continuation);
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public BaseService$Data getData() {
        return this.data;
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public String getTag() {
        return "ShadowsocksVpnService";
    }

    public final Network[] getUnderlyingNetworks() {
        Network network;
        if ((Build.VERSION.SDK_INT != 28 || !this.metered) && (network = this.underlyingNetwork) != null) {
            return new Network[]{network};
        }
        return null;
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public void killProcesses(CoroutineScope coroutineScope) {
        Intrinsics.checkParameterIsNotNull(coroutineScope, "scope");
        LocalDnsService.Interface.DefaultImpls.killProcesses(this, coroutineScope);
        this.active = false;
        ViewGroupUtilsApi14.launch$default(coroutineScope, null, null, new VpnService$killProcesses$1(null), 3, null);
        ProtectWorker protectWorker = this.worker;
        if (protectWorker != null) {
            protectWorker.shutdown(coroutineScope);
        }
        this.worker = null;
        ParcelFileDescriptor parcelFileDescriptor = this.conn;
        if (parcelFileDescriptor != null) {
            parcelFileDescriptor.close();
        }
        this.conn = null;
    }

    public IBinder onBind(Intent intent) {
        Intrinsics.checkParameterIsNotNull(intent, "intent");
        String action = intent.getAction();
        if (action != null && action.hashCode() == -700396143 && action.equals("android.net.VpnService")) {
            return super.onBind(intent);
        }
        Intrinsics.checkParameterIsNotNull(intent, "intent");
        return ViewGroupUtilsApi14.onBind(this, intent);
    }

    public void onDestroy() {
        super.onDestroy();
        this.data.binder.close();
    }

    public void onRevoke() {
        ViewGroupUtilsApi14.stopRunner$default(this, false, null, 3, null);
    }

    public int onStartCommand(Intent intent, int i, int i2) {
        if (Intrinsics.areEqual(DataStore.INSTANCE.getServiceMode(), "vpn")) {
            if (android.net.VpnService.prepare(this) != null) {
                startActivity(new Intent(this, VpnRequestActivity.class).addFlags(268435456));
            } else {
                ViewGroupUtilsApi14.onStartCommand(this);
                return 2;
            }
        }
        ViewGroupUtilsApi14.stopRunner$default(this, false, null, 3, null);
        return 2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0037  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0021  */
    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public Object openConnection(URL url, Continuation<? super URLConnection> continuation) {
        VpnService$openConnection$1 vpnService$openConnection$1;
        int i;
        if (continuation instanceof VpnService$openConnection$1) {
            vpnService$openConnection$1 = (VpnService$openConnection$1) continuation;
            int i2 = vpnService$openConnection$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                vpnService$openConnection$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = vpnService$openConnection$1.result;
                CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = vpnService$openConnection$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    DefaultNetworkListener defaultNetworkListener = DefaultNetworkListener.INSTANCE;
                    vpnService$openConnection$1.L$0 = this;
                    vpnService$openConnection$1.L$1 = url;
                    vpnService$openConnection$1.label = 1;
                    obj = defaultNetworkListener.get(vpnService$openConnection$1);
                    if (obj == coroutineSingletons) {
                        return coroutineSingletons;
                    }
                } else if (i == 1) {
                    url = (URL) vpnService$openConnection$1.L$1;
                    VpnService vpnService = (VpnService) vpnService$openConnection$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                return ((Network) obj).openConnection(url);
            }
        }
        vpnService$openConnection$1 = new VpnService$openConnection$1(this, continuation);
        Object obj2 = vpnService$openConnection$1.result;
        CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = vpnService$openConnection$1.label;
        if (i != 0) {
        }
        return ((Network) obj2).openConnection(url);
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public void persistStats() {
        ViewGroupUtilsApi14.persistStats(this);
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public Object preInit(Continuation<? super Unit> continuation) {
        DefaultNetworkListener defaultNetworkListener = DefaultNetworkListener.INSTANCE;
        Object send = DefaultNetworkListener.networkActor.send(new DefaultNetworkListener.NetworkMessage.Start(this, new VpnService$preInit$2(this)), continuation);
        CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
        if (send != coroutineSingletons) {
            send = Unit.INSTANCE;
        }
        if (send == coroutineSingletons) {
            return send;
        }
        return Unit.INSTANCE;
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x004a  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0077 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0078 A[PHI: r8 
      PHI: (r8v2 java.lang.Object) = (r8v5 java.lang.Object), (r8v1 java.lang.Object) binds: [B:19:0x0075, B:10:0x0026] A[DONT_GENERATE, DONT_INLINE], RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0022  */
    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public Object resolver(String str, Continuation<? super InetAddress[]> continuation) {
        VpnService$resolver$1 vpnService$resolver$1;
        int i;
        DnsResolverCompat.Companion companion;
        VpnService vpnService;
        String str2;
        if (continuation instanceof VpnService$resolver$1) {
            vpnService$resolver$1 = (VpnService$resolver$1) continuation;
            int i2 = vpnService$resolver$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                vpnService$resolver$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = vpnService$resolver$1.result;
                CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = vpnService$resolver$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    DnsResolverCompat.Companion companion2 = DnsResolverCompat.Companion;
                    DefaultNetworkListener defaultNetworkListener = DefaultNetworkListener.INSTANCE;
                    vpnService$resolver$1.L$0 = this;
                    vpnService$resolver$1.L$1 = str;
                    vpnService$resolver$1.L$2 = companion2;
                    vpnService$resolver$1.label = 1;
                    Object obj2 = defaultNetworkListener.get(vpnService$resolver$1);
                    if (obj2 == coroutineSingletons) {
                        return coroutineSingletons;
                    }
                    vpnService = this;
                    str2 = str;
                    companion = companion2;
                    obj = obj2;
                } else if (i == 1) {
                    companion = (DnsResolverCompat.Companion) vpnService$resolver$1.L$2;
                    str2 = (String) vpnService$resolver$1.L$1;
                    vpnService = (VpnService) vpnService$resolver$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                } else if (i == 2) {
                    String str3 = (String) vpnService$resolver$1.L$1;
                    VpnService vpnService2 = (VpnService) vpnService$resolver$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                vpnService$resolver$1.L$0 = vpnService;
                vpnService$resolver$1.L$1 = str2;
                vpnService$resolver$1.label = 2;
                obj = companion.getInstance().resolve((Network) obj, str2, vpnService$resolver$1);
                return obj != coroutineSingletons ? coroutineSingletons : obj;
            }
        }
        vpnService$resolver$1 = new VpnService$resolver$1(this, continuation);
        Object obj3 = vpnService$resolver$1.result;
        CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = vpnService$resolver$1.label;
        if (i != 0) {
        }
        vpnService$resolver$1.L$0 = vpnService;
        vpnService$resolver$1.L$1 = str2;
        vpnService$resolver$1.label = 2;
        obj3 = companion.getInstance().resolve((Network) obj3, str2, vpnService$resolver$1);
        if (obj3 != coroutineSingletons2) {
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0098, code lost:
        r8 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x0099, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r13, r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x009c, code lost:
        throw r8;
     */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x006d A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x006e  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0022  */
    public final Object sendFd(FileDescriptor fileDescriptor, Continuation<? super Unit> continuation) {
        VpnService$sendFd$1 vpnService$sendFd$1;
        CoroutineSingletons coroutineSingletons;
        int i;
        IOException e;
        VpnService$sendFd$1 vpnService$sendFd$12;
        VpnService vpnService;
        int i2;
        String str;
        String str2;
        String str3;
        FileDescriptor fileDescriptor2;
        long j;
        if (continuation instanceof VpnService$sendFd$1) {
            vpnService$sendFd$1 = (VpnService$sendFd$1) continuation;
            int i3 = vpnService$sendFd$1.label;
            if ((i3 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                vpnService$sendFd$1.label = i3 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = vpnService$sendFd$1.result;
                coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = vpnService$sendFd$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    str2 = new File(Core.INSTANCE.getDeviceStorage().getNoBackupFilesDir(), "sock_path").getAbsolutePath();
                    vpnService = this;
                    i2 = 0;
                    j = 50 << i2;
                    vpnService$sendFd$1.L$0 = vpnService;
                    vpnService$sendFd$1.L$1 = fileDescriptor;
                    vpnService$sendFd$1.I$0 = i2;
                    vpnService$sendFd$1.L$2 = str2;
                    vpnService$sendFd$1.label = 1;
                    if (ViewGroupUtilsApi14.delay(j, vpnService$sendFd$1) == coroutineSingletons) {
                        return coroutineSingletons;
                    }
                    fileDescriptor2 = fileDescriptor;
                    str3 = str2;
                } else if (i == 1) {
                    str3 = (String) vpnService$sendFd$1.L$2;
                    i2 = vpnService$sendFd$1.I$0;
                    fileDescriptor2 = (FileDescriptor) vpnService$sendFd$1.L$1;
                    vpnService = (VpnService) vpnService$sendFd$1.L$0;
                    try {
                        ViewGroupUtilsApi14.throwOnFailure(obj);
                    } catch (IOException e2) {
                        e = e2;
                        vpnService$sendFd$12 = vpnService$sendFd$1;
                        str = str3;
                        fileDescriptor = fileDescriptor2;
                    }
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                LocalSocket localSocket = new LocalSocket();
                localSocket.connect(new LocalSocketAddress(str3, LocalSocketAddress.Namespace.FILESYSTEM));
                localSocket.setFileDescriptorsForSend(new FileDescriptor[]{fileDescriptor2});
                localSocket.getOutputStream().write(42);
                Unit unit = Unit.INSTANCE;
                ViewGroupUtilsApi14.closeFinally(localSocket, null);
                return unit;
            }
        }
        vpnService$sendFd$1 = new VpnService$sendFd$1(this, continuation);
        Object obj2 = vpnService$sendFd$1.result;
        coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = vpnService$sendFd$1.label;
        if (i != 0) {
        }
        j = 50 << i2;
        try {
            vpnService$sendFd$1.L$0 = vpnService;
            vpnService$sendFd$1.L$1 = fileDescriptor;
            vpnService$sendFd$1.I$0 = i2;
            vpnService$sendFd$1.L$2 = str2;
            vpnService$sendFd$1.label = 1;
        } catch (IOException e3) {
            vpnService$sendFd$12 = vpnService$sendFd$1;
            str = str2;
            e = e3;
            if (i2 <= 5) {
                i2++;
                str2 = str;
                vpnService$sendFd$1 = vpnService$sendFd$12;
                coroutineSingletons = coroutineSingletons;
                j = 50 << i2;
                vpnService$sendFd$1.L$0 = vpnService;
                vpnService$sendFd$1.L$1 = fileDescriptor;
                vpnService$sendFd$1.I$0 = i2;
                vpnService$sendFd$1.L$2 = str2;
                vpnService$sendFd$1.label = 1;
                if (ViewGroupUtilsApi14.delay(j, vpnService$sendFd$1) == coroutineSingletons) {
                }
            } else {
                throw e;
            }
        }
        if (ViewGroupUtilsApi14.delay(j, vpnService$sendFd$1) == coroutineSingletons) {
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:52:0x0173, code lost:
        if (r0.equals("bypass-china") != false) goto L_0x0199;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:54:0x017c, code lost:
        if (r0.equals("all") != false) goto L_0x0199;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:56:0x0185, code lost:
        if (r0.equals("jiandan-all") != false) goto L_0x0199;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:58:0x018e, code lost:
        if (r0.equals("custom-rules") != false) goto L_0x0199;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x0197, code lost:
        if (r0.equals("jiandan-ss") != false) goto L_0x0199;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x0199, code lost:
        r10.addRoute("0.0.0.0", 0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x01a2, code lost:
        if (r8.getIpv6() == false) goto L_0x01f0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:63:0x01a4, code lost:
        r10.addRoute("::", 0);
     */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0062  */
    /* JADX WARNING: Removed duplicated region for block: B:22:0x008c  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0029  */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x02e2 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x02f8  */
    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public Object startProcesses(HostsFile hostsFile, Continuation<? super Unit> continuation) {
        VpnService$startProcesses$1 vpnService$startProcesses$1;
        int i;
        VpnService vpnService;
        HostsFile hostsFile2;
        VpnService vpnService2;
        VpnService vpnService3;
        HostsFile hostsFile3;
        ProxyInstance proxyInstance;
        if (continuation instanceof VpnService$startProcesses$1) {
            vpnService$startProcesses$1 = (VpnService$startProcesses$1) continuation;
            int i2 = vpnService$startProcesses$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                vpnService$startProcesses$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = vpnService$startProcesses$1.result;
                CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = vpnService$startProcesses$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    ProtectWorker protectWorker = new ProtectWorker();
                    protectWorker.start();
                    this.worker = protectWorker;
                    vpnService$startProcesses$1.L$0 = this;
                    vpnService$startProcesses$1.L$1 = hostsFile;
                    vpnService$startProcesses$1.label = 1;
                    if (LocalDnsService.Interface.DefaultImpls.startProcesses(this, hostsFile, vpnService$startProcesses$1) == coroutineSingletons) {
                        return coroutineSingletons;
                    }
                    hostsFile3 = hostsFile;
                    vpnService3 = this;
                } else if (i == 1) {
                    vpnService3 = (VpnService) vpnService$startProcesses$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    hostsFile3 = (HostsFile) vpnService$startProcesses$1.L$1;
                } else if (i == 2) {
                    vpnService2 = (VpnService) vpnService$startProcesses$1.L$2;
                    hostsFile2 = (HostsFile) vpnService$startProcesses$1.L$1;
                    vpnService = (VpnService) vpnService$startProcesses$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    vpnService$startProcesses$1.L$0 = vpnService;
                    vpnService$startProcesses$1.L$1 = hostsFile2;
                    vpnService$startProcesses$1.label = 3;
                    if (vpnService2.sendFd((FileDescriptor) obj, vpnService$startProcesses$1) == coroutineSingletons) {
                        return coroutineSingletons;
                    }
                    return Unit.INSTANCE;
                } else if (i == 3) {
                    HostsFile hostsFile4 = (HostsFile) vpnService$startProcesses$1.L$1;
                    VpnService vpnService4 = (VpnService) vpnService$startProcesses$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    return Unit.INSTANCE;
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                vpnService$startProcesses$1.L$0 = vpnService3;
                vpnService$startProcesses$1.L$1 = hostsFile3;
                vpnService$startProcesses$1.L$2 = vpnService3;
                vpnService$startProcesses$1.label = 2;
                proxyInstance = vpnService3.data.proxy;
                if (proxyInstance == null) {
                    Profile profile = proxyInstance.profile;
                    VpnService.Builder builder = new VpnService.Builder(vpnService3);
                    Objects.requireNonNull(Core.INSTANCE);
                    Function1<? super Context, PendingIntent> function1 = Core.configureIntent;
                    if (function1 != null) {
                        VpnService.Builder addDnsServer = builder.setConfigureIntent(function1.invoke(vpnService3)).setSession((String) StringsKt__IndentKt.split$default((CharSequence) profile.getFormattedName(), new String[]{"___"}, false, 0, 6).get(0)).setMtu(Constants.MTU_MAX).addAddress("172.19.0.1", 30).addDnsServer("172.19.0.2");
                        if (profile.getIpv6()) {
                            addDnsServer.addAddress("fdfe:dcba:9876::1", 126);
                        }
                        if (profile.getProxyApps()) {
                            String packageName = vpnService3.getPackageName();
                            List split$default = StringsKt__IndentKt.split$default((CharSequence) profile.getIndividual(), new char[]{'\n'}, false, 0, 6);
                            ArrayList arrayList = new ArrayList();
                            for (Object obj2 : split$default) {
                                if (Boolean.valueOf(!Intrinsics.areEqual((String) obj2, packageName)).booleanValue()) {
                                    arrayList.add(obj2);
                                }
                            }
                            Iterator it = arrayList.iterator();
                            while (it.hasNext()) {
                                String str = (String) it.next();
                                try {
                                    if (profile.getBypass()) {
                                        addDnsServer.addDisallowedApplication(str);
                                    } else {
                                        addDnsServer.addAllowedApplication(str);
                                    }
                                } catch (PackageManager.NameNotFoundException e) {
                                    KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
                                    Intrinsics.checkParameterIsNotNull(e, "t");
                                    Log.e("", "", e);
                                    e.printStackTrace();
                                }
                            }
                            if (!profile.getBypass()) {
                                addDnsServer.addAllowedApplication(packageName);
                            }
                        }
                        addDnsServer.addDisallowedApplication(vpnService3.getPackageName());
                        String route = profile.getRoute();
                        switch (route.hashCode()) {
                            case -1108864312:
                                break;
                            case -701902949:
                                break;
                            case -15072711:
                                break;
                            case 96673:
                                break;
                            case 539699250:
                                break;
                            default:
                                String[] stringArray = vpnService3.getResources().getStringArray(R$array.bypass_private_route);
                                Intrinsics.checkExpressionValueIsNotNull(stringArray, "resources.getStringArray…ray.bypass_private_route)");
                                for (String str2 : stringArray) {
                                    Subnet.Companion companion = Subnet.Companion;
                                    Intrinsics.checkExpressionValueIsNotNull(str2, "it");
                                    Subnet fromString$default = Subnet.Companion.fromString$default(companion, str2, 0, 2);
                                    if (fromString$default != null) {
                                        addDnsServer.addRoute(fromString$default.address.getHostAddress(), fromString$default.prefixSize);
                                    } else {
                                        Intrinsics.throwNpe();
                                        throw null;
                                    }
                                }
                                addDnsServer.addRoute("172.19.0.2", 32);
                                if (profile.getIpv6()) {
                                    addDnsServer.addRoute("2000::", 3);
                                }
                                vpnService3.metered = profile.getMetered();
                                vpnService3.active = true;
                                int i3 = Build.VERSION.SDK_INT;
                                addDnsServer.setUnderlyingNetworks(vpnService3.getUnderlyingNetworks());
                                if (i3 >= 29) {
                                    addDnsServer.setMetered(vpnService3.metered);
                                }
                                ParcelFileDescriptor establish = addDnsServer.establish();
                                if (establish != null) {
                                    vpnService3.conn = establish;
                                    StringBuilder sb = new StringBuilder();
                                    DataStore dataStore = DataStore.INSTANCE;
                                    sb.append(dataStore.getListenAddress());
                                    sb.append(':');
                                    sb.append(dataStore.getPortProxy());
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("127.0.0.1:");
                                    outline25.append(dataStore.getLocalPort("portLocalDns", 5450));
                                    ArrayList arrayListOf = ArraysKt___ArraysKt.arrayListOf(new File(vpnService3.getApplicationInfo().nativeLibraryDir, "libtun2socks.so").getAbsolutePath(), "--netif-ipaddr", "172.19.0.2", "--socks-server-addr", sb.toString(), "--tunmtu", String.valueOf((int) Constants.MTU_MAX), "--sock-path", "sock_path", "--dnsgw", outline25.toString(), "--loglevel", "warning");
                                    if (profile.getIpv6()) {
                                        arrayListOf.add("--netif-ip6addr");
                                        arrayListOf.add("fdfe:dcba:9876::2");
                                    }
                                    arrayListOf.add("--enable-udprelay");
                                    GuardedProcessPool guardedProcessPool = vpnService3.data.processes;
                                    if (guardedProcessPool != null) {
                                        guardedProcessPool.start(arrayListOf, new VpnService$startVpn$5(vpnService3, establish, null));
                                        FileDescriptor fileDescriptor = establish.getFileDescriptor();
                                        Intrinsics.checkExpressionValueIsNotNull(fileDescriptor, "conn.fileDescriptor");
                                        if (fileDescriptor == coroutineSingletons) {
                                            return coroutineSingletons;
                                        }
                                        vpnService = vpnService3;
                                        hostsFile2 = hostsFile3;
                                        obj = fileDescriptor;
                                        vpnService2 = vpnService;
                                        vpnService$startProcesses$1.L$0 = vpnService;
                                        vpnService$startProcesses$1.L$1 = hostsFile2;
                                        vpnService$startProcesses$1.label = 3;
                                        if (vpnService2.sendFd((FileDescriptor) obj, vpnService$startProcesses$1) == coroutineSingletons) {
                                        }
                                        return Unit.INSTANCE;
                                    }
                                    Intrinsics.throwNpe();
                                    throw null;
                                }
                                throw new NullConnectionException();
                        }
                    } else {
                        Intrinsics.throwUninitializedPropertyAccessException("configureIntent");
                        throw null;
                    }
                } else {
                    Intrinsics.throwNpe();
                    throw null;
                }
            }
        }
        vpnService$startProcesses$1 = new VpnService$startProcesses$1(this, continuation);
        Object obj3 = vpnService$startProcesses$1.result;
        CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = vpnService$startProcesses$1.label;
        if (i != 0) {
        }
        vpnService$startProcesses$1.L$0 = vpnService3;
        vpnService$startProcesses$1.L$1 = hostsFile3;
        vpnService$startProcesses$1.L$2 = vpnService3;
        vpnService$startProcesses$1.label = 2;
        proxyInstance = vpnService3.data.proxy;
        if (proxyInstance == null) {
        }
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public void startRunner() {
        ViewGroupUtilsApi14.startRunner(this);
    }

    @Override // com.github.shadowsocks.bg.BaseService$Interface
    public void stopRunner(boolean z, String str) {
        ViewGroupUtilsApi14.stopRunner(this, z, str);
    }
}
