package com.github.shadowsocks.net;

import android.util.Log;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.github.shadowsocks.acl.AclMatcher;
import com.github.shadowsocks.bg.BaseService$ExpectedExceptionWrapper;
import java.io.Closeable;
import java.io.IOException;
import java.net.BindException;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.SocketAddress;
import java.nio.ByteBuffer;
import java.nio.channels.DatagramChannel;
import java.nio.channels.SelectionKey;
import java.nio.channels.SocketChannel;
import java.util.Iterator;
import java.util.Objects;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.CoroutineContext;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.functions.Function2;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.CoroutineExceptionHandler;
import kotlinx.coroutines.CoroutineScope;
import kotlinx.coroutines.Deferred;
import kotlinx.coroutines.Job;
import kotlinx.coroutines.SupervisorCoroutine;
import kotlinx.coroutines.SupervisorJobImpl;
import kotlinx.coroutines.internal.SystemPropsKt;
import org.xbill.DNS.AAAARecord;
import org.xbill.DNS.ARecord;
import org.xbill.DNS.DNSInput;
import org.xbill.DNS.Header;
import org.xbill.DNS.Message;
import org.xbill.DNS.Record;

/* compiled from: LocalDnsServer.kt */
public final class LocalDnsServer implements CoroutineScope {
    public static final Companion Companion = new Companion(null);
    public final Deferred<AclMatcher> acl;
    public final CoroutineContext coroutineContext;
    public final HostsFile hosts;
    public final Function2<String, Continuation<? super InetAddress[]>, Object> localResolver;
    public final ChannelMonitor monitor = new ChannelMonitor();
    public final SocketAddress proxy;
    public final Socks5Endpoint remoteDns;
    public final boolean tcp;

    /* compiled from: LocalDnsServer.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }

        public static final ByteBuffer access$cookDnsResponse(Companion companion, Message message, Iterable iterable) {
            Record record;
            Message prepareDnsResponse = companion.prepareDnsResponse(message);
            prepareDnsResponse.header.setFlag(8);
            Iterator it = iterable.iterator();
            while (it.hasNext()) {
                InetAddress inetAddress = (InetAddress) it.next();
                if (inetAddress instanceof Inet4Address) {
                    Record question = prepareDnsResponse.getQuestion();
                    Intrinsics.checkExpressionValueIsNotNull(question, "question");
                    record = new ARecord(question.getName(), 1, 120, inetAddress);
                } else if (inetAddress instanceof Inet6Address) {
                    Record question2 = prepareDnsResponse.getQuestion();
                    Intrinsics.checkExpressionValueIsNotNull(question2, "question");
                    record = new AAAARecord(question2.getName(), 1, 120, inetAddress);
                } else {
                    throw new IllegalStateException(("Unsupported address " + inetAddress).toString());
                }
                prepareDnsResponse.addRecord(record, 1);
            }
            return ByteBuffer.wrap(prepareDnsResponse.toWire());
        }

        public final Message prepareDnsResponse(Message message) {
            Header header = message.header;
            Intrinsics.checkExpressionValueIsNotNull(header, "request.header");
            Message message2 = new Message(header.getID());
            message2.header.setFlag(0);
            if (message.header.getFlag(7)) {
                message2.header.setFlag(7);
            }
            Record question = message.getQuestion();
            if (question != null) {
                message2.addRecord(question, 0);
            }
            return message2;
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r7v0, resolved type: kotlin.jvm.functions.Function2<? super java.lang.String, ? super kotlin.coroutines.Continuation<? super java.net.InetAddress[]>, ? extends java.lang.Object> */
    /* JADX WARN: Multi-variable type inference failed */
    public LocalDnsServer(Function2<? super String, ? super Continuation<? super InetAddress[]>, ? extends Object> function2, Socks5Endpoint socks5Endpoint, SocketAddress socketAddress, HostsFile hostsFile, boolean z, Function1<? super Continuation<? super AclMatcher>, ? extends Object> function1) {
        Intrinsics.checkParameterIsNotNull(function2, "localResolver");
        Intrinsics.checkParameterIsNotNull(socks5Endpoint, "remoteDns");
        Intrinsics.checkParameterIsNotNull(socketAddress, "proxy");
        Intrinsics.checkParameterIsNotNull(hostsFile, "hosts");
        this.localResolver = function2;
        this.remoteDns = socks5Endpoint;
        this.proxy = socketAddress;
        this.hosts = hostsFile;
        this.tcp = z;
        Deferred<AclMatcher> deferred = null;
        SupervisorJobImpl supervisorJobImpl = new SupervisorJobImpl(null);
        int i = CoroutineExceptionHandler.$r8$clinit;
        this.coroutineContext = supervisorJobImpl.plus(new LocalDnsServer$$special$$inlined$CoroutineExceptionHandler$1(CoroutineExceptionHandler.Key.$$INSTANCE));
        this.acl = function1 != null ? ViewGroupUtilsApi14.async$default(this, null, null, new LocalDnsServer$acl$1$1(function1, null), 3, null) : deferred;
    }

    /* JADX WARNING: Removed duplicated region for block: B:104:0x027c  */
    /* JADX WARNING: Removed duplicated region for block: B:119:0x0164 A[ADDED_TO_REGION, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x00f3  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0117  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x0144 A[Catch:{ all -> 0x01b4 }] */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x01a4 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x01a5  */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x0216 A[Catch:{ all -> 0x0288 }] */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x0219 A[Catch:{ all -> 0x0288 }] */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x0238 A[Catch:{ all -> 0x026b }] */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0031  */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x023d A[Catch:{ all -> 0x026b }] */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x0240 A[Catch:{ all -> 0x026b }] */
    /* JADX WARNING: Removed duplicated region for block: B:98:0x0267 A[Catch:{ all -> 0x026b }] */
    public final Object forward(ByteBuffer byteBuffer, Continuation<? super ByteBuffer> continuation) {
        LocalDnsServer$forward$1 localDnsServer$forward$1;
        int i;
        ByteBuffer byteBuffer2;
        Closeable closeable;
        SocketChannel socketChannel;
        CoroutineSingletons coroutineSingletons;
        Throwable th;
        LocalDnsServer$forward$1 localDnsServer$forward$12;
        LocalDnsServer localDnsServer;
        String str;
        ByteBuffer byteBuffer3;
        Closeable closeable2;
        ByteBuffer allocateDirect;
        Socks5Endpoint socks5Endpoint;
        LocalDnsServer$forward$2$1 localDnsServer$forward$2$1;
        LocalDnsServer$forward$$inlined$use$lambda$1 localDnsServer$forward$$inlined$use$lambda$1;
        Throwable th2;
        ByteBuffer byteBuffer4;
        Closeable closeable3;
        ChannelMonitor channelMonitor;
        Closeable closeable4;
        Throwable th3;
        Closeable closeable5;
        Throwable th4;
        LocalDnsServer localDnsServer2;
        ByteBuffer byteBuffer5;
        DatagramChannel datagramChannel;
        Job job;
        DatagramChannel datagramChannel2;
        ByteBuffer allocateDirect2;
        Throwable th5;
        LocalDnsServer localDnsServer3;
        Closeable closeable6;
        SocketChannel socketChannel2;
        ByteBuffer byteBuffer6;
        ByteBuffer byteBuffer7 = byteBuffer;
        if (continuation instanceof LocalDnsServer$forward$1) {
            localDnsServer$forward$1 = (LocalDnsServer$forward$1) continuation;
            int i2 = localDnsServer$forward$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                localDnsServer$forward$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = localDnsServer$forward$1.result;
                CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = localDnsServer$forward$1.label;
                Throwable th6 = null;
                boolean z = false;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    byteBuffer7.position(0);
                    if (this.tcp) {
                        socketChannel2 = SocketChannel.open();
                        socketChannel2.configureBlocking(false);
                        socketChannel2.connect(this.proxy);
                        byteBuffer6 = this.remoteDns.tcpWrap(byteBuffer7);
                        localDnsServer3 = this;
                        closeable6 = socketChannel2;
                    } else {
                        datagramChannel2 = DatagramChannel.open();
                        try {
                            datagramChannel2.configureBlocking(false);
                            try {
                                ChannelMonitor channelMonitor2 = this.monitor;
                                Intrinsics.checkExpressionValueIsNotNull(datagramChannel2, "channel");
                                localDnsServer$forward$1.L$0 = this;
                                localDnsServer$forward$1.L$1 = byteBuffer7;
                                localDnsServer$forward$1.L$2 = datagramChannel2;
                                localDnsServer$forward$1.L$3 = null;
                                localDnsServer$forward$1.L$4 = datagramChannel2;
                                localDnsServer$forward$1.label = 4;
                                if (channelMonitor2.wait(datagramChannel2, 4, localDnsServer$forward$1) == coroutineSingletons2) {
                                    return coroutineSingletons2;
                                }
                                closeable4 = datagramChannel2;
                                localDnsServer2 = this;
                                Socks5Endpoint socks5Endpoint2 = localDnsServer2.remoteDns;
                                Objects.requireNonNull(socks5Endpoint2);
                                Intrinsics.checkParameterIsNotNull(byteBuffer7, "packet");
                                allocateDirect2 = ByteBuffer.allocateDirect(byteBuffer7.remaining() + socks5Endpoint2.dest.length + 3);
                                allocateDirect2.putShort(0);
                                allocateDirect2.put((byte) 0);
                                allocateDirect2.put(socks5Endpoint2.dest);
                                allocateDirect2.put(byteBuffer7);
                                allocateDirect2.flip();
                                if (datagramChannel2.send(allocateDirect2, localDnsServer2.proxy) > 0) {
                                }
                                if (!z) {
                                }
                            } catch (Throwable th7) {
                                th4 = th7;
                                closeable5 = datagramChannel2;
                                th3 = th4;
                                closeable4 = closeable5;
                                throw th3;
                            }
                        } catch (Throwable th8) {
                            th4 = th8;
                            closeable5 = datagramChannel2;
                            th3 = th4;
                            closeable4 = closeable5;
                            throw th3;
                        }
                    }
                } else if (i == 1) {
                    socketChannel2 = (SocketChannel) localDnsServer$forward$1.L$4;
                    th6 = (Throwable) localDnsServer$forward$1.L$3;
                    closeable6 = (Closeable) localDnsServer$forward$1.L$2;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    byteBuffer6 = (ByteBuffer) localDnsServer$forward$1.L$5;
                    byteBuffer7 = (ByteBuffer) localDnsServer$forward$1.L$1;
                    localDnsServer3 = (LocalDnsServer) localDnsServer$forward$1.L$0;
                } else if (i == 2) {
                    byteBuffer3 = (ByteBuffer) localDnsServer$forward$1.L$5;
                    SocketChannel socketChannel3 = (SocketChannel) localDnsServer$forward$1.L$4;
                    Throwable th9 = (Throwable) localDnsServer$forward$1.L$3;
                    closeable2 = (Closeable) localDnsServer$forward$1.L$2;
                    ByteBuffer byteBuffer8 = (ByteBuffer) localDnsServer$forward$1.L$1;
                    LocalDnsServer localDnsServer4 = (LocalDnsServer) localDnsServer$forward$1.L$0;
                    try {
                        ViewGroupUtilsApi14.throwOnFailure(obj);
                        socketChannel = socketChannel3;
                        str = "channel";
                        byteBuffer2 = byteBuffer8;
                        localDnsServer$forward$12 = localDnsServer$forward$1;
                        coroutineSingletons = coroutineSingletons2;
                        th = th9;
                        localDnsServer = localDnsServer4;
                        closeable = closeable2;
                        do {
                            try {
                                if (socketChannel.write(byteBuffer3) < 0 || !byteBuffer3.hasRemaining()) {
                                    allocateDirect = ByteBuffer.allocateDirect(localDnsServer.remoteDns.headerReserved + 4 + 512);
                                    socks5Endpoint = localDnsServer.remoteDns;
                                    Intrinsics.checkExpressionValueIsNotNull(allocateDirect, "result");
                                    localDnsServer$forward$2$1 = new LocalDnsServer$forward$2$1(socketChannel);
                                    localDnsServer$forward$$inlined$use$lambda$1 = new LocalDnsServer$forward$$inlined$use$lambda$1(socketChannel, null, localDnsServer, byteBuffer2, localDnsServer$forward$12);
                                    localDnsServer$forward$12.L$0 = localDnsServer;
                                    localDnsServer$forward$12.L$1 = byteBuffer2;
                                    localDnsServer$forward$12.L$2 = closeable;
                                    localDnsServer$forward$12.L$3 = th;
                                    localDnsServer$forward$12.L$4 = socketChannel;
                                    localDnsServer$forward$12.L$5 = byteBuffer3;
                                    localDnsServer$forward$12.L$6 = allocateDirect;
                                    localDnsServer$forward$12.label = 3;
                                    if (socks5Endpoint.tcpUnwrap(allocateDirect, localDnsServer$forward$2$1, localDnsServer$forward$$inlined$use$lambda$1, localDnsServer$forward$12) == coroutineSingletons) {
                                        return coroutineSingletons;
                                    }
                                    th2 = th;
                                    byteBuffer4 = allocateDirect;
                                    closeable3 = closeable;
                                    ViewGroupUtilsApi14.closeFinally(closeable3, th2);
                                    Intrinsics.checkExpressionValueIsNotNull(byteBuffer4, "SocketChannel.open().use…         result\n        }");
                                    return byteBuffer4;
                                }
                                channelMonitor = localDnsServer.monitor;
                                Intrinsics.checkExpressionValueIsNotNull(socketChannel, str);
                                localDnsServer$forward$12.L$0 = localDnsServer;
                                localDnsServer$forward$12.L$1 = byteBuffer2;
                                localDnsServer$forward$12.L$2 = closeable;
                                localDnsServer$forward$12.L$3 = th;
                                localDnsServer$forward$12.L$4 = socketChannel;
                                localDnsServer$forward$12.L$5 = byteBuffer3;
                                localDnsServer$forward$12.label = 2;
                            } catch (Throwable th10) {
                                th = th10;
                                closeable2 = closeable;
                                th5 = th;
                                try {
                                    throw th5;
                                } catch (Throwable th11) {
                                    ViewGroupUtilsApi14.closeFinally(closeable2, th5);
                                    throw th11;
                                }
                            }
                        } while (channelMonitor.wait(socketChannel, 4, localDnsServer$forward$12) != coroutineSingletons);
                        return coroutineSingletons;
                    } catch (Throwable th12) {
                        th = th12;
                        th5 = th;
                        throw th5;
                    }
                } else if (i == 3) {
                    byteBuffer4 = (ByteBuffer) localDnsServer$forward$1.L$6;
                    ByteBuffer byteBuffer9 = (ByteBuffer) localDnsServer$forward$1.L$5;
                    SocketChannel socketChannel4 = (SocketChannel) localDnsServer$forward$1.L$4;
                    th2 = (Throwable) localDnsServer$forward$1.L$3;
                    closeable3 = (Closeable) localDnsServer$forward$1.L$2;
                    ByteBuffer byteBuffer10 = (ByteBuffer) localDnsServer$forward$1.L$1;
                    LocalDnsServer localDnsServer5 = (LocalDnsServer) localDnsServer$forward$1.L$0;
                    try {
                        ViewGroupUtilsApi14.throwOnFailure(obj);
                        ViewGroupUtilsApi14.closeFinally(closeable3, th2);
                        Intrinsics.checkExpressionValueIsNotNull(byteBuffer4, "SocketChannel.open().use…         result\n        }");
                        return byteBuffer4;
                    } catch (Throwable th13) {
                        th5 = th13;
                        closeable2 = closeable3;
                    }
                } else if (i == 4) {
                    DatagramChannel datagramChannel3 = (DatagramChannel) localDnsServer$forward$1.L$4;
                    th6 = (Throwable) localDnsServer$forward$1.L$3;
                    closeable4 = (Closeable) localDnsServer$forward$1.L$2;
                    ByteBuffer byteBuffer11 = (ByteBuffer) localDnsServer$forward$1.L$1;
                    localDnsServer2 = (LocalDnsServer) localDnsServer$forward$1.L$0;
                    try {
                        ViewGroupUtilsApi14.throwOnFailure(obj);
                        datagramChannel2 = datagramChannel3;
                        byteBuffer7 = byteBuffer11;
                    } catch (Throwable th14) {
                        th4 = th14;
                        closeable5 = closeable4;
                        th3 = th4;
                        closeable4 = closeable5;
                        throw th3;
                    }
                    try {
                        Socks5Endpoint socks5Endpoint22 = localDnsServer2.remoteDns;
                        Objects.requireNonNull(socks5Endpoint22);
                        Intrinsics.checkParameterIsNotNull(byteBuffer7, "packet");
                        allocateDirect2 = ByteBuffer.allocateDirect(byteBuffer7.remaining() + socks5Endpoint22.dest.length + 3);
                        allocateDirect2.putShort(0);
                        allocateDirect2.put((byte) 0);
                        allocateDirect2.put(socks5Endpoint22.dest);
                        allocateDirect2.put(byteBuffer7);
                        allocateDirect2.flip();
                        if (datagramChannel2.send(allocateDirect2, localDnsServer2.proxy) > 0) {
                            z = true;
                        }
                        if (!z) {
                            byteBuffer5 = byteBuffer7;
                            byteBuffer4 = ByteBuffer.allocateDirect(localDnsServer2.remoteDns.headerReserved + 512);
                            closeable5 = closeable4;
                            datagramChannel = datagramChannel2;
                            Intrinsics.checkParameterIsNotNull(localDnsServer2, "$this$isActive");
                            job = (Job) localDnsServer2.coroutineContext.get(Job.Key);
                            if (job == null ? job.isActive() : true) {
                            }
                            byteBuffer4.flip();
                            Socks5Endpoint socks5Endpoint3 = localDnsServer2.remoteDns;
                            Intrinsics.checkExpressionValueIsNotNull(byteBuffer4, "result");
                            socks5Endpoint3.udpUnwrap(byteBuffer4);
                            ViewGroupUtilsApi14.closeFinally(closeable5, th6);
                            return byteBuffer4;
                        }
                        throw new IllegalStateException("Check failed.".toString());
                    } catch (Throwable th15) {
                        th3 = th15;
                        throw th3;
                    }
                } else if (i == 5) {
                    byteBuffer4 = (ByteBuffer) localDnsServer$forward$1.L$5;
                    datagramChannel = (DatagramChannel) localDnsServer$forward$1.L$4;
                    th6 = (Throwable) localDnsServer$forward$1.L$3;
                    closeable5 = (Closeable) localDnsServer$forward$1.L$2;
                    byteBuffer5 = (ByteBuffer) localDnsServer$forward$1.L$1;
                    localDnsServer2 = (LocalDnsServer) localDnsServer$forward$1.L$0;
                    try {
                        ViewGroupUtilsApi14.throwOnFailure(obj);
                        if (Intrinsics.areEqual(datagramChannel.receive(byteBuffer4), localDnsServer2.proxy)) {
                            try {
                                byteBuffer4.clear();
                                Intrinsics.checkParameterIsNotNull(localDnsServer2, "$this$isActive");
                                job = (Job) localDnsServer2.coroutineContext.get(Job.Key);
                                if (job == null ? job.isActive() : true) {
                                    ChannelMonitor channelMonitor3 = localDnsServer2.monitor;
                                    Intrinsics.checkExpressionValueIsNotNull(datagramChannel, "channel");
                                    localDnsServer$forward$1.L$0 = localDnsServer2;
                                    localDnsServer$forward$1.L$1 = byteBuffer5;
                                    localDnsServer$forward$1.L$2 = closeable5;
                                    localDnsServer$forward$1.L$3 = th6;
                                    localDnsServer$forward$1.L$4 = datagramChannel;
                                    localDnsServer$forward$1.L$5 = byteBuffer4;
                                    localDnsServer$forward$1.label = 5;
                                    if (channelMonitor3.wait(datagramChannel, 1, localDnsServer$forward$1) == coroutineSingletons2) {
                                        return coroutineSingletons2;
                                    }
                                    if (Intrinsics.areEqual(datagramChannel.receive(byteBuffer4), localDnsServer2.proxy)) {
                                    }
                                }
                                byteBuffer4.flip();
                                Socks5Endpoint socks5Endpoint32 = localDnsServer2.remoteDns;
                                Intrinsics.checkExpressionValueIsNotNull(byteBuffer4, "result");
                                socks5Endpoint32.udpUnwrap(byteBuffer4);
                                ViewGroupUtilsApi14.closeFinally(closeable5, th6);
                                return byteBuffer4;
                            } catch (Throwable th16) {
                                th4 = th16;
                                th3 = th4;
                                closeable4 = closeable5;
                                try {
                                    throw th3;
                                } catch (Throwable th17) {
                                    ViewGroupUtilsApi14.closeFinally(closeable4, th3);
                                    throw th17;
                                }
                            }
                        }
                        byteBuffer4.flip();
                        Socks5Endpoint socks5Endpoint322 = localDnsServer2.remoteDns;
                        Intrinsics.checkExpressionValueIsNotNull(byteBuffer4, "result");
                        socks5Endpoint322.udpUnwrap(byteBuffer4);
                        ViewGroupUtilsApi14.closeFinally(closeable5, th6);
                        return byteBuffer4;
                    } catch (Throwable th18) {
                        th4 = th18;
                        th3 = th4;
                        closeable4 = closeable5;
                        throw th3;
                    }
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                if (!socketChannel2.finishConnect()) {
                    ChannelMonitor channelMonitor4 = localDnsServer3.monitor;
                    Intrinsics.checkExpressionValueIsNotNull(socketChannel2, "channel");
                    localDnsServer$forward$1.L$0 = localDnsServer3;
                    localDnsServer$forward$1.L$1 = byteBuffer7;
                    localDnsServer$forward$1.L$2 = closeable6;
                    localDnsServer$forward$1.L$3 = th6;
                    localDnsServer$forward$1.L$4 = socketChannel2;
                    localDnsServer$forward$1.L$5 = byteBuffer6;
                    localDnsServer$forward$1.label = 1;
                    if (channelMonitor4.wait(socketChannel2, 8, localDnsServer$forward$1) == coroutineSingletons2) {
                        return coroutineSingletons2;
                    }
                    if (!socketChannel2.finishConnect()) {
                        byteBuffer2 = byteBuffer7;
                        byteBuffer3 = byteBuffer6;
                        socketChannel = socketChannel2;
                        str = "channel";
                        closeable = closeable6;
                        localDnsServer$forward$12 = localDnsServer$forward$1;
                        th = th6;
                        localDnsServer = localDnsServer3;
                        coroutineSingletons = coroutineSingletons2;
                    }
                }
                byteBuffer2 = byteBuffer7;
                byteBuffer3 = byteBuffer6;
                socketChannel = socketChannel2;
                str = "channel";
                closeable = closeable6;
                localDnsServer$forward$12 = localDnsServer$forward$1;
                th = th6;
                localDnsServer = localDnsServer3;
                coroutineSingletons = coroutineSingletons2;
                do {
                    if (socketChannel.write(byteBuffer3) < 0) {
                    }
                    allocateDirect = ByteBuffer.allocateDirect(localDnsServer.remoteDns.headerReserved + 4 + 512);
                    socks5Endpoint = localDnsServer.remoteDns;
                    Intrinsics.checkExpressionValueIsNotNull(allocateDirect, "result");
                    localDnsServer$forward$2$1 = new LocalDnsServer$forward$2$1(socketChannel);
                    localDnsServer$forward$$inlined$use$lambda$1 = new LocalDnsServer$forward$$inlined$use$lambda$1(socketChannel, null, localDnsServer, byteBuffer2, localDnsServer$forward$12);
                    localDnsServer$forward$12.L$0 = localDnsServer;
                    localDnsServer$forward$12.L$1 = byteBuffer2;
                    localDnsServer$forward$12.L$2 = closeable;
                    localDnsServer$forward$12.L$3 = th;
                    localDnsServer$forward$12.L$4 = socketChannel;
                    localDnsServer$forward$12.L$5 = byteBuffer3;
                    localDnsServer$forward$12.L$6 = allocateDirect;
                    localDnsServer$forward$12.label = 3;
                    if (socks5Endpoint.tcpUnwrap(allocateDirect, localDnsServer$forward$2$1, localDnsServer$forward$$inlined$use$lambda$1, localDnsServer$forward$12) == coroutineSingletons) {
                    }
                } while (channelMonitor.wait(socketChannel, 4, localDnsServer$forward$12) != coroutineSingletons);
                return coroutineSingletons;
            }
        }
        localDnsServer$forward$1 = new LocalDnsServer$forward$1(this, continuation);
        Object obj2 = localDnsServer$forward$1.result;
        CoroutineSingletons coroutineSingletons22 = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = localDnsServer$forward$1.label;
        Throwable th62 = null;
        boolean z2 = false;
        if (i != 0) {
        }
        if (!socketChannel2.finishConnect()) {
        }
        byteBuffer2 = byteBuffer7;
        byteBuffer3 = byteBuffer6;
        socketChannel = socketChannel2;
        str = "channel";
        closeable = closeable6;
        localDnsServer$forward$12 = localDnsServer$forward$1;
        th = th62;
        localDnsServer = localDnsServer3;
        coroutineSingletons = coroutineSingletons22;
        do {
            if (socketChannel.write(byteBuffer3) < 0) {
            }
            allocateDirect = ByteBuffer.allocateDirect(localDnsServer.remoteDns.headerReserved + 4 + 512);
            socks5Endpoint = localDnsServer.remoteDns;
            Intrinsics.checkExpressionValueIsNotNull(allocateDirect, "result");
            localDnsServer$forward$2$1 = new LocalDnsServer$forward$2$1(socketChannel);
            localDnsServer$forward$$inlined$use$lambda$1 = new LocalDnsServer$forward$$inlined$use$lambda$1(socketChannel, null, localDnsServer, byteBuffer2, localDnsServer$forward$12);
            localDnsServer$forward$12.L$0 = localDnsServer;
            localDnsServer$forward$12.L$1 = byteBuffer2;
            localDnsServer$forward$12.L$2 = closeable;
            localDnsServer$forward$12.L$3 = th;
            localDnsServer$forward$12.L$4 = socketChannel;
            localDnsServer$forward$12.L$5 = byteBuffer3;
            localDnsServer$forward$12.L$6 = allocateDirect;
            localDnsServer$forward$12.label = 3;
            if (socks5Endpoint.tcpUnwrap(allocateDirect, localDnsServer$forward$2$1, localDnsServer$forward$$inlined$use$lambda$1, localDnsServer$forward$12) == coroutineSingletons) {
            }
        } while (channelMonitor.wait(socketChannel, 4, localDnsServer$forward$12) != coroutineSingletons);
        return coroutineSingletons;
    }

    @Override // kotlinx.coroutines.CoroutineScope
    public CoroutineContext getCoroutineContext() {
        return this.coroutineContext;
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x004e  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0022  */
    public final Object resolve(ByteBuffer byteBuffer, Continuation<? super ByteBuffer> continuation) {
        LocalDnsServer$resolve$1 localDnsServer$resolve$1;
        int i;
        if (continuation instanceof LocalDnsServer$resolve$1) {
            localDnsServer$resolve$1 = (LocalDnsServer$resolve$1) continuation;
            int i2 = localDnsServer$resolve$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                localDnsServer$resolve$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = localDnsServer$resolve$1.result;
                Object obj2 = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = localDnsServer$resolve$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    try {
                        Message message = new Message(new DNSInput(byteBuffer));
                        LocalDnsServer$resolve$2 localDnsServer$resolve$2 = new LocalDnsServer$resolve$2(this, byteBuffer, message, null);
                        localDnsServer$resolve$1.L$0 = this;
                        localDnsServer$resolve$1.L$1 = byteBuffer;
                        localDnsServer$resolve$1.L$2 = message;
                        localDnsServer$resolve$1.label = 2;
                        SupervisorCoroutine supervisorCoroutine = new SupervisorCoroutine(localDnsServer$resolve$1.getContext(), localDnsServer$resolve$1);
                        obj = SystemPropsKt.startUndispatchedOrReturn(supervisorCoroutine, supervisorCoroutine, localDnsServer$resolve$2);
                        if (obj == obj2) {
                            Intrinsics.checkNotNullParameter(localDnsServer$resolve$1, "frame");
                        }
                        if (obj == obj2) {
                            return obj2;
                        }
                    } catch (IOException e) {
                        Log.w("LocalDnsServer", e.getMessage());
                        localDnsServer$resolve$1.L$0 = this;
                        localDnsServer$resolve$1.L$1 = byteBuffer;
                        localDnsServer$resolve$1.L$2 = e;
                        localDnsServer$resolve$1.label = 1;
                        obj = forward(byteBuffer, localDnsServer$resolve$1);
                        if (obj == obj2) {
                            return obj2;
                        }
                    }
                } else if (i == 1) {
                    IOException iOException = (IOException) localDnsServer$resolve$1.L$2;
                    ByteBuffer byteBuffer2 = (ByteBuffer) localDnsServer$resolve$1.L$1;
                    LocalDnsServer localDnsServer = (LocalDnsServer) localDnsServer$resolve$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    return obj;
                } else if (i == 2) {
                    Message message2 = (Message) localDnsServer$resolve$1.L$2;
                    ByteBuffer byteBuffer3 = (ByteBuffer) localDnsServer$resolve$1.L$1;
                    LocalDnsServer localDnsServer2 = (LocalDnsServer) localDnsServer$resolve$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                Intrinsics.checkExpressionValueIsNotNull(obj, "supervisorScope {\n      …)\n            }\n        }");
                return obj;
            }
        }
        localDnsServer$resolve$1 = new LocalDnsServer$resolve$1(this, continuation);
        Object obj3 = localDnsServer$resolve$1.result;
        Object obj22 = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = localDnsServer$resolve$1.label;
        if (i != 0) {
        }
        Intrinsics.checkExpressionValueIsNotNull(obj3, "supervisorScope {\n      …)\n            }\n        }");
        return obj3;
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x003b  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0021  */
    public final Object start(SocketAddress socketAddress, Continuation<? super SelectionKey> continuation) {
        LocalDnsServer$start$1 localDnsServer$start$1;
        int i;
        if (continuation instanceof LocalDnsServer$start$1) {
            localDnsServer$start$1 = (LocalDnsServer$start$1) continuation;
            int i2 = localDnsServer$start$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                localDnsServer$start$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj = localDnsServer$start$1.result;
                CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = localDnsServer$start$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    DatagramChannel open = DatagramChannel.open();
                    open.configureBlocking(false);
                    try {
                        open.socket().bind(socketAddress);
                        ChannelMonitor channelMonitor = this.monitor;
                        Intrinsics.checkExpressionValueIsNotNull(open, "this");
                        LocalDnsServer$start$$inlined$run$lambda$1 localDnsServer$start$$inlined$run$lambda$1 = new LocalDnsServer$start$$inlined$run$lambda$1(open, this, socketAddress, localDnsServer$start$1);
                        localDnsServer$start$1.L$0 = this;
                        localDnsServer$start$1.L$1 = socketAddress;
                        localDnsServer$start$1.L$2 = open;
                        localDnsServer$start$1.label = 1;
                        obj = channelMonitor.register(open, 1, localDnsServer$start$$inlined$run$lambda$1, localDnsServer$start$1);
                        if (obj == coroutineSingletons) {
                            return coroutineSingletons;
                        }
                    } catch (BindException e) {
                        throw new BaseService$ExpectedExceptionWrapper(e);
                    }
                } else if (i == 1) {
                    DatagramChannel datagramChannel = (DatagramChannel) localDnsServer$start$1.L$2;
                    SocketAddress socketAddress2 = (SocketAddress) localDnsServer$start$1.L$1;
                    LocalDnsServer localDnsServer = (LocalDnsServer) localDnsServer$start$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                return (SelectionKey) obj;
            }
        }
        localDnsServer$start$1 = new LocalDnsServer$start$1(this, continuation);
        Object obj2 = localDnsServer$start$1.result;
        CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = localDnsServer$start$1.label;
        if (i != 0) {
        }
        return (SelectionKey) obj2;
    }
}
