package com.github.shadowsocks.preference;

import android.content.ComponentName;
import android.content.pm.PackageManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.github.shadowsocks.BootReceiver;
import com.github.shadowsocks.Core;
import com.github.shadowsocks.database.PrivateDatabase;
import com.github.shadowsocks.database.PublicDatabase;
import com.github.shadowsocks.net.TcpFastOpen;
import com.github.shadowsocks.utils.UtilsKt;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.PropertyReference1Impl;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KProperty;

/* compiled from: DataStore.kt */
public final class DataStore implements OnPreferenceDataStoreChangeListener {
    public static final /* synthetic */ KProperty[] $$delegatedProperties;
    public static final DataStore INSTANCE;
    public static final RoomPreferenceDataStore privateStore;
    public static final RoomPreferenceDataStore publicStore;
    public static final Lazy userIndex$delegate = ViewGroupUtilsApi14.lazy(DataStore$userIndex$2.INSTANCE);

    static {
        PropertyReference1Impl propertyReference1Impl = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(DataStore.class), "userIndex", "getUserIndex()I");
        Objects.requireNonNull(Reflection.factory);
        $$delegatedProperties = new KProperty[]{propertyReference1Impl};
        DataStore dataStore = new DataStore();
        INSTANCE = dataStore;
        Objects.requireNonNull(PublicDatabase.Companion);
        Lazy lazy = PublicDatabase.instance$delegate;
        KProperty kProperty = PublicDatabase.Companion.$$delegatedProperties[0];
        RoomPreferenceDataStore roomPreferenceDataStore = new RoomPreferenceDataStore(((PublicDatabase) lazy.getValue()).keyValuePairDao());
        publicStore = roomPreferenceDataStore;
        Objects.requireNonNull(PrivateDatabase.Companion);
        Lazy lazy2 = PrivateDatabase.instance$delegate;
        KProperty kProperty2 = PrivateDatabase.Companion.$$delegatedProperties[0];
        privateStore = new RoomPreferenceDataStore(((PrivateDatabase) lazy2.getValue()).keyValuePairDao());
        Intrinsics.checkParameterIsNotNull(dataStore, "listener");
        roomPreferenceDataStore.listeners.add(dataStore);
    }

    public final boolean getDirectBootAware() {
        Objects.requireNonNull(Core.INSTANCE);
        Lazy lazy = Core.directBootSupported$delegate;
        KProperty kProperty = Core.$$delegatedProperties[5];
        return ((Boolean) lazy.getValue()).booleanValue() && Intrinsics.areEqual(publicStore.getBoolean("directBootAware"), Boolean.TRUE);
    }

    public final String getListenAddress() {
        return publicStore.getBoolean("shareOverLan", false) ? "0.0.0.0" : "127.0.0.1";
    }

    public final int getLocalPort(String str, int i) {
        RoomPreferenceDataStore roomPreferenceDataStore = publicStore;
        Integer num = roomPreferenceDataStore.getInt(str);
        if (num != null) {
            roomPreferenceDataStore.putString(str, String.valueOf(num.intValue()));
            return num.intValue();
        }
        String string = roomPreferenceDataStore.getString(str);
        Lazy lazy = userIndex$delegate;
        KProperty kProperty = $$delegatedProperties[0];
        return UtilsKt.parsePort(string, i + ((Number) lazy.getValue()).intValue(), 1025);
    }

    public final boolean getPersistAcrossReboot() {
        RoomPreferenceDataStore roomPreferenceDataStore = publicStore;
        Boolean bool = roomPreferenceDataStore.getBoolean("isAutoConnect");
        if (bool != null) {
            return bool.booleanValue();
        }
        BootReceiver.Companion companion = BootReceiver.Companion;
        Objects.requireNonNull(companion);
        PackageManager packageManager = Core.INSTANCE.getApp().getPackageManager();
        Objects.requireNonNull(companion);
        Lazy lazy = BootReceiver.componentName$delegate;
        KProperty kProperty = BootReceiver.Companion.$$delegatedProperties[0];
        int componentEnabledSetting = packageManager.getComponentEnabledSetting((ComponentName) lazy.getValue());
        boolean z = true;
        if (componentEnabledSetting != 1) {
            z = false;
        }
        roomPreferenceDataStore.putBoolean("isAutoConnect", z);
        return z;
    }

    public final int getPortProxy() {
        return getLocalPort("portProxy", 1080);
    }

    public final String getServiceMode() {
        String string = publicStore.getString("serviceMode");
        return string != null ? string : "vpn";
    }

    public final boolean getTcpFastOpen() {
        return TcpFastOpen.INSTANCE.getSendEnabled() && publicStore.getBoolean("tcp_fastopen", false);
    }

    public final void setEditingId(Long l) {
        RoomPreferenceDataStore roomPreferenceDataStore = privateStore;
        Objects.requireNonNull(roomPreferenceDataStore);
        Intrinsics.checkParameterIsNotNull("profileId", "key");
        if (l == null) {
            roomPreferenceDataStore.remove("profileId");
        } else {
            roomPreferenceDataStore.putLong("profileId", l.longValue());
        }
    }
}
