package com.github.shadowsocks.preference;

import com.github.shadowsocks.database.KeyValuePair;
import com.github.shadowsocks.utils.DirectBoot;
import java.nio.ByteBuffer;
import java.util.HashSet;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.Charsets;

/* compiled from: RoomPreferenceDataStore.kt */
public class RoomPreferenceDataStore {
    public final KeyValuePair.Dao kvPairDao;
    public final HashSet<OnPreferenceDataStoreChangeListener> listeners = new HashSet<>();

    public RoomPreferenceDataStore(KeyValuePair.Dao dao) {
        Intrinsics.checkParameterIsNotNull(dao, "kvPairDao");
        this.kvPairDao = dao;
    }

    public final void fireChangeListener(String str) {
        for (T t : this.listeners) {
            Objects.requireNonNull(t);
            Intrinsics.checkParameterIsNotNull(this, "store");
            Intrinsics.checkParameterIsNotNull(str, "key");
            if (str.hashCode() == -1005400924 && str.equals("profileId") && t.getDirectBootAware()) {
                DirectBoot.update$default(DirectBoot.INSTANCE, null, 1);
            }
        }
    }

    public final Boolean getBoolean(String str) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        KeyValuePair keyValuePair = this.kvPairDao.get(str);
        if (keyValuePair != null) {
            boolean z = true;
            if (keyValuePair.valueType == 1) {
                if (ByteBuffer.wrap(keyValuePair.value).get() == ((byte) 0)) {
                    z = false;
                }
                return Boolean.valueOf(z);
            }
        }
        return null;
    }

    public final Integer getInt(String str) {
        Long l;
        Intrinsics.checkParameterIsNotNull(str, "key");
        KeyValuePair keyValuePair = this.kvPairDao.get(str);
        if (keyValuePair == null || (l = keyValuePair.getLong()) == null) {
            return null;
        }
        return Integer.valueOf((int) l.longValue());
    }

    public final Long getLong(String str) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        KeyValuePair keyValuePair = this.kvPairDao.get(str);
        if (keyValuePair != null) {
            return keyValuePair.getLong();
        }
        return null;
    }

    public final String getString(String str) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        KeyValuePair keyValuePair = this.kvPairDao.get(str);
        if (keyValuePair == null || keyValuePair.valueType != 5) {
            return null;
        }
        return new String(keyValuePair.value, Charsets.UTF_8);
    }

    public void putBoolean(String str, boolean z) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        KeyValuePair.Dao dao = this.kvPairDao;
        KeyValuePair keyValuePair = new KeyValuePair(str);
        keyValuePair.valueType = 1;
        byte[] array = ByteBuffer.allocate(1).put(z ? (byte) 1 : 0).array();
        Intrinsics.checkExpressionValueIsNotNull(array, "ByteBuffer.allocate(1).p…else 0).toByte()).array()");
        keyValuePair.value = array;
        dao.put(keyValuePair);
        fireChangeListener(str);
    }

    public void putLong(String str, long j) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        KeyValuePair.Dao dao = this.kvPairDao;
        KeyValuePair keyValuePair = new KeyValuePair(str);
        keyValuePair.put(j);
        dao.put(keyValuePair);
        fireChangeListener(str);
    }

    public void putString(String str, String str2) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        if (str2 == null) {
            remove(str);
            return;
        }
        KeyValuePair.Dao dao = this.kvPairDao;
        KeyValuePair keyValuePair = new KeyValuePair(str);
        Intrinsics.checkParameterIsNotNull(str2, "value");
        keyValuePair.valueType = 5;
        byte[] bytes = str2.getBytes(Charsets.UTF_8);
        Intrinsics.checkExpressionValueIsNotNull(bytes, "(this as java.lang.String).getBytes(charset)");
        keyValuePair.value = bytes;
        dao.put(keyValuePair);
        fireChangeListener(str);
    }

    public final void remove(String str) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        this.kvPairDao.delete(str);
        fireChangeListener(str);
    }

    public boolean getBoolean(String str, boolean z) {
        Intrinsics.checkParameterIsNotNull(str, "key");
        Boolean bool = getBoolean(str);
        return bool != null ? bool.booleanValue() : z;
    }
}
