package com.github.shadowsocks.utils;

import android.annotation.TargetApi;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.database.sqlite.SQLiteCantOpenDatabaseException;
import android.util.Log;
import androidx.transition.ViewGroupUtilsApi14;
import com.github.shadowsocks.Core;
import com.github.shadowsocks.database.PrivateDatabase;
import com.github.shadowsocks.database.Profile;
import com.github.shadowsocks.database.ProfileDao_Impl;
import com.github.shadowsocks.preference.DataStore;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.sql.SQLException;
import java.util.Objects;
import kotlin.Pair;
import kotlin.jvm.internal.Intrinsics;
import kotlin.reflect.KProperty;

@TargetApi(24)
/* compiled from: DirectBoot.kt */
public final class DirectBoot extends BroadcastReceiver {
    public static final DirectBoot INSTANCE = new DirectBoot();
    public static final File file = new File(Core.INSTANCE.getDeviceStorage().getNoBackupFilesDir(), "directBootProfile");
    public static boolean registered;

    private DirectBoot() {
    }

    public static void update$default(DirectBoot directBoot, Profile profile, int i) {
        int i2 = i & 1;
        Profile profile2 = null;
        if (i2 != 0) {
            Objects.requireNonNull(DataStore.INSTANCE);
            Long l = DataStore.publicStore.getLong("profileId");
            try {
                profile2 = ((ProfileDao_Impl) PrivateDatabase.Companion.getProfileDao()).get(l != null ? l.longValue() : 0);
            } catch (SQLiteCantOpenDatabaseException e) {
                throw new IOException(e);
            } catch (SQLException e2) {
                KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
                Intrinsics.checkParameterIsNotNull(e2, "t");
                Log.e("", "", e2);
                e2.printStackTrace();
            }
        }
        directBoot.update(profile2);
    }

    public final void clean() {
        file.delete();
        Core core = Core.INSTANCE;
        new File(core.getDeviceStorage().getNoBackupFilesDir(), "shadowsocks.conf").delete();
        new File(core.getDeviceStorage().getNoBackupFilesDir(), "shadowsocks-udp.conf").delete();
    }

    public final void flushTrafficStats() {
        Pair<Profile, Profile> deviceProfile = getDeviceProfile();
        if (deviceProfile != null) {
            Profile component1 = deviceProfile.component1();
            Profile component2 = deviceProfile.component2();
            boolean z = false;
            if (component1.getDirty()) {
                Intrinsics.checkParameterIsNotNull(component1, "profile");
                ProfileDao_Impl profileDao_Impl = (ProfileDao_Impl) PrivateDatabase.Companion.getProfileDao();
                profileDao_Impl.__db.assertNotSuspendingTransaction();
                profileDao_Impl.__db.beginTransaction();
                try {
                    int handle = profileDao_Impl.__updateAdapterOfProfile.handle(component1) + 0;
                    profileDao_Impl.__db.setTransactionSuccessful();
                    if (!(handle == 1)) {
                        throw new IllegalStateException("Check failed.".toString());
                    }
                } finally {
                    profileDao_Impl.__db.endTransaction();
                }
            }
            if (component2 != null && component2.getDirty()) {
                Intrinsics.checkParameterIsNotNull(component2, "profile");
                ProfileDao_Impl profileDao_Impl2 = (ProfileDao_Impl) PrivateDatabase.Companion.getProfileDao();
                profileDao_Impl2.__db.assertNotSuspendingTransaction();
                profileDao_Impl2.__db.beginTransaction();
                try {
                    int handle2 = profileDao_Impl2.__updateAdapterOfProfile.handle(component2) + 0;
                    profileDao_Impl2.__db.setTransactionSuccessful();
                    if (handle2 == 1) {
                        z = true;
                    }
                    if (!z) {
                        throw new IllegalStateException("Check failed.".toString());
                    }
                } finally {
                    profileDao_Impl2.__db.endTransaction();
                }
            }
        }
        update$default(this, null, 1);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x001f, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0020, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r1, r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0023, code lost:
        throw r3;
     */
    public final Pair<Profile, Profile> getDeviceProfile() {
        try {
            ObjectInputStream objectInputStream = new ObjectInputStream(new FileInputStream(file));
            Object readObject = objectInputStream.readObject();
            if (!(readObject instanceof Pair)) {
                readObject = null;
            }
            Pair<Profile, Profile> pair = (Pair) readObject;
            ViewGroupUtilsApi14.closeFinally(objectInputStream, null);
            return pair;
        } catch (IOException unused) {
            return null;
        }
    }

    public void onReceive(Context context, Intent intent) {
        Intrinsics.checkParameterIsNotNull(context, "context");
        Intrinsics.checkParameterIsNotNull(intent, "intent");
        flushTrafficStats();
        Core.INSTANCE.getApp().unregisterReceiver(this);
        registered = false;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0056, code lost:
        r1 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0057, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r0, r6);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x005a, code lost:
        throw r1;
     */
    public final void update(Profile profile) {
        Profile profile2;
        if (profile == null) {
            clean();
            return;
        }
        ObjectOutputStream objectOutputStream = new ObjectOutputStream(new FileOutputStream(file));
        Intrinsics.checkParameterIsNotNull(profile, "profile");
        Long udpFallback = profile.getUdpFallback();
        if (udpFallback != null) {
            try {
                profile2 = ((ProfileDao_Impl) PrivateDatabase.Companion.getProfileDao()).get(udpFallback.longValue());
            } catch (SQLiteCantOpenDatabaseException e) {
                throw new IOException(e);
            } catch (SQLException e2) {
                KProperty[] kPropertyArr = UtilsKt.$$delegatedProperties;
                Intrinsics.checkParameterIsNotNull(e2, "t");
                Log.e("", "", e2);
                e2.printStackTrace();
            }
            objectOutputStream.writeObject(new Pair(profile, profile2));
            ViewGroupUtilsApi14.closeFinally(objectOutputStream, null);
        }
        profile2 = null;
        objectOutputStream.writeObject(new Pair(profile, profile2));
        ViewGroupUtilsApi14.closeFinally(objectOutputStream, null);
    }
}
