package com.github.shadowsocks.utils;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.IntentFilter;
import android.content.pm.PackageInfo;
import android.content.pm.Signature;
import android.content.pm.SigningInfo;
import android.os.Build;
import android.system.Os;
import android.system.OsConstants;
import android.util.Log;
import androidx.transition.ViewGroupUtilsApi14;
import java.io.FileDescriptor;
import java.lang.reflect.Method;
import java.net.HttpURLConnection;
import java.net.InetAddress;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.TypeCastException;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function2;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.PackageReference;
import kotlin.jvm.internal.PropertyReference0Impl;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KProperty;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.CancellableContinuationImpl;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.GlobalScope;

/* compiled from: Utils.kt */
public abstract class UtilsKt {
    public static final /* synthetic */ KProperty[] $$delegatedProperties = {new PropertyReference0Impl(new PackageReference(UtilsKt.class, "ss-core_release"), "parseNumericAddress", "getParseNumericAddress()Ljava/lang/reflect/Method;")};
    public static final Method getInt;
    public static final Lazy parseNumericAddress$delegate = ViewGroupUtilsApi14.lazy(UtilsKt$parseNumericAddress$2.INSTANCE);

    static {
        Objects.requireNonNull(Reflection.factory);
        Method declaredMethod = FileDescriptor.class.getDeclaredMethod("getInt$", new Class[0]);
        Intrinsics.checkExpressionValueIsNotNull(declaredMethod, "FileDescriptor::class.ja…DeclaredMethod(\"getInt$\")");
        getInt = declaredMethod;
    }

    public static final int getInt(FileDescriptor fileDescriptor) {
        Intrinsics.checkParameterIsNotNull(fileDescriptor, "$this$int");
        Object invoke = getInt.invoke(fileDescriptor, new Object[0]);
        if (invoke != null) {
            return ((Integer) invoke).intValue();
        }
        throw new TypeCastException("null cannot be cast to non-null type kotlin.Int");
    }

    public static final String getReadableMessage(Throwable th) {
        Intrinsics.checkParameterIsNotNull(th, "$this$readableMessage");
        String localizedMessage = th.getLocalizedMessage();
        if (localizedMessage != null) {
            return localizedMessage;
        }
        String name = th.getClass().getName();
        Intrinsics.checkExpressionValueIsNotNull(name, "javaClass.name");
        return name;
    }

    public static final Signature[] getSignaturesCompat(PackageInfo packageInfo) {
        Intrinsics.checkParameterIsNotNull(packageInfo, "$this$signaturesCompat");
        if (Build.VERSION.SDK_INT < 28) {
            return packageInfo.signatures;
        }
        SigningInfo signingInfo = packageInfo.signingInfo;
        Intrinsics.checkExpressionValueIsNotNull(signingInfo, "signingInfo");
        return signingInfo.getApkContentsSigners();
    }

    public static BroadcastReceiver listenForPackageChanges$default(Context context, boolean z, Function0 function0, int i) {
        if ((i & 1) != 0) {
            z = true;
        }
        Intrinsics.checkParameterIsNotNull(context, "$this$listenForPackageChanges");
        Intrinsics.checkParameterIsNotNull(function0, "callback");
        UtilsKt$listenForPackageChanges$1 utilsKt$listenForPackageChanges$1 = new UtilsKt$listenForPackageChanges$1(function0, z);
        IntentFilter intentFilter = new IntentFilter();
        intentFilter.addAction("android.intent.action.PACKAGE_ADDED");
        intentFilter.addAction("android.intent.action.PACKAGE_REMOVED");
        intentFilter.addDataScheme("package");
        context.registerReceiver(utilsKt$listenForPackageChanges$1, intentFilter);
        return utilsKt$listenForPackageChanges$1;
    }

    public static final InetAddress parseNumericAddress(String str) {
        InetAddress inet_pton = Os.inet_pton(OsConstants.AF_INET, str);
        if (inet_pton != null) {
            return inet_pton;
        }
        InetAddress inet_pton2 = Os.inet_pton(OsConstants.AF_INET6, str);
        if (inet_pton2 == null) {
            return null;
        }
        if (Build.VERSION.SDK_INT >= 29) {
            return inet_pton2;
        }
        Lazy lazy = parseNumericAddress$delegate;
        KProperty kProperty = $$delegatedProperties[0];
        Object invoke = ((Method) lazy.getValue()).invoke(null, str);
        if (invoke != null) {
            return (InetAddress) invoke;
        }
        throw new TypeCastException("null cannot be cast to non-null type java.net.InetAddress");
    }

    public static final int parsePort(String str, int i, int i2) {
        Integer intOrNull;
        int intValue = (str == null || (intOrNull = StringsKt__IndentKt.toIntOrNull(str)) == null) ? i : intOrNull.intValue();
        return (intValue < i2 || intValue > 65535) ? i : intValue;
    }

    public static final void printLog(Throwable th) {
        Intrinsics.checkParameterIsNotNull(th, "t");
        Log.e("", "", th);
        th.printStackTrace();
    }

    public static final <T> Object useCancellable(HttpURLConnection httpURLConnection, Function2<? super HttpURLConnection, ? super Continuation<? super T>, ? extends Object> function2, Continuation<? super T> continuation) {
        CancellableContinuationImpl cancellableContinuationImpl = new CancellableContinuationImpl(ViewGroupUtilsApi14.intercepted(continuation), 1);
        cancellableContinuationImpl.invokeOnCancellation(new UtilsKt$useCancellable$$inlined$suspendCancellableCoroutine$lambda$1(httpURLConnection, function2));
        ViewGroupUtilsApi14.launch$default(GlobalScope.INSTANCE, Dispatchers.IO, null, new UtilsKt$useCancellable$$inlined$suspendCancellableCoroutine$lambda$2(cancellableContinuationImpl, null, httpURLConnection, function2), 2, null);
        Object result = cancellableContinuationImpl.getResult();
        if (result == CoroutineSingletons.COROUTINE_SUSPENDED) {
            Intrinsics.checkNotNullParameter(continuation, "frame");
        }
        return result;
    }
}
