package com.google.android.material.circularreveal;

import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.view.View;
import androidx.transition.ViewGroupUtilsApi14;
import com.google.android.material.circularreveal.CircularRevealWidget;

public class CircularRevealHelper {
    public final Delegate delegate;
    public Drawable overlayDrawable;
    public CircularRevealWidget.RevealInfo revealInfo;
    public final Paint revealPaint = new Paint(7);
    public final Path revealPath = new Path();
    public final Paint scrimPaint;
    public final View view;

    public interface Delegate {
        void actualDraw(Canvas canvas);

        boolean actualIsOpaque();
    }

    public CircularRevealHelper(Delegate delegate2) {
        this.delegate = delegate2;
        View view2 = (View) delegate2;
        this.view = view2;
        view2.setWillNotDraw(false);
        Paint paint = new Paint(1);
        this.scrimPaint = paint;
        paint.setColor(0);
    }

    public void draw(Canvas canvas) {
        if (shouldDrawCircularReveal()) {
            this.delegate.actualDraw(canvas);
            if (shouldDrawScrim()) {
                canvas.drawRect(0.0f, 0.0f, (float) this.view.getWidth(), (float) this.view.getHeight(), this.scrimPaint);
            }
        } else {
            this.delegate.actualDraw(canvas);
            if (shouldDrawScrim()) {
                canvas.drawRect(0.0f, 0.0f, (float) this.view.getWidth(), (float) this.view.getHeight(), this.scrimPaint);
            }
        }
        Drawable drawable = this.overlayDrawable;
        if ((drawable == null || this.revealInfo == null) ? false : true) {
            Rect bounds = drawable.getBounds();
            float width = this.revealInfo.centerX - (((float) bounds.width()) / 2.0f);
            float height = this.revealInfo.centerY - (((float) bounds.height()) / 2.0f);
            canvas.translate(width, height);
            this.overlayDrawable.draw(canvas);
            canvas.translate(-width, -height);
        }
    }

    public int getCircularRevealScrimColor() {
        return this.scrimPaint.getColor();
    }

    public final float getDistanceToFurthestCorner(CircularRevealWidget.RevealInfo revealInfo2) {
        return ViewGroupUtilsApi14.distanceToFurthestCorner(revealInfo2.centerX, revealInfo2.centerY, 0.0f, 0.0f, (float) this.view.getWidth(), (float) this.view.getHeight());
    }

    public CircularRevealWidget.RevealInfo getRevealInfo() {
        CircularRevealWidget.RevealInfo revealInfo2 = this.revealInfo;
        if (revealInfo2 == null) {
            return null;
        }
        CircularRevealWidget.RevealInfo revealInfo3 = new CircularRevealWidget.RevealInfo(revealInfo2.centerX, revealInfo2.centerY, revealInfo2.radius);
        if (revealInfo3.radius == Float.MAX_VALUE) {
            revealInfo3.radius = getDistanceToFurthestCorner(revealInfo3);
        }
        return revealInfo3;
    }

    public boolean isOpaque() {
        return this.delegate.actualIsOpaque() && !shouldDrawCircularReveal();
    }

    public void setRevealInfo(CircularRevealWidget.RevealInfo revealInfo2) {
        if (revealInfo2 == null) {
            this.revealInfo = null;
        } else {
            CircularRevealWidget.RevealInfo revealInfo3 = this.revealInfo;
            if (revealInfo3 == null) {
                this.revealInfo = new CircularRevealWidget.RevealInfo(revealInfo2.centerX, revealInfo2.centerY, revealInfo2.radius);
            } else {
                float f = revealInfo2.centerX;
                float f2 = revealInfo2.centerY;
                float f3 = revealInfo2.radius;
                revealInfo3.centerX = f;
                revealInfo3.centerY = f2;
                revealInfo3.radius = f3;
            }
            if (revealInfo2.radius + 1.0E-4f >= getDistanceToFurthestCorner(revealInfo2)) {
                this.revealInfo.radius = Float.MAX_VALUE;
            }
        }
        this.view.invalidate();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:6:0x0012, code lost:
        if ((r0.radius == Float.MAX_VALUE) != false) goto L_0x0014;
     */
    public final boolean shouldDrawCircularReveal() {
        CircularRevealWidget.RevealInfo revealInfo2 = this.revealInfo;
        boolean z = false;
        if (revealInfo2 != null) {
        }
        z = true;
        return !z;
    }

    public final boolean shouldDrawScrim() {
        return Color.alpha(this.scrimPaint.getColor()) != 0;
    }
}
