package com.google.android.material.floatingactionbutton;

import android.animation.Animator;
import android.animation.AnimatorSet;
import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.PorterDuff;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.ViewTreeObserver;
import android.widget.ImageView;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.appcompat.widget.AppCompatDrawableManager;
import androidx.appcompat.widget.AppCompatImageHelper;
import androidx.collection.SimpleArrayMap;
import androidx.coordinatorlayout.widget.CoordinatorLayout;
import androidx.core.view.ViewCompat;
import androidx.transition.ViewGroupUtilsApi14;
import com.google.android.material.R$animator;
import com.google.android.material.R$attr;
import com.google.android.material.R$dimen;
import com.google.android.material.R$style;
import com.google.android.material.R$styleable;
import com.google.android.material.animation.MotionSpec;
import com.google.android.material.animation.TransformationCallback;
import com.google.android.material.appbar.AppBarLayout;
import com.google.android.material.bottomsheet.BottomSheetBehavior;
import com.google.android.material.expandable.ExpandableWidget;
import com.google.android.material.expandable.ExpandableWidgetHelper;
import com.google.android.material.floatingactionbutton.FloatingActionButtonImpl;
import com.google.android.material.internal.DescendantOffsetUtils;
import com.google.android.material.internal.ThemeEnforcement;
import com.google.android.material.internal.VisibilityAwareImageButton;
import com.google.android.material.shadow.ShadowViewDelegate;
import com.google.android.material.shape.MaterialShapeDrawable;
import com.google.android.material.shape.ShapeAppearanceModel;
import com.google.android.material.shape.Shapeable;
import com.google.android.material.stateful.ExtendableSavedState;
import com.google.android.material.theme.overlay.MaterialThemeOverlay;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public class FloatingActionButton extends VisibilityAwareImageButton implements ExpandableWidget, Shapeable, CoordinatorLayout.AttachedBehavior {
    public static final int DEF_STYLE_RES = R$style.Widget_Design_FloatingActionButton;
    public ColorStateList backgroundTint;
    public PorterDuff.Mode backgroundTintMode;
    public int borderWidth;
    public boolean compatPadding;
    public int customSize;
    public final ExpandableWidgetHelper expandableWidgetHelper;
    public final AppCompatImageHelper imageHelper;
    public PorterDuff.Mode imageMode;
    public int imagePadding;
    public ColorStateList imageTint;
    public FloatingActionButtonImpl impl;
    public int maxImageSize;
    public ColorStateList rippleColor;
    public final Rect shadowPadding;
    public int size;
    public final Rect touchArea;

    public static class BaseBehavior<T extends FloatingActionButton> extends CoordinatorLayout.Behavior<T> {
        public boolean autoHideEnabled;
        public OnVisibilityChangedListener internalAutoHideListener;
        public Rect tmpRect;

        public BaseBehavior() {
            this.autoHideEnabled = true;
        }

        @Override // androidx.coordinatorlayout.widget.CoordinatorLayout.Behavior
        public /* bridge */ /* synthetic */ boolean getInsetDodgeRect(CoordinatorLayout coordinatorLayout, View view, Rect rect) {
            return getInsetDodgeRect((FloatingActionButton) view, rect);
        }

        @Override // androidx.coordinatorlayout.widget.CoordinatorLayout.Behavior
        public void onAttachedToLayoutParams(CoordinatorLayout.LayoutParams layoutParams) {
            if (layoutParams.dodgeInsetEdges == 0) {
                layoutParams.dodgeInsetEdges = 80;
            }
        }

        @Override // androidx.coordinatorlayout.widget.CoordinatorLayout.Behavior
        public boolean onDependentViewChanged(CoordinatorLayout coordinatorLayout, View view, View view2) {
            FloatingActionButton floatingActionButton = (FloatingActionButton) view;
            if (view2 instanceof AppBarLayout) {
                updateFabVisibilityForAppBarLayout(coordinatorLayout, (AppBarLayout) view2, floatingActionButton);
            } else {
                ViewGroup.LayoutParams layoutParams = view2.getLayoutParams();
                if (layoutParams instanceof CoordinatorLayout.LayoutParams ? ((CoordinatorLayout.LayoutParams) layoutParams).mBehavior instanceof BottomSheetBehavior : false) {
                    updateFabVisibilityForBottomSheet(view2, floatingActionButton);
                }
            }
            return false;
        }

        @Override // androidx.coordinatorlayout.widget.CoordinatorLayout.Behavior
        public boolean onLayoutChild(CoordinatorLayout coordinatorLayout, View view, int i) {
            int i2;
            FloatingActionButton floatingActionButton = (FloatingActionButton) view;
            List<View> dependencies = coordinatorLayout.getDependencies(floatingActionButton);
            int size = dependencies.size();
            int i3 = 0;
            for (int i4 = 0; i4 < size; i4++) {
                View view2 = dependencies.get(i4);
                if (!(view2 instanceof AppBarLayout)) {
                    ViewGroup.LayoutParams layoutParams = view2.getLayoutParams();
                    if ((layoutParams instanceof CoordinatorLayout.LayoutParams ? ((CoordinatorLayout.LayoutParams) layoutParams).mBehavior instanceof BottomSheetBehavior : false) && updateFabVisibilityForBottomSheet(view2, floatingActionButton)) {
                        break;
                    }
                } else if (updateFabVisibilityForAppBarLayout(coordinatorLayout, (AppBarLayout) view2, floatingActionButton)) {
                    break;
                }
            }
            coordinatorLayout.onLayoutChild(floatingActionButton, i);
            Rect rect = floatingActionButton.shadowPadding;
            if (rect == null || rect.centerX() <= 0 || rect.centerY() <= 0) {
                return true;
            }
            CoordinatorLayout.LayoutParams layoutParams2 = (CoordinatorLayout.LayoutParams) floatingActionButton.getLayoutParams();
            if (floatingActionButton.getRight() >= coordinatorLayout.getWidth() - ((ViewGroup.MarginLayoutParams) layoutParams2).rightMargin) {
                i2 = rect.right;
            } else {
                i2 = floatingActionButton.getLeft() <= ((ViewGroup.MarginLayoutParams) layoutParams2).leftMargin ? -rect.left : 0;
            }
            if (floatingActionButton.getBottom() >= coordinatorLayout.getHeight() - ((ViewGroup.MarginLayoutParams) layoutParams2).bottomMargin) {
                i3 = rect.bottom;
            } else if (floatingActionButton.getTop() <= ((ViewGroup.MarginLayoutParams) layoutParams2).topMargin) {
                i3 = -rect.top;
            }
            if (i3 != 0) {
                ViewCompat.offsetTopAndBottom(floatingActionButton, i3);
            }
            if (i2 == 0) {
                return true;
            }
            ViewCompat.offsetLeftAndRight(floatingActionButton, i2);
            return true;
        }

        public void setInternalAutoHideListener(OnVisibilityChangedListener onVisibilityChangedListener) {
            this.internalAutoHideListener = onVisibilityChangedListener;
        }

        public final boolean shouldUpdateVisibility(View view, FloatingActionButton floatingActionButton) {
            CoordinatorLayout.LayoutParams layoutParams = (CoordinatorLayout.LayoutParams) floatingActionButton.getLayoutParams();
            if (this.autoHideEnabled && layoutParams.mAnchorId == view.getId() && floatingActionButton.getUserSetVisibility() == 0) {
                return true;
            }
            return false;
        }

        public final boolean updateFabVisibilityForAppBarLayout(CoordinatorLayout coordinatorLayout, AppBarLayout appBarLayout, FloatingActionButton floatingActionButton) {
            if (!shouldUpdateVisibility(appBarLayout, floatingActionButton)) {
                return false;
            }
            if (this.tmpRect == null) {
                this.tmpRect = new Rect();
            }
            Rect rect = this.tmpRect;
            DescendantOffsetUtils.getDescendantRect(coordinatorLayout, appBarLayout, rect);
            if (rect.bottom <= appBarLayout.getMinimumHeightForVisibleOverlappingContent()) {
                floatingActionButton.hide(this.internalAutoHideListener, false);
                return true;
            }
            floatingActionButton.show(this.internalAutoHideListener, false);
            return true;
        }

        public final boolean updateFabVisibilityForBottomSheet(View view, FloatingActionButton floatingActionButton) {
            if (!shouldUpdateVisibility(view, floatingActionButton)) {
                return false;
            }
            if (view.getTop() < (floatingActionButton.getHeight() / 2) + ((ViewGroup.MarginLayoutParams) ((CoordinatorLayout.LayoutParams) floatingActionButton.getLayoutParams())).topMargin) {
                floatingActionButton.hide(this.internalAutoHideListener, false);
                return true;
            }
            floatingActionButton.show(this.internalAutoHideListener, false);
            return true;
        }

        public boolean getInsetDodgeRect(FloatingActionButton floatingActionButton, Rect rect) {
            Rect rect2 = floatingActionButton.shadowPadding;
            rect.set(floatingActionButton.getLeft() + rect2.left, floatingActionButton.getTop() + rect2.top, floatingActionButton.getRight() - rect2.right, floatingActionButton.getBottom() - rect2.bottom);
            return true;
        }

        public BaseBehavior(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.FloatingActionButton_Behavior_Layout);
            this.autoHideEnabled = obtainStyledAttributes.getBoolean(R$styleable.FloatingActionButton_Behavior_Layout_behavior_autoHide, true);
            obtainStyledAttributes.recycle();
        }
    }

    public static class Behavior extends BaseBehavior<FloatingActionButton> {
        public Behavior() {
        }

        @Override // com.google.android.material.floatingactionbutton.FloatingActionButton.BaseBehavior
        public /* bridge */ /* synthetic */ void setInternalAutoHideListener(OnVisibilityChangedListener onVisibilityChangedListener) {
            super.setInternalAutoHideListener(onVisibilityChangedListener);
        }

        public Behavior(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }
    }

    public static abstract class OnVisibilityChangedListener {
        public void onHidden(FloatingActionButton floatingActionButton) {
        }

        public void onShown(FloatingActionButton floatingActionButton) {
        }
    }

    public class ShadowDelegateImpl implements ShadowViewDelegate {
        public ShadowDelegateImpl() {
        }
    }

    public class TransformationCallbackWrapper<T extends FloatingActionButton> implements FloatingActionButtonImpl.InternalTransformationCallback {
        public final TransformationCallback<T> listener;

        public TransformationCallbackWrapper(TransformationCallback<T> transformationCallback) {
            this.listener = transformationCallback;
        }

        public boolean equals(Object obj) {
            return (obj instanceof TransformationCallbackWrapper) && ((TransformationCallbackWrapper) obj).listener.equals(this.listener);
        }

        public int hashCode() {
            return this.listener.hashCode();
        }
    }

    public FloatingActionButton(Context context) {
        this(context, null);
    }

    private FloatingActionButtonImpl getImpl() {
        if (this.impl == null) {
            this.impl = new FloatingActionButtonImplLollipop(this, new ShadowDelegateImpl());
        }
        return this.impl;
    }

    public static int resolveAdjustedSize(int i, int i2) {
        int mode = View.MeasureSpec.getMode(i2);
        int size2 = View.MeasureSpec.getSize(i2);
        if (mode == Integer.MIN_VALUE) {
            return Math.min(i, size2);
        }
        if (mode == 0) {
            return i;
        }
        if (mode == 1073741824) {
            return size2;
        }
        throw new IllegalArgumentException();
    }

    public void addOnHideAnimationListener(Animator.AnimatorListener animatorListener) {
        FloatingActionButtonImpl impl2 = getImpl();
        if (impl2.hideListeners == null) {
            impl2.hideListeners = new ArrayList<>();
        }
        impl2.hideListeners.add(animatorListener);
    }

    public void addOnShowAnimationListener(Animator.AnimatorListener animatorListener) {
        FloatingActionButtonImpl impl2 = getImpl();
        if (impl2.showListeners == null) {
            impl2.showListeners = new ArrayList<>();
        }
        impl2.showListeners.add(animatorListener);
    }

    public void addTransformationCallback(TransformationCallback<? extends FloatingActionButton> transformationCallback) {
        FloatingActionButtonImpl impl2 = getImpl();
        TransformationCallbackWrapper transformationCallbackWrapper = new TransformationCallbackWrapper(transformationCallback);
        if (impl2.transformationCallbacks == null) {
            impl2.transformationCallbacks = new ArrayList<>();
        }
        impl2.transformationCallbacks.add(transformationCallbackWrapper);
    }

    public void drawableStateChanged() {
        super.drawableStateChanged();
        getImpl().onDrawableStateChanged(getDrawableState());
    }

    public ColorStateList getBackgroundTintList() {
        return this.backgroundTint;
    }

    public PorterDuff.Mode getBackgroundTintMode() {
        return this.backgroundTintMode;
    }

    @Override // androidx.coordinatorlayout.widget.CoordinatorLayout.AttachedBehavior
    public CoordinatorLayout.Behavior<FloatingActionButton> getBehavior() {
        return new Behavior();
    }

    public float getCompatElevation() {
        return getImpl().getElevation();
    }

    public float getCompatHoveredFocusedTranslationZ() {
        return getImpl().hoveredFocusedTranslationZ;
    }

    public float getCompatPressedTranslationZ() {
        return getImpl().pressedTranslationZ;
    }

    public Drawable getContentBackground() {
        return getImpl().contentBackground;
    }

    @Deprecated
    public boolean getContentRect(Rect rect) {
        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
        if (!isLaidOut()) {
            return false;
        }
        rect.set(0, 0, getWidth(), getHeight());
        offsetRectWithShadow(rect);
        return true;
    }

    public int getCustomSize() {
        return this.customSize;
    }

    public int getExpandedComponentIdHint() {
        return this.expandableWidgetHelper.expandedComponentIdHint;
    }

    public MotionSpec getHideMotionSpec() {
        return getImpl().hideMotionSpec;
    }

    @Deprecated
    public int getRippleColor() {
        ColorStateList colorStateList = this.rippleColor;
        if (colorStateList != null) {
            return colorStateList.getDefaultColor();
        }
        return 0;
    }

    public ColorStateList getRippleColorStateList() {
        return this.rippleColor;
    }

    public ShapeAppearanceModel getShapeAppearanceModel() {
        ShapeAppearanceModel shapeAppearanceModel = getImpl().shapeAppearance;
        Objects.requireNonNull(shapeAppearanceModel);
        return shapeAppearanceModel;
    }

    public MotionSpec getShowMotionSpec() {
        return getImpl().showMotionSpec;
    }

    public int getSize() {
        return this.size;
    }

    public int getSizeDimension() {
        return getSizeDimension(this.size);
    }

    public ColorStateList getSupportBackgroundTintList() {
        return getBackgroundTintList();
    }

    public PorterDuff.Mode getSupportBackgroundTintMode() {
        return getBackgroundTintMode();
    }

    public ColorStateList getSupportImageTintList() {
        return this.imageTint;
    }

    public PorterDuff.Mode getSupportImageTintMode() {
        return this.imageMode;
    }

    public boolean getUseCompatPadding() {
        return this.compatPadding;
    }

    public void hide(OnVisibilityChangedListener onVisibilityChangedListener) {
        hide(onVisibilityChangedListener, true);
    }

    public boolean isOrWillBeHidden() {
        return getImpl().isOrWillBeHidden();
    }

    public boolean isOrWillBeShown() {
        return getImpl().isOrWillBeShown();
    }

    public void jumpDrawablesToCurrentState() {
        super.jumpDrawablesToCurrentState();
        getImpl().jumpDrawableToCurrentState();
    }

    public final void offsetRectWithShadow(Rect rect) {
        int i = rect.left;
        Rect rect2 = this.shadowPadding;
        rect.left = i + rect2.left;
        rect.top += rect2.top;
        rect.right -= rect2.right;
        rect.bottom -= rect2.bottom;
    }

    public final void onApplySupportImageTint() {
        Drawable drawable = getDrawable();
        if (drawable != null) {
            ColorStateList colorStateList = this.imageTint;
            if (colorStateList == null) {
                AppCompatDelegateImpl.Api17Impl.clearColorFilter(drawable);
                return;
            }
            int colorForState = colorStateList.getColorForState(getDrawableState(), 0);
            PorterDuff.Mode mode = this.imageMode;
            if (mode == null) {
                mode = PorterDuff.Mode.SRC_IN;
            }
            drawable.mutate().setColorFilter(AppCompatDrawableManager.getPorterDuffColorFilter(colorForState, mode));
        }
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        FloatingActionButtonImpl impl2 = getImpl();
        MaterialShapeDrawable materialShapeDrawable = impl2.shapeDrawable;
        if (materialShapeDrawable != null) {
            ViewGroupUtilsApi14.setParentAbsoluteElevation(impl2.view, materialShapeDrawable);
        }
        if (!(impl2 instanceof FloatingActionButtonImplLollipop)) {
            ViewTreeObserver viewTreeObserver = impl2.view.getViewTreeObserver();
            if (impl2.preDrawListener == null) {
                impl2.preDrawListener = 
                /*  JADX ERROR: Method code generation error
                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0025: IPUT  
                      (wrap: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$5 : 0x0022: CONSTRUCTOR  (r2v1 com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$5) = (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl) call: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.5.<init>(com.google.android.material.floatingactionbutton.FloatingActionButtonImpl):void type: CONSTRUCTOR)
                      (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl)
                     com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.preDrawListener android.view.ViewTreeObserver$OnPreDrawListener in method: com.google.android.material.floatingactionbutton.FloatingActionButton.onAttachedToWindow():void, file: classes.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                    Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0022: CONSTRUCTOR  (r2v1 com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$5) = (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl) call: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.5.<init>(com.google.android.material.floatingactionbutton.FloatingActionButtonImpl):void type: CONSTRUCTOR in method: com.google.android.material.floatingactionbutton.FloatingActionButton.onAttachedToWindow():void, file: classes.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                    	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:428)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                    	... 26 more
                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, state: GENERATED_AND_UNLOADED
                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                    	... 30 more
                    */
                /*
                    this = this;
                    super.onAttachedToWindow()
                    com.google.android.material.floatingactionbutton.FloatingActionButtonImpl r0 = r3.getImpl()
                    com.google.android.material.shape.MaterialShapeDrawable r1 = r0.shapeDrawable
                    if (r1 == 0) goto L_0x0010
                    com.google.android.material.floatingactionbutton.FloatingActionButton r2 = r0.view
                    androidx.transition.ViewGroupUtilsApi14.setParentAbsoluteElevation(r2, r1)
                L_0x0010:
                    boolean r1 = r0 instanceof com.google.android.material.floatingactionbutton.FloatingActionButtonImplLollipop
                    r1 = r1 ^ 1
                    if (r1 == 0) goto L_0x002c
                    com.google.android.material.floatingactionbutton.FloatingActionButton r1 = r0.view
                    android.view.ViewTreeObserver r1 = r1.getViewTreeObserver()
                    android.view.ViewTreeObserver$OnPreDrawListener r2 = r0.preDrawListener
                    if (r2 != 0) goto L_0x0027
                    com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$5 r2 = new com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$5
                    r2.<init>()
                    r0.preDrawListener = r2
                L_0x0027:
                    android.view.ViewTreeObserver$OnPreDrawListener r0 = r0.preDrawListener
                    r1.addOnPreDrawListener(r0)
                L_0x002c:
                    return
                */
                throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.floatingactionbutton.FloatingActionButton.onAttachedToWindow():void");
            }

            public void onDetachedFromWindow() {
                super.onDetachedFromWindow();
                FloatingActionButtonImpl impl2 = getImpl();
                ViewTreeObserver viewTreeObserver = impl2.view.getViewTreeObserver();
                ViewTreeObserver.OnPreDrawListener onPreDrawListener = impl2.preDrawListener;
                if (onPreDrawListener != null) {
                    viewTreeObserver.removeOnPreDrawListener(onPreDrawListener);
                    impl2.preDrawListener = null;
                }
            }

            public void onMeasure(int i, int i2) {
                int sizeDimension = getSizeDimension();
                this.imagePadding = (sizeDimension - this.maxImageSize) / 2;
                getImpl().updatePadding();
                int min = Math.min(resolveAdjustedSize(sizeDimension, i), resolveAdjustedSize(sizeDimension, i2));
                Rect rect = this.shadowPadding;
                setMeasuredDimension(rect.left + min + rect.right, min + rect.top + rect.bottom);
            }

            public void onRestoreInstanceState(Parcelable parcelable) {
                if (!(parcelable instanceof ExtendableSavedState)) {
                    super.onRestoreInstanceState(parcelable);
                    return;
                }
                ExtendableSavedState extendableSavedState = (ExtendableSavedState) parcelable;
                super.onRestoreInstanceState(extendableSavedState.mSuperState);
                ExpandableWidgetHelper expandableWidgetHelper2 = this.expandableWidgetHelper;
                Bundle orDefault = extendableSavedState.extendableStates.getOrDefault("expandableWidgetHelper", null);
                Objects.requireNonNull(orDefault);
                Bundle bundle = orDefault;
                Objects.requireNonNull(expandableWidgetHelper2);
                expandableWidgetHelper2.expanded = bundle.getBoolean("expanded", false);
                expandableWidgetHelper2.expandedComponentIdHint = bundle.getInt("expandedComponentIdHint", 0);
                if (expandableWidgetHelper2.expanded) {
                    ViewParent parent = expandableWidgetHelper2.widget.getParent();
                    if (parent instanceof CoordinatorLayout) {
                        ((CoordinatorLayout) parent).dispatchDependentViewsChanged(expandableWidgetHelper2.widget);
                    }
                }
            }

            public Parcelable onSaveInstanceState() {
                Parcelable onSaveInstanceState = super.onSaveInstanceState();
                if (onSaveInstanceState == null) {
                    onSaveInstanceState = new Bundle();
                }
                ExtendableSavedState extendableSavedState = new ExtendableSavedState(onSaveInstanceState);
                SimpleArrayMap<String, Bundle> simpleArrayMap = extendableSavedState.extendableStates;
                ExpandableWidgetHelper expandableWidgetHelper2 = this.expandableWidgetHelper;
                Objects.requireNonNull(expandableWidgetHelper2);
                Bundle bundle = new Bundle();
                bundle.putBoolean("expanded", expandableWidgetHelper2.expanded);
                bundle.putInt("expandedComponentIdHint", expandableWidgetHelper2.expandedComponentIdHint);
                simpleArrayMap.put("expandableWidgetHelper", bundle);
                return extendableSavedState;
            }

            public boolean onTouchEvent(MotionEvent motionEvent) {
                if (motionEvent.getAction() != 0 || !getContentRect(this.touchArea) || this.touchArea.contains((int) motionEvent.getX(), (int) motionEvent.getY())) {
                    return super.onTouchEvent(motionEvent);
                }
                return false;
            }

            public void setBackgroundColor(int i) {
                Log.i("FloatingActionButton", "Setting a custom background is not supported.");
            }

            public void setBackgroundDrawable(Drawable drawable) {
                Log.i("FloatingActionButton", "Setting a custom background is not supported.");
            }

            public void setBackgroundResource(int i) {
                Log.i("FloatingActionButton", "Setting a custom background is not supported.");
            }

            public void setBackgroundTintList(ColorStateList colorStateList) {
                if (this.backgroundTint != colorStateList) {
                    this.backgroundTint = colorStateList;
                    FloatingActionButtonImpl impl2 = getImpl();
                    MaterialShapeDrawable materialShapeDrawable = impl2.shapeDrawable;
                    if (materialShapeDrawable != null) {
                        materialShapeDrawable.setTintList(colorStateList);
                    }
                    BorderDrawable borderDrawable = impl2.borderDrawable;
                    if (borderDrawable != null) {
                        borderDrawable.setBorderTint(colorStateList);
                    }
                }
            }

            public void setBackgroundTintMode(PorterDuff.Mode mode) {
                if (this.backgroundTintMode != mode) {
                    this.backgroundTintMode = mode;
                    MaterialShapeDrawable materialShapeDrawable = getImpl().shapeDrawable;
                    if (materialShapeDrawable != null) {
                        materialShapeDrawable.setTintMode(mode);
                    }
                }
            }

            public void setCompatElevation(float f) {
                FloatingActionButtonImpl impl2 = getImpl();
                if (impl2.elevation != f) {
                    impl2.elevation = f;
                    impl2.onElevationsChanged(f, impl2.hoveredFocusedTranslationZ, impl2.pressedTranslationZ);
                }
            }

            public void setCompatElevationResource(int i) {
                setCompatElevation(getResources().getDimension(i));
            }

            public void setCompatHoveredFocusedTranslationZ(float f) {
                FloatingActionButtonImpl impl2 = getImpl();
                if (impl2.hoveredFocusedTranslationZ != f) {
                    impl2.hoveredFocusedTranslationZ = f;
                    impl2.onElevationsChanged(impl2.elevation, f, impl2.pressedTranslationZ);
                }
            }

            public void setCompatHoveredFocusedTranslationZResource(int i) {
                setCompatHoveredFocusedTranslationZ(getResources().getDimension(i));
            }

            public void setCompatPressedTranslationZ(float f) {
                FloatingActionButtonImpl impl2 = getImpl();
                if (impl2.pressedTranslationZ != f) {
                    impl2.pressedTranslationZ = f;
                    impl2.onElevationsChanged(impl2.elevation, impl2.hoveredFocusedTranslationZ, f);
                }
            }

            public void setCompatPressedTranslationZResource(int i) {
                setCompatPressedTranslationZ(getResources().getDimension(i));
            }

            public void setCustomSize(int i) {
                if (i < 0) {
                    throw new IllegalArgumentException("Custom size must be non-negative");
                } else if (i != this.customSize) {
                    this.customSize = i;
                    requestLayout();
                }
            }

            public void setElevation(float f) {
                super.setElevation(f);
                getImpl().updateShapeElevation(f);
            }

            public void setEnsureMinTouchTargetSize(boolean z) {
                if (z != getImpl().ensureMinTouchTargetSize) {
                    getImpl().ensureMinTouchTargetSize = z;
                    requestLayout();
                }
            }

            public void setExpandedComponentIdHint(int i) {
                this.expandableWidgetHelper.expandedComponentIdHint = i;
            }

            public void setHideMotionSpec(MotionSpec motionSpec) {
                getImpl().hideMotionSpec = motionSpec;
            }

            public void setHideMotionSpecResource(int i) {
                setHideMotionSpec(MotionSpec.createFromResource(getContext(), i));
            }

            public void setImageDrawable(Drawable drawable) {
                if (getDrawable() != drawable) {
                    super.setImageDrawable(drawable);
                    FloatingActionButtonImpl impl2 = getImpl();
                    impl2.setImageMatrixScale(impl2.imageMatrixScale);
                    if (this.imageTint != null) {
                        onApplySupportImageTint();
                    }
                }
            }

            public void setImageResource(int i) {
                this.imageHelper.setImageResource(i);
                onApplySupportImageTint();
            }

            public void setRippleColor(int i) {
                setRippleColor(ColorStateList.valueOf(i));
            }

            public void setScaleX(float f) {
                super.setScaleX(f);
                getImpl().onScaleChanged();
            }

            public void setScaleY(float f) {
                super.setScaleY(f);
                getImpl().onScaleChanged();
            }

            public void setShadowPaddingEnabled(boolean z) {
                FloatingActionButtonImpl impl2 = getImpl();
                impl2.shadowPaddingEnabled = z;
                impl2.updatePadding();
            }

            @Override // com.google.android.material.shape.Shapeable
            public void setShapeAppearanceModel(ShapeAppearanceModel shapeAppearanceModel) {
                getImpl().setShapeAppearance(shapeAppearanceModel);
            }

            public void setShowMotionSpec(MotionSpec motionSpec) {
                getImpl().showMotionSpec = motionSpec;
            }

            public void setShowMotionSpecResource(int i) {
                setShowMotionSpec(MotionSpec.createFromResource(getContext(), i));
            }

            public void setSize(int i) {
                this.customSize = 0;
                if (i != this.size) {
                    this.size = i;
                    requestLayout();
                }
            }

            public void setSupportBackgroundTintList(ColorStateList colorStateList) {
                setBackgroundTintList(colorStateList);
            }

            public void setSupportBackgroundTintMode(PorterDuff.Mode mode) {
                setBackgroundTintMode(mode);
            }

            public void setSupportImageTintList(ColorStateList colorStateList) {
                if (this.imageTint != colorStateList) {
                    this.imageTint = colorStateList;
                    onApplySupportImageTint();
                }
            }

            public void setSupportImageTintMode(PorterDuff.Mode mode) {
                if (this.imageMode != mode) {
                    this.imageMode = mode;
                    onApplySupportImageTint();
                }
            }

            public void setTranslationX(float f) {
                super.setTranslationX(f);
                getImpl().onTranslationChanged();
            }

            public void setTranslationY(float f) {
                super.setTranslationY(f);
                getImpl().onTranslationChanged();
            }

            public void setTranslationZ(float f) {
                super.setTranslationZ(f);
                getImpl().onTranslationChanged();
            }

            public void setUseCompatPadding(boolean z) {
                if (this.compatPadding != z) {
                    this.compatPadding = z;
                    getImpl().onCompatShadowChanged();
                }
            }

            @Override // com.google.android.material.internal.VisibilityAwareImageButton
            public void setVisibility(int i) {
                super.setVisibility(i);
            }

            public void show(OnVisibilityChangedListener onVisibilityChangedListener) {
                show(onVisibilityChangedListener, true);
            }

            public FloatingActionButton(Context context, AttributeSet attributeSet) {
                this(context, attributeSet, R$attr.floatingActionButtonStyle);
            }

            public final int getSizeDimension(int i) {
                int i2 = this.customSize;
                if (i2 != 0) {
                    return i2;
                }
                Resources resources = getResources();
                if (i != -1) {
                    if (i != 1) {
                        return resources.getDimensionPixelSize(R$dimen.design_fab_size_normal);
                    }
                    return resources.getDimensionPixelSize(R$dimen.design_fab_size_mini);
                } else if (Math.max(resources.getConfiguration().screenWidthDp, resources.getConfiguration().screenHeightDp) < 470) {
                    return getSizeDimension(1);
                } else {
                    return getSizeDimension(0);
                }
            }

            public void hide(final OnVisibilityChangedListener onVisibilityChangedListener, boolean z) {
                AnonymousClass1 r4;
                FloatingActionButtonImpl impl2 = getImpl();
                if (onVisibilityChangedListener == null) {
                    r4 = null;
                } else {
                    r4 = new FloatingActionButtonImpl.InternalVisibilityChangedListener() {
                        /* class com.google.android.material.floatingactionbutton.FloatingActionButton.AnonymousClass1 */
                    };
                }
                if (!impl2.isOrWillBeHidden()) {
                    Animator animator = impl2.currentAnimator;
                    if (animator != null) {
                        animator.cancel();
                    }
                    if (impl2.shouldAnimateVisibilityChange()) {
                        MotionSpec motionSpec = impl2.hideMotionSpec;
                        if (motionSpec == null) {
                            if (impl2.defaultHideMotionSpec == null) {
                                impl2.defaultHideMotionSpec = MotionSpec.createFromResource(impl2.view.getContext(), R$animator.design_fab_hide_motion_spec);
                            }
                            motionSpec = impl2.defaultHideMotionSpec;
                            Objects.requireNonNull(motionSpec);
                        }
                        AnimatorSet createAnimator = impl2.createAnimator(motionSpec, 0.0f, 0.0f, 0.0f);
                        createAnimator.addListener(
                        /*  JADX ERROR: Method code generation error
                            jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0048: INVOKE  
                              (r1v8 'createAnimator' android.animation.AnimatorSet)
                              (wrap: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$1 : 0x0045: CONSTRUCTOR  (r2v1 com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$1) = 
                              (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl)
                              (r5v0 'z' boolean)
                              (r4v1 'r4' com.google.android.material.floatingactionbutton.FloatingActionButton$1)
                             call: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.1.<init>(com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, boolean, com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$InternalVisibilityChangedListener):void type: CONSTRUCTOR)
                             type: VIRTUAL call: android.animation.AnimatorSet.addListener(android.animation.Animator$AnimatorListener):void in method: com.google.android.material.floatingactionbutton.FloatingActionButton.hide(com.google.android.material.floatingactionbutton.FloatingActionButton$OnVisibilityChangedListener, boolean):void, file: classes.dex
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                            	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                            	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                            	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                            	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                            	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                            	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                            	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                            	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                            	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                            	at java.util.ArrayList.forEach(ArrayList.java:1259)
                            	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                            	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                            Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0045: CONSTRUCTOR  (r2v1 com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$1) = 
                              (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl)
                              (r5v0 'z' boolean)
                              (r4v1 'r4' com.google.android.material.floatingactionbutton.FloatingActionButton$1)
                             call: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.1.<init>(com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, boolean, com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$InternalVisibilityChangedListener):void type: CONSTRUCTOR in method: com.google.android.material.floatingactionbutton.FloatingActionButton.hide(com.google.android.material.floatingactionbutton.FloatingActionButton$OnVisibilityChangedListener, boolean):void, file: classes.dex
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                            	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                            	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                            	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                            	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                            	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                            	... 28 more
                            Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, state: GENERATED_AND_UNLOADED
                            	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                            	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                            	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                            	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                            	... 34 more
                            */
                        /*
                        // Method dump skipped, instructions count: 124
                        */
                        throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.floatingactionbutton.FloatingActionButton.hide(com.google.android.material.floatingactionbutton.FloatingActionButton$OnVisibilityChangedListener, boolean):void");
                    }

                    public void setRippleColor(ColorStateList colorStateList) {
                        if (this.rippleColor != colorStateList) {
                            this.rippleColor = colorStateList;
                            getImpl().setRippleColor(this.rippleColor);
                        }
                    }

                    public void show(final OnVisibilityChangedListener onVisibilityChangedListener, boolean z) {
                        AnonymousClass1 r5;
                        FloatingActionButtonImpl impl2 = getImpl();
                        if (onVisibilityChangedListener == null) {
                            r5 = null;
                        } else {
                            r5 = new FloatingActionButtonImpl.InternalVisibilityChangedListener() {
                                /* class com.google.android.material.floatingactionbutton.FloatingActionButton.AnonymousClass1 */
                            };
                        }
                        if (!impl2.isOrWillBeShown()) {
                            Animator animator = impl2.currentAnimator;
                            if (animator != null) {
                                animator.cancel();
                            }
                            if (impl2.shouldAnimateVisibilityChange()) {
                                if (impl2.view.getVisibility() != 0) {
                                    impl2.view.setAlpha(0.0f);
                                    impl2.view.setScaleY(0.0f);
                                    impl2.view.setScaleX(0.0f);
                                    impl2.setImageMatrixScale(0.0f);
                                }
                                MotionSpec motionSpec = impl2.showMotionSpec;
                                if (motionSpec == null) {
                                    if (impl2.defaultShowMotionSpec == null) {
                                        impl2.defaultShowMotionSpec = MotionSpec.createFromResource(impl2.view.getContext(), R$animator.design_fab_show_motion_spec);
                                    }
                                    motionSpec = impl2.defaultShowMotionSpec;
                                    Objects.requireNonNull(motionSpec);
                                }
                                AnimatorSet createAnimator = impl2.createAnimator(motionSpec, 1.0f, 1.0f, 1.0f);
                                createAnimator.addListener(
                                /*  JADX ERROR: Method code generation error
                                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0065: INVOKE  
                                      (r1v8 'createAnimator' android.animation.AnimatorSet)
                                      (wrap: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$2 : 0x0062: CONSTRUCTOR  (r2v1 com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$2) = 
                                      (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl)
                                      (r6v0 'z' boolean)
                                      (r5v1 'r5' com.google.android.material.floatingactionbutton.FloatingActionButton$1)
                                     call: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.2.<init>(com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, boolean, com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$InternalVisibilityChangedListener):void type: CONSTRUCTOR)
                                     type: VIRTUAL call: android.animation.AnimatorSet.addListener(android.animation.Animator$AnimatorListener):void in method: com.google.android.material.floatingactionbutton.FloatingActionButton.show(com.google.android.material.floatingactionbutton.FloatingActionButton$OnVisibilityChangedListener, boolean):void, file: classes.dex
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                                    Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0062: CONSTRUCTOR  (r2v1 com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$2) = 
                                      (r0v0 'impl2' com.google.android.material.floatingactionbutton.FloatingActionButtonImpl)
                                      (r6v0 'z' boolean)
                                      (r5v1 'r5' com.google.android.material.floatingactionbutton.FloatingActionButton$1)
                                     call: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl.2.<init>(com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, boolean, com.google.android.material.floatingactionbutton.FloatingActionButtonImpl$InternalVisibilityChangedListener):void type: CONSTRUCTOR in method: com.google.android.material.floatingactionbutton.FloatingActionButton.show(com.google.android.material.floatingactionbutton.FloatingActionButton$OnVisibilityChangedListener, boolean):void, file: classes.dex
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                    	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                                    	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                                    	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                                    	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                                    	... 28 more
                                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: com.google.android.material.floatingactionbutton.FloatingActionButtonImpl, state: GENERATED_AND_UNLOADED
                                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                                    	... 34 more
                                    */
                                /*
                                // Method dump skipped, instructions count: 166
                                */
                                throw new UnsupportedOperationException("Method not decompiled: com.google.android.material.floatingactionbutton.FloatingActionButton.show(com.google.android.material.floatingactionbutton.FloatingActionButton$OnVisibilityChangedListener, boolean):void");
                            }

                            /* JADX WARNING: Illegal instructions before constructor call */
                            public FloatingActionButton(Context context, AttributeSet attributeSet, int i) {
                                super(MaterialThemeOverlay.wrap(context, attributeSet, i, r6), attributeSet, i);
                                int i2 = DEF_STYLE_RES;
                                this.shadowPadding = new Rect();
                                this.touchArea = new Rect();
                                Context context2 = getContext();
                                TypedArray obtainStyledAttributes = ThemeEnforcement.obtainStyledAttributes(context2, attributeSet, R$styleable.FloatingActionButton, i, i2, new int[0]);
                                this.backgroundTint = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, R$styleable.FloatingActionButton_backgroundTint);
                                this.backgroundTintMode = ViewGroupUtilsApi14.parseTintMode(obtainStyledAttributes.getInt(R$styleable.FloatingActionButton_backgroundTintMode, -1), null);
                                this.rippleColor = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, R$styleable.FloatingActionButton_rippleColor);
                                this.size = obtainStyledAttributes.getInt(R$styleable.FloatingActionButton_fabSize, -1);
                                this.customSize = obtainStyledAttributes.getDimensionPixelSize(R$styleable.FloatingActionButton_fabCustomSize, 0);
                                this.borderWidth = obtainStyledAttributes.getDimensionPixelSize(R$styleable.FloatingActionButton_borderWidth, 0);
                                float dimension = obtainStyledAttributes.getDimension(R$styleable.FloatingActionButton_elevation, 0.0f);
                                float dimension2 = obtainStyledAttributes.getDimension(R$styleable.FloatingActionButton_hoveredFocusedTranslationZ, 0.0f);
                                float dimension3 = obtainStyledAttributes.getDimension(R$styleable.FloatingActionButton_pressedTranslationZ, 0.0f);
                                this.compatPadding = obtainStyledAttributes.getBoolean(R$styleable.FloatingActionButton_useCompatPadding, false);
                                int dimensionPixelSize = getResources().getDimensionPixelSize(R$dimen.mtrl_fab_min_touch_target);
                                this.maxImageSize = obtainStyledAttributes.getDimensionPixelSize(R$styleable.FloatingActionButton_maxImageSize, 0);
                                MotionSpec createFromAttribute = MotionSpec.createFromAttribute(context2, obtainStyledAttributes, R$styleable.FloatingActionButton_showMotionSpec);
                                MotionSpec createFromAttribute2 = MotionSpec.createFromAttribute(context2, obtainStyledAttributes, R$styleable.FloatingActionButton_hideMotionSpec);
                                ShapeAppearanceModel build = ShapeAppearanceModel.builder(context2, attributeSet, i, i2, ShapeAppearanceModel.PILL).build();
                                boolean z = obtainStyledAttributes.getBoolean(R$styleable.FloatingActionButton_ensureMinTouchTargetSize, false);
                                setEnabled(obtainStyledAttributes.getBoolean(R$styleable.FloatingActionButton_android_enabled, true));
                                obtainStyledAttributes.recycle();
                                AppCompatImageHelper appCompatImageHelper = new AppCompatImageHelper(this);
                                this.imageHelper = appCompatImageHelper;
                                appCompatImageHelper.loadFromAttributes(attributeSet, i);
                                this.expandableWidgetHelper = new ExpandableWidgetHelper(this);
                                getImpl().setShapeAppearance(build);
                                getImpl().initializeBackgroundDrawable(this.backgroundTint, this.backgroundTintMode, this.rippleColor, this.borderWidth);
                                getImpl().minTouchTargetSize = dimensionPixelSize;
                                FloatingActionButtonImpl impl2 = getImpl();
                                if (impl2.elevation != dimension) {
                                    impl2.elevation = dimension;
                                    impl2.onElevationsChanged(dimension, impl2.hoveredFocusedTranslationZ, impl2.pressedTranslationZ);
                                }
                                FloatingActionButtonImpl impl3 = getImpl();
                                if (impl3.hoveredFocusedTranslationZ != dimension2) {
                                    impl3.hoveredFocusedTranslationZ = dimension2;
                                    impl3.onElevationsChanged(impl3.elevation, dimension2, impl3.pressedTranslationZ);
                                }
                                FloatingActionButtonImpl impl4 = getImpl();
                                if (impl4.pressedTranslationZ != dimension3) {
                                    impl4.pressedTranslationZ = dimension3;
                                    impl4.onElevationsChanged(impl4.elevation, impl4.hoveredFocusedTranslationZ, dimension3);
                                }
                                FloatingActionButtonImpl impl5 = getImpl();
                                int i3 = this.maxImageSize;
                                if (impl5.maxImageSize != i3) {
                                    impl5.maxImageSize = i3;
                                    impl5.setImageMatrixScale(impl5.imageMatrixScale);
                                }
                                getImpl().showMotionSpec = createFromAttribute;
                                getImpl().hideMotionSpec = createFromAttribute2;
                                getImpl().ensureMinTouchTargetSize = z;
                                setScaleType(ImageView.ScaleType.MATRIX);
                            }
                        }
