package com.google.android.material.shape;

import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Path;
import android.graphics.PointF;
import android.graphics.RectF;
import com.google.android.material.shadow.ShadowRenderer;
import com.google.android.material.shape.MaterialShapeDrawable;
import com.google.android.material.shape.ShapePath;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;

public class ShapeAppearancePathProvider {
    public final Path boundsPath = new Path();
    public final Path cornerPath = new Path();
    public final ShapePath[] cornerPaths = new ShapePath[4];
    public final Matrix[] cornerTransforms = new Matrix[4];
    public boolean edgeIntersectionCheckEnabled = true;
    public final Path edgePath = new Path();
    public final Matrix[] edgeTransforms = new Matrix[4];
    public final Path overlappedEdgePath = new Path();
    public final PointF pointF = new PointF();
    public final float[] scratch = new float[2];
    public final float[] scratch2 = new float[2];
    public final ShapePath shapePath = new ShapePath();

    public abstract class Lazy {
        public static final ShapeAppearancePathProvider INSTANCE = new ShapeAppearancePathProvider();
    }

    public ShapeAppearancePathProvider() {
        for (int i = 0; i < 4; i++) {
            this.cornerPaths[i] = new ShapePath();
            this.cornerTransforms[i] = new Matrix();
            this.edgeTransforms[i] = new Matrix();
        }
    }

    public void calculatePath(ShapeAppearanceModel shapeAppearanceModel, float f, RectF rectF, Path path) {
        calculatePath(shapeAppearanceModel, f, rectF, null, path);
    }

    public final boolean pathOverlapsCorner(Path path, int i) {
        this.cornerPath.reset();
        this.cornerPaths[i].applyToPath(this.cornerTransforms[i], this.cornerPath);
        RectF rectF = new RectF();
        path.computeBounds(rectF, true);
        this.cornerPath.computeBounds(rectF, true);
        path.op(this.cornerPath, Path.Op.INTERSECT);
        path.computeBounds(rectF, true);
        if (!rectF.isEmpty()) {
            return true;
        }
        if (rectF.width() <= 1.0f || rectF.height() <= 1.0f) {
            return false;
        }
        return true;
    }

    public void calculatePath(ShapeAppearanceModel shapeAppearanceModel, float f, RectF rectF, MaterialShapeDrawable.AnonymousClass1 r21, Path path) {
        int i;
        float f2;
        EdgeTreatment edgeTreatment;
        CornerSize cornerSize;
        CornerTreatment cornerTreatment;
        path.rewind();
        this.overlappedEdgePath.rewind();
        this.boundsPath.rewind();
        this.boundsPath.addRect(rectF, Path.Direction.CW);
        int i2 = 0;
        while (true) {
            if (i2 >= 4) {
                break;
            }
            if (i2 == 1) {
                cornerSize = shapeAppearanceModel.bottomRightCornerSize;
            } else if (i2 == 2) {
                cornerSize = shapeAppearanceModel.bottomLeftCornerSize;
            } else if (i2 != 3) {
                cornerSize = shapeAppearanceModel.topRightCornerSize;
            } else {
                cornerSize = shapeAppearanceModel.topLeftCornerSize;
            }
            if (i2 == 1) {
                cornerTreatment = shapeAppearanceModel.bottomRightCorner;
            } else if (i2 == 2) {
                cornerTreatment = shapeAppearanceModel.bottomLeftCorner;
            } else if (i2 != 3) {
                cornerTreatment = shapeAppearanceModel.topRightCorner;
            } else {
                cornerTreatment = shapeAppearanceModel.topLeftCorner;
            }
            ShapePath shapePath2 = this.cornerPaths[i2];
            Objects.requireNonNull(cornerTreatment);
            cornerTreatment.getCornerPath(shapePath2, 90.0f, f, cornerSize.getCornerSize(rectF));
            int i3 = i2 + 1;
            float f3 = (float) (i3 * 90);
            this.cornerTransforms[i2].reset();
            PointF pointF2 = this.pointF;
            if (i2 == 1) {
                pointF2.set(rectF.right, rectF.bottom);
            } else if (i2 == 2) {
                pointF2.set(rectF.left, rectF.bottom);
            } else if (i2 != 3) {
                pointF2.set(rectF.right, rectF.top);
            } else {
                pointF2.set(rectF.left, rectF.top);
            }
            Matrix matrix = this.cornerTransforms[i2];
            PointF pointF3 = this.pointF;
            matrix.setTranslate(pointF3.x, pointF3.y);
            this.cornerTransforms[i2].preRotate(f3);
            float[] fArr = this.scratch;
            ShapePath[] shapePathArr = this.cornerPaths;
            fArr[0] = shapePathArr[i2].endX;
            fArr[1] = shapePathArr[i2].endY;
            this.cornerTransforms[i2].mapPoints(fArr);
            this.edgeTransforms[i2].reset();
            Matrix matrix2 = this.edgeTransforms[i2];
            float[] fArr2 = this.scratch;
            matrix2.setTranslate(fArr2[0], fArr2[1]);
            this.edgeTransforms[i2].preRotate(f3);
            i2 = i3;
        }
        int i4 = 0;
        for (i = 4; i4 < i; i = 4) {
            float[] fArr3 = this.scratch;
            ShapePath[] shapePathArr2 = this.cornerPaths;
            fArr3[0] = shapePathArr2[i4].startX;
            fArr3[1] = shapePathArr2[i4].startY;
            this.cornerTransforms[i4].mapPoints(fArr3);
            if (i4 == 0) {
                float[] fArr4 = this.scratch;
                path.moveTo(fArr4[0], fArr4[1]);
            } else {
                float[] fArr5 = this.scratch;
                path.lineTo(fArr5[0], fArr5[1]);
            }
            this.cornerPaths[i4].applyToPath(this.cornerTransforms[i4], path);
            if (r21 != null) {
                ShapePath shapePath3 = this.cornerPaths[i4];
                Matrix matrix3 = this.cornerTransforms[i4];
                BitSet bitSet = MaterialShapeDrawable.this.containsIncompatibleShadowOp;
                Objects.requireNonNull(shapePath3);
                bitSet.set(i4, false);
                ShapePath.ShadowCompatOperation[] shadowCompatOperationArr = MaterialShapeDrawable.this.cornerShadowOperation;
                shapePath3.addConnectingShadowIfNecessary(shapePath3.endShadowAngle);
                shadowCompatOperationArr[i4] = new ShapePath.ShadowCompatOperation(shapePath3, new ArrayList(shapePath3.shadowCompatOperations), new Matrix(matrix3)) {
                    /* class com.google.android.material.shape.ShapePath.AnonymousClass1 */
                    public final /* synthetic */ List val$operations;
                    public final /* synthetic */ Matrix val$transformCopy;

                    {
                        this.val$operations = r2;
                        this.val$transformCopy = r3;
                    }

                    @Override // com.google.android.material.shape.ShapePath.ShadowCompatOperation
                    public void draw(Matrix matrix, ShadowRenderer shadowRenderer, int i, Canvas canvas) {
                        for (ShadowCompatOperation shadowCompatOperation : this.val$operations) {
                            shadowCompatOperation.draw(this.val$transformCopy, shadowRenderer, i, canvas);
                        }
                    }
                };
            }
            int i5 = i4 + 1;
            int i6 = i5 % 4;
            float[] fArr6 = this.scratch;
            ShapePath[] shapePathArr3 = this.cornerPaths;
            fArr6[0] = shapePathArr3[i4].endX;
            fArr6[1] = shapePathArr3[i4].endY;
            this.cornerTransforms[i4].mapPoints(fArr6);
            float[] fArr7 = this.scratch2;
            ShapePath[] shapePathArr4 = this.cornerPaths;
            fArr7[0] = shapePathArr4[i6].startX;
            fArr7[1] = shapePathArr4[i6].startY;
            this.cornerTransforms[i6].mapPoints(fArr7);
            float[] fArr8 = this.scratch;
            float f4 = fArr8[0];
            float[] fArr9 = this.scratch2;
            float max = Math.max(((float) Math.hypot((double) (f4 - fArr9[0]), (double) (fArr8[1] - fArr9[1]))) - 0.001f, 0.0f);
            float[] fArr10 = this.scratch;
            ShapePath[] shapePathArr5 = this.cornerPaths;
            fArr10[0] = shapePathArr5[i4].endX;
            fArr10[1] = shapePathArr5[i4].endY;
            this.cornerTransforms[i4].mapPoints(fArr10);
            if (i4 == 1 || i4 == 3) {
                f2 = Math.abs(rectF.centerX() - this.scratch[0]);
            } else {
                f2 = Math.abs(rectF.centerY() - this.scratch[1]);
            }
            this.shapePath.reset(0.0f, 0.0f);
            if (i4 == 1) {
                edgeTreatment = shapeAppearanceModel.bottomEdge;
            } else if (i4 == 2) {
                edgeTreatment = shapeAppearanceModel.leftEdge;
            } else if (i4 != 3) {
                edgeTreatment = shapeAppearanceModel.rightEdge;
            } else {
                edgeTreatment = shapeAppearanceModel.topEdge;
            }
            edgeTreatment.getEdgePath(max, f2, f, this.shapePath);
            this.edgePath.reset();
            this.shapePath.applyToPath(this.edgeTransforms[i4], this.edgePath);
            if (!this.edgeIntersectionCheckEnabled || (!edgeTreatment.forceIntersection() && !pathOverlapsCorner(this.edgePath, i4) && !pathOverlapsCorner(this.edgePath, i6))) {
                this.shapePath.applyToPath(this.edgeTransforms[i4], path);
            } else {
                Path path2 = this.edgePath;
                path2.op(path2, this.boundsPath, Path.Op.DIFFERENCE);
                float[] fArr11 = this.scratch;
                ShapePath shapePath4 = this.shapePath;
                fArr11[0] = shapePath4.startX;
                fArr11[1] = shapePath4.startY;
                this.edgeTransforms[i4].mapPoints(fArr11);
                Path path3 = this.overlappedEdgePath;
                float[] fArr12 = this.scratch;
                path3.moveTo(fArr12[0], fArr12[1]);
                this.shapePath.applyToPath(this.edgeTransforms[i4], this.overlappedEdgePath);
            }
            if (r21 != null) {
                ShapePath shapePath5 = this.shapePath;
                Matrix matrix4 = this.edgeTransforms[i4];
                Objects.requireNonNull(shapePath5);
                MaterialShapeDrawable.this.containsIncompatibleShadowOp.set(i4 + 4, false);
                ShapePath.ShadowCompatOperation[] shadowCompatOperationArr2 = MaterialShapeDrawable.this.edgeShadowOperation;
                shapePath5.addConnectingShadowIfNecessary(shapePath5.endShadowAngle);
                shadowCompatOperationArr2[i4] = new ShapePath.ShadowCompatOperation(shapePath5, new ArrayList(shapePath5.shadowCompatOperations), new Matrix(matrix4)) {
                    /* class com.google.android.material.shape.ShapePath.AnonymousClass1 */
                    public final /* synthetic */ List val$operations;
                    public final /* synthetic */ Matrix val$transformCopy;

                    {
                        this.val$operations = r2;
                        this.val$transformCopy = r3;
                    }

                    @Override // com.google.android.material.shape.ShapePath.ShadowCompatOperation
                    public void draw(Matrix matrix, ShadowRenderer shadowRenderer, int i, Canvas canvas) {
                        for (ShadowCompatOperation shadowCompatOperation : this.val$operations) {
                            shadowCompatOperation.draw(this.val$transformCopy, shadowRenderer, i, canvas);
                        }
                    }
                };
            }
            i4 = i5;
        }
        path.close();
        this.overlappedEdgePath.close();
        if (!this.overlappedEdgePath.isEmpty()) {
            path.op(this.overlappedEdgePath, Path.Op.UNION);
        }
    }
}
