package com.google.android.material.slider;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.Region;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.RippleDrawable;
import android.os.Build;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityManager;
import android.view.accessibility.AccessibilityNodeInfo;
import android.widget.SeekBar;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.appcompat.content.res.AppCompatResources;
import androidx.core.graphics.ColorUtils;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import androidx.customview.widget.ExploreByTouchHelper;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.android.material.R$attr;
import com.google.android.material.R$color;
import com.google.android.material.R$dimen;
import com.google.android.material.R$string;
import com.google.android.material.R$style;
import com.google.android.material.R$styleable;
import com.google.android.material.animation.AnimationUtils;
import com.google.android.material.internal.DescendantOffsetUtils;
import com.google.android.material.internal.ThemeEnforcement;
import com.google.android.material.internal.ViewOverlayApi18;
import com.google.android.material.internal.ViewOverlayImpl;
import com.google.android.material.shape.CornerTreatment;
import com.google.android.material.shape.MaterialShapeDrawable;
import com.google.android.material.shape.ShapeAppearanceModel;
import com.google.android.material.slider.BaseOnChangeListener;
import com.google.android.material.slider.BaseOnSliderTouchListener;
import com.google.android.material.slider.BaseSlider;
import com.google.android.material.theme.overlay.MaterialThemeOverlay;
import com.google.android.material.tooltip.TooltipDrawable;
import java.lang.reflect.InvocationTargetException;
import java.math.BigDecimal;
import java.math.MathContext;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public abstract class BaseSlider<S extends BaseSlider<S, L, T>, L extends BaseOnChangeListener<S>, T extends BaseOnSliderTouchListener<S>> extends View {
    public static final int DEF_STYLE_RES = R$style.Widget_MaterialComponents_Slider;
    public static final String TAG = BaseSlider.class.getSimpleName();
    public BaseSlider<S, L, T>.AccessibilityEventSender accessibilityEventSender;
    public final AccessibilityHelper accessibilityHelper;
    public final AccessibilityManager accessibilityManager;
    public int activeThumbIdx = -1;
    public final Paint activeTicksPaint;
    public final Paint activeTrackPaint;
    public final List<L> changeListeners = new ArrayList();
    public int defaultThumbRadius;
    public boolean dirtyConfig;
    public int focusedThumbIdx = -1;
    public LabelFormatter formatter;
    public ColorStateList haloColor;
    public final Paint haloPaint;
    public int haloRadius;
    public final Paint inactiveTicksPaint;
    public final Paint inactiveTrackPaint;
    public boolean isLongPress = false;
    public int labelBehavior;
    public final TooltipDrawableFactory labelMaker;
    public int labelPadding;
    public final List<TooltipDrawable> labels = new ArrayList();
    public boolean labelsAreAnimatedIn = false;
    public ValueAnimator labelsInAnimator;
    public ValueAnimator labelsOutAnimator;
    public MotionEvent lastEvent;
    public int minTrackSidePadding;
    public final int scaledTouchSlop;
    public int separationUnit;
    public float stepSize = 0.0f;
    public final MaterialShapeDrawable thumbDrawable;
    public boolean thumbIsPressed = false;
    public final Paint thumbPaint;
    public int thumbRadius;
    public ColorStateList tickColorActive;
    public ColorStateList tickColorInactive;
    public boolean tickVisible = true;
    public float[] ticksCoordinates;
    public float touchDownX;
    public final List<T> touchListeners = new ArrayList();
    public float touchPosition;
    public ColorStateList trackColorActive;
    public ColorStateList trackColorInactive;
    public int trackHeight;
    public int trackSidePadding;
    public int trackTop;
    public int trackWidth;
    public float valueFrom;
    public float valueTo;
    public ArrayList<Float> values = new ArrayList<>();
    public int widgetHeight;

    public class AccessibilityEventSender implements Runnable {
        public int virtualViewId = -1;

        public AccessibilityEventSender(AnonymousClass1 r2) {
        }

        public void run() {
            BaseSlider.this.accessibilityHelper.sendEventForVirtualView(this.virtualViewId, 4);
        }
    }

    public class AccessibilityHelper extends ExploreByTouchHelper {
        public final BaseSlider<?, ?, ?> slider;
        public Rect virtualViewBounds = new Rect();

        public AccessibilityHelper(BaseSlider<?, ?, ?> baseSlider) {
            super(baseSlider);
            this.slider = baseSlider;
        }

        @Override // androidx.customview.widget.ExploreByTouchHelper
        public int getVirtualViewAt(float f, float f2) {
            for (int i = 0; i < this.slider.getValues().size(); i++) {
                this.slider.updateBoundsForVirturalViewId(i, this.virtualViewBounds);
                if (this.virtualViewBounds.contains((int) f, (int) f2)) {
                    return i;
                }
            }
            return -1;
        }

        @Override // androidx.customview.widget.ExploreByTouchHelper
        public void getVisibleVirtualViews(List<Integer> list) {
            for (int i = 0; i < this.slider.getValues().size(); i++) {
                list.add(Integer.valueOf(i));
            }
        }

        @Override // androidx.customview.widget.ExploreByTouchHelper
        public boolean onPerformActionForVirtualView(int i, int i2, Bundle bundle) {
            if (!this.slider.isEnabled()) {
                return false;
            }
            if (i2 == 4096 || i2 == 8192) {
                float calculateStepIncrement = this.slider.calculateStepIncrement(20);
                if (i2 == 8192) {
                    calculateStepIncrement = -calculateStepIncrement;
                }
                if (this.slider.isRtl()) {
                    calculateStepIncrement = -calculateStepIncrement;
                }
                if (!this.slider.snapThumbToValue(i, AppCompatDelegateImpl.Api17Impl.clamp(this.slider.getValues().get(i).floatValue() + calculateStepIncrement, this.slider.getValueFrom(), this.slider.getValueTo()))) {
                    return false;
                }
                this.slider.updateHaloHotspot();
                this.slider.postInvalidate();
                invalidateVirtualView(i);
                return true;
            }
            if (i2 == 16908349 && bundle != null && bundle.containsKey("android.view.accessibility.action.ARGUMENT_PROGRESS_VALUE")) {
                if (this.slider.snapThumbToValue(i, bundle.getFloat("android.view.accessibility.action.ARGUMENT_PROGRESS_VALUE"))) {
                    this.slider.updateHaloHotspot();
                    this.slider.postInvalidate();
                    invalidateVirtualView(i);
                    return true;
                }
            }
            return false;
        }

        @Override // androidx.customview.widget.ExploreByTouchHelper
        public void onPopulateNodeForVirtualView(int i, AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
            String str;
            accessibilityNodeInfoCompat.addAction(AccessibilityNodeInfoCompat.AccessibilityActionCompat.ACTION_SET_PROGRESS);
            List<Float> values = this.slider.getValues();
            float floatValue = values.get(i).floatValue();
            float valueFrom = this.slider.getValueFrom();
            float valueTo = this.slider.getValueTo();
            if (this.slider.isEnabled()) {
                if (floatValue > valueFrom) {
                    accessibilityNodeInfoCompat.mInfo.addAction(8192);
                }
                if (floatValue < valueTo) {
                    accessibilityNodeInfoCompat.mInfo.addAction(4096);
                }
            }
            accessibilityNodeInfoCompat.mInfo.setRangeInfo(AccessibilityNodeInfo.RangeInfo.obtain(1, valueFrom, valueTo, floatValue));
            accessibilityNodeInfoCompat.mInfo.setClassName(SeekBar.class.getName());
            StringBuilder sb = new StringBuilder();
            if (this.slider.getContentDescription() != null) {
                sb.append(this.slider.getContentDescription());
                sb.append(",");
            }
            if (values.size() > 1) {
                if (i == this.slider.getValues().size() - 1) {
                    str = this.slider.getContext().getString(R$string.material_slider_range_end);
                } else {
                    str = i == 0 ? this.slider.getContext().getString(R$string.material_slider_range_start) : "";
                }
                sb.append(str);
                sb.append(this.slider.formatValue(floatValue));
            }
            accessibilityNodeInfoCompat.mInfo.setContentDescription(sb.toString());
            this.slider.updateBoundsForVirturalViewId(i, this.virtualViewBounds);
            accessibilityNodeInfoCompat.mInfo.setBoundsInParent(this.virtualViewBounds);
        }
    }

    public static class SliderState extends View.BaseSavedState {
        public static final Parcelable.Creator<SliderState> CREATOR = new Parcelable.Creator<SliderState>() {
            /* class com.google.android.material.slider.BaseSlider.SliderState.AnonymousClass1 */

            /* Return type fixed from 'java.lang.Object' to match base method */
            @Override // android.os.Parcelable.Creator
            public SliderState createFromParcel(Parcel parcel) {
                return new SliderState(parcel, null);
            }

            /* Return type fixed from 'java.lang.Object[]' to match base method */
            @Override // android.os.Parcelable.Creator
            public SliderState[] newArray(int i) {
                return new SliderState[i];
            }
        };
        public boolean hasFocus;
        public float stepSize;
        public float valueFrom;
        public float valueTo;
        public ArrayList<Float> values;

        public SliderState(Parcelable parcelable) {
            super(parcelable);
        }

        public void writeToParcel(Parcel parcel, int i) {
            super.writeToParcel(parcel, i);
            parcel.writeFloat(this.valueFrom);
            parcel.writeFloat(this.valueTo);
            parcel.writeList(this.values);
            parcel.writeFloat(this.stepSize);
            parcel.writeBooleanArray(new boolean[]{this.hasFocus});
        }

        public SliderState(Parcel parcel, AnonymousClass1 r3) {
            super(parcel);
            this.valueFrom = parcel.readFloat();
            this.valueTo = parcel.readFloat();
            ArrayList<Float> arrayList = new ArrayList<>();
            this.values = arrayList;
            parcel.readList(arrayList, Float.class.getClassLoader());
            this.stepSize = parcel.readFloat();
            this.hasFocus = parcel.createBooleanArray()[0];
        }
    }

    public interface TooltipDrawableFactory {
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public BaseSlider(Context context, final AttributeSet attributeSet, final int i) {
        super(MaterialThemeOverlay.wrap(context, attributeSet, i, r6), attributeSet, i);
        int i2;
        int i3;
        int i4 = DEF_STYLE_RES;
        MaterialShapeDrawable materialShapeDrawable = new MaterialShapeDrawable();
        this.thumbDrawable = materialShapeDrawable;
        this.separationUnit = 0;
        Context context2 = getContext();
        Paint paint = new Paint();
        this.inactiveTrackPaint = paint;
        paint.setStyle(Paint.Style.STROKE);
        paint.setStrokeCap(Paint.Cap.ROUND);
        Paint paint2 = new Paint();
        this.activeTrackPaint = paint2;
        paint2.setStyle(Paint.Style.STROKE);
        paint2.setStrokeCap(Paint.Cap.ROUND);
        Paint paint3 = new Paint(1);
        this.thumbPaint = paint3;
        paint3.setStyle(Paint.Style.FILL);
        paint3.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.CLEAR));
        Paint paint4 = new Paint(1);
        this.haloPaint = paint4;
        paint4.setStyle(Paint.Style.FILL);
        Paint paint5 = new Paint();
        this.inactiveTicksPaint = paint5;
        paint5.setStyle(Paint.Style.STROKE);
        paint5.setStrokeCap(Paint.Cap.ROUND);
        Paint paint6 = new Paint();
        this.activeTicksPaint = paint6;
        paint6.setStyle(Paint.Style.STROKE);
        paint6.setStrokeCap(Paint.Cap.ROUND);
        Resources resources = context2.getResources();
        this.widgetHeight = resources.getDimensionPixelSize(R$dimen.mtrl_slider_widget_height);
        int dimensionPixelOffset = resources.getDimensionPixelOffset(R$dimen.mtrl_slider_track_side_padding);
        this.minTrackSidePadding = dimensionPixelOffset;
        this.trackSidePadding = dimensionPixelOffset;
        this.defaultThumbRadius = resources.getDimensionPixelSize(R$dimen.mtrl_slider_thumb_radius);
        this.trackTop = resources.getDimensionPixelOffset(R$dimen.mtrl_slider_track_top);
        this.labelPadding = resources.getDimensionPixelSize(R$dimen.mtrl_slider_label_padding);
        this.labelMaker = new TooltipDrawableFactory() {
            /* class com.google.android.material.slider.BaseSlider.AnonymousClass1 */
        };
        int[] iArr = R$styleable.Slider;
        ThemeEnforcement.checkCompatibleTheme(context2, attributeSet, i, i4);
        ThemeEnforcement.checkTextAppearance(context2, attributeSet, iArr, i, i4, new int[0]);
        TypedArray obtainStyledAttributes = context2.obtainStyledAttributes(attributeSet, iArr, i, i4);
        this.valueFrom = obtainStyledAttributes.getFloat(R$styleable.Slider_android_valueFrom, 0.0f);
        this.valueTo = obtainStyledAttributes.getFloat(R$styleable.Slider_android_valueTo, 1.0f);
        setValues(Float.valueOf(this.valueFrom));
        this.stepSize = obtainStyledAttributes.getFloat(R$styleable.Slider_android_stepSize, 0.0f);
        int i5 = R$styleable.Slider_trackColor;
        boolean hasValue = obtainStyledAttributes.hasValue(i5);
        if (hasValue) {
            i2 = i5;
        } else {
            i2 = R$styleable.Slider_trackColorInactive;
        }
        i5 = !hasValue ? R$styleable.Slider_trackColorActive : i5;
        ColorStateList colorStateList = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, i2);
        setTrackInactiveTintList(colorStateList == null ? AppCompatResources.getColorStateList(context2, R$color.material_slider_inactive_track_color) : colorStateList);
        ColorStateList colorStateList2 = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, i5);
        setTrackActiveTintList(colorStateList2 == null ? AppCompatResources.getColorStateList(context2, R$color.material_slider_active_track_color) : colorStateList2);
        materialShapeDrawable.setFillColor(ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, R$styleable.Slider_thumbColor));
        int i6 = R$styleable.Slider_thumbStrokeColor;
        if (obtainStyledAttributes.hasValue(i6)) {
            setThumbStrokeColor(ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, i6));
        }
        setThumbStrokeWidth(obtainStyledAttributes.getDimension(R$styleable.Slider_thumbStrokeWidth, 0.0f));
        ColorStateList colorStateList3 = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, R$styleable.Slider_haloColor);
        setHaloTintList(colorStateList3 == null ? AppCompatResources.getColorStateList(context2, R$color.material_slider_halo_color) : colorStateList3);
        this.tickVisible = obtainStyledAttributes.getBoolean(R$styleable.Slider_tickVisible, true);
        int i7 = R$styleable.Slider_tickColor;
        boolean hasValue2 = obtainStyledAttributes.hasValue(i7);
        if (hasValue2) {
            i3 = i7;
        } else {
            i3 = R$styleable.Slider_tickColorInactive;
        }
        i7 = !hasValue2 ? R$styleable.Slider_tickColorActive : i7;
        ColorStateList colorStateList4 = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, i3);
        setTickInactiveTintList(colorStateList4 == null ? AppCompatResources.getColorStateList(context2, R$color.material_slider_inactive_tick_marks_color) : colorStateList4);
        ColorStateList colorStateList5 = ViewGroupUtilsApi14.getColorStateList(context2, obtainStyledAttributes, i7);
        setTickActiveTintList(colorStateList5 == null ? AppCompatResources.getColorStateList(context2, R$color.material_slider_active_tick_marks_color) : colorStateList5);
        setThumbRadius(obtainStyledAttributes.getDimensionPixelSize(R$styleable.Slider_thumbRadius, 0));
        setHaloRadius(obtainStyledAttributes.getDimensionPixelSize(R$styleable.Slider_haloRadius, 0));
        setThumbElevation(obtainStyledAttributes.getDimension(R$styleable.Slider_thumbElevation, 0.0f));
        setTrackHeight(obtainStyledAttributes.getDimensionPixelSize(R$styleable.Slider_trackHeight, 0));
        this.labelBehavior = obtainStyledAttributes.getInt(R$styleable.Slider_labelBehavior, 0);
        if (!obtainStyledAttributes.getBoolean(R$styleable.Slider_android_enabled, true)) {
            setEnabled(false);
        }
        obtainStyledAttributes.recycle();
        setFocusable(true);
        setClickable(true);
        materialShapeDrawable.setShadowCompatibilityMode(2);
        this.scaledTouchSlop = ViewConfiguration.get(context2).getScaledTouchSlop();
        AccessibilityHelper accessibilityHelper2 = new AccessibilityHelper(this);
        this.accessibilityHelper = accessibilityHelper2;
        ViewCompat.setAccessibilityDelegate(this, accessibilityHelper2);
        this.accessibilityManager = (AccessibilityManager) getContext().getSystemService("accessibility");
    }

    public void addOnChangeListener(L l) {
        this.changeListeners.add(l);
    }

    public void addOnSliderTouchListener(T t) {
        this.touchListeners.add(t);
    }

    public final void attachLabelToContentView(TooltipDrawable tooltipDrawable) {
        ViewGroup contentView = ViewGroupUtilsApi14.getContentView(this);
        Objects.requireNonNull(tooltipDrawable);
        if (contentView != null) {
            int[] iArr = new int[2];
            contentView.getLocationOnScreen(iArr);
            tooltipDrawable.locationOnScreenX = iArr[0];
            contentView.getWindowVisibleDisplayFrame(tooltipDrawable.displayFrame);
            contentView.addOnLayoutChangeListener(tooltipDrawable.attachedViewLayoutChangeListener);
        }
    }

    public final float calculateStepIncrement(int i) {
        float f = this.stepSize;
        if (f == 0.0f) {
            f = 1.0f;
        }
        float f2 = (this.valueTo - this.valueFrom) / f;
        float f3 = (float) i;
        if (f2 <= f3) {
            return f;
        }
        return ((float) Math.round(f2 / f3)) * f;
    }

    public final int calculateTop() {
        int i = this.trackTop;
        int i2 = 0;
        if (this.labelBehavior == 1) {
            i2 = this.labels.get(0).getIntrinsicHeight();
        }
        return i + i2;
    }

    public final ValueAnimator createLabelAnimator(boolean z) {
        float f = 0.0f;
        float f2 = z ? 0.0f : 1.0f;
        ValueAnimator valueAnimator = z ? this.labelsOutAnimator : this.labelsInAnimator;
        if (valueAnimator != null && valueAnimator.isRunning()) {
            f2 = ((Float) valueAnimator.getAnimatedValue()).floatValue();
            valueAnimator.cancel();
        }
        if (z) {
            f = 1.0f;
        }
        ValueAnimator ofFloat = ValueAnimator.ofFloat(f2, f);
        ofFloat.setDuration(z ? 83 : 117);
        ofFloat.setInterpolator(z ? AnimationUtils.DECELERATE_INTERPOLATOR : AnimationUtils.FAST_OUT_LINEAR_IN_INTERPOLATOR);
        ofFloat.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.google.android.material.slider.BaseSlider.AnonymousClass2 */

            public void onAnimationUpdate(ValueAnimator valueAnimator) {
                float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                for (TooltipDrawable tooltipDrawable : BaseSlider.this.labels) {
                    tooltipDrawable.tooltipPivotY = 1.2f;
                    tooltipDrawable.tooltipScaleX = floatValue;
                    tooltipDrawable.tooltipScaleY = floatValue;
                    tooltipDrawable.labelOpacity = AnimationUtils.lerp(0.0f, 1.0f, 0.19f, 1.0f, floatValue);
                    tooltipDrawable.invalidateSelf();
                }
                BaseSlider baseSlider = BaseSlider.this;
                AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                baseSlider.postInvalidateOnAnimation();
            }
        });
        return ofFloat;
    }

    public final void detachLabelFromContentView(TooltipDrawable tooltipDrawable) {
        ViewOverlayImpl contentViewOverlay = ViewGroupUtilsApi14.getContentViewOverlay(this);
        if (contentViewOverlay != null) {
            ((ViewOverlayApi18) contentViewOverlay).viewOverlay.remove(tooltipDrawable);
            ViewGroup contentView = ViewGroupUtilsApi14.getContentView(this);
            Objects.requireNonNull(tooltipDrawable);
            if (contentView != null) {
                contentView.removeOnLayoutChangeListener(tooltipDrawable.attachedViewLayoutChangeListener);
            }
        }
    }

    public boolean dispatchHoverEvent(MotionEvent motionEvent) {
        return this.accessibilityHelper.dispatchHoverEvent(motionEvent) || super.dispatchHoverEvent(motionEvent);
    }

    public boolean dispatchKeyEvent(KeyEvent keyEvent) {
        return super.dispatchKeyEvent(keyEvent);
    }

    public final void dispatchOnChangedProgramatically() {
        for (L l : this.changeListeners) {
            Iterator<Float> it = this.values.iterator();
            while (it.hasNext()) {
                l.onValueChange(this, it.next().floatValue(), false);
            }
        }
    }

    public void drawableStateChanged() {
        super.drawableStateChanged();
        this.inactiveTrackPaint.setColor(getColorForState(this.trackColorInactive));
        this.activeTrackPaint.setColor(getColorForState(this.trackColorActive));
        this.inactiveTicksPaint.setColor(getColorForState(this.tickColorInactive));
        this.activeTicksPaint.setColor(getColorForState(this.tickColorActive));
        for (TooltipDrawable tooltipDrawable : this.labels) {
            if (tooltipDrawable.isStateful()) {
                tooltipDrawable.setState(getDrawableState());
            }
        }
        if (this.thumbDrawable.isStateful()) {
            this.thumbDrawable.setState(getDrawableState());
        }
        this.haloPaint.setColor(getColorForState(this.haloColor));
        this.haloPaint.setAlpha(63);
    }

    public final void ensureLabelsRemoved() {
        if (this.labelsAreAnimatedIn) {
            this.labelsAreAnimatedIn = false;
            ValueAnimator createLabelAnimator = createLabelAnimator(false);
            this.labelsOutAnimator = createLabelAnimator;
            this.labelsInAnimator = null;
            createLabelAnimator.addListener(new AnimatorListenerAdapter() {
                /* class com.google.android.material.slider.BaseSlider.AnonymousClass3 */

                public void onAnimationEnd(Animator animator) {
                    super.onAnimationEnd(animator);
                    for (TooltipDrawable tooltipDrawable : BaseSlider.this.labels) {
                        ((ViewOverlayApi18) ViewGroupUtilsApi14.getContentViewOverlay(BaseSlider.this)).viewOverlay.remove(tooltipDrawable);
                    }
                }
            });
            this.labelsOutAnimator.start();
        }
    }

    public final String formatValue(float f) {
        LabelFormatter labelFormatter = this.formatter;
        if (labelFormatter != null) {
            return labelFormatter.getFormattedValue(f);
        }
        return String.format(((float) ((int) f)) == f ? "%.0f" : "%.2f", Float.valueOf(f));
    }

    public CharSequence getAccessibilityClassName() {
        return SeekBar.class.getName();
    }

    public final int getAccessibilityFocusedVirtualViewId() {
        return this.accessibilityHelper.mAccessibilityFocusedVirtualViewId;
    }

    public final float[] getActiveRange() {
        float floatValue = ((Float) Collections.max(getValues())).floatValue();
        float floatValue2 = ((Float) Collections.min(getValues())).floatValue();
        if (this.values.size() == 1) {
            floatValue2 = this.valueFrom;
        }
        float normalizeValue = normalizeValue(floatValue2);
        float normalizeValue2 = normalizeValue(floatValue);
        if (isRtl()) {
            return new float[]{normalizeValue2, normalizeValue};
        }
        return new float[]{normalizeValue, normalizeValue2};
    }

    public final int getColorForState(ColorStateList colorStateList) {
        return colorStateList.getColorForState(getDrawableState(), colorStateList.getDefaultColor());
    }

    public float getMinSeparation() {
        return 0.0f;
    }

    public ColorStateList getTickTintList() {
        if (this.tickColorInactive.equals(this.tickColorActive)) {
            return this.tickColorActive;
        }
        throw new IllegalStateException("The inactive and active ticks are different colors. Use the getTickColorInactive() and getTickColorActive() methods instead.");
    }

    public ColorStateList getTrackTintList() {
        if (this.trackColorInactive.equals(this.trackColorActive)) {
            return this.trackColorActive;
        }
        throw new IllegalStateException("The inactive and active parts of the track are different colors. Use the getInactiveTrackColor() and getActiveTrackColor() methods instead.");
    }

    public abstract float getValueFrom();

    public abstract float getValueTo();

    public List<Float> getValues() {
        return new ArrayList(this.values);
    }

    public final boolean isInVerticalScrollingContainer() {
        ViewParent parent = getParent();
        while (true) {
            boolean z = false;
            if (!(parent instanceof ViewGroup)) {
                return false;
            }
            ViewGroup viewGroup = (ViewGroup) parent;
            if (viewGroup.canScrollVertically(1) || viewGroup.canScrollVertically(-1)) {
                z = true;
            }
            if (z && viewGroup.shouldDelayChildPressedState()) {
                return true;
            }
            parent = parent.getParent();
        }
    }

    public final boolean isRtl() {
        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
        return getLayoutDirection() == 1;
    }

    public final void maybeCalculateTicksCoordinates() {
        if (this.stepSize > 0.0f) {
            validateConfigurationIfDirty();
            int min = Math.min((int) (((this.valueTo - this.valueFrom) / this.stepSize) + 1.0f), (this.trackWidth / (this.trackHeight * 2)) + 1);
            float[] fArr = this.ticksCoordinates;
            if (fArr == null || fArr.length != min * 2) {
                this.ticksCoordinates = new float[(min * 2)];
            }
            float f = ((float) this.trackWidth) / ((float) (min - 1));
            for (int i = 0; i < min * 2; i += 2) {
                float[] fArr2 = this.ticksCoordinates;
                fArr2[i] = (((float) (i / 2)) * f) + ((float) this.trackSidePadding);
                fArr2[i + 1] = (float) calculateTop();
            }
        }
    }

    public final boolean moveFocus(int i) {
        int i2 = this.focusedThumbIdx;
        long j = ((long) i2) + ((long) i);
        long size = (long) (this.values.size() - 1);
        if (j < 0) {
            j = 0;
        } else if (j > size) {
            j = size;
        }
        int i3 = (int) j;
        this.focusedThumbIdx = i3;
        if (i3 == i2) {
            return false;
        }
        if (this.activeThumbIdx != -1) {
            this.activeThumbIdx = i3;
        }
        updateHaloHotspot();
        postInvalidate();
        return true;
    }

    public final boolean moveFocusInAbsoluteDirection(int i) {
        if (isRtl()) {
            i = i == Integer.MIN_VALUE ? Integer.MAX_VALUE : -i;
        }
        return moveFocus(i);
    }

    public final float normalizeValue(float f) {
        float f2 = this.valueFrom;
        float f3 = (f - f2) / (this.valueTo - f2);
        return isRtl() ? 1.0f - f3 : f3;
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        for (TooltipDrawable tooltipDrawable : this.labels) {
            attachLabelToContentView(tooltipDrawable);
        }
    }

    public void onDetachedFromWindow() {
        BaseSlider<S, L, T>.AccessibilityEventSender accessibilityEventSender2 = this.accessibilityEventSender;
        if (accessibilityEventSender2 != null) {
            removeCallbacks(accessibilityEventSender2);
        }
        this.labelsAreAnimatedIn = false;
        for (TooltipDrawable tooltipDrawable : this.labels) {
            detachLabelFromContentView(tooltipDrawable);
        }
        super.onDetachedFromWindow();
    }

    public void onDraw(Canvas canvas) {
        if (this.dirtyConfig) {
            validateConfigurationIfDirty();
            maybeCalculateTicksCoordinates();
        }
        super.onDraw(canvas);
        int calculateTop = calculateTop();
        int i = this.trackWidth;
        float[] activeRange = getActiveRange();
        int i2 = this.trackSidePadding;
        float f = (float) i;
        float f2 = (activeRange[1] * f) + ((float) i2);
        float f3 = (float) (i2 + i);
        if (f2 < f3) {
            float f4 = (float) calculateTop;
            canvas.drawLine(f2, f4, f3, f4, this.inactiveTrackPaint);
        }
        float f5 = (float) this.trackSidePadding;
        float f6 = (activeRange[0] * f) + f5;
        if (f6 > f5) {
            float f7 = (float) calculateTop;
            canvas.drawLine(f5, f7, f6, f7, this.inactiveTrackPaint);
        }
        if (((Float) Collections.max(getValues())).floatValue() > this.valueFrom) {
            int i3 = this.trackWidth;
            float[] activeRange2 = getActiveRange();
            float f8 = (float) this.trackSidePadding;
            float f9 = (float) i3;
            float f10 = (float) calculateTop;
            canvas.drawLine((activeRange2[0] * f9) + f8, f10, (activeRange2[1] * f9) + f8, f10, this.activeTrackPaint);
        }
        if (this.tickVisible && this.stepSize > 0.0f) {
            float[] activeRange3 = getActiveRange();
            int round = Math.round(activeRange3[0] * ((float) ((this.ticksCoordinates.length / 2) - 1)));
            int round2 = Math.round(activeRange3[1] * ((float) ((this.ticksCoordinates.length / 2) - 1)));
            int i4 = round * 2;
            canvas.drawPoints(this.ticksCoordinates, 0, i4, this.inactiveTicksPaint);
            int i5 = round2 * 2;
            canvas.drawPoints(this.ticksCoordinates, i4, i5 - i4, this.activeTicksPaint);
            float[] fArr = this.ticksCoordinates;
            canvas.drawPoints(fArr, i5, fArr.length - i5, this.inactiveTicksPaint);
        }
        if ((this.thumbIsPressed || isFocused()) && isEnabled()) {
            int i6 = this.trackWidth;
            if (shouldDrawCompatHalo()) {
                int normalizeValue = (int) ((normalizeValue(this.values.get(this.focusedThumbIdx).floatValue()) * ((float) i6)) + ((float) this.trackSidePadding));
                if (Build.VERSION.SDK_INT < 28) {
                    int i7 = this.haloRadius;
                    canvas.clipRect((float) (normalizeValue - i7), (float) (calculateTop - i7), (float) (normalizeValue + i7), (float) (i7 + calculateTop), Region.Op.UNION);
                }
                canvas.drawCircle((float) normalizeValue, (float) calculateTop, (float) this.haloRadius, this.haloPaint);
            }
            if (!(this.activeThumbIdx == -1 || this.labelBehavior == 2)) {
                if (!this.labelsAreAnimatedIn) {
                    this.labelsAreAnimatedIn = true;
                    ValueAnimator createLabelAnimator = createLabelAnimator(true);
                    this.labelsInAnimator = createLabelAnimator;
                    this.labelsOutAnimator = null;
                    createLabelAnimator.start();
                }
                Iterator<TooltipDrawable> it = this.labels.iterator();
                for (int i8 = 0; i8 < this.values.size() && it.hasNext(); i8++) {
                    if (i8 != this.focusedThumbIdx) {
                        setValueForLabel(it.next(), this.values.get(i8).floatValue());
                    }
                }
                if (it.hasNext()) {
                    setValueForLabel(it.next(), this.values.get(this.focusedThumbIdx).floatValue());
                } else {
                    throw new IllegalStateException(String.format("Not enough labels(%d) to display all the values(%d)", Integer.valueOf(this.labels.size()), Integer.valueOf(this.values.size())));
                }
            }
        }
        int i9 = this.trackWidth;
        if (!isEnabled()) {
            Iterator<Float> it2 = this.values.iterator();
            while (it2.hasNext()) {
                canvas.drawCircle((normalizeValue(it2.next().floatValue()) * ((float) i9)) + ((float) this.trackSidePadding), (float) calculateTop, (float) this.thumbRadius, this.thumbPaint);
            }
        }
        Iterator<Float> it3 = this.values.iterator();
        while (it3.hasNext()) {
            canvas.save();
            int normalizeValue2 = this.trackSidePadding + ((int) (normalizeValue(it3.next().floatValue()) * ((float) i9)));
            int i10 = this.thumbRadius;
            canvas.translate((float) (normalizeValue2 - i10), (float) (calculateTop - i10));
            this.thumbDrawable.draw(canvas);
            canvas.restore();
        }
    }

    public void onFocusChanged(boolean z, int i, Rect rect) {
        super.onFocusChanged(z, i, rect);
        if (!z) {
            this.activeThumbIdx = -1;
            ensureLabelsRemoved();
            this.accessibilityHelper.clearKeyboardFocusForVirtualView(this.focusedThumbIdx);
            return;
        }
        if (i == 1) {
            moveFocus(Integer.MAX_VALUE);
        } else if (i == 2) {
            moveFocus(LinearLayoutManager.INVALID_OFFSET);
        } else if (i == 17) {
            moveFocusInAbsoluteDirection(Integer.MAX_VALUE);
        } else if (i == 66) {
            moveFocusInAbsoluteDirection(LinearLayoutManager.INVALID_OFFSET);
        }
        this.accessibilityHelper.requestKeyboardFocusForVirtualView(this.focusedThumbIdx);
    }

    public boolean onKeyDown(int i, KeyEvent keyEvent) {
        float f;
        if (!isEnabled()) {
            return super.onKeyDown(i, keyEvent);
        }
        if (this.values.size() == 1) {
            this.activeThumbIdx = 0;
        }
        Float f2 = null;
        Boolean bool = null;
        if (this.activeThumbIdx == -1) {
            if (i != 61) {
                if (i != 66) {
                    if (i != 81) {
                        if (i != 69) {
                            if (i != 70) {
                                switch (i) {
                                    case 21:
                                        moveFocusInAbsoluteDirection(-1);
                                        bool = Boolean.TRUE;
                                        break;
                                    case 22:
                                        moveFocusInAbsoluteDirection(1);
                                        bool = Boolean.TRUE;
                                        break;
                                }
                            }
                        } else {
                            moveFocus(-1);
                            bool = Boolean.TRUE;
                        }
                    }
                    moveFocus(1);
                    bool = Boolean.TRUE;
                }
                this.activeThumbIdx = this.focusedThumbIdx;
                postInvalidate();
                bool = Boolean.TRUE;
            } else if (keyEvent.hasNoModifiers()) {
                bool = Boolean.valueOf(moveFocus(1));
            } else if (keyEvent.isShiftPressed()) {
                bool = Boolean.valueOf(moveFocus(-1));
            } else {
                bool = Boolean.FALSE;
            }
            return bool != null ? bool.booleanValue() : super.onKeyDown(i, keyEvent);
        }
        boolean isLongPress2 = this.isLongPress | keyEvent.isLongPress();
        this.isLongPress = isLongPress2;
        if (isLongPress2) {
            f = calculateStepIncrement(20);
        } else {
            f = this.stepSize;
            if (f == 0.0f) {
                f = 1.0f;
            }
        }
        if (i == 21) {
            if (!isRtl()) {
                f = -f;
            }
            f2 = Float.valueOf(f);
        } else if (i == 22) {
            if (isRtl()) {
                f = -f;
            }
            f2 = Float.valueOf(f);
        } else if (i == 69) {
            f2 = Float.valueOf(-f);
        } else if (i == 70 || i == 81) {
            f2 = Float.valueOf(f);
        }
        if (f2 != null) {
            if (snapThumbToValue(this.activeThumbIdx, f2.floatValue() + this.values.get(this.activeThumbIdx).floatValue())) {
                updateHaloHotspot();
                postInvalidate();
            }
            return true;
        }
        if (i != 23) {
            if (i != 61) {
                if (i != 66) {
                    return super.onKeyDown(i, keyEvent);
                }
            } else if (keyEvent.hasNoModifiers()) {
                return moveFocus(1);
            } else {
                if (keyEvent.isShiftPressed()) {
                    return moveFocus(-1);
                }
                return false;
            }
        }
        this.activeThumbIdx = -1;
        ensureLabelsRemoved();
        postInvalidate();
        return true;
    }

    public boolean onKeyUp(int i, KeyEvent keyEvent) {
        this.isLongPress = false;
        return super.onKeyUp(i, keyEvent);
    }

    public void onMeasure(int i, int i2) {
        int i3 = this.widgetHeight;
        int i4 = 0;
        if (this.labelBehavior == 1) {
            i4 = this.labels.get(0).getIntrinsicHeight();
        }
        super.onMeasure(i, View.MeasureSpec.makeMeasureSpec(i3 + i4, 1073741824));
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        SliderState sliderState = (SliderState) parcelable;
        super.onRestoreInstanceState(sliderState.getSuperState());
        this.valueFrom = sliderState.valueFrom;
        this.valueTo = sliderState.valueTo;
        setValuesInternal(sliderState.values);
        this.stepSize = sliderState.stepSize;
        if (sliderState.hasFocus) {
            requestFocus();
        }
        dispatchOnChangedProgramatically();
    }

    public Parcelable onSaveInstanceState() {
        SliderState sliderState = new SliderState(super.onSaveInstanceState());
        sliderState.valueFrom = this.valueFrom;
        sliderState.valueTo = this.valueTo;
        sliderState.values = new ArrayList<>(this.values);
        sliderState.stepSize = this.stepSize;
        sliderState.hasFocus = hasFocus();
        return sliderState;
    }

    public void onSizeChanged(int i, int i2, int i3, int i4) {
        this.trackWidth = Math.max(i - (this.trackSidePadding * 2), 0);
        maybeCalculateTicksCoordinates();
        updateHaloHotspot();
    }

    public final void onStartTrackingTouch() {
        for (T t : this.touchListeners) {
            t.onStartTrackingTouch(this);
        }
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        if (!isEnabled()) {
            return false;
        }
        float x = motionEvent.getX();
        float f = (x - ((float) this.trackSidePadding)) / ((float) this.trackWidth);
        this.touchPosition = f;
        float max = Math.max(0.0f, f);
        this.touchPosition = max;
        this.touchPosition = Math.min(1.0f, max);
        int actionMasked = motionEvent.getActionMasked();
        if (actionMasked == 0) {
            this.touchDownX = x;
            if (!isInVerticalScrollingContainer()) {
                getParent().requestDisallowInterceptTouchEvent(true);
                if (pickActiveThumb()) {
                    requestFocus();
                    this.thumbIsPressed = true;
                    snapTouchPosition();
                    updateHaloHotspot();
                    invalidate();
                    onStartTrackingTouch();
                }
            }
        } else if (actionMasked == 1) {
            this.thumbIsPressed = false;
            MotionEvent motionEvent2 = this.lastEvent;
            if (motionEvent2 != null && motionEvent2.getActionMasked() == 0 && Math.abs(this.lastEvent.getX() - motionEvent.getX()) <= ((float) this.scaledTouchSlop) && Math.abs(this.lastEvent.getY() - motionEvent.getY()) <= ((float) this.scaledTouchSlop) && pickActiveThumb()) {
                onStartTrackingTouch();
            }
            if (this.activeThumbIdx != -1) {
                snapTouchPosition();
                this.activeThumbIdx = -1;
                for (T t : this.touchListeners) {
                    t.onStopTrackingTouch(this);
                }
            }
            ensureLabelsRemoved();
            invalidate();
        } else if (actionMasked == 2) {
            if (!this.thumbIsPressed) {
                if (isInVerticalScrollingContainer() && Math.abs(x - this.touchDownX) < ((float) this.scaledTouchSlop)) {
                    return false;
                }
                getParent().requestDisallowInterceptTouchEvent(true);
                onStartTrackingTouch();
            }
            if (pickActiveThumb()) {
                this.thumbIsPressed = true;
                snapTouchPosition();
                updateHaloHotspot();
                invalidate();
            }
        }
        setPressed(this.thumbIsPressed);
        this.lastEvent = MotionEvent.obtain(motionEvent);
        return true;
    }

    public boolean pickActiveThumb() {
        if (this.activeThumbIdx != -1) {
            return true;
        }
        float f = this.touchPosition;
        if (isRtl()) {
            f = 1.0f - f;
        }
        float f2 = this.valueTo;
        float f3 = this.valueFrom;
        float outline0 = GeneratedOutlineSupport.outline0(f2, f3, f, f3);
        float normalizeValue = (normalizeValue(outline0) * ((float) this.trackWidth)) + ((float) this.trackSidePadding);
        this.activeThumbIdx = 0;
        float abs = Math.abs(this.values.get(0).floatValue() - outline0);
        for (int i = 1; i < this.values.size(); i++) {
            float abs2 = Math.abs(this.values.get(i).floatValue() - outline0);
            float normalizeValue2 = (normalizeValue(this.values.get(i).floatValue()) * ((float) this.trackWidth)) + ((float) this.trackSidePadding);
            if (Float.compare(abs2, abs) > 1) {
                break;
            }
            boolean z = !isRtl() ? normalizeValue2 - normalizeValue < 0.0f : normalizeValue2 - normalizeValue > 0.0f;
            if (Float.compare(abs2, abs) < 0) {
                this.activeThumbIdx = i;
            } else {
                if (Float.compare(abs2, abs) != 0) {
                    continue;
                } else if (Math.abs(normalizeValue2 - normalizeValue) < ((float) this.scaledTouchSlop)) {
                    this.activeThumbIdx = -1;
                    return false;
                } else if (z) {
                    this.activeThumbIdx = i;
                }
            }
            abs = abs2;
        }
        if (this.activeThumbIdx != -1) {
            return true;
        }
        return false;
    }

    public void removeOnChangeListener(L l) {
        this.changeListeners.remove(l);
    }

    public void removeOnSliderTouchListener(T t) {
        this.touchListeners.remove(t);
    }

    public void setActiveThumbIndex(int i) {
        this.activeThumbIdx = i;
    }

    public void setEnabled(boolean z) {
        super.setEnabled(z);
        setLayerType(z ? 0 : 2, null);
    }

    public void setFocusedThumbIndex(int i) {
        if (i < 0 || i >= this.values.size()) {
            throw new IllegalArgumentException("index out of range");
        }
        this.focusedThumbIdx = i;
        this.accessibilityHelper.requestKeyboardFocusForVirtualView(i);
        postInvalidate();
    }

    public void setHaloRadius(int i) {
        if (i != this.haloRadius) {
            this.haloRadius = i;
            Drawable background = getBackground();
            if (shouldDrawCompatHalo() || !(background instanceof RippleDrawable)) {
                postInvalidate();
                return;
            }
            RippleDrawable rippleDrawable = (RippleDrawable) background;
            int i2 = this.haloRadius;
            if (Build.VERSION.SDK_INT >= 23) {
                rippleDrawable.setRadius(i2);
                return;
            }
            try {
                RippleDrawable.class.getDeclaredMethod("setMaxRadius", Integer.TYPE).invoke(rippleDrawable, Integer.valueOf(i2));
            } catch (IllegalAccessException | NoSuchMethodException | InvocationTargetException e) {
                throw new IllegalStateException("Couldn't set RippleDrawable radius", e);
            }
        }
    }

    public void setHaloTintList(ColorStateList colorStateList) {
        if (!colorStateList.equals(this.haloColor)) {
            this.haloColor = colorStateList;
            Drawable background = getBackground();
            if (shouldDrawCompatHalo() || !(background instanceof RippleDrawable)) {
                this.haloPaint.setColor(colorStateList.getColorForState(getDrawableState(), colorStateList.getDefaultColor()));
                this.haloPaint.setAlpha(63);
                invalidate();
                return;
            }
            ((RippleDrawable) background).setColor(colorStateList);
        }
    }

    public void setSeparationUnit(int i) {
        this.separationUnit = i;
    }

    public void setStepSize(float f) {
        if (f < 0.0f) {
            throw new IllegalArgumentException(String.format("The stepSize(%s) must be 0, or a factor of the valueFrom(%s)-valueTo(%s) range", Float.toString(f), Float.toString(this.valueFrom), Float.toString(this.valueTo)));
        } else if (this.stepSize != f) {
            this.stepSize = f;
            this.dirtyConfig = true;
            postInvalidate();
        }
    }

    public abstract void setThumbElevation(float f);

    public void setThumbRadius(int i) {
        if (i != this.thumbRadius) {
            this.thumbRadius = i;
            this.trackSidePadding = this.minTrackSidePadding + Math.max(i - this.defaultThumbRadius, 0);
            AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
            if (isLaidOut()) {
                this.trackWidth = Math.max(getWidth() - (this.trackSidePadding * 2), 0);
                maybeCalculateTicksCoordinates();
            }
            MaterialShapeDrawable materialShapeDrawable = this.thumbDrawable;
            ShapeAppearanceModel.Builder builder = new ShapeAppearanceModel.Builder();
            CornerTreatment createCornerTreatment = ViewGroupUtilsApi14.createCornerTreatment(0);
            builder.topLeftCorner = createCornerTreatment;
            ShapeAppearanceModel.Builder.compatCornerTreatmentSize(createCornerTreatment);
            builder.topRightCorner = createCornerTreatment;
            ShapeAppearanceModel.Builder.compatCornerTreatmentSize(createCornerTreatment);
            builder.bottomRightCorner = createCornerTreatment;
            ShapeAppearanceModel.Builder.compatCornerTreatmentSize(createCornerTreatment);
            builder.bottomLeftCorner = createCornerTreatment;
            ShapeAppearanceModel.Builder.compatCornerTreatmentSize(createCornerTreatment);
            builder.setAllCornerSizes((float) this.thumbRadius);
            materialShapeDrawable.drawableState.shapeAppearanceModel = builder.build();
            materialShapeDrawable.invalidateSelf();
            MaterialShapeDrawable materialShapeDrawable2 = this.thumbDrawable;
            int i2 = this.thumbRadius;
            materialShapeDrawable2.setBounds(0, 0, i2 * 2, i2 * 2);
            postInvalidate();
        }
    }

    public abstract void setThumbStrokeColor(ColorStateList colorStateList);

    public abstract void setThumbStrokeWidth(float f);

    public void setThumbTintList(ColorStateList colorStateList) {
        if (!colorStateList.equals(this.thumbDrawable.drawableState.fillColor)) {
            this.thumbDrawable.setFillColor(colorStateList);
            invalidate();
        }
    }

    public void setTickActiveTintList(ColorStateList colorStateList) {
        if (!colorStateList.equals(this.tickColorActive)) {
            this.tickColorActive = colorStateList;
            this.activeTicksPaint.setColor(getColorForState(colorStateList));
            invalidate();
        }
    }

    public void setTickInactiveTintList(ColorStateList colorStateList) {
        if (!colorStateList.equals(this.tickColorInactive)) {
            this.tickColorInactive = colorStateList;
            this.inactiveTicksPaint.setColor(getColorForState(colorStateList));
            invalidate();
        }
    }

    public void setTrackActiveTintList(ColorStateList colorStateList) {
        if (!colorStateList.equals(this.trackColorActive)) {
            this.trackColorActive = colorStateList;
            this.activeTrackPaint.setColor(getColorForState(colorStateList));
            invalidate();
        }
    }

    public void setTrackHeight(int i) {
        if (this.trackHeight != i) {
            this.trackHeight = i;
            this.inactiveTrackPaint.setStrokeWidth((float) i);
            this.activeTrackPaint.setStrokeWidth((float) this.trackHeight);
            this.inactiveTicksPaint.setStrokeWidth(((float) this.trackHeight) / 2.0f);
            this.activeTicksPaint.setStrokeWidth(((float) this.trackHeight) / 2.0f);
            postInvalidate();
        }
    }

    public void setTrackInactiveTintList(ColorStateList colorStateList) {
        if (!colorStateList.equals(this.trackColorInactive)) {
            this.trackColorInactive = colorStateList;
            this.inactiveTrackPaint.setColor(getColorForState(colorStateList));
            invalidate();
        }
    }

    public final void setValueForLabel(TooltipDrawable tooltipDrawable, float f) {
        String formatValue = formatValue(f);
        if (!TextUtils.equals(tooltipDrawable.text, formatValue)) {
            tooltipDrawable.text = formatValue;
            tooltipDrawable.textDrawableHelper.textWidthDirty = true;
            tooltipDrawable.invalidateSelf();
        }
        int normalizeValue = (this.trackSidePadding + ((int) (normalizeValue(f) * ((float) this.trackWidth)))) - (tooltipDrawable.getIntrinsicWidth() / 2);
        int calculateTop = calculateTop() - (this.labelPadding + this.thumbRadius);
        tooltipDrawable.setBounds(normalizeValue, calculateTop - tooltipDrawable.getIntrinsicHeight(), tooltipDrawable.getIntrinsicWidth() + normalizeValue, calculateTop);
        Rect rect = new Rect(tooltipDrawable.getBounds());
        DescendantOffsetUtils.offsetDescendantRect(ViewGroupUtilsApi14.getContentView(this), this, rect);
        tooltipDrawable.setBounds(rect);
        ((ViewOverlayApi18) ViewGroupUtilsApi14.getContentViewOverlay(this)).viewOverlay.add(tooltipDrawable);
    }

    public void setValues(Float... fArr) {
        ArrayList<Float> arrayList = new ArrayList<>();
        Collections.addAll(arrayList, fArr);
        setValuesInternal(arrayList);
    }

    public final void setValuesInternal(ArrayList<Float> arrayList) {
        if (!arrayList.isEmpty()) {
            Collections.sort(arrayList);
            if (this.values.size() != arrayList.size() || !this.values.equals(arrayList)) {
                this.values = arrayList;
                int i = 1;
                this.dirtyConfig = true;
                this.focusedThumbIdx = 0;
                updateHaloHotspot();
                if (this.labels.size() > this.values.size()) {
                    List<TooltipDrawable> subList = this.labels.subList(this.values.size(), this.labels.size());
                    for (TooltipDrawable tooltipDrawable : subList) {
                        AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
                        if (isAttachedToWindow()) {
                            detachLabelFromContentView(tooltipDrawable);
                        }
                    }
                    subList.clear();
                }
                while (this.labels.size() < this.values.size()) {
                    AnonymousClass1 r1 = (AnonymousClass1) this.labelMaker;
                    TypedArray obtainStyledAttributes = ThemeEnforcement.obtainStyledAttributes(BaseSlider.this.getContext(), attributeSet, R$styleable.Slider, i, DEF_STYLE_RES, new int[0]);
                    Context context = BaseSlider.this.getContext();
                    int resourceId = obtainStyledAttributes.getResourceId(R$styleable.Slider_labelStyle, R$style.Widget_MaterialComponents_Tooltip);
                    TooltipDrawable tooltipDrawable2 = new TooltipDrawable(context, null, 0, resourceId);
                    TypedArray obtainStyledAttributes2 = ThemeEnforcement.obtainStyledAttributes(tooltipDrawable2.context, null, R$styleable.Tooltip, 0, resourceId, new int[0]);
                    tooltipDrawable2.arrowSize = tooltipDrawable2.context.getResources().getDimensionPixelSize(R$dimen.mtrl_tooltip_arrowSize);
                    ShapeAppearanceModel shapeAppearanceModel = tooltipDrawable2.drawableState.shapeAppearanceModel;
                    Objects.requireNonNull(shapeAppearanceModel);
                    ShapeAppearanceModel.Builder builder = new ShapeAppearanceModel.Builder(shapeAppearanceModel);
                    builder.bottomEdge = tooltipDrawable2.createMarkerEdge();
                    tooltipDrawable2.drawableState.shapeAppearanceModel = builder.build();
                    tooltipDrawable2.invalidateSelf();
                    CharSequence text = obtainStyledAttributes2.getText(R$styleable.Tooltip_android_text);
                    if (!TextUtils.equals(tooltipDrawable2.text, text)) {
                        tooltipDrawable2.text = text;
                        tooltipDrawable2.textDrawableHelper.textWidthDirty = true;
                        tooltipDrawable2.invalidateSelf();
                    }
                    tooltipDrawable2.textDrawableHelper.setTextAppearance(ViewGroupUtilsApi14.getTextAppearance(tooltipDrawable2.context, obtainStyledAttributes2, R$styleable.Tooltip_android_textAppearance), tooltipDrawable2.context);
                    int resolveOrThrow = ViewGroupUtilsApi14.resolveOrThrow(tooltipDrawable2.context, R$attr.colorOnBackground, TooltipDrawable.class.getCanonicalName());
                    tooltipDrawable2.setFillColor(ColorStateList.valueOf(obtainStyledAttributes2.getColor(R$styleable.Tooltip_backgroundTint, ColorUtils.compositeColors(ColorUtils.setAlphaComponent(resolveOrThrow, 153), ColorUtils.setAlphaComponent(ViewGroupUtilsApi14.resolveOrThrow(tooltipDrawable2.context, 16842801, TooltipDrawable.class.getCanonicalName()), 229)))));
                    tooltipDrawable2.setStrokeColor(ColorStateList.valueOf(ViewGroupUtilsApi14.resolveOrThrow(tooltipDrawable2.context, R$attr.colorSurface, TooltipDrawable.class.getCanonicalName())));
                    tooltipDrawable2.padding = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.Tooltip_android_padding, 0);
                    tooltipDrawable2.minWidth = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.Tooltip_android_minWidth, 0);
                    tooltipDrawable2.minHeight = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.Tooltip_android_minHeight, 0);
                    tooltipDrawable2.layoutMargin = obtainStyledAttributes2.getDimensionPixelSize(R$styleable.Tooltip_android_layout_margin, 0);
                    obtainStyledAttributes2.recycle();
                    obtainStyledAttributes.recycle();
                    this.labels.add(tooltipDrawable2);
                    AtomicInteger atomicInteger2 = ViewCompat.sNextGeneratedId;
                    if (isAttachedToWindow()) {
                        attachLabelToContentView(tooltipDrawable2);
                    }
                }
                if (this.labels.size() == 1) {
                    i = 0;
                }
                for (TooltipDrawable tooltipDrawable3 : this.labels) {
                    tooltipDrawable3.setStrokeWidth((float) i);
                }
                dispatchOnChangedProgramatically();
                postInvalidate();
                return;
            }
            return;
        }
        throw new IllegalArgumentException("At least one value must be set");
    }

    public final boolean shouldDrawCompatHalo() {
        return !(getBackground() instanceof RippleDrawable);
    }

    public final boolean snapThumbToValue(int i, float f) {
        if (((double) Math.abs(f - this.values.get(i).floatValue())) < 1.0E-4d) {
            return false;
        }
        float f2 = 0.0f;
        float minSeparation = this.stepSize == 0.0f ? getMinSeparation() : 0.0f;
        if (this.separationUnit == 0) {
            if (minSeparation != 0.0f) {
                float f3 = (minSeparation - ((float) this.trackSidePadding)) / ((float) this.trackWidth);
                float f4 = this.valueFrom;
                f2 = GeneratedOutlineSupport.outline0(f4, this.valueTo, f3, f4);
            }
            minSeparation = f2;
        }
        if (isRtl()) {
            minSeparation = -minSeparation;
        }
        int i2 = i + 1;
        int i3 = i - 1;
        this.values.set(i, Float.valueOf(AppCompatDelegateImpl.Api17Impl.clamp(f, i3 < 0 ? this.valueFrom : minSeparation + this.values.get(i3).floatValue(), i2 >= this.values.size() ? this.valueTo : this.values.get(i2).floatValue() - minSeparation)));
        this.focusedThumbIdx = i;
        for (L l : this.changeListeners) {
            l.onValueChange(this, this.values.get(i).floatValue(), true);
        }
        AccessibilityManager accessibilityManager2 = this.accessibilityManager;
        if (accessibilityManager2 != null && accessibilityManager2.isEnabled()) {
            BaseSlider<S, L, T>.AccessibilityEventSender accessibilityEventSender2 = this.accessibilityEventSender;
            if (accessibilityEventSender2 == null) {
                this.accessibilityEventSender = new AccessibilityEventSender(null);
            } else {
                removeCallbacks(accessibilityEventSender2);
            }
            BaseSlider<S, L, T>.AccessibilityEventSender accessibilityEventSender3 = this.accessibilityEventSender;
            accessibilityEventSender3.virtualViewId = i;
            postDelayed(accessibilityEventSender3, 200);
        }
        return true;
    }

    public final boolean snapTouchPosition() {
        double d;
        float f = this.touchPosition;
        float f2 = this.stepSize;
        if (f2 > 0.0f) {
            int i = (int) ((this.valueTo - this.valueFrom) / f2);
            d = ((double) Math.round(f * ((float) i))) / ((double) i);
        } else {
            d = (double) f;
        }
        if (isRtl()) {
            d = 1.0d - d;
        }
        float f3 = this.valueTo;
        float f4 = this.valueFrom;
        return snapThumbToValue(this.activeThumbIdx, (float) ((d * ((double) (f3 - f4))) + ((double) f4)));
    }

    public void updateBoundsForVirturalViewId(int i, Rect rect) {
        int normalizeValue = this.trackSidePadding + ((int) (normalizeValue(getValues().get(i).floatValue()) * ((float) this.trackWidth)));
        int calculateTop = calculateTop();
        int i2 = this.thumbRadius;
        rect.set(normalizeValue - i2, calculateTop - i2, normalizeValue + i2, calculateTop + i2);
    }

    public final void updateHaloHotspot() {
        if (!shouldDrawCompatHalo() && getMeasuredWidth() > 0) {
            Drawable background = getBackground();
            if (background instanceof RippleDrawable) {
                int normalizeValue = (int) ((normalizeValue(this.values.get(this.focusedThumbIdx).floatValue()) * ((float) this.trackWidth)) + ((float) this.trackSidePadding));
                int calculateTop = calculateTop();
                int i = this.haloRadius;
                background.setHotspotBounds(normalizeValue - i, calculateTop - i, normalizeValue + i, calculateTop + i);
            }
        }
    }

    public final void validateConfigurationIfDirty() {
        if (this.dirtyConfig) {
            float f = this.valueFrom;
            float f2 = this.valueTo;
            if (f >= f2) {
                throw new IllegalStateException(String.format("valueFrom(%s) must be smaller than valueTo(%s)", Float.toString(this.valueFrom), Float.toString(this.valueTo)));
            } else if (f2 <= f) {
                throw new IllegalStateException(String.format("valueTo(%s) must be greater than valueFrom(%s)", Float.toString(this.valueTo), Float.toString(this.valueFrom)));
            } else if (this.stepSize <= 0.0f || valueLandsOnTick(f2)) {
                Iterator<Float> it = this.values.iterator();
                while (it.hasNext()) {
                    Float next = it.next();
                    if (next.floatValue() < this.valueFrom || next.floatValue() > this.valueTo) {
                        throw new IllegalStateException(String.format("Slider value(%s) must be greater or equal to valueFrom(%s), and lower or equal to valueTo(%s)", Float.toString(next.floatValue()), Float.toString(this.valueFrom), Float.toString(this.valueTo)));
                    } else if (this.stepSize > 0.0f && !valueLandsOnTick(next.floatValue())) {
                        throw new IllegalStateException(String.format("Value(%s) must be equal to valueFrom(%s) plus a multiple of stepSize(%s) when using stepSize(%s)", Float.toString(next.floatValue()), Float.toString(this.valueFrom), Float.toString(this.stepSize), Float.toString(this.stepSize)));
                    }
                }
                float f3 = this.stepSize;
                if (f3 != 0.0f) {
                    if (((float) ((int) f3)) != f3) {
                        Log.w(TAG, String.format("Floating point value used for %s(%s). Using floats can have rounding errors which may result in incorrect values. Instead, consider using integers with a custom LabelFormatter to display the  value correctly.", "stepSize", Float.valueOf(f3)));
                    }
                    float f4 = this.valueFrom;
                    if (((float) ((int) f4)) != f4) {
                        Log.w(TAG, String.format("Floating point value used for %s(%s). Using floats can have rounding errors which may result in incorrect values. Instead, consider using integers with a custom LabelFormatter to display the  value correctly.", "valueFrom", Float.valueOf(f4)));
                    }
                    float f5 = this.valueTo;
                    if (((float) ((int) f5)) != f5) {
                        Log.w(TAG, String.format("Floating point value used for %s(%s). Using floats can have rounding errors which may result in incorrect values. Instead, consider using integers with a custom LabelFormatter to display the  value correctly.", "valueTo", Float.valueOf(f5)));
                    }
                }
                this.dirtyConfig = false;
            } else {
                throw new IllegalStateException(String.format("The stepSize(%s) must be 0, or a factor of the valueFrom(%s)-valueTo(%s) range", Float.toString(this.stepSize), Float.toString(this.valueFrom), Float.toString(this.valueTo)));
            }
        }
    }

    public final boolean valueLandsOnTick(float f) {
        double doubleValue = new BigDecimal(Float.toString(f)).subtract(new BigDecimal(Float.toString(this.valueFrom))).divide(new BigDecimal(Float.toString(this.stepSize)), MathContext.DECIMAL64).doubleValue();
        return Math.abs(((double) Math.round(doubleValue)) - doubleValue) < 1.0E-4d;
    }

    public void setValues(List<Float> list) {
        setValuesInternal(new ArrayList<>(list));
    }
}
