package com.google.android.material.timepicker;

import android.content.Context;
import android.util.AttributeSet;
import android.view.GestureDetector;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Checkable;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.constraintlayout.widget.ConstraintSet;
import androidx.core.view.ViewCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import com.google.android.material.R$id;
import com.google.android.material.R$layout;
import com.google.android.material.button.MaterialButtonToggleGroup;
import com.google.android.material.chip.Chip;
import com.google.android.material.timepicker.ClockHandView;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicInteger;

public class TimePickerView extends ConstraintLayout {
    public static final /* synthetic */ int $r8$clinit = 0;
    public final ClockHandView clockHandView = ((ClockHandView) findViewById(R$id.material_clock_hand));
    public final Chip hourView;
    public final Chip minuteView;
    public OnDoubleTapListener onDoubleTapListener;
    public OnPeriodChangeListener onPeriodChangeListener;
    public final View.OnClickListener selectionListener;
    public final MaterialButtonToggleGroup toggle;

    public interface OnDoubleTapListener {
        void onDoubleTap();
    }

    public interface OnPeriodChangeListener {
        void onPeriodChange(int i);
    }

    public TimePickerView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet, 0);
        AnonymousClass1 r6 = new View.OnClickListener() {
            /* class com.google.android.material.timepicker.TimePickerView.AnonymousClass1 */

            public void onClick(View view) {
                TimePickerView timePickerView = TimePickerView.this;
                int i = TimePickerView.$r8$clinit;
                Objects.requireNonNull(timePickerView);
            }
        };
        this.selectionListener = r6;
        LayoutInflater.from(context).inflate(R$layout.material_timepicker, this);
        ClockFaceView clockFaceView = (ClockFaceView) findViewById(R$id.material_clock_face);
        MaterialButtonToggleGroup materialButtonToggleGroup = (MaterialButtonToggleGroup) findViewById(R$id.material_clock_period_toggle);
        this.toggle = materialButtonToggleGroup;
        materialButtonToggleGroup.addOnButtonCheckedListener(new MaterialButtonToggleGroup.OnButtonCheckedListener() {
            /* class com.google.android.material.timepicker.TimePickerView.AnonymousClass2 */
        });
        Chip chip = (Chip) findViewById(R$id.material_minute_tv);
        this.minuteView = chip;
        Chip chip2 = (Chip) findViewById(R$id.material_hour_tv);
        this.hourView = chip2;
        final GestureDetector gestureDetector = new GestureDetector(getContext(), new GestureDetector.SimpleOnGestureListener() {
            /* class com.google.android.material.timepicker.TimePickerView.AnonymousClass3 */

            public boolean onDoubleTap(MotionEvent motionEvent) {
                boolean onDoubleTap = super.onDoubleTap(motionEvent);
                OnDoubleTapListener onDoubleTapListener = TimePickerView.this.onDoubleTapListener;
                if (onDoubleTapListener != null) {
                    onDoubleTapListener.onDoubleTap();
                }
                return onDoubleTap;
            }
        });
        AnonymousClass4 r2 = new View.OnTouchListener(this) {
            /* class com.google.android.material.timepicker.TimePickerView.AnonymousClass4 */

            public boolean onTouch(View view, MotionEvent motionEvent) {
                if (((Checkable) view).isChecked()) {
                    return gestureDetector.onTouchEvent(motionEvent);
                }
                return false;
            }
        };
        chip.setOnTouchListener(r2);
        chip2.setOnTouchListener(r2);
        int i = R$id.selection_type;
        chip.setTag(i, 12);
        chip2.setTag(i, 10);
        chip.setOnClickListener(r6);
        chip2.setOnClickListener(r6);
    }

    public void addOnRotateListener(ClockHandView.OnRotateListener onRotateListener) {
        this.clockHandView.addOnRotateListener(onRotateListener);
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        updateToggleConstraints();
    }

    public void onVisibilityChanged(View view, int i) {
        super.onVisibilityChanged(view, i);
        if (view == this && i == 0) {
            updateToggleConstraints();
        }
    }

    public void setOnActionUpListener(ClockHandView.OnActionUpListener onActionUpListener) {
        this.clockHandView.setOnActionUpListener(onActionUpListener);
    }

    public void setOnDoubleTapListener(OnDoubleTapListener onDoubleTapListener2) {
        this.onDoubleTapListener = onDoubleTapListener2;
    }

    public void setOnPeriodChangeListener(OnPeriodChangeListener onPeriodChangeListener2) {
        this.onPeriodChangeListener = onPeriodChangeListener2;
    }

    public final void updateToggleConstraints() {
        ConstraintSet.Constraint constraint;
        if (this.toggle.getVisibility() == 0) {
            ConstraintSet constraintSet = new ConstraintSet();
            constraintSet.clone(this);
            AtomicInteger atomicInteger = ViewCompat.sNextGeneratedId;
            char c = getLayoutDirection() == 0 ? (char) 2 : 1;
            int i = R$id.material_clock_display;
            if (constraintSet.mConstraints.containsKey(Integer.valueOf(i)) && (constraint = constraintSet.mConstraints.get(Integer.valueOf(i))) != null) {
                switch (c) {
                    case 1:
                        ConstraintSet.Layout layout = constraint.layout;
                        layout.leftToRight = -1;
                        layout.leftToLeft = -1;
                        layout.leftMargin = -1;
                        layout.goneLeftMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case 2:
                        ConstraintSet.Layout layout2 = constraint.layout;
                        layout2.rightToRight = -1;
                        layout2.rightToLeft = -1;
                        layout2.rightMargin = -1;
                        layout2.goneRightMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case 3:
                        ConstraintSet.Layout layout3 = constraint.layout;
                        layout3.topToBottom = -1;
                        layout3.topToTop = -1;
                        layout3.topMargin = 0;
                        layout3.goneTopMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case 4:
                        ConstraintSet.Layout layout4 = constraint.layout;
                        layout4.bottomToTop = -1;
                        layout4.bottomToBottom = -1;
                        layout4.bottomMargin = 0;
                        layout4.goneBottomMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case 5:
                        ConstraintSet.Layout layout5 = constraint.layout;
                        layout5.baselineToBaseline = -1;
                        layout5.baselineToTop = -1;
                        layout5.baselineToBottom = -1;
                        layout5.baselineMargin = 0;
                        layout5.goneBaselineMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case 6:
                        ConstraintSet.Layout layout6 = constraint.layout;
                        layout6.startToEnd = -1;
                        layout6.startToStart = -1;
                        layout6.startMargin = 0;
                        layout6.goneStartMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case 7:
                        ConstraintSet.Layout layout7 = constraint.layout;
                        layout7.endToStart = -1;
                        layout7.endToEnd = -1;
                        layout7.endMargin = 0;
                        layout7.goneEndMargin = LinearLayoutManager.INVALID_OFFSET;
                        break;
                    case '\b':
                        ConstraintSet.Layout layout8 = constraint.layout;
                        layout8.circleAngle = -1.0f;
                        layout8.circleRadius = -1;
                        layout8.circleConstraint = -1;
                        break;
                    default:
                        throw new IllegalArgumentException("unknown constraint");
                }
            }
            constraintSet.applyToInternal(this, true);
            setConstraintSet(null);
            requestLayout();
        }
    }
}
