package com.google.protobuf;

import com.google.protobuf.Descriptors;
import com.google.protobuf.Internal;
import com.google.protobuf.StructuralMessageInfo;
import java.lang.reflect.Field;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.Stack;
import java.util.concurrent.ConcurrentHashMap;

public final class DescriptorMessageInfoFactory implements MessageInfoFactory {
    public static IsInitializedCheckAnalyzer isInitializedCheckAnalyzer = new IsInitializedCheckAnalyzer();
    public static final Set<String> specialFieldNames = new HashSet(Arrays.asList("cached_size", "serialized_size", "class"));

    public class IsInitializedCheckAnalyzer {
        public int index = 0;
        public final Map<Descriptors.Descriptor, Node> nodeCache = new HashMap();
        public final Map<Descriptors.Descriptor, Boolean> resultCache = new ConcurrentHashMap();
        public final Stack<Node> stack = new Stack<>();

        public class Node {
            public StronglyConnectedComponent component = null;
            public final Descriptors.Descriptor descriptor;
            public final int index;
            public int lowLink;

            public Node(Descriptors.Descriptor descriptor2, int i) {
                this.descriptor = descriptor2;
                this.index = i;
                this.lowLink = i;
            }
        }

        public class StronglyConnectedComponent {
            public final List<Descriptors.Descriptor> messages = new ArrayList();
            public boolean needsIsInitializedCheck = false;

            public StronglyConnectedComponent(AnonymousClass1 r1) {
            }
        }

        public final Node dfs(Descriptors.Descriptor descriptor) {
            Node pop;
            boolean z;
            StronglyConnectedComponent stronglyConnectedComponent;
            int i = this.index;
            this.index = i + 1;
            Node node = new Node(descriptor, i);
            this.stack.push(node);
            this.nodeCache.put(descriptor, node);
            for (Descriptors.FieldDescriptor fieldDescriptor : descriptor.getFields()) {
                if (fieldDescriptor.getJavaType() == Descriptors.FieldDescriptor.JavaType.MESSAGE) {
                    Node node2 = this.nodeCache.get(fieldDescriptor.getMessageType());
                    if (node2 == null) {
                        node.lowLink = Math.min(node.lowLink, dfs(fieldDescriptor.getMessageType()).lowLink);
                    } else if (node2.component == null) {
                        node.lowLink = Math.min(node.lowLink, node2.lowLink);
                    }
                }
            }
            if (node.index == node.lowLink) {
                StronglyConnectedComponent stronglyConnectedComponent2 = new StronglyConnectedComponent(null);
                do {
                    pop = this.stack.pop();
                    pop.component = stronglyConnectedComponent2;
                    stronglyConnectedComponent2.messages.add(pop.descriptor);
                } while (pop != node);
                Iterator<Descriptors.Descriptor> it = stronglyConnectedComponent2.messages.iterator();
                loop2:
                while (true) {
                    z = false;
                    if (!it.hasNext()) {
                        break;
                    }
                    Descriptors.Descriptor next = it.next();
                    if (next.proto.getExtensionRangeList().size() != 0) {
                        z = true;
                    }
                    if (z) {
                        break;
                    }
                    Iterator<Descriptors.FieldDescriptor> it2 = next.getFields().iterator();
                    while (true) {
                        if (it2.hasNext()) {
                            Descriptors.FieldDescriptor next2 = it2.next();
                            if (next2.isRequired() || (next2.getJavaType() == Descriptors.FieldDescriptor.JavaType.MESSAGE && (stronglyConnectedComponent = this.nodeCache.get(next2.getMessageType()).component) != stronglyConnectedComponent2 && stronglyConnectedComponent.needsIsInitializedCheck)) {
                                break loop2;
                            }
                        }
                    }
                }
                z = true;
                stronglyConnectedComponent2.needsIsInitializedCheck = z;
                for (Descriptors.Descriptor descriptor2 : stronglyConnectedComponent2.messages) {
                    this.resultCache.put(descriptor2, Boolean.valueOf(stronglyConnectedComponent2.needsIsInitializedCheck));
                }
            }
            return node;
        }
    }

    public final class OneofState {
        public OneofInfo[] oneofs = new OneofInfo[2];

        public OneofState(AnonymousClass1 r1) {
        }
    }

    public static FieldInfo buildOneofMember(Class<?> cls, Descriptors.FieldDescriptor fieldDescriptor, OneofState oneofState, boolean z, Internal.EnumVerifier enumVerifier) {
        OneofInfo oneofInfo;
        Class<?> cls2;
        Descriptors.OneofDescriptor oneofDescriptor = fieldDescriptor.containingOneof;
        int i = oneofDescriptor.index;
        OneofInfo[] oneofInfoArr = oneofState.oneofs;
        if (i >= oneofInfoArr.length) {
            oneofState.oneofs = (OneofInfo[]) Arrays.copyOf(oneofInfoArr, i * 2);
        }
        OneofInfo oneofInfo2 = oneofState.oneofs[i];
        if (oneofInfo2 == null) {
            String snakeCaseToCamelCase = snakeCaseToCamelCase(oneofDescriptor.proto.getName());
            OneofInfo oneofInfo3 = new OneofInfo(oneofDescriptor.index, field(cls, String.valueOf(snakeCaseToCamelCase).concat("Case_")), field(cls, String.valueOf(snakeCaseToCamelCase).concat("_")));
            oneofState.oneofs[i] = oneofInfo3;
            oneofInfo = oneofInfo3;
        } else {
            oneofInfo = oneofInfo2;
        }
        FieldType fieldType = getFieldType(fieldDescriptor);
        switch (fieldType.getJavaType().ordinal()) {
            case 1:
            case 8:
                cls2 = Integer.class;
                break;
            case 2:
                cls2 = Long.class;
                break;
            case 3:
                cls2 = Float.class;
                break;
            case 4:
                cls2 = Double.class;
                break;
            case 5:
                cls2 = Boolean.class;
                break;
            case 6:
                cls2 = String.class;
                break;
            case 7:
                cls2 = ByteString.class;
                break;
            case 9:
                try {
                    cls2 = cls.getDeclaredMethod(getterForField(fieldDescriptor.type == Descriptors.FieldDescriptor.Type.GROUP ? fieldDescriptor.getMessageType().getName() : fieldDescriptor.getName()), new Class[0]).getReturnType();
                    break;
                } catch (Exception e) {
                    throw new RuntimeException(e);
                }
            default:
                String valueOf = String.valueOf(fieldType);
                StringBuilder sb = new StringBuilder(valueOf.length() + 24);
                sb.append("Invalid type for oneof: ");
                sb.append(valueOf);
                throw new IllegalArgumentException(sb.toString());
        }
        int number = fieldDescriptor.getNumber();
        FieldInfo.checkFieldNumber(number);
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(cls2, "oneofStoredType");
        if (fieldType.isScalar()) {
            return new FieldInfo(null, number, fieldType, null, null, 0, false, z, oneofInfo, cls2, null, enumVerifier, null);
        }
        String valueOf2 = String.valueOf(fieldType);
        StringBuilder sb2 = new StringBuilder(valueOf2.length() + 72);
        sb2.append("Oneof is only supported for scalar fields. Field ");
        sb2.append(number);
        sb2.append(" is of type ");
        sb2.append(valueOf2);
        throw new IllegalArgumentException(sb2.toString());
    }

    public static Field cachedSizeField(Class<?> cls, Descriptors.FieldDescriptor fieldDescriptor) {
        return field(cls, String.valueOf(snakeCaseToCamelCase(fieldDescriptor.getName())).concat("MemoizedSerializedSize"));
    }

    public static Field field(Class<?> cls, String str) {
        try {
            return cls.getDeclaredField(str);
        } catch (Exception unused) {
            String name = cls.getName();
            StringBuilder sb = new StringBuilder(name.length() + String.valueOf(str).length() + 39);
            sb.append("Unable to find field ");
            sb.append(str);
            sb.append(" in message class ");
            sb.append(name);
            throw new IllegalArgumentException(sb.toString());
        }
    }

    public static Message getDefaultInstance(Class<?> cls) {
        try {
            return (Message) cls.getDeclaredMethod("getDefaultInstance", new Class[0]).invoke(null, new Object[0]);
        } catch (Exception e) {
            String name = cls.getName();
            throw new IllegalArgumentException(name.length() != 0 ? "Unable to get default instance for message class ".concat(name) : new String("Unable to get default instance for message class "), e);
        }
    }

    public static FieldType getFieldType(Descriptors.FieldDescriptor fieldDescriptor) {
        switch (fieldDescriptor.type.ordinal()) {
            case 0:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.DOUBLE;
                }
                return fieldDescriptor.isPacked() ? FieldType.DOUBLE_LIST_PACKED : FieldType.DOUBLE_LIST;
            case 1:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.FLOAT;
                }
                return fieldDescriptor.isPacked() ? FieldType.FLOAT_LIST_PACKED : FieldType.FLOAT_LIST;
            case 2:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.INT64;
                }
                return fieldDescriptor.isPacked() ? FieldType.INT64_LIST_PACKED : FieldType.INT64_LIST;
            case 3:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.UINT64;
                }
                return fieldDescriptor.isPacked() ? FieldType.UINT64_LIST_PACKED : FieldType.UINT64_LIST;
            case 4:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.INT32;
                }
                return fieldDescriptor.isPacked() ? FieldType.INT32_LIST_PACKED : FieldType.INT32_LIST;
            case 5:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.FIXED64;
                }
                return fieldDescriptor.isPacked() ? FieldType.FIXED64_LIST_PACKED : FieldType.FIXED64_LIST;
            case 6:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.FIXED32;
                }
                return fieldDescriptor.isPacked() ? FieldType.FIXED32_LIST_PACKED : FieldType.FIXED32_LIST;
            case 7:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.BOOL;
                }
                return fieldDescriptor.isPacked() ? FieldType.BOOL_LIST_PACKED : FieldType.BOOL_LIST;
            case 8:
                return fieldDescriptor.isRepeated() ? FieldType.STRING_LIST : FieldType.STRING;
            case 9:
                return fieldDescriptor.isRepeated() ? FieldType.GROUP_LIST : FieldType.GROUP;
            case 10:
                if (fieldDescriptor.isMapField()) {
                    return FieldType.MAP;
                }
                return fieldDescriptor.isRepeated() ? FieldType.MESSAGE_LIST : FieldType.MESSAGE;
            case 11:
                return fieldDescriptor.isRepeated() ? FieldType.BYTES_LIST : FieldType.BYTES;
            case 12:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.UINT32;
                }
                return fieldDescriptor.isPacked() ? FieldType.UINT32_LIST_PACKED : FieldType.UINT32_LIST;
            case 13:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.ENUM;
                }
                return fieldDescriptor.isPacked() ? FieldType.ENUM_LIST_PACKED : FieldType.ENUM_LIST;
            case 14:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.SFIXED32;
                }
                return fieldDescriptor.isPacked() ? FieldType.SFIXED32_LIST_PACKED : FieldType.SFIXED32_LIST;
            case 15:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.SFIXED64;
                }
                return fieldDescriptor.isPacked() ? FieldType.SFIXED64_LIST_PACKED : FieldType.SFIXED64_LIST;
            case 16:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.SINT32;
                }
                return fieldDescriptor.isPacked() ? FieldType.SINT32_LIST_PACKED : FieldType.SINT32_LIST;
            case 17:
                if (!fieldDescriptor.isRepeated()) {
                    return FieldType.SINT64;
                }
                return fieldDescriptor.isPacked() ? FieldType.SINT64_LIST_PACKED : FieldType.SINT64_LIST;
            default:
                String valueOf = String.valueOf(fieldDescriptor.type);
                StringBuilder sb = new StringBuilder(valueOf.length() + 24);
                sb.append("Unsupported field type: ");
                sb.append(valueOf);
                throw new IllegalArgumentException(sb.toString());
        }
    }

    public static Class<?> getTypeForRepeatedMessageField(Class<?> cls, Descriptors.FieldDescriptor fieldDescriptor) {
        try {
            return cls.getDeclaredMethod(getterForField(fieldDescriptor.type == Descriptors.FieldDescriptor.Type.GROUP ? fieldDescriptor.getMessageType().getName() : fieldDescriptor.getName()), Integer.TYPE).getReturnType();
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
    }

    public static String getterForField(String str) {
        String snakeCaseToCamelCase = snakeCaseToCamelCase(str);
        return "get" + Character.toUpperCase(snakeCaseToCamelCase.charAt(0)) + snakeCaseToCamelCase.substring(1, snakeCaseToCamelCase.length());
    }

    public static String snakeCaseToCamelCase(String str) {
        StringBuilder sb = new StringBuilder(str.length() + 1);
        boolean z = false;
        for (int i = 0; i < str.length(); i++) {
            char charAt = str.charAt(i);
            if (charAt != '_') {
                if (Character.isDigit(charAt)) {
                    sb.append(charAt);
                } else {
                    if (z) {
                        sb.append(Character.toUpperCase(charAt));
                        z = false;
                    } else if (i == 0) {
                        sb.append(Character.toLowerCase(charAt));
                    } else {
                        sb.append(charAt);
                    }
                }
            }
            z = true;
        }
        return sb.toString();
    }

    @Override // com.google.protobuf.MessageInfoFactory
    public boolean isSupported(Class<?> cls) {
        return GeneratedMessageV3.class.isAssignableFrom(cls);
    }

    @Override // com.google.protobuf.MessageInfoFactory
    public MessageInfo messageInfoFor(Class<?> cls) {
        boolean z;
        int i;
        Field field;
        if (!GeneratedMessageV3.class.isAssignableFrom(cls)) {
            String name = cls.getName();
            throw new IllegalArgumentException(name.length() != 0 ? "Unsupported message type: ".concat(name) : new String("Unsupported message type: "));
        }
        Descriptors.Descriptor descriptorForType = getDefaultInstance(cls).getDescriptorForType();
        int ordinal = descriptorForType.file.getSyntax().ordinal();
        int i2 = 2;
        if (ordinal == 1) {
            List<Descriptors.FieldDescriptor> fields = descriptorForType.getFields();
            StructuralMessageInfo.Builder builder = new StructuralMessageInfo.Builder(fields.size());
            builder.defaultInstance = getDefaultInstance(cls);
            ProtoSyntax protoSyntax = ProtoSyntax.PROTO2;
            Charset charset = Internal.UTF_8;
            Objects.requireNonNull(protoSyntax, "syntax");
            builder.syntax = protoSyntax;
            builder.messageSetWireFormat = descriptorForType.getOptions().getMessageSetWireFormat();
            OneofState oneofState = new OneofState(null);
            Field field2 = null;
            int i3 = 0;
            int i4 = 0;
            int i5 = 1;
            while (i3 < fields.size()) {
                final Descriptors.FieldDescriptor fieldDescriptor = fields.get(i3);
                boolean javaStringCheckUtf8 = fieldDescriptor.file.proto.getOptions().getJavaStringCheckUtf8();
                Descriptors.FieldDescriptor.JavaType javaType = fieldDescriptor.getJavaType();
                Descriptors.FieldDescriptor.JavaType javaType2 = Descriptors.FieldDescriptor.JavaType.ENUM;
                Internal.EnumVerifier r13 = javaType == javaType2 ? new Internal.EnumVerifier() {
                    /* class com.google.protobuf.DescriptorMessageInfoFactory.AnonymousClass1 */

                    @Override // com.google.protobuf.Internal.EnumVerifier
                    public boolean isInRange(int i) {
                        return Descriptors.FieldDescriptor.this.getEnumType().findValueByNumber(i) != null;
                    }
                } : null;
                if (fieldDescriptor.containingOneof != null) {
                    builder.withField(buildOneofMember(cls, fieldDescriptor, oneofState, javaStringCheckUtf8, r13));
                    i = i5;
                } else {
                    Field field3 = field(cls, fieldDescriptor);
                    int number = fieldDescriptor.getNumber();
                    FieldType fieldType = getFieldType(fieldDescriptor);
                    if (fieldDescriptor.isMapField()) {
                        final Descriptors.FieldDescriptor findFieldByNumber = fieldDescriptor.getMessageType().findFieldByNumber(i2);
                        if (findFieldByNumber.getJavaType() == javaType2) {
                            r13 = new Internal.EnumVerifier() {
                                /* class com.google.protobuf.DescriptorMessageInfoFactory.AnonymousClass2 */

                                @Override // com.google.protobuf.Internal.EnumVerifier
                                public boolean isInRange(int i) {
                                    return Descriptors.FieldDescriptor.this.getEnumType().findValueByNumber(i) != null;
                                }
                            };
                        }
                        builder.withField(FieldInfo.forMapField(field3, number, SchemaUtil.getMapDefaultEntry(cls, fieldDescriptor.getName()), r13));
                    } else if (!fieldDescriptor.isRepeated()) {
                        if (field2 == null) {
                            StringBuilder sb = new StringBuilder(20);
                            sb.append("bitField");
                            sb.append(i4);
                            sb.append("_");
                            field = field(cls, sb.toString());
                        } else {
                            field = field2;
                        }
                        if (fieldDescriptor.isRequired()) {
                            FieldInfo.checkFieldNumber(number);
                            Charset charset2 = Internal.UTF_8;
                            Objects.requireNonNull(field3, "field");
                            Objects.requireNonNull(fieldType, "fieldType");
                            Objects.requireNonNull(field, "presenceField");
                            if (i5 != 0 && ((i5 + -1) & i5) == 0) {
                                builder.withField(new FieldInfo(field3, number, fieldType, null, field, i5, true, javaStringCheckUtf8, null, null, null, r13, null));
                                i = i5;
                            } else {
                                StringBuilder sb2 = new StringBuilder(55);
                                sb2.append("presenceMask must have exactly one bit set: ");
                                sb2.append(i5);
                                throw new IllegalArgumentException(sb2.toString());
                            }
                        } else {
                            i = i5;
                            FieldInfo.checkFieldNumber(number);
                            Charset charset3 = Internal.UTF_8;
                            Objects.requireNonNull(field3, "field");
                            Objects.requireNonNull(fieldType, "fieldType");
                            Objects.requireNonNull(field, "presenceField");
                            if (i != 0 && ((i + -1) & i) == 0) {
                                builder.withField(new FieldInfo(field3, number, fieldType, null, field, i, false, javaStringCheckUtf8, null, null, null, r13, null));
                            } else {
                                StringBuilder sb3 = new StringBuilder(55);
                                sb3.append("presenceMask must have exactly one bit set: ");
                                sb3.append(i);
                                throw new IllegalArgumentException(sb3.toString());
                            }
                        }
                        field2 = field;
                    } else if (r13 != null) {
                        if (fieldDescriptor.isPacked()) {
                            Field cachedSizeField = cachedSizeField(cls, fieldDescriptor);
                            FieldInfo.checkFieldNumber(number);
                            Charset charset4 = Internal.UTF_8;
                            Objects.requireNonNull(field3, "field");
                            builder.withField(new FieldInfo(field3, number, fieldType, null, null, 0, false, false, null, null, null, r13, cachedSizeField));
                        } else {
                            FieldInfo.checkFieldNumber(number);
                            Charset charset5 = Internal.UTF_8;
                            Objects.requireNonNull(field3, "field");
                            builder.withField(new FieldInfo(field3, number, fieldType, null, null, 0, false, false, null, null, null, r13, null));
                        }
                    } else if (fieldDescriptor.getJavaType() == Descriptors.FieldDescriptor.JavaType.MESSAGE) {
                        builder.withField(FieldInfo.forRepeatedMessageField(field3, number, fieldType, getTypeForRepeatedMessageField(cls, fieldDescriptor)));
                    } else if (fieldDescriptor.isPacked()) {
                        builder.withField(FieldInfo.forPackedField(field3, number, fieldType, cachedSizeField(cls, fieldDescriptor)));
                    } else {
                        builder.withField(FieldInfo.forField(field3, number, fieldType, javaStringCheckUtf8));
                    }
                    i3++;
                    i2 = 2;
                }
                i5 = i << 1;
                if (i5 == 0) {
                    i4++;
                    field2 = null;
                    i5 = 1;
                }
                i3++;
                i2 = 2;
            }
            ArrayList arrayList = new ArrayList();
            for (int i6 = 0; i6 < fields.size(); i6++) {
                Descriptors.FieldDescriptor fieldDescriptor2 = fields.get(i6);
                if (!fieldDescriptor2.isRequired()) {
                    if (fieldDescriptor2.getJavaType() == Descriptors.FieldDescriptor.JavaType.MESSAGE) {
                        Descriptors.Descriptor messageType = fieldDescriptor2.getMessageType();
                        IsInitializedCheckAnalyzer isInitializedCheckAnalyzer2 = isInitializedCheckAnalyzer;
                        Boolean bool = isInitializedCheckAnalyzer2.resultCache.get(messageType);
                        if (bool != null) {
                            z = bool.booleanValue();
                        } else {
                            synchronized (isInitializedCheckAnalyzer2) {
                                Boolean bool2 = isInitializedCheckAnalyzer2.resultCache.get(messageType);
                                if (bool2 != null) {
                                    z = bool2.booleanValue();
                                } else {
                                    z = isInitializedCheckAnalyzer2.dfs(messageType).component.needsIsInitializedCheck;
                                }
                            }
                        }
                        if (z) {
                        }
                    } else {
                        continue;
                    }
                }
                arrayList.add(Integer.valueOf(fieldDescriptor2.getNumber()));
            }
            int[] iArr = new int[arrayList.size()];
            for (int i7 = 0; i7 < arrayList.size(); i7++) {
                iArr[i7] = ((Integer) arrayList.get(i7)).intValue();
            }
            builder.checkInitialized = iArr;
            return builder.build();
        } else if (ordinal == 2) {
            List<Descriptors.FieldDescriptor> fields2 = descriptorForType.getFields();
            StructuralMessageInfo.Builder builder2 = new StructuralMessageInfo.Builder(fields2.size());
            builder2.defaultInstance = getDefaultInstance(cls);
            ProtoSyntax protoSyntax2 = ProtoSyntax.PROTO3;
            Charset charset6 = Internal.UTF_8;
            Objects.requireNonNull(protoSyntax2, "syntax");
            builder2.syntax = protoSyntax2;
            OneofState oneofState2 = new OneofState(null);
            for (int i8 = 0; i8 < fields2.size(); i8++) {
                Descriptors.FieldDescriptor fieldDescriptor3 = fields2.get(i8);
                if (fieldDescriptor3.containingOneof != null) {
                    builder2.withField(buildOneofMember(cls, fieldDescriptor3, oneofState2, true, null));
                } else if (fieldDescriptor3.isMapField()) {
                    builder2.withField(FieldInfo.forMapField(field(cls, fieldDescriptor3), fieldDescriptor3.getNumber(), SchemaUtil.getMapDefaultEntry(cls, fieldDescriptor3.getName()), null));
                } else if (fieldDescriptor3.isRepeated() && fieldDescriptor3.getJavaType() == Descriptors.FieldDescriptor.JavaType.MESSAGE) {
                    builder2.withField(FieldInfo.forRepeatedMessageField(field(cls, fieldDescriptor3), fieldDescriptor3.getNumber(), getFieldType(fieldDescriptor3), getTypeForRepeatedMessageField(cls, fieldDescriptor3)));
                } else if (fieldDescriptor3.isPacked()) {
                    builder2.withField(FieldInfo.forPackedField(field(cls, fieldDescriptor3), fieldDescriptor3.getNumber(), getFieldType(fieldDescriptor3), cachedSizeField(cls, fieldDescriptor3)));
                } else {
                    builder2.withField(FieldInfo.forField(field(cls, fieldDescriptor3), fieldDescriptor3.getNumber(), getFieldType(fieldDescriptor3), true));
                }
            }
            return builder2.build();
        } else {
            String valueOf = String.valueOf(descriptorForType.file.getSyntax());
            StringBuilder sb4 = new StringBuilder(valueOf.length() + 20);
            sb4.append("Unsupported syntax: ");
            sb4.append(valueOf);
            throw new IllegalArgumentException(sb4.toString());
        }
    }

    public static Field field(Class<?> cls, Descriptors.FieldDescriptor fieldDescriptor) {
        String str;
        if (fieldDescriptor.type == Descriptors.FieldDescriptor.Type.GROUP) {
            str = fieldDescriptor.getMessageType().getName();
        } else {
            str = fieldDescriptor.getName();
        }
        String str2 = specialFieldNames.contains(str) ? "__" : "_";
        String valueOf = String.valueOf(snakeCaseToCamelCase(str));
        return field(cls, str2.length() != 0 ? valueOf.concat(str2) : new String(valueOf));
    }
}
