package com.google.protobuf;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.protobuf.DescriptorProtos;
import com.google.protobuf.FieldSet;
import com.google.protobuf.Internal;
import com.google.protobuf.Message;
import com.google.protobuf.MessageLite;
import com.google.protobuf.TextFormat;
import com.google.protobuf.WireFormat;
import io.netty.handler.codec.compression.FastLz;
import io.netty.util.internal.StringUtil;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.WeakHashMap;
import java.util.logging.Logger;

public abstract class Descriptors {
    public static final Logger logger = Logger.getLogger(Descriptors.class.getName());

    public final class DescriptorPool {
        public boolean allowUnknownDependencies;
        public final Set<FileDescriptor> dependencies = new HashSet();
        public final Map<String, GenericDescriptor> descriptorsByName = new HashMap();
        public final Map<DescriptorIntPair, EnumValueDescriptor> enumValuesByNumber = new HashMap();
        public final Map<DescriptorIntPair, FieldDescriptor> fieldsByNumber = new HashMap();

        public final class DescriptorIntPair {
            public final GenericDescriptor descriptor;
            public final int number;

            public DescriptorIntPair(GenericDescriptor genericDescriptor, int i) {
                this.descriptor = genericDescriptor;
                this.number = i;
            }

            public boolean equals(Object obj) {
                if (!(obj instanceof DescriptorIntPair)) {
                    return false;
                }
                DescriptorIntPair descriptorIntPair = (DescriptorIntPair) obj;
                if (this.descriptor == descriptorIntPair.descriptor && this.number == descriptorIntPair.number) {
                    return true;
                }
                return false;
            }

            public int hashCode() {
                return (this.descriptor.hashCode() * FastLz.MAX_CHUNK_LENGTH) + this.number;
            }
        }

        public final class PackageDescriptor extends GenericDescriptor {
            public final FileDescriptor file;
            public final String fullName;
            public final String name;

            public PackageDescriptor(String str, String str2, FileDescriptor fileDescriptor) {
                super(null);
                this.file = fileDescriptor;
                this.fullName = str2;
                this.name = str;
            }

            @Override // com.google.protobuf.Descriptors.GenericDescriptor
            public FileDescriptor getFile() {
                return this.file;
            }

            @Override // com.google.protobuf.Descriptors.GenericDescriptor
            public String getFullName() {
                return this.fullName;
            }

            @Override // com.google.protobuf.Descriptors.GenericDescriptor
            public String getName() {
                return this.name;
            }

            @Override // com.google.protobuf.Descriptors.GenericDescriptor
            public Message toProto() {
                return this.file.proto;
            }
        }

        public enum SearchFilter {
            TYPES_ONLY,
            AGGREGATES_ONLY,
            ALL_SYMBOLS
        }

        public DescriptorPool(FileDescriptor[] fileDescriptorArr, boolean z) {
            this.allowUnknownDependencies = z;
            for (int i = 0; i < fileDescriptorArr.length; i++) {
                this.dependencies.add(fileDescriptorArr[i]);
                importPublicDependencies(fileDescriptorArr[i]);
            }
            for (FileDescriptor fileDescriptor : this.dependencies) {
                try {
                    addPackage(fileDescriptor.getPackage(), fileDescriptor);
                } catch (DescriptorValidationException e) {
                    throw new AssertionError(e);
                }
            }
        }

        public void addPackage(String str, FileDescriptor fileDescriptor) {
            String str2;
            int lastIndexOf = str.lastIndexOf(46);
            if (lastIndexOf == -1) {
                str2 = str;
            } else {
                addPackage(str.substring(0, lastIndexOf), fileDescriptor);
                str2 = str.substring(lastIndexOf + 1);
            }
            GenericDescriptor put = this.descriptorsByName.put(str, new PackageDescriptor(str2, str, fileDescriptor));
            if (put != null) {
                this.descriptorsByName.put(str, put);
                if (!(put instanceof PackageDescriptor)) {
                    String name = put.getFile().getName();
                    StringBuilder sb = new StringBuilder(String.valueOf(name).length() + String.valueOf(str2).length() + 69);
                    sb.append(StringUtil.DOUBLE_QUOTE);
                    sb.append(str2);
                    sb.append("\" is already defined (as something other than a package) in file \"");
                    sb.append(name);
                    sb.append("\".");
                    throw new DescriptorValidationException(fileDescriptor, sb.toString(), (AnonymousClass1) null);
                }
            }
        }

        public void addSymbol(GenericDescriptor genericDescriptor) {
            String name = genericDescriptor.getName();
            if (name.length() != 0) {
                for (int i = 0; i < name.length(); i++) {
                    char charAt = name.charAt(i);
                    if (('a' > charAt || charAt > 'z') && (('A' > charAt || charAt > 'Z') && charAt != '_' && ('0' > charAt || charAt > '9' || i <= 0))) {
                        throw new DescriptorValidationException(genericDescriptor, GeneratedOutlineSupport.outline6(name.length() + 29, StringUtil.DOUBLE_QUOTE, name, "\" is not a valid identifier."));
                    }
                }
                String fullName = genericDescriptor.getFullName();
                GenericDescriptor put = this.descriptorsByName.put(fullName, genericDescriptor);
                if (put != null) {
                    this.descriptorsByName.put(fullName, put);
                    if (genericDescriptor.getFile() == put.getFile()) {
                        int lastIndexOf = fullName.lastIndexOf(46);
                        if (lastIndexOf == -1) {
                            throw new DescriptorValidationException(genericDescriptor, GeneratedOutlineSupport.outline6(fullName.length() + 22, StringUtil.DOUBLE_QUOTE, fullName, "\" is already defined."));
                        }
                        String substring = fullName.substring(lastIndexOf + 1);
                        String substring2 = fullName.substring(0, lastIndexOf);
                        StringBuilder sb = new StringBuilder(GeneratedOutlineSupport.outline3(substring2, GeneratedOutlineSupport.outline3(substring, 28)));
                        sb.append(StringUtil.DOUBLE_QUOTE);
                        sb.append(substring);
                        sb.append("\" is already defined in \"");
                        sb.append(substring2);
                        sb.append("\".");
                        throw new DescriptorValidationException(genericDescriptor, sb.toString());
                    }
                    String name2 = put.getFile().getName();
                    StringBuilder sb2 = new StringBuilder(GeneratedOutlineSupport.outline3(name2, GeneratedOutlineSupport.outline3(fullName, 33)));
                    sb2.append(StringUtil.DOUBLE_QUOTE);
                    sb2.append(fullName);
                    sb2.append("\" is already defined in file \"");
                    sb2.append(name2);
                    sb2.append("\".");
                    throw new DescriptorValidationException(genericDescriptor, sb2.toString());
                }
                return;
            }
            throw new DescriptorValidationException(genericDescriptor, "Missing name.");
        }

        public GenericDescriptor findSymbol(String str) {
            return findSymbol(str, SearchFilter.ALL_SYMBOLS);
        }

        public final void importPublicDependencies(FileDescriptor fileDescriptor) {
            for (FileDescriptor fileDescriptor2 : Collections.unmodifiableList(Arrays.asList(fileDescriptor.publicDependencies))) {
                if (this.dependencies.add(fileDescriptor2)) {
                    importPublicDependencies(fileDescriptor2);
                }
            }
        }

        public boolean isAggregate(GenericDescriptor genericDescriptor) {
            return (genericDescriptor instanceof Descriptor) || (genericDescriptor instanceof EnumDescriptor) || (genericDescriptor instanceof PackageDescriptor) || (genericDescriptor instanceof ServiceDescriptor);
        }

        public GenericDescriptor lookupSymbol(String str, GenericDescriptor genericDescriptor, SearchFilter searchFilter) {
            GenericDescriptor genericDescriptor2;
            String str2;
            String str3;
            if (str.startsWith(".")) {
                str2 = str.substring(1);
                genericDescriptor2 = findSymbol(str2, searchFilter);
            } else {
                int indexOf = str.indexOf(46);
                if (indexOf == -1) {
                    str3 = str;
                } else {
                    str3 = str.substring(0, indexOf);
                }
                StringBuilder sb = new StringBuilder(genericDescriptor.getFullName());
                while (true) {
                    int lastIndexOf = sb.lastIndexOf(".");
                    if (lastIndexOf == -1) {
                        genericDescriptor2 = findSymbol(str, searchFilter);
                        str2 = str;
                        break;
                    }
                    int i = lastIndexOf + 1;
                    sb.setLength(i);
                    sb.append(str3);
                    GenericDescriptor findSymbol = findSymbol(sb.toString(), SearchFilter.AGGREGATES_ONLY);
                    if (findSymbol != null) {
                        if (indexOf != -1) {
                            sb.setLength(i);
                            sb.append(str);
                            genericDescriptor2 = findSymbol(sb.toString(), searchFilter);
                        } else {
                            genericDescriptor2 = findSymbol;
                        }
                        str2 = sb.toString();
                    } else {
                        sb.setLength(lastIndexOf);
                    }
                }
            }
            if (genericDescriptor2 != null) {
                return genericDescriptor2;
            }
            if (!this.allowUnknownDependencies || searchFilter != SearchFilter.TYPES_ONLY) {
                throw new DescriptorValidationException(genericDescriptor, GeneratedOutlineSupport.outline6(str.length() + 18, StringUtil.DOUBLE_QUOTE, str, "\" is not defined."));
            }
            Logger logger = Descriptors.logger;
            StringBuilder sb2 = new StringBuilder(str.length() + 87);
            sb2.append("The descriptor for message type \"");
            sb2.append(str);
            sb2.append("\" can not be found and a placeholder is created for it");
            logger.warning(sb2.toString());
            Descriptor descriptor = new Descriptor(str2);
            this.dependencies.add(descriptor.file);
            return descriptor;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:12:0x0020, code lost:
            if (((r0 instanceof com.google.protobuf.Descriptors.Descriptor) || (r0 instanceof com.google.protobuf.Descriptors.EnumDescriptor)) == false) goto L_0x0022;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:16:0x002a, code lost:
            if (isAggregate(r0) != false) goto L_0x002c;
         */
        public GenericDescriptor findSymbol(String str, SearchFilter searchFilter) {
            GenericDescriptor genericDescriptor = this.descriptorsByName.get(str);
            if (genericDescriptor != null) {
                if (searchFilter != SearchFilter.ALL_SYMBOLS) {
                    if (searchFilter == SearchFilter.TYPES_ONLY) {
                    }
                    if (searchFilter == SearchFilter.AGGREGATES_ONLY) {
                    }
                }
                return genericDescriptor;
            }
            for (FileDescriptor fileDescriptor : this.dependencies) {
                GenericDescriptor genericDescriptor2 = fileDescriptor.pool.descriptorsByName.get(str);
                if (genericDescriptor2 != null) {
                    if (searchFilter != SearchFilter.ALL_SYMBOLS) {
                        if (searchFilter == SearchFilter.TYPES_ONLY) {
                            if ((genericDescriptor2 instanceof Descriptor) || (genericDescriptor2 instanceof EnumDescriptor)) {
                            }
                        }
                        if (searchFilter == SearchFilter.AGGREGATES_ONLY && isAggregate(genericDescriptor2)) {
                        }
                    }
                    return genericDescriptor2;
                }
            }
            return null;
        }
    }

    public class DescriptorValidationException extends Exception {
        private static final long serialVersionUID = 5750205775490483148L;
        private final String description;
        private final String name;
        private final Message proto;

        public String getDescription() {
            return this.description;
        }

        public Message getProblemProto() {
            return this.proto;
        }

        public String getProblemSymbolName() {
            return this.name;
        }

        /* JADX WARNING: Illegal instructions before constructor call */
        public DescriptorValidationException(GenericDescriptor genericDescriptor, String str) {
            super(GeneratedOutlineSupport.outline7(GeneratedOutlineSupport.outline3(str, GeneratedOutlineSupport.outline3(r0, 2)), r0, ": ", str));
            String fullName = genericDescriptor.getFullName();
            this.name = genericDescriptor.getFullName();
            this.proto = genericDescriptor.toProto();
            this.description = str;
        }

        public DescriptorValidationException(GenericDescriptor genericDescriptor, String str, Throwable th, AnonymousClass1 r4) {
            this(genericDescriptor, str);
            initCause(th);
        }

        /* JADX WARNING: Illegal instructions before constructor call */
        public DescriptorValidationException(FileDescriptor fileDescriptor, String str, AnonymousClass1 r5) {
            super(GeneratedOutlineSupport.outline7(GeneratedOutlineSupport.outline3(str, GeneratedOutlineSupport.outline3(r5, 2)), r5, ": ", str));
            String name2 = fileDescriptor.getName();
            this.name = fileDescriptor.getName();
            this.proto = fileDescriptor.proto;
            this.description = str;
        }
    }

    public static final class EnumDescriptor extends GenericDescriptor implements Internal.EnumLiteMap<EnumValueDescriptor> {
        public final FileDescriptor file;
        public final String fullName;
        public DescriptorProtos.EnumDescriptorProto proto;
        public final WeakHashMap<Integer, WeakReference<EnumValueDescriptor>> unknownValues = new WeakHashMap<>();
        public EnumValueDescriptor[] values;

        public EnumDescriptor(DescriptorProtos.EnumDescriptorProto enumDescriptorProto, FileDescriptor fileDescriptor, Descriptor descriptor, int i, AnonymousClass1 r11) {
            super(null);
            this.proto = enumDescriptorProto;
            this.fullName = Descriptors.access$1700(fileDescriptor, descriptor, enumDescriptorProto.getName());
            this.file = fileDescriptor;
            if (enumDescriptorProto.getValueCount() != 0) {
                this.values = new EnumValueDescriptor[enumDescriptorProto.getValueCount()];
                for (int i2 = 0; i2 < enumDescriptorProto.getValueCount(); i2++) {
                    this.values[i2] = new EnumValueDescriptor(enumDescriptorProto.getValue(i2), fileDescriptor, this, i2, null);
                }
                fileDescriptor.pool.addSymbol(this);
                return;
            }
            throw new DescriptorValidationException(this, "Enums must contain at least one value.");
        }

        public EnumValueDescriptor findValueByName(String str) {
            DescriptorPool descriptorPool = this.file.pool;
            String str2 = this.fullName;
            StringBuilder sb = new StringBuilder(String.valueOf(str).length() + String.valueOf(str2).length() + 1);
            sb.append(str2);
            sb.append('.');
            sb.append(str);
            GenericDescriptor findSymbol = descriptorPool.findSymbol(sb.toString());
            if (findSymbol == null || !(findSymbol instanceof EnumValueDescriptor)) {
                return null;
            }
            return (EnumValueDescriptor) findSymbol;
        }

        public EnumValueDescriptor findValueByNumber(int i) {
            return this.file.pool.enumValuesByNumber.get(new DescriptorPool.DescriptorIntPair(this, i));
        }

        public EnumValueDescriptor findValueByNumberCreatingIfUnknown(int i) {
            EnumValueDescriptor findValueByNumber = findValueByNumber(i);
            if (findValueByNumber != null) {
                return findValueByNumber;
            }
            synchronized (this) {
                Integer num = new Integer(i);
                WeakReference<EnumValueDescriptor> weakReference = this.unknownValues.get(num);
                if (weakReference != null) {
                    findValueByNumber = weakReference.get();
                }
                if (findValueByNumber == null) {
                    findValueByNumber = new EnumValueDescriptor(this.file, this, num, null);
                    this.unknownValues.put(num, new WeakReference<>(findValueByNumber));
                }
            }
            return findValueByNumber;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        public List<EnumValueDescriptor> getValues() {
            return Collections.unmodifiableList(Arrays.asList(this.values));
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }
    }

    public static final class FieldDescriptor extends GenericDescriptor implements Comparable<FieldDescriptor>, FieldSet.FieldDescriptorLite<FieldDescriptor> {
        public static final WireFormat.FieldType[] table = WireFormat.FieldType.values();
        public OneofDescriptor containingOneof;
        public Descriptor containingType;
        public Object defaultValue;
        public EnumDescriptor enumType;
        public final Descriptor extensionScope;
        public final FileDescriptor file;
        public final String fullName;
        public final int index;
        public final boolean isProto3Optional;
        public Descriptor messageType;
        public DescriptorProtos.FieldDescriptorProto proto;
        public Type type;

        public enum JavaType {
            INT(0),
            LONG(0L),
            FLOAT(Float.valueOf(0.0f)),
            DOUBLE(Double.valueOf(0.0d)),
            BOOLEAN(Boolean.FALSE),
            STRING(""),
            BYTE_STRING(ByteString.EMPTY),
            ENUM(null),
            MESSAGE(null);
            
            private final Object defaultDefault;

            /* access modifiers changed from: public */
            JavaType(Object obj) {
                this.defaultDefault = obj;
            }
        }

        /* JADX WARN: Init of enum INT64 can be incorrect */
        /* JADX WARN: Init of enum UINT64 can be incorrect */
        /* JADX WARN: Init of enum INT32 can be incorrect */
        /* JADX WARN: Init of enum FIXED64 can be incorrect */
        /* JADX WARN: Init of enum FIXED32 can be incorrect */
        /* JADX WARN: Init of enum GROUP can be incorrect */
        /* JADX WARN: Init of enum MESSAGE can be incorrect */
        /* JADX WARN: Init of enum UINT32 can be incorrect */
        /* JADX WARN: Init of enum SFIXED32 can be incorrect */
        /* JADX WARN: Init of enum SFIXED64 can be incorrect */
        /* JADX WARN: Init of enum SINT32 can be incorrect */
        /* JADX WARN: Init of enum SINT64 can be incorrect */
        public enum Type {
            DOUBLE(JavaType.DOUBLE),
            FLOAT(JavaType.FLOAT),
            INT64(r4),
            UINT64(r4),
            INT32(r10),
            FIXED64(r4),
            FIXED32(r10),
            BOOL(JavaType.BOOLEAN),
            STRING(JavaType.STRING),
            GROUP(r14),
            MESSAGE(r14),
            BYTES(JavaType.BYTE_STRING),
            UINT32(r10),
            ENUM(JavaType.ENUM),
            SFIXED32(r10),
            SFIXED64(r4),
            SINT32(r10),
            SINT64(r4);
            
            private JavaType javaType;

            /* access modifiers changed from: public */
            static {
                JavaType javaType2 = JavaType.LONG;
                JavaType javaType3 = JavaType.INT;
                JavaType javaType4 = JavaType.MESSAGE;
            }

            /* access modifiers changed from: public */
            Type(JavaType javaType2) {
                this.javaType = javaType2;
            }

            public JavaType getJavaType() {
                return this.javaType;
            }

            public DescriptorProtos.FieldDescriptorProto.Type toProto() {
                return DescriptorProtos.FieldDescriptorProto.Type.forNumber(ordinal() + 1);
            }

            public static Type valueOf(DescriptorProtos.FieldDescriptorProto.Type type) {
                return values()[type.getNumber() - 1];
            }
        }

        static {
            Type.values();
            DescriptorProtos.FieldDescriptorProto.Type.values();
        }

        public FieldDescriptor(DescriptorProtos.FieldDescriptorProto fieldDescriptorProto, FileDescriptor fileDescriptor, Descriptor descriptor, int i, boolean z, AnonymousClass1 r13) {
            super(null);
            this.index = i;
            this.proto = fieldDescriptorProto;
            this.fullName = Descriptors.access$1700(fileDescriptor, descriptor, fieldDescriptorProto.getName());
            this.file = fileDescriptor;
            if (fieldDescriptorProto.hasJsonName()) {
                fieldDescriptorProto.getJsonName();
            } else {
                String name = fieldDescriptorProto.getName();
                int length = name.length();
                boolean z2 = false;
                for (int i2 = 0; i2 < length; i2++) {
                    if (name.charAt(i2) == '_') {
                        z2 = true;
                    } else if (z2) {
                        z2 = false;
                    }
                }
            }
            if (fieldDescriptorProto.hasType()) {
                this.type = Type.valueOf(fieldDescriptorProto.getType());
            }
            this.isProto3Optional = fieldDescriptorProto.getProto3Optional();
            if (getNumber() > 0) {
                if (z) {
                    if (fieldDescriptorProto.hasExtendee()) {
                        this.containingType = null;
                        if (descriptor != null) {
                            this.extensionScope = descriptor;
                        } else {
                            this.extensionScope = null;
                        }
                        if (!fieldDescriptorProto.hasOneofIndex()) {
                            this.containingOneof = null;
                        } else {
                            throw new DescriptorValidationException(this, "FieldDescriptorProto.oneof_index set for extension field.");
                        }
                    } else {
                        throw new DescriptorValidationException(this, "FieldDescriptorProto.extendee not set for extension field.");
                    }
                } else if (!fieldDescriptorProto.hasExtendee()) {
                    this.containingType = descriptor;
                    if (!fieldDescriptorProto.hasOneofIndex()) {
                        this.containingOneof = null;
                    } else if (fieldDescriptorProto.getOneofIndex() < 0 || fieldDescriptorProto.getOneofIndex() >= descriptor.proto.getOneofDeclCount()) {
                        String valueOf = String.valueOf(descriptor.getName());
                        throw new DescriptorValidationException(this, valueOf.length() != 0 ? "FieldDescriptorProto.oneof_index is out of range for type ".concat(valueOf) : new String("FieldDescriptorProto.oneof_index is out of range for type "));
                    } else {
                        OneofDescriptor oneofDescriptor = descriptor.getOneofs().get(fieldDescriptorProto.getOneofIndex());
                        this.containingOneof = oneofDescriptor;
                        oneofDescriptor.fieldCount++;
                    }
                    this.extensionScope = null;
                } else {
                    throw new DescriptorValidationException(this, "FieldDescriptorProto.extendee set for non-extension field.");
                }
                fileDescriptor.pool.addSymbol(this);
                return;
            }
            throw new DescriptorValidationException(this, "Field numbers must be positive integers.");
        }

        @Override // java.lang.Comparable
        public int compareTo(Object obj) {
            FieldDescriptor fieldDescriptor = (FieldDescriptor) obj;
            if (fieldDescriptor.containingType == this.containingType) {
                return getNumber() - fieldDescriptor.getNumber();
            }
            throw new IllegalArgumentException("FieldDescriptors can only be compared to other FieldDescriptors for fields of the same message type.");
        }

        public final void crossLink() {
            if (this.proto.hasExtendee()) {
                GenericDescriptor lookupSymbol = this.file.pool.lookupSymbol(this.proto.getExtendee(), this, DescriptorPool.SearchFilter.TYPES_ONLY);
                if (lookupSymbol instanceof Descriptor) {
                    Descriptor descriptor = (Descriptor) lookupSymbol;
                    this.containingType = descriptor;
                    if (!descriptor.isExtensionNumber(getNumber())) {
                        String str = this.containingType.fullName;
                        int number = getNumber();
                        StringBuilder sb = new StringBuilder(GeneratedOutlineSupport.outline3(str, 55));
                        sb.append(StringUtil.DOUBLE_QUOTE);
                        sb.append(str);
                        sb.append("\" does not declare ");
                        sb.append(number);
                        sb.append(" as an extension number.");
                        throw new DescriptorValidationException(this, sb.toString());
                    }
                } else {
                    String extendee = this.proto.getExtendee();
                    throw new DescriptorValidationException(this, GeneratedOutlineSupport.outline6(GeneratedOutlineSupport.outline3(extendee, 25), StringUtil.DOUBLE_QUOTE, extendee, "\" is not a message type."));
                }
            }
            if (this.proto.hasTypeName()) {
                GenericDescriptor lookupSymbol2 = this.file.pool.lookupSymbol(this.proto.getTypeName(), this, DescriptorPool.SearchFilter.TYPES_ONLY);
                if (!this.proto.hasType()) {
                    if (lookupSymbol2 instanceof Descriptor) {
                        this.type = Type.MESSAGE;
                    } else if (lookupSymbol2 instanceof EnumDescriptor) {
                        this.type = Type.ENUM;
                    } else {
                        String typeName = this.proto.getTypeName();
                        throw new DescriptorValidationException(this, GeneratedOutlineSupport.outline6(GeneratedOutlineSupport.outline3(typeName, 17), StringUtil.DOUBLE_QUOTE, typeName, "\" is not a type."));
                    }
                }
                if (getJavaType() == JavaType.MESSAGE) {
                    if (lookupSymbol2 instanceof Descriptor) {
                        this.messageType = (Descriptor) lookupSymbol2;
                        if (this.proto.hasDefaultValue()) {
                            throw new DescriptorValidationException(this, "Messages can't have default values.");
                        }
                    } else {
                        String typeName2 = this.proto.getTypeName();
                        throw new DescriptorValidationException(this, GeneratedOutlineSupport.outline6(GeneratedOutlineSupport.outline3(typeName2, 25), StringUtil.DOUBLE_QUOTE, typeName2, "\" is not a message type."));
                    }
                } else if (getJavaType() != JavaType.ENUM) {
                    throw new DescriptorValidationException(this, "Field with primitive type has type_name.");
                } else if (lookupSymbol2 instanceof EnumDescriptor) {
                    this.enumType = (EnumDescriptor) lookupSymbol2;
                } else {
                    String typeName3 = this.proto.getTypeName();
                    throw new DescriptorValidationException(this, GeneratedOutlineSupport.outline6(GeneratedOutlineSupport.outline3(typeName3, 23), StringUtil.DOUBLE_QUOTE, typeName3, "\" is not an enum type."));
                }
            } else if (getJavaType() == JavaType.MESSAGE || getJavaType() == JavaType.ENUM) {
                throw new DescriptorValidationException(this, "Field with message or enum type missing type_name.");
            }
            if (!this.proto.getOptions().getPacked() || isPackable()) {
                if (this.proto.hasDefaultValue()) {
                    if (!isRepeated()) {
                        try {
                            switch (this.type.ordinal()) {
                                case 0:
                                    if (!this.proto.getDefaultValue().equals("inf")) {
                                        if (!this.proto.getDefaultValue().equals("-inf")) {
                                            if (!this.proto.getDefaultValue().equals("nan")) {
                                                this.defaultValue = Double.valueOf(this.proto.getDefaultValue());
                                                break;
                                            } else {
                                                this.defaultValue = Double.valueOf(Double.NaN);
                                                break;
                                            }
                                        } else {
                                            this.defaultValue = Double.valueOf(Double.NEGATIVE_INFINITY);
                                            break;
                                        }
                                    } else {
                                        this.defaultValue = Double.valueOf(Double.POSITIVE_INFINITY);
                                        break;
                                    }
                                case 1:
                                    if (!this.proto.getDefaultValue().equals("inf")) {
                                        if (!this.proto.getDefaultValue().equals("-inf")) {
                                            if (!this.proto.getDefaultValue().equals("nan")) {
                                                this.defaultValue = Float.valueOf(this.proto.getDefaultValue());
                                                break;
                                            } else {
                                                this.defaultValue = Float.valueOf(Float.NaN);
                                                break;
                                            }
                                        } else {
                                            this.defaultValue = Float.valueOf(Float.NEGATIVE_INFINITY);
                                            break;
                                        }
                                    } else {
                                        this.defaultValue = Float.valueOf(Float.POSITIVE_INFINITY);
                                        break;
                                    }
                                case 2:
                                case 15:
                                case 17:
                                    this.defaultValue = Long.valueOf(TextFormat.parseInteger(this.proto.getDefaultValue(), true, true));
                                    break;
                                case 3:
                                case 5:
                                    this.defaultValue = Long.valueOf(TextFormat.parseInteger(this.proto.getDefaultValue(), false, true));
                                    break;
                                case 4:
                                case 14:
                                case 16:
                                    this.defaultValue = Integer.valueOf((int) TextFormat.parseInteger(this.proto.getDefaultValue(), true, false));
                                    break;
                                case 6:
                                case 12:
                                    this.defaultValue = Integer.valueOf((int) TextFormat.parseInteger(this.proto.getDefaultValue(), false, false));
                                    break;
                                case 7:
                                    this.defaultValue = Boolean.valueOf(this.proto.getDefaultValue());
                                    break;
                                case 8:
                                    this.defaultValue = this.proto.getDefaultValue();
                                    break;
                                case 9:
                                case 10:
                                    throw new DescriptorValidationException(this, "Message type had default value.");
                                case 11:
                                    try {
                                        this.defaultValue = TextFormat.unescapeBytes(this.proto.getDefaultValue());
                                        break;
                                    } catch (TextFormat.InvalidEscapeSequenceException e) {
                                        String valueOf = String.valueOf(e.getMessage());
                                        throw new DescriptorValidationException(this, valueOf.length() != 0 ? "Couldn't parse default value: ".concat(valueOf) : new String("Couldn't parse default value: "), e, null);
                                    }
                                case 13:
                                    EnumValueDescriptor findValueByName = this.enumType.findValueByName(this.proto.getDefaultValue());
                                    this.defaultValue = findValueByName;
                                    if (findValueByName == null) {
                                        String defaultValue2 = this.proto.getDefaultValue();
                                        StringBuilder sb2 = new StringBuilder(String.valueOf(defaultValue2).length() + 30);
                                        sb2.append("Unknown enum default value: \"");
                                        sb2.append(defaultValue2);
                                        sb2.append(StringUtil.DOUBLE_QUOTE);
                                        throw new DescriptorValidationException(this, sb2.toString());
                                    }
                                    break;
                            }
                        } catch (NumberFormatException e2) {
                            String defaultValue3 = this.proto.getDefaultValue();
                            StringBuilder sb3 = new StringBuilder(GeneratedOutlineSupport.outline3(defaultValue3, 33));
                            sb3.append("Could not parse default value: \"");
                            sb3.append(defaultValue3);
                            sb3.append(StringUtil.DOUBLE_QUOTE);
                            throw new DescriptorValidationException(this, sb3.toString(), e2, null);
                        }
                    } else {
                        throw new DescriptorValidationException(this, "Repeated fields cannot have default values.");
                    }
                } else if (isRepeated()) {
                    this.defaultValue = Collections.emptyList();
                } else {
                    int ordinal = getJavaType().ordinal();
                    if (ordinal == 7) {
                        this.defaultValue = this.enumType.getValues().get(0);
                    } else if (ordinal != 8) {
                        this.defaultValue = getJavaType().defaultDefault;
                    } else {
                        this.defaultValue = null;
                    }
                }
                if (!isExtension()) {
                    DescriptorPool descriptorPool = this.file.pool;
                    Objects.requireNonNull(descriptorPool);
                    DescriptorPool.DescriptorIntPair descriptorIntPair = new DescriptorPool.DescriptorIntPair(this.containingType, getNumber());
                    FieldDescriptor put = descriptorPool.fieldsByNumber.put(descriptorIntPair, this);
                    if (put != null) {
                        descriptorPool.fieldsByNumber.put(descriptorIntPair, put);
                        int number2 = getNumber();
                        String str2 = this.containingType.fullName;
                        String name = put.getName();
                        StringBuilder sb4 = new StringBuilder(GeneratedOutlineSupport.outline3(name, GeneratedOutlineSupport.outline3(str2, 65)));
                        sb4.append("Field number ");
                        sb4.append(number2);
                        sb4.append(" has already been used in \"");
                        sb4.append(str2);
                        sb4.append("\" by field \"");
                        sb4.append(name);
                        sb4.append("\".");
                        throw new DescriptorValidationException(this, sb4.toString());
                    }
                }
                Descriptor descriptor2 = this.containingType;
                if (descriptor2 != null && descriptor2.getOptions().getMessageSetWireFormat()) {
                    if (!isExtension()) {
                        throw new DescriptorValidationException(this, "MessageSets cannot have fields, only extensions.");
                    } else if (!isOptional() || this.type != Type.MESSAGE) {
                        throw new DescriptorValidationException(this, "Extensions of MessageSets must be optional messages.");
                    }
                }
            } else {
                throw new DescriptorValidationException(this, "[packed = true] can only be specified for repeated primitive fields.");
            }
        }

        public Object getDefaultValue() {
            if (getJavaType() != JavaType.MESSAGE) {
                return this.defaultValue;
            }
            throw new UnsupportedOperationException("FieldDescriptor.getDefaultValue() called on an embedded message field.");
        }

        public EnumDescriptor getEnumType() {
            if (getJavaType() == JavaType.ENUM) {
                return this.enumType;
            }
            throw new UnsupportedOperationException(String.format("This field is not of enum type. (%s)", this.fullName));
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        public JavaType getJavaType() {
            return this.type.getJavaType();
        }

        public WireFormat.JavaType getLiteJavaType() {
            return getLiteType().getJavaType();
        }

        public WireFormat.FieldType getLiteType() {
            return table[this.type.ordinal()];
        }

        public Descriptor getMessageType() {
            if (getJavaType() == JavaType.MESSAGE) {
                return this.messageType;
            }
            throw new UnsupportedOperationException(String.format("This field is not of message type. (%s)", this.fullName));
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        public int getNumber() {
            return this.proto.getNumber();
        }

        public DescriptorProtos.FieldOptions getOptions() {
            return this.proto.getOptions();
        }

        public MessageLite.Builder internalMergeFrom(MessageLite.Builder builder, MessageLite messageLite) {
            return ((Message.Builder) builder).mergeFrom((Message) messageLite);
        }

        public boolean isExtension() {
            return this.proto.hasExtendee();
        }

        public boolean isMapField() {
            return this.type == Type.MESSAGE && isRepeated() && getMessageType().getOptions().getMapEntry();
        }

        public boolean isOptional() {
            return this.proto.getLabel() == DescriptorProtos.FieldDescriptorProto.Label.LABEL_OPTIONAL;
        }

        public boolean isPackable() {
            return isRepeated() && getLiteType().isPackable();
        }

        public boolean isPacked() {
            if (!isPackable()) {
                return false;
            }
            if (this.file.getSyntax() == FileDescriptor.Syntax.PROTO2) {
                return getOptions().getPacked();
            }
            if (!getOptions().hasPacked() || getOptions().getPacked()) {
                return true;
            }
            return false;
        }

        public boolean isRepeated() {
            return this.proto.getLabel() == DescriptorProtos.FieldDescriptorProto.Label.LABEL_REPEATED;
        }

        public boolean isRequired() {
            return this.proto.getLabel() == DescriptorProtos.FieldDescriptorProto.Label.LABEL_REQUIRED;
        }

        public boolean needsUtf8Check() {
            if (this.type != Type.STRING) {
                return false;
            }
            if (!this.containingType.getOptions().getMapEntry() && this.file.getSyntax() != FileDescriptor.Syntax.PROTO3) {
                return this.file.proto.getOptions().getJavaStringCheckUtf8();
            }
            return true;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }

        public String toString() {
            return this.fullName;
        }
    }

    public abstract class GenericDescriptor {
        public GenericDescriptor(AnonymousClass1 r1) {
        }

        public abstract FileDescriptor getFile();

        public abstract String getFullName();

        public abstract String getName();

        public abstract Message toProto();
    }

    public final class MethodDescriptor extends GenericDescriptor {
        public final FileDescriptor file;
        public final String fullName;
        public DescriptorProtos.MethodDescriptorProto proto;

        public MethodDescriptor(DescriptorProtos.MethodDescriptorProto methodDescriptorProto, FileDescriptor fileDescriptor, ServiceDescriptor serviceDescriptor, int i, AnonymousClass1 r5) {
            super(null);
            this.proto = methodDescriptorProto;
            this.file = fileDescriptor;
            String str = serviceDescriptor.fullName;
            String name = methodDescriptorProto.getName();
            StringBuilder sb = new StringBuilder(String.valueOf(name).length() + String.valueOf(str).length() + 1);
            sb.append(str);
            sb.append('.');
            sb.append(name);
            this.fullName = sb.toString();
            fileDescriptor.pool.addSymbol(this);
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }
    }

    public static final class OneofDescriptor extends GenericDescriptor {
        public Descriptor containingType;
        public int fieldCount = 0;
        public FieldDescriptor[] fields;
        public final FileDescriptor file;
        public final String fullName;
        public final int index;
        public DescriptorProtos.OneofDescriptorProto proto;

        public OneofDescriptor(DescriptorProtos.OneofDescriptorProto oneofDescriptorProto, FileDescriptor fileDescriptor, Descriptor descriptor, int i, AnonymousClass1 r5) {
            super(null);
            this.proto = oneofDescriptorProto;
            this.fullName = Descriptors.access$1700(fileDescriptor, descriptor, oneofDescriptorProto.getName());
            this.file = fileDescriptor;
            this.index = i;
            this.containingType = descriptor;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        public boolean isSynthetic() {
            FieldDescriptor[] fieldDescriptorArr = this.fields;
            if (fieldDescriptorArr.length != 1 || !fieldDescriptorArr[0].isProto3Optional) {
                return false;
            }
            return true;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }
    }

    public final class ServiceDescriptor extends GenericDescriptor {
        public final FileDescriptor file;
        public final String fullName;
        public MethodDescriptor[] methods;
        public DescriptorProtos.ServiceDescriptorProto proto;

        public ServiceDescriptor(DescriptorProtos.ServiceDescriptorProto serviceDescriptorProto, FileDescriptor fileDescriptor, int i, AnonymousClass1 r11) {
            super(null);
            this.proto = serviceDescriptorProto;
            this.fullName = Descriptors.access$1700(fileDescriptor, null, serviceDescriptorProto.getName());
            this.file = fileDescriptor;
            this.methods = new MethodDescriptor[serviceDescriptorProto.getMethodCount()];
            for (int i2 = 0; i2 < serviceDescriptorProto.getMethodCount(); i2++) {
                this.methods[i2] = new MethodDescriptor(serviceDescriptorProto.getMethod(i2), fileDescriptor, this, i2, null);
            }
            fileDescriptor.pool.addSymbol(this);
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }
    }

    public static String access$1700(FileDescriptor fileDescriptor, Descriptor descriptor, String str) {
        if (descriptor != null) {
            String str2 = descriptor.fullName;
            StringBuilder sb = new StringBuilder(String.valueOf(str).length() + String.valueOf(str2).length() + 1);
            sb.append(str2);
            sb.append('.');
            sb.append(str);
            return sb.toString();
        }
        String str3 = fileDescriptor.getPackage();
        if (str3.isEmpty()) {
            return str;
        }
        StringBuilder sb2 = new StringBuilder(String.valueOf(str).length() + str3.length() + 1);
        sb2.append(str3);
        sb2.append('.');
        sb2.append(str);
        return sb2.toString();
    }

    public static final class EnumValueDescriptor extends GenericDescriptor implements Internal.EnumLite {
        public final FileDescriptor file;
        public final String fullName;
        public final int index;
        public DescriptorProtos.EnumValueDescriptorProto proto;
        public final EnumDescriptor type;

        public EnumValueDescriptor(DescriptorProtos.EnumValueDescriptorProto enumValueDescriptorProto, FileDescriptor fileDescriptor, EnumDescriptor enumDescriptor, int i, AnonymousClass1 r6) {
            super(null);
            this.index = i;
            this.proto = enumValueDescriptorProto;
            this.file = fileDescriptor;
            this.type = enumDescriptor;
            String str = enumDescriptor.fullName;
            String name = enumValueDescriptorProto.getName();
            StringBuilder sb = new StringBuilder(String.valueOf(name).length() + String.valueOf(str).length() + 1);
            sb.append(str);
            sb.append('.');
            sb.append(name);
            this.fullName = sb.toString();
            fileDescriptor.pool.addSymbol(this);
            DescriptorPool descriptorPool = fileDescriptor.pool;
            Objects.requireNonNull(descriptorPool);
            DescriptorPool.DescriptorIntPair descriptorIntPair = new DescriptorPool.DescriptorIntPair(enumDescriptor, getNumber());
            EnumValueDescriptor put = descriptorPool.enumValuesByNumber.put(descriptorIntPair, this);
            if (put != null) {
                descriptorPool.enumValuesByNumber.put(descriptorIntPair, put);
            }
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        @Override // com.google.protobuf.Internal.EnumLite
        public int getNumber() {
            return this.proto.getNumber();
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }

        public String toString() {
            return this.proto.getName();
        }

        public EnumValueDescriptor(FileDescriptor fileDescriptor, EnumDescriptor enumDescriptor, Integer num, AnonymousClass1 r7) {
            super(null);
            String name = enumDescriptor.proto.getName();
            String valueOf = String.valueOf(num);
            StringBuilder sb = new StringBuilder(valueOf.length() + String.valueOf(name).length() + 20);
            sb.append("UNKNOWN_ENUM_VALUE_");
            sb.append(name);
            sb.append("_");
            sb.append(valueOf);
            String sb2 = sb.toString();
            DescriptorProtos.EnumValueDescriptorProto.Builder newBuilder = DescriptorProtos.EnumValueDescriptorProto.newBuilder();
            Objects.requireNonNull(newBuilder);
            Objects.requireNonNull(sb2);
            newBuilder.bitField0_ |= 1;
            newBuilder.name_ = sb2;
            newBuilder.onChanged();
            int intValue = num.intValue();
            newBuilder.bitField0_ |= 2;
            newBuilder.number_ = intValue;
            newBuilder.onChanged();
            DescriptorProtos.EnumValueDescriptorProto build = newBuilder.build();
            this.index = -1;
            this.proto = build;
            this.file = fileDescriptor;
            this.type = enumDescriptor;
            String str = enumDescriptor.fullName;
            String name2 = build.getName();
            StringBuilder sb3 = new StringBuilder(String.valueOf(name2).length() + String.valueOf(str).length() + 1);
            sb3.append(str);
            sb3.append('.');
            sb3.append(name2);
            this.fullName = sb3.toString();
        }
    }

    public static final class Descriptor extends GenericDescriptor {
        public final EnumDescriptor[] enumTypes;
        public final FieldDescriptor[] extensions;
        public final FieldDescriptor[] fields;
        public final FileDescriptor file;
        public final String fullName;
        public final Descriptor[] nestedTypes;
        public final OneofDescriptor[] oneofs;
        public DescriptorProtos.DescriptorProto proto;

        public Descriptor(String str) {
            super(null);
            String str2;
            String str3;
            int lastIndexOf = str.lastIndexOf(46);
            if (lastIndexOf != -1) {
                str2 = str.substring(lastIndexOf + 1);
                str3 = str.substring(0, lastIndexOf);
            } else {
                str3 = "";
                str2 = str;
            }
            DescriptorProtos.DescriptorProto.Builder newBuilder = DescriptorProtos.DescriptorProto.newBuilder();
            Objects.requireNonNull(newBuilder);
            Objects.requireNonNull(str2);
            newBuilder.bitField0_ |= 1;
            newBuilder.name_ = str2;
            newBuilder.onChanged();
            DescriptorProtos.DescriptorProto.ExtensionRange.Builder newBuilder2 = DescriptorProtos.DescriptorProto.ExtensionRange.newBuilder();
            newBuilder2.bitField0_ |= 1;
            newBuilder2.start_ = 1;
            newBuilder2.onChanged();
            newBuilder2.bitField0_ |= 2;
            newBuilder2.end_ = 536870912;
            newBuilder2.onChanged();
            DescriptorProtos.DescriptorProto.ExtensionRange build = newBuilder2.build();
            RepeatedFieldBuilderV3<DescriptorProtos.DescriptorProto.ExtensionRange, DescriptorProtos.DescriptorProto.ExtensionRange.Builder, DescriptorProtos.DescriptorProto.ExtensionRangeOrBuilder> repeatedFieldBuilderV3 = newBuilder.extensionRangeBuilder_;
            if (repeatedFieldBuilderV3 == null) {
                newBuilder.ensureExtensionRangeIsMutable();
                newBuilder.extensionRange_.add(build);
                newBuilder.onChanged();
            } else {
                repeatedFieldBuilderV3.addMessage(build);
            }
            this.proto = newBuilder.build();
            this.fullName = str;
            this.nestedTypes = new Descriptor[0];
            this.enumTypes = new EnumDescriptor[0];
            this.fields = new FieldDescriptor[0];
            this.extensions = new FieldDescriptor[0];
            this.oneofs = new OneofDescriptor[0];
            this.file = new FileDescriptor(str3, this);
        }

        public final void crossLink() {
            for (Descriptor descriptor : this.nestedTypes) {
                descriptor.crossLink();
            }
            FieldDescriptor[] fieldDescriptorArr = this.fields;
            for (FieldDescriptor fieldDescriptor : fieldDescriptorArr) {
                WireFormat.FieldType[] fieldTypeArr = FieldDescriptor.table;
                fieldDescriptor.crossLink();
            }
            FieldDescriptor[] fieldDescriptorArr2 = this.extensions;
            for (FieldDescriptor fieldDescriptor2 : fieldDescriptorArr2) {
                WireFormat.FieldType[] fieldTypeArr2 = FieldDescriptor.table;
                fieldDescriptor2.crossLink();
            }
        }

        public FieldDescriptor findFieldByName(String str) {
            DescriptorPool descriptorPool = this.file.pool;
            String str2 = this.fullName;
            StringBuilder sb = new StringBuilder(String.valueOf(str).length() + String.valueOf(str2).length() + 1);
            sb.append(str2);
            sb.append('.');
            sb.append(str);
            GenericDescriptor findSymbol = descriptorPool.findSymbol(sb.toString());
            if (findSymbol == null || !(findSymbol instanceof FieldDescriptor)) {
                return null;
            }
            return (FieldDescriptor) findSymbol;
        }

        public FieldDescriptor findFieldByNumber(int i) {
            return this.file.pool.fieldsByNumber.get(new DescriptorPool.DescriptorIntPair(this, i));
        }

        public List<EnumDescriptor> getEnumTypes() {
            return Collections.unmodifiableList(Arrays.asList(this.enumTypes));
        }

        public List<FieldDescriptor> getFields() {
            return Collections.unmodifiableList(Arrays.asList(this.fields));
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this.file;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.fullName;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        public List<Descriptor> getNestedTypes() {
            return Collections.unmodifiableList(Arrays.asList(this.nestedTypes));
        }

        public List<OneofDescriptor> getOneofs() {
            return Collections.unmodifiableList(Arrays.asList(this.oneofs));
        }

        public DescriptorProtos.MessageOptions getOptions() {
            return this.proto.getOptions();
        }

        public boolean isExtensionNumber(int i) {
            for (DescriptorProtos.DescriptorProto.ExtensionRange extensionRange : this.proto.getExtensionRangeList()) {
                if (extensionRange.getStart() <= i && i < extensionRange.getEnd()) {
                    return true;
                }
            }
            return false;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }

        public Descriptor(DescriptorProtos.DescriptorProto descriptorProto, FileDescriptor fileDescriptor, Descriptor descriptor, int i) {
            super(null);
            this.proto = descriptorProto;
            this.fullName = Descriptors.access$1700(fileDescriptor, descriptor, descriptorProto.getName());
            this.file = fileDescriptor;
            this.oneofs = new OneofDescriptor[descriptorProto.getOneofDeclCount()];
            for (int i2 = 0; i2 < descriptorProto.getOneofDeclCount(); i2++) {
                this.oneofs[i2] = new OneofDescriptor(descriptorProto.getOneofDecl(i2), fileDescriptor, this, i2, null);
            }
            this.nestedTypes = new Descriptor[descriptorProto.getNestedTypeCount()];
            for (int i3 = 0; i3 < descriptorProto.getNestedTypeCount(); i3++) {
                this.nestedTypes[i3] = new Descriptor(descriptorProto.getNestedType(i3), fileDescriptor, this, i3);
            }
            this.enumTypes = new EnumDescriptor[descriptorProto.getEnumTypeCount()];
            for (int i4 = 0; i4 < descriptorProto.getEnumTypeCount(); i4++) {
                this.enumTypes[i4] = new EnumDescriptor(descriptorProto.getEnumType(i4), fileDescriptor, this, i4, null);
            }
            this.fields = new FieldDescriptor[descriptorProto.getFieldCount()];
            for (int i5 = 0; i5 < descriptorProto.getFieldCount(); i5++) {
                this.fields[i5] = new FieldDescriptor(descriptorProto.getField(i5), fileDescriptor, this, i5, false, null);
            }
            this.extensions = new FieldDescriptor[descriptorProto.getExtensionCount()];
            for (int i6 = 0; i6 < descriptorProto.getExtensionCount(); i6++) {
                this.extensions[i6] = new FieldDescriptor(descriptorProto.getExtension(i6), fileDescriptor, this, i6, true, null);
            }
            for (int i7 = 0; i7 < descriptorProto.getOneofDeclCount(); i7++) {
                OneofDescriptor[] oneofDescriptorArr = this.oneofs;
                oneofDescriptorArr[i7].fields = new FieldDescriptor[oneofDescriptorArr[i7].fieldCount];
                oneofDescriptorArr[i7].fieldCount = 0;
            }
            for (int i8 = 0; i8 < descriptorProto.getFieldCount(); i8++) {
                FieldDescriptor[] fieldDescriptorArr = this.fields;
                OneofDescriptor oneofDescriptor = fieldDescriptorArr[i8].containingOneof;
                if (oneofDescriptor != null) {
                    FieldDescriptor[] fieldDescriptorArr2 = oneofDescriptor.fields;
                    int i9 = oneofDescriptor.fieldCount;
                    oneofDescriptor.fieldCount = i9 + 1;
                    fieldDescriptorArr2[i9] = fieldDescriptorArr[i8];
                }
            }
            int i10 = 0;
            for (OneofDescriptor oneofDescriptor2 : this.oneofs) {
                if (oneofDescriptor2.isSynthetic()) {
                    i10++;
                } else if (i10 > 0) {
                    throw new DescriptorValidationException(this, "Synthetic oneofs must come last.");
                }
            }
            int length = this.oneofs.length;
            fileDescriptor.pool.addSymbol(this);
        }
    }

    public static final class FileDescriptor extends GenericDescriptor {
        public final EnumDescriptor[] enumTypes;
        public final FieldDescriptor[] extensions;
        public final Descriptor[] messageTypes;
        public final DescriptorPool pool;
        public DescriptorProtos.FileDescriptorProto proto;
        public final FileDescriptor[] publicDependencies;
        public final ServiceDescriptor[] services;

        public enum Syntax {
            UNKNOWN("unknown"),
            PROTO2("proto2"),
            PROTO3("proto3");
            
            private final String name;

            /* access modifiers changed from: public */
            Syntax(String str) {
                this.name = str;
            }
        }

        public FileDescriptor(DescriptorProtos.FileDescriptorProto fileDescriptorProto, FileDescriptor[] fileDescriptorArr, DescriptorPool descriptorPool, boolean z) {
            super(null);
            this.pool = descriptorPool;
            this.proto = fileDescriptorProto;
            HashMap hashMap = new HashMap();
            for (FileDescriptor fileDescriptor : fileDescriptorArr) {
                hashMap.put(fileDescriptor.getName(), fileDescriptor);
            }
            ArrayList arrayList = new ArrayList();
            for (int i = 0; i < fileDescriptorProto.getPublicDependencyCount(); i++) {
                int publicDependency = fileDescriptorProto.getPublicDependency(i);
                if (publicDependency < 0 || publicDependency >= fileDescriptorProto.getDependencyCount()) {
                    throw new DescriptorValidationException(this, "Invalid public dependency index.", (AnonymousClass1) null);
                }
                String dependency = fileDescriptorProto.getDependency(publicDependency);
                FileDescriptor fileDescriptor2 = (FileDescriptor) hashMap.get(dependency);
                if (fileDescriptor2 != null) {
                    arrayList.add(fileDescriptor2);
                } else if (!z) {
                    String valueOf = String.valueOf(dependency);
                    throw new DescriptorValidationException(this, valueOf.length() != 0 ? "Invalid public dependency: ".concat(valueOf) : new String("Invalid public dependency: "), (AnonymousClass1) null);
                }
            }
            FileDescriptor[] fileDescriptorArr2 = new FileDescriptor[arrayList.size()];
            this.publicDependencies = fileDescriptorArr2;
            arrayList.toArray(fileDescriptorArr2);
            descriptorPool.addPackage(getPackage(), this);
            this.messageTypes = new Descriptor[fileDescriptorProto.getMessageTypeCount()];
            for (int i2 = 0; i2 < fileDescriptorProto.getMessageTypeCount(); i2++) {
                this.messageTypes[i2] = new Descriptor(fileDescriptorProto.getMessageType(i2), this, null, i2);
            }
            this.enumTypes = new EnumDescriptor[fileDescriptorProto.getEnumTypeCount()];
            for (int i3 = 0; i3 < fileDescriptorProto.getEnumTypeCount(); i3++) {
                this.enumTypes[i3] = new EnumDescriptor(fileDescriptorProto.getEnumType(i3), this, null, i3, null);
            }
            this.services = new ServiceDescriptor[fileDescriptorProto.getServiceCount()];
            for (int i4 = 0; i4 < fileDescriptorProto.getServiceCount(); i4++) {
                this.services[i4] = new ServiceDescriptor(fileDescriptorProto.getService(i4), this, i4, null);
            }
            this.extensions = new FieldDescriptor[fileDescriptorProto.getExtensionCount()];
            for (int i5 = 0; i5 < fileDescriptorProto.getExtensionCount(); i5++) {
                this.extensions[i5] = new FieldDescriptor(fileDescriptorProto.getExtension(i5), this, null, i5, true, null);
            }
        }

        public static FileDescriptor buildFrom(DescriptorProtos.FileDescriptorProto fileDescriptorProto, FileDescriptor[] fileDescriptorArr, boolean z) {
            FileDescriptor fileDescriptor = new FileDescriptor(fileDescriptorProto, fileDescriptorArr, new DescriptorPool(fileDescriptorArr, z), z);
            for (Descriptor descriptor : fileDescriptor.messageTypes) {
                descriptor.crossLink();
            }
            for (ServiceDescriptor serviceDescriptor : fileDescriptor.services) {
                MethodDescriptor[] methodDescriptorArr = serviceDescriptor.methods;
                for (MethodDescriptor methodDescriptor : methodDescriptorArr) {
                    DescriptorPool descriptorPool = methodDescriptor.file.pool;
                    String inputType = methodDescriptor.proto.getInputType();
                    DescriptorPool.SearchFilter searchFilter = DescriptorPool.SearchFilter.TYPES_ONLY;
                    GenericDescriptor lookupSymbol = descriptorPool.lookupSymbol(inputType, methodDescriptor, searchFilter);
                    if (lookupSymbol instanceof Descriptor) {
                        Descriptor descriptor2 = (Descriptor) lookupSymbol;
                        GenericDescriptor lookupSymbol2 = methodDescriptor.file.pool.lookupSymbol(methodDescriptor.proto.getOutputType(), methodDescriptor, searchFilter);
                        if (lookupSymbol2 instanceof Descriptor) {
                            Descriptor descriptor3 = (Descriptor) lookupSymbol2;
                        } else {
                            String outputType = methodDescriptor.proto.getOutputType();
                            throw new DescriptorValidationException(methodDescriptor, GeneratedOutlineSupport.outline6(GeneratedOutlineSupport.outline3(outputType, 25), StringUtil.DOUBLE_QUOTE, outputType, "\" is not a message type."));
                        }
                    } else {
                        String inputType2 = methodDescriptor.proto.getInputType();
                        throw new DescriptorValidationException(methodDescriptor, GeneratedOutlineSupport.outline6(GeneratedOutlineSupport.outline3(inputType2, 25), StringUtil.DOUBLE_QUOTE, inputType2, "\" is not a message type."));
                    }
                }
            }
            FieldDescriptor[] fieldDescriptorArr = fileDescriptor.extensions;
            for (FieldDescriptor fieldDescriptor : fieldDescriptorArr) {
                WireFormat.FieldType[] fieldTypeArr = FieldDescriptor.table;
                fieldDescriptor.crossLink();
            }
            return fileDescriptor;
        }

        public static FileDescriptor internalBuildGeneratedFileFrom(String[] strArr, FileDescriptor[] fileDescriptorArr) {
            byte[] bArr;
            DescriptorProtos.FileDescriptorProto fileDescriptorProto;
            if (strArr.length == 1) {
                bArr = strArr[0].getBytes(Internal.ISO_8859_1);
            } else {
                StringBuilder sb = new StringBuilder();
                for (String str : strArr) {
                    sb.append(str);
                }
                bArr = sb.toString().getBytes(Internal.ISO_8859_1);
            }
            try {
                try {
                    return buildFrom(DescriptorProtos.FileDescriptorProto.parseFrom(bArr), fileDescriptorArr, true);
                } catch (DescriptorValidationException e) {
                    String name = fileDescriptorProto.getName();
                    throw new IllegalArgumentException(GeneratedOutlineSupport.outline7(GeneratedOutlineSupport.outline3(name, 35), "Invalid embedded descriptor for \"", name, "\"."), e);
                }
            } catch (InvalidProtocolBufferException e2) {
                throw new IllegalArgumentException("Failed to parse protocol buffer descriptor for generated code.", e2);
            }
        }

        public List<EnumDescriptor> getEnumTypes() {
            return Collections.unmodifiableList(Arrays.asList(this.enumTypes));
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public FileDescriptor getFile() {
            return this;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getFullName() {
            return this.proto.getName();
        }

        public List<Descriptor> getMessageTypes() {
            return Collections.unmodifiableList(Arrays.asList(this.messageTypes));
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public String getName() {
            return this.proto.getName();
        }

        public String getPackage() {
            return this.proto.getPackage();
        }

        public Syntax getSyntax() {
            Syntax syntax = Syntax.PROTO3;
            if (syntax.name.equals(this.proto.getSyntax())) {
                return syntax;
            }
            return Syntax.PROTO2;
        }

        public boolean supportsUnknownEnumValue() {
            return getSyntax() == Syntax.PROTO3;
        }

        @Override // com.google.protobuf.Descriptors.GenericDescriptor
        public Message toProto() {
            return this.proto;
        }

        public FileDescriptor(String str, Descriptor descriptor) {
            super(null);
            DescriptorPool descriptorPool = new DescriptorPool(new FileDescriptor[0], true);
            this.pool = descriptorPool;
            DescriptorProtos.FileDescriptorProto.Builder newBuilder = DescriptorProtos.FileDescriptorProto.newBuilder();
            String concat = String.valueOf(descriptor.fullName).concat(".placeholder.proto");
            Objects.requireNonNull(newBuilder);
            Objects.requireNonNull(concat);
            newBuilder.bitField0_ |= 1;
            newBuilder.name_ = concat;
            newBuilder.onChanged();
            Objects.requireNonNull(str);
            newBuilder.bitField0_ |= 2;
            newBuilder.package_ = str;
            newBuilder.onChanged();
            DescriptorProtos.DescriptorProto descriptorProto = descriptor.proto;
            RepeatedFieldBuilderV3<DescriptorProtos.DescriptorProto, DescriptorProtos.DescriptorProto.Builder, DescriptorProtos.DescriptorProtoOrBuilder> repeatedFieldBuilderV3 = newBuilder.messageTypeBuilder_;
            if (repeatedFieldBuilderV3 == null) {
                Objects.requireNonNull(descriptorProto);
                newBuilder.ensureMessageTypeIsMutable();
                newBuilder.messageType_.add(descriptorProto);
                newBuilder.onChanged();
            } else {
                repeatedFieldBuilderV3.addMessage(descriptorProto);
            }
            this.proto = newBuilder.build();
            this.publicDependencies = new FileDescriptor[0];
            this.messageTypes = new Descriptor[]{descriptor};
            this.enumTypes = new EnumDescriptor[0];
            this.services = new ServiceDescriptor[0];
            this.extensions = new FieldDescriptor[0];
            descriptorPool.addPackage(str, this);
            descriptorPool.addSymbol(descriptor);
        }
    }
}
