package com.google.protobuf;

import com.google.protobuf.Descriptors;
import com.google.protobuf.FieldSet;
import com.google.protobuf.FieldSet.FieldDescriptorLite;
import com.google.protobuf.Internal;
import com.google.protobuf.LazyField;
import com.google.protobuf.MessageLite;
import com.google.protobuf.SmallSortedMap;
import com.google.protobuf.WireFormat;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.logging.Logger;

public final class FieldSet<T extends FieldDescriptorLite<T>> {
    public static final FieldSet DEFAULT_INSTANCE = new FieldSet(true);
    public final SmallSortedMap<T, Object> fields;
    public boolean hasLazyField;
    public boolean isImmutable;

    public interface FieldDescriptorLite<T extends FieldDescriptorLite<T>> extends Comparable<T> {
    }

    public FieldSet(boolean z) {
        int i = SmallSortedMap.$r8$clinit;
        this.fields = new SmallSortedMap<FieldDescriptorType, Object>(0) {
            /* class com.google.protobuf.SmallSortedMap.AnonymousClass1 */

            @Override // com.google.protobuf.SmallSortedMap
            public void makeImmutable() {
                Map<K, V> map;
                Map<K, V> map2;
                if (!this.isImmutable) {
                    for (int i = 0; i < getNumArrayEntries(); i++) {
                        Map.Entry<K, V> arrayEntryAt = getArrayEntryAt(i);
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) arrayEntryAt.getKey())).isRepeated()) {
                            arrayEntryAt.setValue((V) Collections.unmodifiableList(arrayEntryAt.getValue()));
                        }
                    }
                    for (Map.Entry<K, V> entry : getOverflowEntries()) {
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) entry.getKey())).isRepeated()) {
                            entry.setValue((V) Collections.unmodifiableList(entry.getValue()));
                        }
                    }
                }
                if (!this.isImmutable) {
                    if (this.overflowEntries.isEmpty()) {
                        map = Collections.emptyMap();
                    } else {
                        map = Collections.unmodifiableMap(this.overflowEntries);
                    }
                    this.overflowEntries = map;
                    if (this.overflowEntriesDescending.isEmpty()) {
                        map2 = Collections.emptyMap();
                    } else {
                        map2 = Collections.unmodifiableMap(this.overflowEntriesDescending);
                    }
                    this.overflowEntriesDescending = map2;
                    this.isImmutable = true;
                }
            }
        };
        makeImmutable();
        makeImmutable();
    }

    public static <T extends FieldDescriptorLite<T>> SmallSortedMap<T, Object> cloneAllFieldsMap(SmallSortedMap<T, Object> smallSortedMap, boolean z) {
        int i = SmallSortedMap.$r8$clinit;
        SmallSortedMap.AnonymousClass1 r0 = new SmallSortedMap<FieldDescriptorType, Object>(16) {
            /* class com.google.protobuf.SmallSortedMap.AnonymousClass1 */

            @Override // com.google.protobuf.SmallSortedMap
            public void makeImmutable() {
                Map<K, V> map;
                Map<K, V> map2;
                if (!this.isImmutable) {
                    for (int i = 0; i < getNumArrayEntries(); i++) {
                        Map.Entry<K, V> arrayEntryAt = getArrayEntryAt(i);
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) arrayEntryAt.getKey())).isRepeated()) {
                            arrayEntryAt.setValue((V) Collections.unmodifiableList(arrayEntryAt.getValue()));
                        }
                    }
                    for (Map.Entry<K, V> entry : getOverflowEntries()) {
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) entry.getKey())).isRepeated()) {
                            entry.setValue((V) Collections.unmodifiableList(entry.getValue()));
                        }
                    }
                }
                if (!this.isImmutable) {
                    if (this.overflowEntries.isEmpty()) {
                        map = Collections.emptyMap();
                    } else {
                        map = Collections.unmodifiableMap(this.overflowEntries);
                    }
                    this.overflowEntries = map;
                    if (this.overflowEntriesDescending.isEmpty()) {
                        map2 = Collections.emptyMap();
                    } else {
                        map2 = Collections.unmodifiableMap(this.overflowEntriesDescending);
                    }
                    this.overflowEntriesDescending = map2;
                    this.isImmutable = true;
                }
            }
        };
        for (int i2 = 0; i2 < smallSortedMap.getNumArrayEntries(); i2++) {
            cloneFieldEntry(r0, smallSortedMap.getArrayEntryAt(i2), z);
        }
        for (Map.Entry<T, Object> entry : smallSortedMap.getOverflowEntries()) {
            cloneFieldEntry(r0, entry, z);
        }
        return r0;
    }

    public static <T extends FieldDescriptorLite<T>> void cloneFieldEntry(Map<T, Object> map, Map.Entry<T, Object> entry, boolean z) {
        T key = entry.getKey();
        Object value = entry.getValue();
        if (!z || !(value instanceof List)) {
            ((SmallSortedMap.AnonymousClass1) map).put((Object) key, value);
            return;
        }
        ((SmallSortedMap.AnonymousClass1) map).put((Object) key, (Object) new ArrayList((List) value));
    }

    public static Object cloneIfMutable(Object obj) {
        if (!(obj instanceof byte[])) {
            return obj;
        }
        byte[] bArr = (byte[]) obj;
        byte[] bArr2 = new byte[bArr.length];
        System.arraycopy(bArr, 0, bArr2, 0, bArr.length);
        return bArr2;
    }

    public static int computeElementSize(WireFormat.FieldType fieldType, int i, Object obj) {
        int computeTagSize = CodedOutputStream.computeTagSize(i);
        if (fieldType == WireFormat.FieldType.GROUP) {
            computeTagSize *= 2;
        }
        return computeElementSizeNoTag(fieldType, obj) + computeTagSize;
    }

    public static int computeElementSizeNoTag(WireFormat.FieldType fieldType, Object obj) {
        switch (fieldType.ordinal()) {
            case 0:
                ((Double) obj).doubleValue();
                Logger logger = CodedOutputStream.logger;
                return 8;
            case 1:
                ((Float) obj).floatValue();
                Logger logger2 = CodedOutputStream.logger;
                return 4;
            case 2:
                return CodedOutputStream.computeUInt64SizeNoTag(((Long) obj).longValue());
            case 3:
                return CodedOutputStream.computeUInt64SizeNoTag(((Long) obj).longValue());
            case 4:
                return CodedOutputStream.computeInt32SizeNoTag(((Integer) obj).intValue());
            case 5:
                ((Long) obj).longValue();
                Logger logger3 = CodedOutputStream.logger;
                return 8;
            case 6:
                ((Integer) obj).intValue();
                Logger logger4 = CodedOutputStream.logger;
                return 4;
            case 7:
                ((Boolean) obj).booleanValue();
                Logger logger5 = CodedOutputStream.logger;
                return 1;
            case 8:
                if (obj instanceof ByteString) {
                    return CodedOutputStream.computeBytesSizeNoTag((ByteString) obj);
                }
                return CodedOutputStream.computeStringSizeNoTag((String) obj);
            case 9:
                Logger logger6 = CodedOutputStream.logger;
                return ((MessageLite) obj).getSerializedSize();
            case 10:
                Logger logger7 = CodedOutputStream.logger;
                return CodedOutputStream.computeLengthDelimitedFieldSize(((MessageLite) obj).getSerializedSize());
            case 11:
                if (obj instanceof ByteString) {
                    return CodedOutputStream.computeBytesSizeNoTag((ByteString) obj);
                }
                Logger logger8 = CodedOutputStream.logger;
                return CodedOutputStream.computeLengthDelimitedFieldSize(((byte[]) obj).length);
            case 12:
                return CodedOutputStream.computeUInt32SizeNoTag(((Integer) obj).intValue());
            case 13:
                if (obj instanceof Internal.EnumLite) {
                    return CodedOutputStream.computeInt32SizeNoTag(((Internal.EnumLite) obj).getNumber());
                }
                return CodedOutputStream.computeInt32SizeNoTag(((Integer) obj).intValue());
            case 14:
                ((Integer) obj).intValue();
                Logger logger9 = CodedOutputStream.logger;
                return 4;
            case 15:
                ((Long) obj).longValue();
                Logger logger10 = CodedOutputStream.logger;
                return 8;
            case 16:
                return CodedOutputStream.computeSInt32SizeNoTag(((Integer) obj).intValue());
            case 17:
                return CodedOutputStream.computeSInt64SizeNoTag(((Long) obj).longValue());
            default:
                throw new RuntimeException("There is no way to get here, but the compiler thinks otherwise.");
        }
    }

    public static int computeFieldSize(FieldDescriptorLite<?> fieldDescriptorLite, Object obj) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) fieldDescriptorLite;
        WireFormat.FieldType liteType = fieldDescriptor.getLiteType();
        int number = fieldDescriptor.getNumber();
        if (!fieldDescriptor.isRepeated()) {
            return computeElementSize(liteType, number, obj);
        }
        int i = 0;
        if (fieldDescriptor.isPacked()) {
            for (Object obj2 : (List) obj) {
                i += computeElementSizeNoTag(liteType, obj2);
            }
            return CodedOutputStream.computeTagSize(number) + i + CodedOutputStream.computeUInt32SizeNoTag(i);
        }
        for (Object obj3 : (List) obj) {
            i += computeElementSize(liteType, number, obj3);
        }
        return i;
    }

    public static int getWireFormatForFieldType(WireFormat.FieldType fieldType, boolean z) {
        if (z) {
            return 2;
        }
        return fieldType.getWireType();
    }

    public static boolean isValidType(WireFormat.FieldType fieldType, Object obj) {
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(obj);
        switch (fieldType.getJavaType().ordinal()) {
            case 0:
                return obj instanceof Integer;
            case 1:
                return obj instanceof Long;
            case 2:
                return obj instanceof Float;
            case 3:
                return obj instanceof Double;
            case 4:
                return obj instanceof Boolean;
            case 5:
                return obj instanceof String;
            case 6:
                if ((obj instanceof ByteString) || (obj instanceof byte[])) {
                    return true;
                }
                return false;
            case 7:
                if ((obj instanceof Integer) || (obj instanceof Internal.EnumLite)) {
                    return true;
                }
                return false;
            case 8:
                if ((obj instanceof MessageLite) || (obj instanceof LazyField)) {
                    return true;
                }
                return false;
            default:
                return false;
        }
    }

    public static void writeElement(CodedOutputStream codedOutputStream, WireFormat.FieldType fieldType, int i, Object obj) {
        if (fieldType == WireFormat.FieldType.GROUP) {
            codedOutputStream.writeTag(i, 3);
            ((MessageLite) obj).writeTo(codedOutputStream);
            codedOutputStream.writeTag(i, 4);
            return;
        }
        codedOutputStream.writeTag(i, getWireFormatForFieldType(fieldType, false));
        writeElementNoTag(codedOutputStream, fieldType, obj);
    }

    public static void writeElementNoTag(CodedOutputStream codedOutputStream, WireFormat.FieldType fieldType, Object obj) {
        switch (fieldType.ordinal()) {
            case 0:
                codedOutputStream.writeFixed64NoTag(Double.doubleToRawLongBits(((Double) obj).doubleValue()));
                return;
            case 1:
                codedOutputStream.writeFixed32NoTag(Float.floatToRawIntBits(((Float) obj).floatValue()));
                return;
            case 2:
                codedOutputStream.writeUInt64NoTag(((Long) obj).longValue());
                return;
            case 3:
                codedOutputStream.writeUInt64NoTag(((Long) obj).longValue());
                return;
            case 4:
                codedOutputStream.writeInt32NoTag(((Integer) obj).intValue());
                return;
            case 5:
                codedOutputStream.writeFixed64NoTag(((Long) obj).longValue());
                return;
            case 6:
                codedOutputStream.writeFixed32NoTag(((Integer) obj).intValue());
                return;
            case 7:
                codedOutputStream.write(((Boolean) obj).booleanValue() ? (byte) 1 : 0);
                return;
            case 8:
                if (obj instanceof ByteString) {
                    codedOutputStream.writeBytesNoTag((ByteString) obj);
                    return;
                } else {
                    codedOutputStream.writeStringNoTag((String) obj);
                    return;
                }
            case 9:
                ((MessageLite) obj).writeTo(codedOutputStream);
                return;
            case 10:
                codedOutputStream.writeMessageNoTag((MessageLite) obj);
                return;
            case 11:
                if (obj instanceof ByteString) {
                    codedOutputStream.writeBytesNoTag((ByteString) obj);
                    return;
                }
                byte[] bArr = (byte[]) obj;
                codedOutputStream.writeByteArrayNoTag(bArr, 0, bArr.length);
                return;
            case 12:
                codedOutputStream.writeUInt32NoTag(((Integer) obj).intValue());
                return;
            case 13:
                if (obj instanceof Internal.EnumLite) {
                    codedOutputStream.writeInt32NoTag(((Internal.EnumLite) obj).getNumber());
                    return;
                } else {
                    codedOutputStream.writeInt32NoTag(((Integer) obj).intValue());
                    return;
                }
            case 14:
                codedOutputStream.writeFixed32NoTag(((Integer) obj).intValue());
                return;
            case 15:
                codedOutputStream.writeFixed64NoTag(((Long) obj).longValue());
                return;
            case 16:
                int intValue = ((Integer) obj).intValue();
                codedOutputStream.writeUInt32NoTag((intValue >> 31) ^ (intValue << 1));
                return;
            case 17:
                long longValue = ((Long) obj).longValue();
                codedOutputStream.writeUInt64NoTag((longValue >> 63) ^ (longValue << 1));
                return;
            default:
                return;
        }
    }

    public static void writeField(FieldDescriptorLite<?> fieldDescriptorLite, Object obj, CodedOutputStream codedOutputStream) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) fieldDescriptorLite;
        WireFormat.FieldType liteType = fieldDescriptor.getLiteType();
        int number = fieldDescriptor.getNumber();
        if (fieldDescriptor.isRepeated()) {
            List<Object> list = (List) obj;
            if (fieldDescriptor.isPacked()) {
                codedOutputStream.writeTag(number, 2);
                int i = 0;
                for (Object obj2 : list) {
                    i += computeElementSizeNoTag(liteType, obj2);
                }
                codedOutputStream.writeUInt32NoTag(i);
                for (Object obj3 : list) {
                    writeElementNoTag(codedOutputStream, liteType, obj3);
                }
                return;
            }
            for (Object obj4 : list) {
                writeElement(codedOutputStream, liteType, number, obj4);
            }
            return;
        }
        writeElement(codedOutputStream, liteType, number, obj);
    }

    public void addRepeatedField(T t, Object obj) {
        List list;
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
        if (fieldDescriptor.isRepeated()) {
            verifyType(fieldDescriptor.getLiteType(), obj);
            Object field = getField(fieldDescriptor);
            if (field == null) {
                list = new ArrayList();
                this.fields.put((T) fieldDescriptor, (Object) list);
            } else {
                list = (List) field;
            }
            list.add(obj);
            return;
        }
        throw new IllegalArgumentException("addRepeatedField() can only be called on repeated fields.");
    }

    public void clearField(T t) {
        this.fields.remove(t);
        if (this.fields.isEmpty()) {
            this.hasLazyField = false;
        }
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof FieldSet)) {
            return false;
        }
        return this.fields.equals(((FieldSet) obj).fields);
    }

    public Map<T, Object> getAllFields() {
        if (this.hasLazyField) {
            SmallSortedMap cloneAllFieldsMap = cloneAllFieldsMap(this.fields, false);
            if (this.fields.isImmutable) {
                cloneAllFieldsMap.makeImmutable();
            }
            return cloneAllFieldsMap;
        }
        SmallSortedMap<T, Object> smallSortedMap = this.fields;
        return smallSortedMap.isImmutable ? smallSortedMap : Collections.unmodifiableMap(smallSortedMap);
    }

    public Object getField(T t) {
        return this.fields.get(t);
    }

    public int getMessageSetSerializedSize() {
        int i = 0;
        for (int i2 = 0; i2 < this.fields.getNumArrayEntries(); i2++) {
            i += getMessageSetSerializedSize(this.fields.getArrayEntryAt(i2));
        }
        for (Map.Entry<T, Object> entry : this.fields.getOverflowEntries()) {
            i += getMessageSetSerializedSize(entry);
        }
        return i;
    }

    public Object getRepeatedField(T t, int i) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
        if (fieldDescriptor.isRepeated()) {
            Object field = getField(fieldDescriptor);
            if (field != null) {
                return ((List) field).get(i);
            }
            throw new IndexOutOfBoundsException();
        }
        throw new IllegalArgumentException("getRepeatedField() can only be called on repeated fields.");
    }

    public int getRepeatedFieldCount(T t) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
        if (fieldDescriptor.isRepeated()) {
            Object field = getField(fieldDescriptor);
            if (field == null) {
                return 0;
            }
            return ((List) field).size();
        }
        throw new IllegalArgumentException("getRepeatedField() can only be called on repeated fields.");
    }

    public int getSerializedSize() {
        int i = 0;
        for (int i2 = 0; i2 < this.fields.getNumArrayEntries(); i2++) {
            Map.Entry<T, Object> arrayEntryAt = this.fields.getArrayEntryAt(i2);
            i += computeFieldSize(arrayEntryAt.getKey(), arrayEntryAt.getValue());
        }
        for (Map.Entry<T, Object> entry : this.fields.getOverflowEntries()) {
            i += computeFieldSize(entry.getKey(), entry.getValue());
        }
        return i;
    }

    public boolean hasField(T t) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
        if (!fieldDescriptor.isRepeated()) {
            return this.fields.get(fieldDescriptor) != null;
        }
        throw new IllegalArgumentException("hasField() can only be called on non-repeated fields.");
    }

    public int hashCode() {
        return this.fields.hashCode();
    }

    public boolean isInitialized() {
        for (int i = 0; i < this.fields.getNumArrayEntries(); i++) {
            if (!isInitialized(this.fields.getArrayEntryAt(i))) {
                return false;
            }
        }
        for (Map.Entry<T, Object> entry : this.fields.getOverflowEntries()) {
            if (!isInitialized(entry)) {
                return false;
            }
        }
        return true;
    }

    public Iterator<Map.Entry<T, Object>> iterator() {
        if (this.hasLazyField) {
            return new LazyField.LazyIterator(((SmallSortedMap.EntrySet) this.fields.entrySet()).iterator());
        }
        return ((SmallSortedMap.EntrySet) this.fields.entrySet()).iterator();
    }

    public void makeImmutable() {
        if (!this.isImmutable) {
            this.fields.makeImmutable();
            this.isImmutable = true;
        }
    }

    public void mergeFrom(FieldSet<T> fieldSet) {
        for (int i = 0; i < fieldSet.fields.getNumArrayEntries(); i++) {
            mergeFromField(fieldSet.fields.getArrayEntryAt(i));
        }
        for (Map.Entry<T, Object> entry : fieldSet.fields.getOverflowEntries()) {
            mergeFromField(entry);
        }
    }

    public final void mergeFromField(Map.Entry<T, Object> entry) {
        T key = entry.getKey();
        Object value = entry.getValue();
        if (value instanceof LazyField) {
            value = ((LazyField) value).getValue();
        }
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) key;
        if (fieldDescriptor.isRepeated()) {
            Object field = getField(fieldDescriptor);
            if (field == null) {
                field = new ArrayList();
            }
            for (Object obj : (List) value) {
                ((List) field).add(cloneIfMutable(obj));
            }
            this.fields.put((T) fieldDescriptor, field);
        } else if (fieldDescriptor.getLiteJavaType() == WireFormat.JavaType.MESSAGE) {
            Object field2 = getField(fieldDescriptor);
            if (field2 == null) {
                this.fields.put((T) fieldDescriptor, cloneIfMutable(value));
                return;
            }
            this.fields.put((T) fieldDescriptor, (Object) fieldDescriptor.internalMergeFrom(((MessageLite) field2).toBuilder(), (MessageLite) value).build());
        } else {
            this.fields.put((T) fieldDescriptor, cloneIfMutable(value));
        }
    }

    public void setField(T t, Object obj) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
        if (!fieldDescriptor.isRepeated()) {
            verifyType(fieldDescriptor.getLiteType(), obj);
        } else if (obj instanceof List) {
            ArrayList arrayList = new ArrayList();
            arrayList.addAll((List) obj);
            Iterator it = arrayList.iterator();
            while (it.hasNext()) {
                verifyType(fieldDescriptor.getLiteType(), it.next());
            }
            obj = arrayList;
        } else {
            throw new IllegalArgumentException("Wrong object type used with protocol message reflection.");
        }
        if (obj instanceof LazyField) {
            this.hasLazyField = true;
        }
        this.fields.put((T) fieldDescriptor, obj);
    }

    public final void verifyType(WireFormat.FieldType fieldType, Object obj) {
        if (!isValidType(fieldType, obj)) {
            throw new IllegalArgumentException("Wrong object type used with protocol message reflection.");
        }
    }

    public final void writeMessageSetTo(Map.Entry<T, Object> entry, CodedOutputStream codedOutputStream) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) entry.getKey();
        if (fieldDescriptor.getLiteJavaType() != WireFormat.JavaType.MESSAGE || fieldDescriptor.isRepeated() || fieldDescriptor.isPacked()) {
            writeField(fieldDescriptor, entry.getValue(), codedOutputStream);
            return;
        }
        Object value = entry.getValue();
        if (value instanceof LazyField) {
            value = ((LazyField) value).getValue();
        }
        codedOutputStream.writeMessageSetExtension(((Descriptors.FieldDescriptor) entry.getKey()).getNumber(), (MessageLite) value);
    }

    public FieldSet<T> clone() {
        FieldSet<T> fieldSet = new FieldSet<>();
        for (int i = 0; i < this.fields.getNumArrayEntries(); i++) {
            Map.Entry<T, Object> arrayEntryAt = this.fields.getArrayEntryAt(i);
            fieldSet.setField(arrayEntryAt.getKey(), arrayEntryAt.getValue());
        }
        for (Map.Entry<T, Object> entry : this.fields.getOverflowEntries()) {
            fieldSet.setField(entry.getKey(), entry.getValue());
        }
        fieldSet.hasLazyField = this.hasLazyField;
        return fieldSet;
    }

    public final class Builder<T extends FieldDescriptorLite<T>> {
        public SmallSortedMap<T, Object> fields = new SmallSortedMap<FieldDescriptorType, Object>(16) {
            /* class com.google.protobuf.SmallSortedMap.AnonymousClass1 */

            @Override // com.google.protobuf.SmallSortedMap
            public void makeImmutable() {
                Map<K, V> map;
                Map<K, V> map2;
                if (!this.isImmutable) {
                    for (int i = 0; i < getNumArrayEntries(); i++) {
                        Map.Entry<K, V> arrayEntryAt = getArrayEntryAt(i);
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) arrayEntryAt.getKey())).isRepeated()) {
                            arrayEntryAt.setValue((V) Collections.unmodifiableList(arrayEntryAt.getValue()));
                        }
                    }
                    for (Map.Entry<K, V> entry : getOverflowEntries()) {
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) entry.getKey())).isRepeated()) {
                            entry.setValue((V) Collections.unmodifiableList(entry.getValue()));
                        }
                    }
                }
                if (!this.isImmutable) {
                    if (this.overflowEntries.isEmpty()) {
                        map = Collections.emptyMap();
                    } else {
                        map = Collections.unmodifiableMap(this.overflowEntries);
                    }
                    this.overflowEntries = map;
                    if (this.overflowEntriesDescending.isEmpty()) {
                        map2 = Collections.emptyMap();
                    } else {
                        map2 = Collections.unmodifiableMap(this.overflowEntriesDescending);
                    }
                    this.overflowEntriesDescending = map2;
                    this.isImmutable = true;
                }
            }
        };
        public boolean hasLazyField;
        public boolean hasNestedBuilders;
        public boolean isMutable = true;

        public Builder(AnonymousClass1 r2) {
            int i = SmallSortedMap.$r8$clinit;
        }

        public static Object replaceBuilder(Object obj) {
            return obj instanceof MessageLite.Builder ? ((MessageLite.Builder) obj).build() : obj;
        }

        public static <T extends FieldDescriptorLite<T>> void replaceBuilders(SmallSortedMap<T, Object> smallSortedMap) {
            for (int i = 0; i < smallSortedMap.getNumArrayEntries(); i++) {
                Map.Entry<T, Object> arrayEntryAt = smallSortedMap.getArrayEntryAt(i);
                arrayEntryAt.setValue(replaceBuilders(arrayEntryAt.getKey(), arrayEntryAt.getValue()));
            }
            for (Map.Entry<T, Object> entry : smallSortedMap.getOverflowEntries()) {
                entry.setValue(replaceBuilders(entry.getKey(), entry.getValue()));
            }
        }

        public static void verifyType(WireFormat.FieldType fieldType, Object obj) {
            if (FieldSet.isValidType(fieldType, obj)) {
                return;
            }
            if (fieldType.getJavaType() != WireFormat.JavaType.MESSAGE || !(obj instanceof MessageLite.Builder)) {
                throw new IllegalArgumentException("Wrong object type used with protocol message reflection.");
            }
        }

        public final void ensureIsMutable() {
            if (!this.isMutable) {
                this.fields = FieldSet.cloneAllFieldsMap(this.fields, true);
                this.isMutable = true;
            }
        }

        public Object getFieldAllowBuilders(T t) {
            Object obj = this.fields.get(t);
            return obj instanceof LazyField ? ((LazyField) obj).getValue() : obj;
        }

        public Object getRepeatedFieldAllowBuilders(T t, int i) {
            Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
            if (fieldDescriptor.isRepeated()) {
                Object fieldAllowBuilders = getFieldAllowBuilders(fieldDescriptor);
                if (fieldAllowBuilders != null) {
                    return ((List) fieldAllowBuilders).get(i);
                }
                throw new IndexOutOfBoundsException();
            }
            throw new IllegalArgumentException("getRepeatedField() can only be called on repeated fields.");
        }

        public final void mergeFromField(Map.Entry<T, Object> entry) {
            T key = entry.getKey();
            Object value = entry.getValue();
            if (value instanceof LazyField) {
                value = ((LazyField) value).getValue();
            }
            Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) key;
            if (fieldDescriptor.isRepeated()) {
                Object replaceBuilders = replaceBuilders(fieldDescriptor, getFieldAllowBuilders(fieldDescriptor));
                if (replaceBuilders == null) {
                    replaceBuilders = new ArrayList();
                }
                for (Object obj : (List) value) {
                    ((List) replaceBuilders).add(FieldSet.cloneIfMutable(obj));
                }
                this.fields.put((T) fieldDescriptor, replaceBuilders);
            } else if (fieldDescriptor.getLiteJavaType() == WireFormat.JavaType.MESSAGE) {
                Object replaceBuilders2 = replaceBuilders(fieldDescriptor, getFieldAllowBuilders(fieldDescriptor));
                if (replaceBuilders2 == null) {
                    this.fields.put((T) fieldDescriptor, FieldSet.cloneIfMutable(value));
                } else if (replaceBuilders2 instanceof MessageLite.Builder) {
                    fieldDescriptor.internalMergeFrom((MessageLite.Builder) replaceBuilders2, (MessageLite) value);
                } else {
                    this.fields.put((T) fieldDescriptor, (Object) fieldDescriptor.internalMergeFrom(((MessageLite) replaceBuilders2).toBuilder(), (MessageLite) value).build());
                }
            } else {
                this.fields.put((T) fieldDescriptor, FieldSet.cloneIfMutable(value));
            }
        }

        public void setField(T t, Object obj) {
            ensureIsMutable();
            Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
            boolean z = true;
            if (!fieldDescriptor.isRepeated()) {
                verifyType(fieldDescriptor.getLiteType(), obj);
            } else if (obj instanceof List) {
                ArrayList arrayList = new ArrayList();
                arrayList.addAll((List) obj);
                Iterator it = arrayList.iterator();
                while (it.hasNext()) {
                    Object next = it.next();
                    verifyType(fieldDescriptor.getLiteType(), next);
                    this.hasNestedBuilders = this.hasNestedBuilders || (next instanceof MessageLite.Builder);
                }
                obj = arrayList;
            } else {
                throw new IllegalArgumentException("Wrong object type used with protocol message reflection.");
            }
            if (!this.hasNestedBuilders && !(obj instanceof MessageLite.Builder)) {
                z = false;
            }
            this.hasNestedBuilders = z;
            this.fields.put((T) fieldDescriptor, obj);
        }

        public static <T extends FieldDescriptorLite<T>> Object replaceBuilders(T t, Object obj) {
            if (obj == null) {
                return obj;
            }
            Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) t;
            if (fieldDescriptor.getLiteJavaType() != WireFormat.JavaType.MESSAGE) {
                return obj;
            }
            if (!fieldDescriptor.isRepeated()) {
                return replaceBuilder(obj);
            }
            if (obj instanceof List) {
                List list = (List) obj;
                for (int i = 0; i < list.size(); i++) {
                    Object obj2 = list.get(i);
                    Object replaceBuilder = replaceBuilder(obj2);
                    if (replaceBuilder != obj2) {
                        if (list == obj) {
                            list = new ArrayList(list);
                        }
                        list.set(i, replaceBuilder);
                    }
                }
                return list;
            }
            String valueOf = String.valueOf(obj.getClass());
            StringBuilder sb = new StringBuilder(valueOf.length() + 66);
            sb.append("Repeated field should contains a List but actually contains type: ");
            sb.append(valueOf);
            throw new IllegalStateException(sb.toString());
        }
    }

    public static <T extends FieldDescriptorLite<T>> boolean isInitialized(Map.Entry<T, Object> entry) {
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) entry.getKey();
        if (fieldDescriptor.getLiteJavaType() == WireFormat.JavaType.MESSAGE) {
            if (fieldDescriptor.isRepeated()) {
                for (MessageLite messageLite : (List) entry.getValue()) {
                    if (!messageLite.isInitialized()) {
                        return false;
                    }
                }
            } else {
                Object value = entry.getValue();
                if (value instanceof MessageLite) {
                    if (!((MessageLite) value).isInitialized()) {
                        return false;
                    }
                } else if (value instanceof LazyField) {
                    return true;
                } else {
                    throw new IllegalArgumentException("Wrong object type used with protocol message reflection.");
                }
            }
        }
        return true;
    }

    public final int getMessageSetSerializedSize(Map.Entry<T, Object> entry) {
        Object value = entry.getValue();
        Descriptors.FieldDescriptor fieldDescriptor = (Descriptors.FieldDescriptor) entry.getKey();
        if (fieldDescriptor.getLiteJavaType() != WireFormat.JavaType.MESSAGE || fieldDescriptor.isRepeated() || fieldDescriptor.isPacked()) {
            return computeFieldSize(fieldDescriptor, value);
        }
        if (!(value instanceof LazyField)) {
            return CodedOutputStream.computeMessageSetExtensionSize(((Descriptors.FieldDescriptor) entry.getKey()).getNumber(), (MessageLite) value);
        }
        return CodedOutputStream.computeLazyFieldSizeNoTag((LazyField) value) + CodedOutputStream.computeTagSize(3) + CodedOutputStream.computeUInt32Size(2, ((Descriptors.FieldDescriptor) entry.getKey()).getNumber()) + (CodedOutputStream.computeTagSize(1) * 2);
    }

    public FieldSet() {
        int i = SmallSortedMap.$r8$clinit;
        this.fields = new SmallSortedMap<FieldDescriptorType, Object>(16) {
            /* class com.google.protobuf.SmallSortedMap.AnonymousClass1 */

            @Override // com.google.protobuf.SmallSortedMap
            public void makeImmutable() {
                Map<K, V> map;
                Map<K, V> map2;
                if (!this.isImmutable) {
                    for (int i = 0; i < getNumArrayEntries(); i++) {
                        Map.Entry<K, V> arrayEntryAt = getArrayEntryAt(i);
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) arrayEntryAt.getKey())).isRepeated()) {
                            arrayEntryAt.setValue((V) Collections.unmodifiableList(arrayEntryAt.getValue()));
                        }
                    }
                    for (Map.Entry<K, V> entry : getOverflowEntries()) {
                        if (((Descriptors.FieldDescriptor) ((FieldSet.FieldDescriptorLite) entry.getKey())).isRepeated()) {
                            entry.setValue((V) Collections.unmodifiableList(entry.getValue()));
                        }
                    }
                }
                if (!this.isImmutable) {
                    if (this.overflowEntries.isEmpty()) {
                        map = Collections.emptyMap();
                    } else {
                        map = Collections.unmodifiableMap(this.overflowEntries);
                    }
                    this.overflowEntries = map;
                    if (this.overflowEntriesDescending.isEmpty()) {
                        map2 = Collections.emptyMap();
                    } else {
                        map2 = Collections.unmodifiableMap(this.overflowEntriesDescending);
                    }
                    this.overflowEntriesDescending = map2;
                    this.isImmutable = true;
                }
            }
        };
    }

    public FieldSet(SmallSortedMap smallSortedMap, AnonymousClass1 r2) {
        this.fields = smallSortedMap;
        makeImmutable();
    }
}
