package com.google.protobuf;

import com.google.protobuf.ByteString;
import com.google.protobuf.CodedOutputStream;
import com.google.protobuf.MessageLite;
import com.google.protobuf.TextFormat;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.TreeMap;
import java.util.logging.Logger;

public final class UnknownFieldSet implements MessageLite {
    public static final Parser PARSER = new Parser();
    public static final UnknownFieldSet defaultInstance = new UnknownFieldSet(Collections.emptyMap(), Collections.emptyMap());
    public final Map<Integer, Field> fields;
    public final Map<Integer, Field> fieldsDescending;

    public static final class Builder implements MessageLite.Builder {
        public Map<Integer, Field> fields;
        public Field.Builder lastField;
        public int lastFieldNumber;

        public Builder addField(int i, Field field) {
            if (i != 0) {
                if (this.lastField != null && this.lastFieldNumber == i) {
                    this.lastField = null;
                    this.lastFieldNumber = 0;
                }
                if (this.fields.isEmpty()) {
                    this.fields = new TreeMap();
                }
                this.fields.put(Integer.valueOf(i), field);
                return this;
            }
            throw new IllegalArgumentException("Zero is not a valid field number.");
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public MessageLite buildPartial() {
            return build();
        }

        @Override // java.lang.Object
        public Object clone() {
            getFieldBuilder(0);
            Map unmodifiableMap = Collections.unmodifiableMap(((TreeMap) this.fields).descendingMap());
            Builder newBuilder = UnknownFieldSet.newBuilder();
            newBuilder.mergeFrom(new UnknownFieldSet(this.fields, unmodifiableMap));
            return newBuilder;
        }

        @Override // com.google.protobuf.MessageLiteOrBuilder
        public MessageLite getDefaultInstanceForType() {
            return UnknownFieldSet.defaultInstance;
        }

        public final Field.Builder getFieldBuilder(int i) {
            Field.Builder builder = this.lastField;
            if (builder != null) {
                int i2 = this.lastFieldNumber;
                if (i == i2) {
                    return builder;
                }
                addField(i2, builder.build());
            }
            if (i == 0) {
                return null;
            }
            Field field = this.fields.get(Integer.valueOf(i));
            this.lastFieldNumber = i;
            Field.Builder newBuilder = Field.newBuilder();
            this.lastField = newBuilder;
            if (field != null) {
                newBuilder.mergeFrom(field);
            }
            return this.lastField;
        }

        @Override // com.google.protobuf.MessageLiteOrBuilder
        public boolean isInitialized() {
            return true;
        }

        public Builder mergeField(int i, Field field) {
            if (i == 0) {
                throw new IllegalArgumentException("Zero is not a valid field number.");
            } else if (i != 0) {
                if (i == this.lastFieldNumber || this.fields.containsKey(Integer.valueOf(i))) {
                    getFieldBuilder(i).mergeFrom(field);
                } else {
                    addField(i, field);
                }
                return this;
            } else {
                throw new IllegalArgumentException("Zero is not a valid field number.");
            }
        }

        public boolean mergeFieldFrom(int i, CodedInputStream codedInputStream) {
            int i2 = i >>> 3;
            int i3 = i & 7;
            if (i3 == 0) {
                getFieldBuilder(i2).addVarint(codedInputStream.readInt64());
                return true;
            } else if (i3 == 1) {
                getFieldBuilder(i2).addFixed64(codedInputStream.readFixed64());
                return true;
            } else if (i3 == 2) {
                getFieldBuilder(i2).addLengthDelimited(codedInputStream.readBytes());
                return true;
            } else if (i3 == 3) {
                Builder newBuilder = UnknownFieldSet.newBuilder();
                codedInputStream.readGroup(i2, newBuilder, ExtensionRegistry.EMPTY_REGISTRY);
                Field.Builder fieldBuilder = getFieldBuilder(i2);
                UnknownFieldSet build = newBuilder.build();
                Field field = fieldBuilder.result;
                if (field.group == null) {
                    field.group = new ArrayList();
                }
                fieldBuilder.result.group.add(build);
                return true;
            } else if (i3 == 4) {
                return false;
            } else {
                if (i3 == 5) {
                    getFieldBuilder(i2).addFixed32(codedInputStream.readFixed32());
                    return true;
                }
                throw InvalidProtocolBufferException.invalidWireType();
            }
        }

        public Builder mergeFrom(UnknownFieldSet unknownFieldSet) {
            if (unknownFieldSet != UnknownFieldSet.defaultInstance) {
                for (Map.Entry<Integer, Field> entry : unknownFieldSet.fields.entrySet()) {
                    mergeField(entry.getKey().intValue(), entry.getValue());
                }
            }
            return this;
        }

        public Builder mergeVarintField(int i, int i2) {
            if (i != 0) {
                getFieldBuilder(i).addVarint((long) i2);
                return this;
            }
            throw new IllegalArgumentException("Zero is not a valid field number.");
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public UnknownFieldSet build() {
            UnknownFieldSet unknownFieldSet;
            getFieldBuilder(0);
            if (this.fields.isEmpty()) {
                unknownFieldSet = UnknownFieldSet.defaultInstance;
            } else {
                unknownFieldSet = new UnknownFieldSet(Collections.unmodifiableMap(this.fields), Collections.unmodifiableMap(((TreeMap) this.fields).descendingMap()));
            }
            this.fields = null;
            return unknownFieldSet;
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public MessageLite.Builder mergeFrom(byte[] bArr) {
            try {
                CodedInputStream newInstance = CodedInputStream.newInstance(bArr, 0, bArr.length);
                mergeFrom(newInstance);
                newInstance.checkLastTagWas(0);
                return this;
            } catch (InvalidProtocolBufferException e) {
                throw e;
            } catch (IOException e2) {
                throw new RuntimeException("Reading from a byte array threw an IOException (should never happen).", e2);
            }
        }

        public Builder mergeFrom(CodedInputStream codedInputStream) {
            int readTag;
            do {
                readTag = codedInputStream.readTag();
                if (readTag == 0) {
                    break;
                }
            } while (mergeFieldFrom(readTag, codedInputStream));
            return this;
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public MessageLite.Builder mergeFrom(CodedInputStream codedInputStream, ExtensionRegistryLite extensionRegistryLite) {
            return mergeFrom(codedInputStream);
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public Builder mergeFrom(byte[] bArr, int i, int i2) {
            try {
                CodedInputStream newInstance = CodedInputStream.newInstance(bArr, i, i2);
                mergeFrom(newInstance);
                newInstance.checkLastTagWas(0);
                return this;
            } catch (InvalidProtocolBufferException e) {
                throw e;
            } catch (IOException e2) {
                throw new RuntimeException("Reading from a byte array threw an IOException (should never happen).", e2);
            }
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public MessageLite.Builder mergeFrom(byte[] bArr, int i, int i2, ExtensionRegistryLite extensionRegistryLite) {
            mergeFrom(bArr, i, i2);
            return this;
        }

        @Override // com.google.protobuf.MessageLite.Builder
        public MessageLite.Builder mergeFrom(MessageLite messageLite) {
            if (messageLite instanceof UnknownFieldSet) {
                mergeFrom((UnknownFieldSet) messageLite);
                return this;
            }
            throw new IllegalArgumentException("mergeFrom(MessageLite) can only merge messages of the same type.");
        }
    }

    public final class Field {
        public List<Integer> fixed32;
        public List<Long> fixed64;
        public List<UnknownFieldSet> group;
        public List<ByteString> lengthDelimited;
        public List<Long> varint;

        public final class Builder {
            public Field result;

            public Builder addFixed32(int i) {
                Field field = this.result;
                if (field.fixed32 == null) {
                    field.fixed32 = new ArrayList();
                }
                this.result.fixed32.add(Integer.valueOf(i));
                return this;
            }

            public Builder addFixed64(long j) {
                Field field = this.result;
                if (field.fixed64 == null) {
                    field.fixed64 = new ArrayList();
                }
                this.result.fixed64.add(Long.valueOf(j));
                return this;
            }

            public Builder addLengthDelimited(ByteString byteString) {
                Field field = this.result;
                if (field.lengthDelimited == null) {
                    field.lengthDelimited = new ArrayList();
                }
                this.result.lengthDelimited.add(byteString);
                return this;
            }

            public Builder addVarint(long j) {
                Field field = this.result;
                if (field.varint == null) {
                    field.varint = new ArrayList();
                }
                this.result.varint.add(Long.valueOf(j));
                return this;
            }

            public Field build() {
                Field field = this.result;
                List<Long> list = field.varint;
                if (list == null) {
                    field.varint = Collections.emptyList();
                } else {
                    field.varint = Collections.unmodifiableList(list);
                }
                Field field2 = this.result;
                List<Integer> list2 = field2.fixed32;
                if (list2 == null) {
                    field2.fixed32 = Collections.emptyList();
                } else {
                    field2.fixed32 = Collections.unmodifiableList(list2);
                }
                Field field3 = this.result;
                List<Long> list3 = field3.fixed64;
                if (list3 == null) {
                    field3.fixed64 = Collections.emptyList();
                } else {
                    field3.fixed64 = Collections.unmodifiableList(list3);
                }
                Field field4 = this.result;
                List<ByteString> list4 = field4.lengthDelimited;
                if (list4 == null) {
                    field4.lengthDelimited = Collections.emptyList();
                } else {
                    field4.lengthDelimited = Collections.unmodifiableList(list4);
                }
                Field field5 = this.result;
                List<UnknownFieldSet> list5 = field5.group;
                if (list5 == null) {
                    field5.group = Collections.emptyList();
                } else {
                    field5.group = Collections.unmodifiableList(list5);
                }
                Field field6 = this.result;
                this.result = null;
                return field6;
            }

            public Builder mergeFrom(Field field) {
                if (!field.varint.isEmpty()) {
                    Field field2 = this.result;
                    if (field2.varint == null) {
                        field2.varint = new ArrayList();
                    }
                    this.result.varint.addAll(field.varint);
                }
                if (!field.fixed32.isEmpty()) {
                    Field field3 = this.result;
                    if (field3.fixed32 == null) {
                        field3.fixed32 = new ArrayList();
                    }
                    this.result.fixed32.addAll(field.fixed32);
                }
                if (!field.fixed64.isEmpty()) {
                    Field field4 = this.result;
                    if (field4.fixed64 == null) {
                        field4.fixed64 = new ArrayList();
                    }
                    this.result.fixed64.addAll(field.fixed64);
                }
                if (!field.lengthDelimited.isEmpty()) {
                    Field field5 = this.result;
                    if (field5.lengthDelimited == null) {
                        field5.lengthDelimited = new ArrayList();
                    }
                    this.result.lengthDelimited.addAll(field.lengthDelimited);
                }
                if (!field.group.isEmpty()) {
                    Field field6 = this.result;
                    if (field6.group == null) {
                        field6.group = new ArrayList();
                    }
                    this.result.group.addAll(field.group);
                }
                return this;
            }
        }

        static {
            newBuilder().build();
        }

        public Field(AnonymousClass1 r1) {
        }

        public static Builder newBuilder() {
            Builder builder = new Builder();
            builder.result = new Field(null);
            return builder;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof Field)) {
                return false;
            }
            return Arrays.equals(getIdentityArray(), ((Field) obj).getIdentityArray());
        }

        public final Object[] getIdentityArray() {
            return new Object[]{this.varint, this.fixed32, this.fixed64, this.lengthDelimited, this.group};
        }

        public int hashCode() {
            return Arrays.hashCode(getIdentityArray());
        }
    }

    public final class Parser extends AbstractParser<UnknownFieldSet> {
        @Override // com.google.protobuf.Parser
        public Object parsePartialFrom(CodedInputStream codedInputStream, ExtensionRegistryLite extensionRegistryLite) {
            Builder newBuilder = UnknownFieldSet.newBuilder();
            try {
                newBuilder.mergeFrom(codedInputStream);
                return newBuilder.build();
            } catch (InvalidProtocolBufferException e) {
                throw e.setUnfinishedMessage(newBuilder.build());
            } catch (IOException e2) {
                throw new InvalidProtocolBufferException(e2).setUnfinishedMessage(newBuilder.build());
            }
        }
    }

    public UnknownFieldSet(Map<Integer, Field> map, Map<Integer, Field> map2) {
        this.fields = map;
        this.fieldsDescending = map2;
    }

    public static Builder newBuilder(UnknownFieldSet unknownFieldSet) {
        Builder newBuilder = newBuilder();
        newBuilder.mergeFrom(unknownFieldSet);
        return newBuilder;
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        return (obj instanceof UnknownFieldSet) && this.fields.equals(((UnknownFieldSet) obj).fields);
    }

    @Override // com.google.protobuf.MessageLiteOrBuilder
    public MessageLite getDefaultInstanceForType() {
        return defaultInstance;
    }

    @Override // com.google.protobuf.MessageLite
    public Parser getParserForType() {
        return PARSER;
    }

    @Override // com.google.protobuf.MessageLite
    public int getSerializedSize() {
        int i = 0;
        for (Map.Entry<Integer, Field> entry : this.fields.entrySet()) {
            Field value = entry.getValue();
            int intValue = entry.getKey().intValue();
            int i2 = 0;
            for (Long l : value.varint) {
                i2 += CodedOutputStream.computeUInt64Size(intValue, l.longValue());
            }
            for (Integer num : value.fixed32) {
                i2 += CodedOutputStream.computeFixed32Size(intValue, num.intValue());
            }
            for (Long l2 : value.fixed64) {
                i2 += CodedOutputStream.computeFixed64Size(intValue, l2.longValue());
            }
            for (ByteString byteString : value.lengthDelimited) {
                i2 += CodedOutputStream.computeBytesSize(intValue, byteString);
            }
            for (UnknownFieldSet unknownFieldSet : value.group) {
                i2 += unknownFieldSet.getSerializedSize() + (CodedOutputStream.computeTagSize(intValue) * 2);
            }
            i += i2;
        }
        return i;
    }

    public int getSerializedSizeAsMessageSet() {
        int i = 0;
        for (Map.Entry<Integer, Field> entry : this.fields.entrySet()) {
            int intValue = entry.getKey().intValue();
            int i2 = 0;
            for (ByteString byteString : entry.getValue().lengthDelimited) {
                i2 += CodedOutputStream.computeRawMessageSetExtensionSize(intValue, byteString);
            }
            i += i2;
        }
        return i;
    }

    public int hashCode() {
        return this.fields.hashCode();
    }

    @Override // com.google.protobuf.MessageLiteOrBuilder
    public boolean isInitialized() {
        return true;
    }

    @Override // com.google.protobuf.MessageLite
    public MessageLite.Builder newBuilderForType() {
        return newBuilder();
    }

    @Override // com.google.protobuf.MessageLite
    public MessageLite.Builder toBuilder() {
        Builder newBuilder = newBuilder();
        newBuilder.mergeFrom(this);
        return newBuilder;
    }

    @Override // com.google.protobuf.MessageLite
    public byte[] toByteArray() {
        try {
            int serializedSize = getSerializedSize();
            byte[] bArr = new byte[serializedSize];
            Logger logger = CodedOutputStream.logger;
            CodedOutputStream.ArrayEncoder arrayEncoder = new CodedOutputStream.ArrayEncoder(bArr, 0, serializedSize);
            writeTo(arrayEncoder);
            arrayEncoder.checkNoSpaceLeft();
            return bArr;
        } catch (IOException e) {
            throw new RuntimeException("Serializing to a byte array threw an IOException (should never happen).", e);
        }
    }

    @Override // com.google.protobuf.MessageLite
    public ByteString toByteString() {
        try {
            ByteString.CodedBuilder newCodedBuilder = ByteString.newCodedBuilder(getSerializedSize());
            writeTo(newCodedBuilder.output);
            return newCodedBuilder.build();
        } catch (IOException e) {
            throw new RuntimeException("Serializing to a ByteString threw an IOException (should never happen).", e);
        }
    }

    public String toString() {
        Logger logger = TextFormat.logger;
        Objects.requireNonNull(TextFormat.Printer.DEFAULT);
        try {
            StringBuilder sb = new StringBuilder();
            TextFormat.Printer.printUnknownFields(this, new TextFormat.TextGenerator(sb, false, null));
            return sb.toString();
        } catch (IOException e) {
            throw new IllegalStateException(e);
        }
    }

    public void writeAsMessageSetTo(CodedOutputStream codedOutputStream) {
        for (Map.Entry<Integer, Field> entry : this.fields.entrySet()) {
            int intValue = entry.getKey().intValue();
            for (ByteString byteString : entry.getValue().lengthDelimited) {
                codedOutputStream.writeRawMessageSetExtension(intValue, byteString);
            }
        }
    }

    @Override // com.google.protobuf.MessageLite
    public void writeTo(CodedOutputStream codedOutputStream) {
        for (Map.Entry<Integer, Field> entry : this.fields.entrySet()) {
            Field value = entry.getValue();
            int intValue = entry.getKey().intValue();
            for (Long l : value.varint) {
                codedOutputStream.writeUInt64(intValue, l.longValue());
            }
            for (Integer num : value.fixed32) {
                codedOutputStream.writeFixed32(intValue, num.intValue());
            }
            for (Long l2 : value.fixed64) {
                codedOutputStream.writeFixed64(intValue, l2.longValue());
            }
            for (ByteString byteString : value.lengthDelimited) {
                codedOutputStream.writeBytes(intValue, byteString);
            }
            for (UnknownFieldSet unknownFieldSet : value.group) {
                codedOutputStream.writeTag(intValue, 3);
                unknownFieldSet.writeTo(codedOutputStream);
                codedOutputStream.writeTag(intValue, 4);
            }
        }
    }

    public static Builder newBuilder() {
        Builder builder = new Builder();
        builder.fields = Collections.emptyMap();
        builder.lastFieldNumber = 0;
        builder.lastField = null;
        return builder;
    }
}
