package com.google.zxing.datamatrix;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.Dimension;
import com.google.zxing.EncodeHintType;
import com.google.zxing.Writer;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.datamatrix.encoder.ASCIIEncoder;
import com.google.zxing.datamatrix.encoder.Base256Encoder;
import com.google.zxing.datamatrix.encoder.C40Encoder;
import com.google.zxing.datamatrix.encoder.DefaultPlacement;
import com.google.zxing.datamatrix.encoder.EdifactEncoder;
import com.google.zxing.datamatrix.encoder.Encoder;
import com.google.zxing.datamatrix.encoder.EncoderContext;
import com.google.zxing.datamatrix.encoder.ErrorCorrection;
import com.google.zxing.datamatrix.encoder.SymbolInfo;
import com.google.zxing.datamatrix.encoder.SymbolShapeHint;
import com.google.zxing.datamatrix.encoder.TextEncoder;
import com.google.zxing.datamatrix.encoder.X12Encoder;
import com.google.zxing.qrcode.encoder.ByteMatrix;
import java.util.Map;
import org.xbill.DNS.CERTRecord;

public final class DataMatrixWriter implements Writer {
    @Override // com.google.zxing.Writer
    public BitMatrix encode(String str, BarcodeFormat barcodeFormat, int i, int i2, Map<EncodeHintType, ?> map) {
        int i3;
        int i4;
        if (str.isEmpty()) {
            throw new IllegalArgumentException("Found empty contents");
        } else if (barcodeFormat != BarcodeFormat.DATA_MATRIX) {
            throw new IllegalArgumentException("Can only encode DATA_MATRIX, but got " + barcodeFormat);
        } else if (i < 0 || i2 < 0) {
            throw new IllegalArgumentException("Requested dimensions are too small: " + i + 'x' + i2);
        } else {
            SymbolShapeHint symbolShapeHint = SymbolShapeHint.FORCE_NONE;
            if (map != null) {
                SymbolShapeHint symbolShapeHint2 = (SymbolShapeHint) map.get(EncodeHintType.DATA_MATRIX_SHAPE);
                if (symbolShapeHint2 != null) {
                    symbolShapeHint = symbolShapeHint2;
                }
                Dimension dimension = (Dimension) map.get(EncodeHintType.MIN_SIZE);
                Dimension dimension2 = (Dimension) map.get(EncodeHintType.MAX_SIZE);
            }
            Encoder[] encoderArr = {new ASCIIEncoder(), new C40Encoder(), new TextEncoder(), new X12Encoder(), new EdifactEncoder(), new Base256Encoder()};
            EncoderContext encoderContext = new EncoderContext(str);
            encoderContext.shape = symbolShapeHint;
            if (str.startsWith("[)>\u001e05\u001d") && str.endsWith("\u001e\u0004")) {
                encoderContext.codewords.append((char) 236);
                encoderContext.skipAtEnd = 2;
                encoderContext.pos += 7;
            } else if (str.startsWith("[)>\u001e06\u001d") && str.endsWith("\u001e\u0004")) {
                encoderContext.codewords.append((char) 237);
                encoderContext.skipAtEnd = 2;
                encoderContext.pos += 7;
            }
            int i5 = 0;
            while (encoderContext.hasMoreCharacters()) {
                encoderArr[i5].encode(encoderContext);
                int i6 = encoderContext.newEncoding;
                if (i6 >= 0) {
                    encoderContext.newEncoding = -1;
                    i5 = i6;
                }
            }
            int codewordCount = encoderContext.getCodewordCount();
            encoderContext.updateSymbolInfo();
            int i7 = encoderContext.symbolInfo.dataCapacity;
            if (!(codewordCount >= i7 || i5 == 0 || i5 == 5)) {
                encoderContext.codewords.append((char) 254);
            }
            StringBuilder sb = encoderContext.codewords;
            if (sb.length() < i7) {
                sb.append((char) 129);
            }
            while (sb.length() < i7) {
                int length = (((sb.length() + 1) * 149) % CERTRecord.URI) + 1 + 129;
                if (length > 254) {
                    length -= 254;
                }
                sb.append((char) length);
            }
            String sb2 = encoderContext.codewords.toString();
            SymbolInfo lookup = SymbolInfo.lookup(sb2.length(), symbolShapeHint, true);
            int[] iArr = ErrorCorrection.FACTOR_SETS;
            int length2 = sb2.length();
            int i8 = lookup.dataCapacity;
            if (length2 == i8) {
                StringBuilder sb3 = new StringBuilder(i8 + lookup.errorCodewords);
                sb3.append(sb2);
                int interleavedBlockCount = lookup.getInterleavedBlockCount();
                if (interleavedBlockCount == 1) {
                    sb3.append(ErrorCorrection.createECCBlock(sb2, lookup.errorCodewords));
                } else {
                    sb3.setLength(sb3.capacity());
                    int[] iArr2 = new int[interleavedBlockCount];
                    int[] iArr3 = new int[interleavedBlockCount];
                    int[] iArr4 = new int[interleavedBlockCount];
                    int i9 = 0;
                    while (i9 < interleavedBlockCount) {
                        int i10 = i9 + 1;
                        iArr2[i9] = lookup.getDataLengthForInterleavedBlock(i10);
                        iArr3[i9] = lookup.rsBlockError;
                        iArr4[i9] = 0;
                        if (i9 > 0) {
                            iArr4[i9] = iArr4[i9 - 1] + iArr2[i9];
                        }
                        i9 = i10;
                    }
                    for (int i11 = 0; i11 < interleavedBlockCount; i11++) {
                        StringBuilder sb4 = new StringBuilder(iArr2[i11]);
                        for (int i12 = i11; i12 < lookup.dataCapacity; i12 += interleavedBlockCount) {
                            sb4.append(sb2.charAt(i12));
                        }
                        String createECCBlock = ErrorCorrection.createECCBlock(sb4.toString(), iArr3[i11]);
                        int i13 = i11;
                        int i14 = 0;
                        while (i13 < iArr3[i11] * interleavedBlockCount) {
                            sb3.setCharAt(lookup.dataCapacity + i13, createECCBlock.charAt(i14));
                            i13 += interleavedBlockCount;
                            i14++;
                        }
                    }
                }
                DefaultPlacement defaultPlacement = new DefaultPlacement(sb3.toString(), lookup.getSymbolDataWidth(), lookup.getSymbolDataHeight());
                int i15 = 4;
                int i16 = 0;
                int i17 = 0;
                while (true) {
                    int i18 = defaultPlacement.numrows;
                    if (i15 == i18 && i16 == 0) {
                        defaultPlacement.module(i18 - 1, 0, i17, 1);
                        defaultPlacement.module(defaultPlacement.numrows - 1, 1, i17, 2);
                        defaultPlacement.module(defaultPlacement.numrows - 1, 2, i17, 3);
                        defaultPlacement.module(0, defaultPlacement.numcols - 2, i17, 4);
                        defaultPlacement.module(0, defaultPlacement.numcols - 1, i17, 5);
                        defaultPlacement.module(1, defaultPlacement.numcols - 1, i17, 6);
                        defaultPlacement.module(2, defaultPlacement.numcols - 1, i17, 7);
                        defaultPlacement.module(3, defaultPlacement.numcols - 1, i17, 8);
                        i17++;
                    }
                    int i19 = defaultPlacement.numrows;
                    if (i15 == i19 - 2 && i16 == 0 && defaultPlacement.numcols % 4 != 0) {
                        defaultPlacement.module(i19 - 3, 0, i17, 1);
                        defaultPlacement.module(defaultPlacement.numrows - 2, 0, i17, 2);
                        defaultPlacement.module(defaultPlacement.numrows - 1, 0, i17, 3);
                        defaultPlacement.module(0, defaultPlacement.numcols - 4, i17, 4);
                        defaultPlacement.module(0, defaultPlacement.numcols - 3, i17, 5);
                        defaultPlacement.module(0, defaultPlacement.numcols - 2, i17, 6);
                        defaultPlacement.module(0, defaultPlacement.numcols - 1, i17, 7);
                        defaultPlacement.module(1, defaultPlacement.numcols - 1, i17, 8);
                        i17++;
                    }
                    int i20 = defaultPlacement.numrows;
                    if (i15 == i20 - 2 && i16 == 0 && defaultPlacement.numcols % 8 == 4) {
                        defaultPlacement.module(i20 - 3, 0, i17, 1);
                        defaultPlacement.module(defaultPlacement.numrows - 2, 0, i17, 2);
                        defaultPlacement.module(defaultPlacement.numrows - 1, 0, i17, 3);
                        defaultPlacement.module(0, defaultPlacement.numcols - 2, i17, 4);
                        defaultPlacement.module(0, defaultPlacement.numcols - 1, i17, 5);
                        defaultPlacement.module(1, defaultPlacement.numcols - 1, i17, 6);
                        defaultPlacement.module(2, defaultPlacement.numcols - 1, i17, 7);
                        defaultPlacement.module(3, defaultPlacement.numcols - 1, i17, 8);
                        i17++;
                    }
                    int i21 = defaultPlacement.numrows;
                    if (i15 == i21 + 4 && i16 == 2 && defaultPlacement.numcols % 8 == 0) {
                        defaultPlacement.module(i21 - 1, 0, i17, 1);
                        defaultPlacement.module(defaultPlacement.numrows - 1, defaultPlacement.numcols - 1, i17, 2);
                        defaultPlacement.module(0, defaultPlacement.numcols - 3, i17, 3);
                        defaultPlacement.module(0, defaultPlacement.numcols - 2, i17, 4);
                        defaultPlacement.module(0, defaultPlacement.numcols - 1, i17, 5);
                        defaultPlacement.module(1, defaultPlacement.numcols - 3, i17, 6);
                        defaultPlacement.module(1, defaultPlacement.numcols - 2, i17, 7);
                        defaultPlacement.module(1, defaultPlacement.numcols - 1, i17, 8);
                        i17++;
                    }
                    do {
                        if (i15 < defaultPlacement.numrows && i16 >= 0 && !defaultPlacement.hasBit(i16, i15)) {
                            defaultPlacement.utah(i15, i16, i17);
                            i17++;
                        }
                        i15 -= 2;
                        i16 += 2;
                        if (i15 < 0) {
                            break;
                        }
                    } while (i16 < defaultPlacement.numcols);
                    int i22 = i15 + 1;
                    int i23 = i16 + 3;
                    do {
                        if (i22 >= 0 && i23 < defaultPlacement.numcols && !defaultPlacement.hasBit(i23, i22)) {
                            defaultPlacement.utah(i22, i23, i17);
                            i17++;
                        }
                        i22 += 2;
                        i23 -= 2;
                        i3 = defaultPlacement.numrows;
                        if (i22 >= i3) {
                            break;
                        }
                    } while (i23 >= 0);
                    i15 = i22 + 3;
                    i16 = i23 + 1;
                    if (i15 >= i3 && i16 >= (i4 = defaultPlacement.numcols)) {
                        break;
                    }
                }
                if (!defaultPlacement.hasBit(i4 - 1, i3 - 1)) {
                    defaultPlacement.setBit(defaultPlacement.numcols - 1, defaultPlacement.numrows - 1, true);
                    defaultPlacement.setBit(defaultPlacement.numcols - 2, defaultPlacement.numrows - 2, true);
                }
                int symbolDataWidth = lookup.getSymbolDataWidth();
                int symbolDataHeight = lookup.getSymbolDataHeight();
                ByteMatrix byteMatrix = new ByteMatrix(lookup.getSymbolWidth(), lookup.getSymbolHeight());
                int i24 = 0;
                for (int i25 = 0; i25 < symbolDataHeight; i25++) {
                    if (i25 % lookup.matrixHeight == 0) {
                        int i26 = 0;
                        for (int i27 = 0; i27 < lookup.getSymbolWidth(); i27++) {
                            byteMatrix.set(i26, i24, i27 % 2 == 0);
                            i26++;
                        }
                        i24++;
                    }
                    int i28 = 0;
                    for (int i29 = 0; i29 < symbolDataWidth; i29++) {
                        if (i29 % lookup.matrixWidth == 0) {
                            byteMatrix.set(i28, i24, true);
                            i28++;
                        }
                        byteMatrix.set(i28, i24, defaultPlacement.bits[(defaultPlacement.numcols * i25) + i29] == 1);
                        i28++;
                        int i30 = lookup.matrixWidth;
                        if (i29 % i30 == i30 - 1) {
                            byteMatrix.set(i28, i24, i25 % 2 == 0);
                            i28++;
                        }
                    }
                    i24++;
                    int i31 = lookup.matrixHeight;
                    if (i25 % i31 == i31 - 1) {
                        int i32 = 0;
                        for (int i33 = 0; i33 < lookup.getSymbolWidth(); i33++) {
                            byteMatrix.set(i32, i24, true);
                            i32++;
                        }
                        i24++;
                    }
                }
                int i34 = byteMatrix.width;
                int i35 = byteMatrix.height;
                BitMatrix bitMatrix = new BitMatrix(i34, i35);
                int length3 = bitMatrix.bits.length;
                for (int i36 = 0; i36 < length3; i36++) {
                    bitMatrix.bits[i36] = 0;
                }
                for (int i37 = 0; i37 < i34; i37++) {
                    for (int i38 = 0; i38 < i35; i38++) {
                        if (byteMatrix.get(i37, i38) == 1) {
                            bitMatrix.set(i37, i38);
                        }
                    }
                }
                return bitMatrix;
            }
            throw new IllegalArgumentException("The number of codewords does not match the selected symbol");
        }
    }
}
