package com.google.zxing.datamatrix.detector;

import androidx.transition.ViewGroupUtilsApi14;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.common.DefaultGridSampler;
import com.google.zxing.common.PerspectiveTransform;
import com.google.zxing.common.detector.WhiteRectangleDetector;
import java.io.Serializable;
import java.util.Comparator;
import java.util.Map;

public final class Detector {
    public final BitMatrix image;
    public final WhiteRectangleDetector rectangleDetector;

    public final class ResultPointsAndTransitions {
        public final ResultPoint from;
        public final ResultPoint to;
        public final int transitions;

        public ResultPointsAndTransitions(ResultPoint resultPoint, ResultPoint resultPoint2, int i, AnonymousClass1 r4) {
            this.from = resultPoint;
            this.to = resultPoint2;
            this.transitions = i;
        }

        public String toString() {
            return this.from + "/" + this.to + '/' + this.transitions;
        }
    }

    public final class ResultPointsAndTransitionsComparator implements Serializable, Comparator<ResultPointsAndTransitions> {
        public ResultPointsAndTransitionsComparator(AnonymousClass1 r1) {
        }

        public int compare(ResultPointsAndTransitions resultPointsAndTransitions, ResultPointsAndTransitions resultPointsAndTransitions2) {
            return resultPointsAndTransitions.transitions - resultPointsAndTransitions2.transitions;
        }
    }

    public Detector(BitMatrix bitMatrix) {
        this.image = bitMatrix;
        this.rectangleDetector = new WhiteRectangleDetector(bitMatrix, 10, bitMatrix.width / 2, bitMatrix.height / 2);
    }

    public static int distance(ResultPoint resultPoint, ResultPoint resultPoint2) {
        return ViewGroupUtilsApi14.round(ViewGroupUtilsApi14.distance(resultPoint.x, resultPoint.y, resultPoint2.x, resultPoint2.y));
    }

    public static void increment(Map<ResultPoint, Integer> map, ResultPoint resultPoint) {
        Integer num = map.get(resultPoint);
        int i = 1;
        if (num != null) {
            i = 1 + num.intValue();
        }
        map.put(resultPoint, Integer.valueOf(i));
    }

    public static BitMatrix sampleGrid(BitMatrix bitMatrix, ResultPoint resultPoint, ResultPoint resultPoint2, ResultPoint resultPoint3, ResultPoint resultPoint4, int i, int i2) {
        float f = ((float) i) - 0.5f;
        float f2 = ((float) i2) - 0.5f;
        return DefaultGridSampler.gridSampler.sampleGrid(bitMatrix, i, i2, PerspectiveTransform.quadrilateralToQuadrilateral(0.5f, 0.5f, f, 0.5f, f, f2, 0.5f, f2, resultPoint.x, resultPoint.y, resultPoint4.x, resultPoint4.y, resultPoint3.x, resultPoint3.y, resultPoint2.x, resultPoint2.y));
    }

    public final boolean isValid(ResultPoint resultPoint) {
        float f = resultPoint.x;
        if (f < 0.0f) {
            return false;
        }
        BitMatrix bitMatrix = this.image;
        if (f >= ((float) bitMatrix.width)) {
            return false;
        }
        float f2 = resultPoint.y;
        return f2 > 0.0f && f2 < ((float) bitMatrix.height);
    }

    public final ResultPointsAndTransitions transitionsBetween(ResultPoint resultPoint, ResultPoint resultPoint2) {
        Detector detector = this;
        int i = (int) resultPoint.x;
        int i2 = (int) resultPoint.y;
        int i3 = (int) resultPoint2.x;
        int i4 = (int) resultPoint2.y;
        int i5 = 1;
        boolean z = Math.abs(i4 - i2) > Math.abs(i3 - i);
        if (z) {
            i2 = i;
            i = i2;
            i4 = i3;
            i3 = i4;
        }
        int abs = Math.abs(i3 - i);
        int abs2 = Math.abs(i4 - i2);
        int i6 = (-abs) / 2;
        int i7 = i2 < i4 ? 1 : -1;
        if (i >= i3) {
            i5 = -1;
        }
        boolean z2 = detector.image.get(z ? i2 : i, z ? i : i2);
        int i8 = 0;
        while (i != i3) {
            boolean z3 = detector.image.get(z ? i2 : i, z ? i : i2);
            if (z3 != z2) {
                i8++;
                z2 = z3;
            }
            i6 += abs2;
            if (i6 > 0) {
                if (i2 == i4) {
                    break;
                }
                i2 += i7;
                i6 -= abs;
            }
            i += i5;
            detector = this;
        }
        return new ResultPointsAndTransitions(resultPoint, resultPoint2, i8, null);
    }
}
