package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.DecodeHintType;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.Arrays;
import java.util.Map;

public final class CodaBarReader extends OneDReader {
    public static final char[] ALPHABET = "0123456789-$:/.+ABCD".toCharArray();
    public static final int[] CHARACTER_ENCODINGS = {3, 6, 9, 96, 18, 66, 33, 36, 48, 72, 12, 24, 69, 81, 84, 21, 26, 41, 11, 14};
    public static final char[] STARTEND_ENCODING = {'A', 'B', 'C', 'D'};
    public int counterLength = 0;
    public int[] counters = new int[80];
    public final StringBuilder decodeRowResult = new StringBuilder(20);

    public static boolean arrayContains(char[] cArr, char c) {
        if (cArr != null) {
            for (char c2 : cArr) {
                if (c2 == c) {
                    return true;
                }
            }
        }
        return false;
    }

    public final void counterAppend(int i) {
        int[] iArr = this.counters;
        int i2 = this.counterLength;
        iArr[i2] = i;
        int i3 = i2 + 1;
        this.counterLength = i3;
        if (i3 >= iArr.length) {
            int[] iArr2 = new int[(i3 << 1)];
            System.arraycopy(iArr, 0, iArr2, 0, i3);
            this.counters = iArr2;
        }
    }

    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) {
        Arrays.fill(this.counters, 0);
        this.counterLength = 0;
        int nextUnset = bitArray.getNextUnset(0);
        int i2 = bitArray.size;
        if (nextUnset < i2) {
            int i3 = 0;
            boolean z = true;
            while (nextUnset < i2) {
                if (bitArray.get(nextUnset) ^ z) {
                    i3++;
                } else {
                    counterAppend(i3);
                    z = !z;
                    i3 = 1;
                }
                nextUnset++;
            }
            counterAppend(i3);
            int i4 = 1;
            while (i4 < this.counterLength) {
                int narrowWidePattern = toNarrowWidePattern(i4);
                if (narrowWidePattern != -1 && arrayContains(STARTEND_ENCODING, ALPHABET[narrowWidePattern])) {
                    int i5 = 0;
                    for (int i6 = i4; i6 < i4 + 7; i6++) {
                        i5 += this.counters[i6];
                    }
                    if (i4 == 1 || this.counters[i4 - 1] >= i5 / 2) {
                        this.decodeRowResult.setLength(0);
                        int i7 = i4;
                        while (true) {
                            int narrowWidePattern2 = toNarrowWidePattern(i7);
                            if (narrowWidePattern2 != -1) {
                                this.decodeRowResult.append((char) narrowWidePattern2);
                                i7 += 8;
                                if ((this.decodeRowResult.length() <= 1 || !arrayContains(STARTEND_ENCODING, ALPHABET[narrowWidePattern2])) && i7 < this.counterLength) {
                                }
                            } else {
                                throw NotFoundException.getNotFoundInstance();
                            }
                        }
                        int i8 = i7 - 1;
                        int i9 = this.counters[i8];
                        int i10 = 0;
                        for (int i11 = -8; i11 < -1; i11++) {
                            i10 += this.counters[i7 + i11];
                        }
                        if (i7 >= this.counterLength || i9 >= i10 / 2) {
                            int[] iArr = {0, 0, 0, 0};
                            int[] iArr2 = {0, 0, 0, 0};
                            int length = this.decodeRowResult.length() - 1;
                            int i12 = i4;
                            int i13 = 0;
                            while (true) {
                                int i14 = CHARACTER_ENCODINGS[this.decodeRowResult.charAt(i13)];
                                for (int i15 = 6; i15 >= 0; i15--) {
                                    int i16 = (i15 & 1) + ((i14 & 1) << 1);
                                    iArr[i16] = iArr[i16] + this.counters[i12 + i15];
                                    iArr2[i16] = iArr2[i16] + 1;
                                    i14 >>= 1;
                                }
                                if (i13 >= length) {
                                    break;
                                }
                                i12 += 8;
                                i13++;
                            }
                            float[] fArr = new float[4];
                            float[] fArr2 = new float[4];
                            int i17 = 0;
                            for (int i18 = 2; i17 < i18; i18 = 2) {
                                fArr2[i17] = 0.0f;
                                int i19 = i17 + 2;
                                fArr2[i19] = ((((float) iArr[i19]) / ((float) iArr2[i19])) + (((float) iArr[i17]) / ((float) iArr2[i17]))) / 2.0f;
                                fArr[i17] = fArr2[i19];
                                fArr[i19] = ((((float) iArr[i19]) * 2.0f) + 1.5f) / ((float) iArr2[i19]);
                                i17++;
                            }
                            int i20 = i4;
                            int i21 = 0;
                            loop8:
                            while (true) {
                                int i22 = CHARACTER_ENCODINGS[this.decodeRowResult.charAt(i21)];
                                for (int i23 = 6; i23 >= 0; i23--) {
                                    int i24 = (i23 & 1) + ((i22 & 1) << 1);
                                    float f = (float) this.counters[i20 + i23];
                                    if (f >= fArr2[i24] && f <= fArr[i24]) {
                                        i22 >>= 1;
                                    }
                                }
                                if (i21 < length) {
                                    i20 += 8;
                                    i21++;
                                } else {
                                    for (int i25 = 0; i25 < this.decodeRowResult.length(); i25++) {
                                        StringBuilder sb = this.decodeRowResult;
                                        sb.setCharAt(i25, ALPHABET[sb.charAt(i25)]);
                                    }
                                    char charAt = this.decodeRowResult.charAt(0);
                                    char[] cArr = STARTEND_ENCODING;
                                    if (arrayContains(cArr, charAt)) {
                                        StringBuilder sb2 = this.decodeRowResult;
                                        if (!arrayContains(cArr, sb2.charAt(sb2.length() - 1))) {
                                            throw NotFoundException.getNotFoundInstance();
                                        } else if (this.decodeRowResult.length() > 3) {
                                            if (map == null || !map.containsKey(DecodeHintType.RETURN_CODABAR_START_END)) {
                                                StringBuilder sb3 = this.decodeRowResult;
                                                sb3.deleteCharAt(sb3.length() - 1);
                                                this.decodeRowResult.deleteCharAt(0);
                                            }
                                            int i26 = 0;
                                            for (int i27 = 0; i27 < i4; i27++) {
                                                i26 += this.counters[i27];
                                            }
                                            float f2 = (float) i26;
                                            while (i4 < i8) {
                                                i26 += this.counters[i4];
                                                i4++;
                                            }
                                            float f3 = (float) i;
                                            return new Result(this.decodeRowResult.toString(), null, new ResultPoint[]{new ResultPoint(f2, f3), new ResultPoint((float) i26, f3)}, BarcodeFormat.CODABAR);
                                        } else {
                                            throw NotFoundException.getNotFoundInstance();
                                        }
                                    } else {
                                        throw NotFoundException.getNotFoundInstance();
                                    }
                                }
                            }
                            throw NotFoundException.getNotFoundInstance();
                        }
                        throw NotFoundException.getNotFoundInstance();
                    }
                }
                i4 += 2;
            }
            throw NotFoundException.getNotFoundInstance();
        }
        throw NotFoundException.getNotFoundInstance();
    }

    public final int toNarrowWidePattern(int i) {
        int i2 = i + 7;
        if (i2 >= this.counterLength) {
            return -1;
        }
        int[] iArr = this.counters;
        int i3 = Integer.MAX_VALUE;
        int i4 = 0;
        int i5 = Integer.MAX_VALUE;
        int i6 = 0;
        for (int i7 = i; i7 < i2; i7 += 2) {
            int i8 = iArr[i7];
            if (i8 < i5) {
                i5 = i8;
            }
            if (i8 > i6) {
                i6 = i8;
            }
        }
        int i9 = (i5 + i6) / 2;
        int i10 = 0;
        for (int i11 = i + 1; i11 < i2; i11 += 2) {
            int i12 = iArr[i11];
            if (i12 < i3) {
                i3 = i12;
            }
            if (i12 > i10) {
                i10 = i12;
            }
        }
        int i13 = (i3 + i10) / 2;
        int i14 = 128;
        int i15 = 0;
        for (int i16 = 0; i16 < 7; i16++) {
            i14 >>= 1;
            if (iArr[i + i16] > ((i16 & 1) == 0 ? i9 : i13)) {
                i15 |= i14;
            }
        }
        while (true) {
            int[] iArr2 = CHARACTER_ENCODINGS;
            if (i4 >= iArr2.length) {
                return -1;
            }
            if (iArr2[i4] == i15) {
                return i4;
            }
            i4++;
        }
    }
}
