package com.google.zxing.oned.rss.expanded;

import androidx.transition.ViewGroupUtilsApi14;
import com.allpayx.sdk.constants.AllPayConst;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.DecodeHintType;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import com.google.zxing.oned.OneDReader;
import com.google.zxing.oned.rss.AbstractRSSReader;
import com.google.zxing.oned.rss.DataCharacter;
import com.google.zxing.oned.rss.FinderPattern;
import com.google.zxing.oned.rss.expanded.decoders.AI013103decoder;
import com.google.zxing.oned.rss.expanded.decoders.AI01320xDecoder;
import com.google.zxing.oned.rss.expanded.decoders.AI01392xDecoder;
import com.google.zxing.oned.rss.expanded.decoders.AI01393xDecoder;
import com.google.zxing.oned.rss.expanded.decoders.AI013x0x1xDecoder;
import com.google.zxing.oned.rss.expanded.decoders.AI01AndOtherAIs;
import com.google.zxing.oned.rss.expanded.decoders.AbstractExpandedDecoder;
import com.google.zxing.oned.rss.expanded.decoders.AnyAIDecoder;
import com.google.zxing.oned.rss.expanded.decoders.GeneralAppIdDecoder;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public final class RSSExpandedReader extends AbstractRSSReader {
    public static final int[] EVEN_TOTAL_SUBSET = {4, 20, 52, 104, 204};
    public static final int[][] FINDER_PATTERNS = {new int[]{1, 8, 4, 1}, new int[]{3, 6, 4, 1}, new int[]{3, 4, 6, 1}, new int[]{3, 2, 8, 1}, new int[]{2, 6, 5, 1}, new int[]{2, 2, 9, 1}};
    public static final int[][] FINDER_PATTERN_SEQUENCES = {new int[]{0, 0}, new int[]{0, 1, 1}, new int[]{0, 2, 1, 3}, new int[]{0, 4, 1, 3, 2}, new int[]{0, 4, 1, 3, 3, 5}, new int[]{0, 4, 1, 3, 4, 5, 5}, new int[]{0, 0, 1, 1, 2, 2, 3, 3}, new int[]{0, 0, 1, 1, 2, 2, 3, 4, 4}, new int[]{0, 0, 1, 1, 2, 2, 3, 4, 5, 5}, new int[]{0, 0, 1, 1, 2, 3, 3, 4, 4, 5, 5}};
    public static final int[] GSUM = {0, 348, 1388, 2948, 3988};
    public static final int[] SYMBOL_WIDEST = {7, 5, 4, 3, 1};
    public static final int[][] WEIGHTS = {new int[]{1, 3, 9, 27, 81, 32, 96, 77}, new int[]{20, 60, 180, 118, 143, 7, 21, 63}, new int[]{189, 145, 13, 39, 117, 140, 209, 205}, new int[]{193, 157, 49, 147, 19, 57, 171, 91}, new int[]{62, 186, 136, 197, 169, 85, 44, 132}, new int[]{185, 133, 188, 142, 4, 12, 36, 108}, new int[]{113, 128, 173, 97, 80, 29, 87, 50}, new int[]{150, 28, 84, 41, 123, 158, 52, 156}, new int[]{46, 138, 203, 187, 139, 206, 196, 166}, new int[]{76, 17, 51, 153, 37, 111, 122, 155}, new int[]{43, 129, 176, 106, 107, 110, 119, 146}, new int[]{16, 48, 144, 10, 30, 90, 59, 177}, new int[]{109, 116, 137, AllPayConst.VTPAY_PAY_RESULT_CODE, 178, 112, 125, 164}, new int[]{70, 210, 208, 202, 184, 130, 179, 115}, new int[]{134, 191, 151, 31, 93, 68, 204, 190}, new int[]{148, 22, 66, 198, 172, 94, 71, 2}, new int[]{6, 18, 54, 162, 64, 192, 154, 40}, new int[]{120, 149, 25, 75, 14, 42, 126, 167}, new int[]{79, 26, 78, 23, 69, 207, 199, 175}, new int[]{103, 98, 83, 38, 114, 131, 182, 124}, new int[]{161, 61, 183, 127, 170, 88, 53, 159}, new int[]{55, 165, 73, 8, 24, 72, 5, 15}, new int[]{45, 135, 194, 160, 58, 174, 100, 89}};
    public final List<ExpandedPair> pairs = new ArrayList(11);
    public final List<ExpandedRow> rows = new ArrayList();
    public final int[] startEnd = new int[2];
    public boolean startFromEven;

    public static Result constructResult(List<ExpandedPair> list) {
        AbstractExpandedDecoder abstractExpandedDecoder;
        int size = (list.size() << 1) - 1;
        if (list.get(list.size() - 1).rightChar == null) {
            size--;
        }
        BitArray bitArray = new BitArray(size * 12);
        int i = list.get(0).rightChar.value;
        int i2 = 0;
        for (int i3 = 11; i3 >= 0; i3--) {
            if (((1 << i3) & i) != 0) {
                bitArray.set(i2);
            }
            i2++;
        }
        for (int i4 = 1; i4 < list.size(); i4++) {
            ExpandedPair expandedPair = list.get(i4);
            int i5 = expandedPair.leftChar.value;
            for (int i6 = 11; i6 >= 0; i6--) {
                if (((1 << i6) & i5) != 0) {
                    bitArray.set(i2);
                }
                i2++;
            }
            DataCharacter dataCharacter = expandedPair.rightChar;
            if (dataCharacter != null) {
                int i7 = dataCharacter.value;
                for (int i8 = 11; i8 >= 0; i8--) {
                    if (((1 << i8) & i7) != 0) {
                        bitArray.set(i2);
                    }
                    i2++;
                }
            }
        }
        if (bitArray.get(1)) {
            abstractExpandedDecoder = new AI01AndOtherAIs(bitArray);
        } else if (!bitArray.get(2)) {
            abstractExpandedDecoder = new AnyAIDecoder(bitArray);
        } else {
            int extractNumericValueFromBitArray = GeneralAppIdDecoder.extractNumericValueFromBitArray(bitArray, 1, 4);
            if (extractNumericValueFromBitArray == 4) {
                abstractExpandedDecoder = new AI013103decoder(bitArray);
            } else if (extractNumericValueFromBitArray != 5) {
                int extractNumericValueFromBitArray2 = GeneralAppIdDecoder.extractNumericValueFromBitArray(bitArray, 1, 5);
                if (extractNumericValueFromBitArray2 == 12) {
                    abstractExpandedDecoder = new AI01392xDecoder(bitArray);
                } else if (extractNumericValueFromBitArray2 != 13) {
                    switch (GeneralAppIdDecoder.extractNumericValueFromBitArray(bitArray, 1, 7)) {
                        case 56:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "310", "11");
                            break;
                        case 57:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "320", "11");
                            break;
                        case 58:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "310", "13");
                            break;
                        case 59:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "320", "13");
                            break;
                        case 60:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "310", "15");
                            break;
                        case 61:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "320", "15");
                            break;
                        case 62:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "310", "17");
                            break;
                        case 63:
                            abstractExpandedDecoder = new AI013x0x1xDecoder(bitArray, "320", "17");
                            break;
                        default:
                            throw new IllegalStateException("unknown decoder: " + bitArray);
                    }
                } else {
                    abstractExpandedDecoder = new AI01393xDecoder(bitArray);
                }
            } else {
                abstractExpandedDecoder = new AI01320xDecoder(bitArray);
            }
        }
        String parseInformation = abstractExpandedDecoder.parseInformation();
        ResultPoint[] resultPointArr = list.get(0).finderPattern.resultPoints;
        ResultPoint[] resultPointArr2 = list.get(list.size() - 1).finderPattern.resultPoints;
        return new Result(parseInformation, null, new ResultPoint[]{resultPointArr[0], resultPointArr[1], resultPointArr2[0], resultPointArr2[1]}, BarcodeFormat.RSS_EXPANDED);
    }

    public static void reverseCounters(int[] iArr) {
        int length = iArr.length;
        for (int i = 0; i < length / 2; i++) {
            int i2 = iArr[i];
            int i3 = (length - i) - 1;
            iArr[i] = iArr[i3];
            iArr[i3] = i2;
        }
    }

    public final boolean checkChecksum() {
        ExpandedPair expandedPair = this.pairs.get(0);
        DataCharacter dataCharacter = expandedPair.leftChar;
        DataCharacter dataCharacter2 = expandedPair.rightChar;
        if (dataCharacter2 == null) {
            return false;
        }
        int i = dataCharacter2.checksumPortion;
        int i2 = 2;
        for (int i3 = 1; i3 < this.pairs.size(); i3++) {
            ExpandedPair expandedPair2 = this.pairs.get(i3);
            i += expandedPair2.leftChar.checksumPortion;
            i2++;
            DataCharacter dataCharacter3 = expandedPair2.rightChar;
            if (dataCharacter3 != null) {
                i += dataCharacter3.checksumPortion;
                i2++;
            }
        }
        if (((i2 - 4) * 211) + (i % 211) == dataCharacter.value) {
            return true;
        }
        return false;
    }

    public final List<ExpandedPair> checkRows(boolean z) {
        List<ExpandedPair> list = null;
        if (this.rows.size() > 25) {
            this.rows.clear();
            return null;
        }
        this.pairs.clear();
        if (z) {
            Collections.reverse(this.rows);
        }
        try {
            list = checkRows(new ArrayList(), 0);
        } catch (NotFoundException unused) {
        }
        if (z) {
            Collections.reverse(this.rows);
        }
        return list;
    }

    /* JADX WARNING: Removed duplicated region for block: B:100:0x0173  */
    /* JADX WARNING: Removed duplicated region for block: B:111:0x0199  */
    /* JADX WARNING: Removed duplicated region for block: B:122:0x01bd A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:81:0x012d  */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x013e  */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x0147  */
    /* JADX WARNING: Removed duplicated region for block: B:93:0x0158  */
    /* JADX WARNING: Removed duplicated region for block: B:96:0x0165  */
    /* JADX WARNING: Removed duplicated region for block: B:97:0x0167  */
    public DataCharacter decodeDataCharacter(BitArray bitArray, FinderPattern finderPattern, boolean z, boolean z2) {
        boolean z3;
        boolean z4;
        boolean z5;
        boolean z6;
        int length;
        int i;
        int length2;
        int[] iArr = this.dataCharacterCounters;
        iArr[0] = 0;
        iArr[1] = 0;
        iArr[2] = 0;
        iArr[3] = 0;
        iArr[4] = 0;
        iArr[5] = 0;
        iArr[6] = 0;
        iArr[7] = 0;
        if (z2) {
            OneDReader.recordPatternInReverse(bitArray, finderPattern.startEnd[0], iArr);
        } else {
            OneDReader.recordPattern(bitArray, finderPattern.startEnd[1], iArr);
            int i2 = 0;
            for (int length3 = iArr.length - 1; i2 < length3; length3--) {
                int i3 = iArr[i2];
                iArr[i2] = iArr[length3];
                iArr[length3] = i3;
                i2++;
            }
        }
        float sum = ((float) ViewGroupUtilsApi14.sum(iArr)) / 17.0f;
        int[] iArr2 = finderPattern.startEnd;
        float f = ((float) (iArr2[1] - iArr2[0])) / 15.0f;
        if (Math.abs(sum - f) / f <= 0.3f) {
            int[] iArr3 = this.oddCounts;
            int[] iArr4 = this.evenCounts;
            float[] fArr = this.oddRoundingErrors;
            float[] fArr2 = this.evenRoundingErrors;
            for (int i4 = 0; i4 < iArr.length; i4++) {
                float f2 = (((float) iArr[i4]) * 1.0f) / sum;
                int i5 = (int) (0.5f + f2);
                if (i5 <= 0) {
                    if (f2 >= 0.3f) {
                        i5 = 1;
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                } else if (i5 > 8) {
                    if (f2 <= 8.7f) {
                        i5 = 8;
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                }
                int i6 = i4 / 2;
                if ((i4 & 1) == 0) {
                    iArr3[i6] = i5;
                    fArr[i6] = f2 - ((float) i5);
                } else {
                    iArr4[i6] = i5;
                    fArr2[i6] = f2 - ((float) i5);
                }
            }
            int sum2 = ViewGroupUtilsApi14.sum(this.oddCounts);
            int sum3 = ViewGroupUtilsApi14.sum(this.evenCounts);
            if (sum2 > 13) {
                z4 = false;
                z3 = true;
            } else {
                z4 = sum2 < 4;
                z3 = false;
            }
            if (sum3 > 13) {
                z6 = false;
                z5 = true;
            } else {
                z6 = sum3 < 4;
                z5 = false;
            }
            int i7 = (sum2 + sum3) - 17;
            boolean z7 = (sum2 & 1) == 1;
            boolean z8 = (sum3 & 1) == 0;
            if (i7 != 1) {
                if (i7 == -1) {
                    if (z7) {
                        if (!z8) {
                            z4 = true;
                        } else {
                            throw NotFoundException.getNotFoundInstance();
                        }
                    } else if (z8) {
                        z6 = true;
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                } else if (i7 != 0) {
                    throw NotFoundException.getNotFoundInstance();
                } else if (z7) {
                    if (!z8) {
                        throw NotFoundException.getNotFoundInstance();
                    } else if (sum2 < sum3) {
                        z4 = true;
                    } else {
                        z6 = true;
                        z3 = true;
                    }
                } else if (z8) {
                    throw NotFoundException.getNotFoundInstance();
                }
                if (z4) {
                }
                if (z3) {
                }
                if (z6) {
                }
                if (z5) {
                }
                int i8 = (((finderPattern.value * 4) + (z ? 0 : 2)) + (!z2 ? 1 : 0)) - 1;
                int i9 = 0;
                i = 0;
                while (length >= 0) {
                }
                int i10 = 0;
                while (length2 >= 0) {
                }
                int i11 = i9 + i10;
                if ((i & 1) == 0) {
                }
                throw NotFoundException.getNotFoundInstance();
            } else if (z7) {
                if (z8) {
                    throw NotFoundException.getNotFoundInstance();
                }
                z3 = true;
                if (z4) {
                    if (!z3) {
                        AbstractRSSReader.increment(this.oddCounts, this.oddRoundingErrors);
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                }
                if (z3) {
                    AbstractRSSReader.decrement(this.oddCounts, this.oddRoundingErrors);
                }
                if (z6) {
                    if (!z5) {
                        AbstractRSSReader.increment(this.evenCounts, this.oddRoundingErrors);
                    } else {
                        throw NotFoundException.getNotFoundInstance();
                    }
                }
                if (z5) {
                    AbstractRSSReader.decrement(this.evenCounts, this.evenRoundingErrors);
                }
                int i82 = (((finderPattern.value * 4) + (z ? 0 : 2)) + (!z2 ? 1 : 0)) - 1;
                int i92 = 0;
                i = 0;
                for (length = iArr3.length - 1; length >= 0; length--) {
                    if (finderPattern.value != 0 || !z || !z2) {
                        i92 += iArr3[length] * WEIGHTS[i82][length * 2];
                    }
                    i += iArr3[length];
                }
                int i102 = 0;
                for (length2 = iArr4.length - 1; length2 >= 0; length2--) {
                    if (finderPattern.value != 0 || !z || !z2) {
                        i102 += iArr4[length2] * WEIGHTS[i82][(length2 * 2) + 1];
                    }
                }
                int i112 = i92 + i102;
                if ((i & 1) == 0 || i > 13 || i < 4) {
                    throw NotFoundException.getNotFoundInstance();
                }
                int i12 = (13 - i) / 2;
                int i13 = SYMBOL_WIDEST[i12];
                return new DataCharacter((ViewGroupUtilsApi14.getRSSvalue(iArr3, i13, true) * EVEN_TOTAL_SUBSET[i12]) + ViewGroupUtilsApi14.getRSSvalue(iArr4, 9 - i13, false) + GSUM[i12], i112);
            } else if (!z8) {
                throw NotFoundException.getNotFoundInstance();
            }
            z5 = true;
            if (z4) {
            }
            if (z3) {
            }
            if (z6) {
            }
            if (z5) {
            }
            int i822 = (((finderPattern.value * 4) + (z ? 0 : 2)) + (!z2 ? 1 : 0)) - 1;
            int i922 = 0;
            i = 0;
            while (length >= 0) {
            }
            int i1022 = 0;
            while (length2 >= 0) {
            }
            int i1122 = i922 + i1022;
            if ((i & 1) == 0) {
            }
            throw NotFoundException.getNotFoundInstance();
        }
        throw NotFoundException.getNotFoundInstance();
    }

    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) {
        this.pairs.clear();
        this.startFromEven = false;
        try {
            return constructResult(decodeRow2pairs(i, bitArray));
        } catch (NotFoundException unused) {
            this.pairs.clear();
            this.startFromEven = true;
            return constructResult(decodeRow2pairs(i, bitArray));
        }
    }

    public List<ExpandedPair> decodeRow2pairs(int i, BitArray bitArray) {
        boolean z;
        boolean z2;
        boolean z3;
        boolean z4;
        boolean z5;
        boolean z6;
        while (true) {
            try {
                this.pairs.add(retrieveNextPair(bitArray, this.pairs, i));
            } catch (NotFoundException e) {
                if (this.pairs.isEmpty()) {
                    throw e;
                } else if (checkChecksum()) {
                    return this.pairs;
                } else {
                    boolean z7 = !this.rows.isEmpty();
                    int i2 = 0;
                    boolean z8 = false;
                    while (true) {
                        if (i2 >= this.rows.size()) {
                            z = false;
                            break;
                        }
                        ExpandedRow expandedRow = this.rows.get(i2);
                        if (expandedRow.rowNumber > i) {
                            z = expandedRow.pairs.equals(this.pairs);
                            break;
                        }
                        z8 = expandedRow.pairs.equals(this.pairs);
                        i2++;
                    }
                    if (!z && !z8) {
                        List<ExpandedPair> list = this.pairs;
                        Iterator<T> it = this.rows.iterator();
                        while (true) {
                            if (!it.hasNext()) {
                                z2 = false;
                                break;
                            }
                            T next = it.next();
                            Iterator<T> it2 = list.iterator();
                            while (true) {
                                if (!it2.hasNext()) {
                                    z5 = true;
                                    continue;
                                    break;
                                }
                                T next2 = it2.next();
                                Iterator<ExpandedPair> it3 = next.pairs.iterator();
                                while (true) {
                                    if (it3.hasNext()) {
                                        if (next2.equals(it3.next())) {
                                            z6 = true;
                                            continue;
                                            break;
                                        }
                                    } else {
                                        z6 = false;
                                        continue;
                                        break;
                                    }
                                }
                                if (!z6) {
                                    z5 = false;
                                    continue;
                                    break;
                                }
                            }
                            if (z5) {
                                z2 = true;
                                break;
                            }
                        }
                        if (!z2) {
                            this.rows.add(i2, new ExpandedRow(this.pairs, i, false));
                            List<ExpandedPair> list2 = this.pairs;
                            Iterator<ExpandedRow> it4 = this.rows.iterator();
                            while (it4.hasNext()) {
                                ExpandedRow next3 = it4.next();
                                if (next3.pairs.size() != list2.size()) {
                                    Iterator<ExpandedPair> it5 = next3.pairs.iterator();
                                    while (true) {
                                        if (!it5.hasNext()) {
                                            z3 = true;
                                            break;
                                        }
                                        ExpandedPair next4 = it5.next();
                                        Iterator<ExpandedPair> it6 = list2.iterator();
                                        while (true) {
                                            if (it6.hasNext()) {
                                                if (next4.equals(it6.next())) {
                                                    z4 = true;
                                                    continue;
                                                    break;
                                                }
                                            } else {
                                                z4 = false;
                                                continue;
                                                break;
                                            }
                                        }
                                        if (!z4) {
                                            z3 = false;
                                            break;
                                        }
                                    }
                                    if (z3) {
                                        it4.remove();
                                    }
                                }
                            }
                        }
                    }
                    if (z7) {
                        List<ExpandedPair> checkRows = checkRows(false);
                        if (checkRows != null) {
                            return checkRows;
                        }
                        List<ExpandedPair> checkRows2 = checkRows(true);
                        if (checkRows2 != null) {
                            return checkRows2;
                        }
                    }
                    throw NotFoundException.getNotFoundInstance();
                }
            }
        }
    }

    @Override // com.google.zxing.Reader, com.google.zxing.oned.OneDReader
    public void reset() {
        this.pairs.clear();
        this.rows.clear();
    }

    public ExpandedPair retrieveNextPair(BitArray bitArray, List<ExpandedPair> list, int i) {
        int i2;
        int i3;
        int i4;
        int i5;
        FinderPattern finderPattern;
        int i6 = 2;
        boolean z = list.size() % 2 == 0;
        if (this.startFromEven) {
            z = !z;
        }
        int i7 = -1;
        boolean z2 = true;
        while (true) {
            int[] iArr = this.decodeFinderCounters;
            iArr[0] = 0;
            iArr[1] = 0;
            iArr[i6] = 0;
            iArr[3] = 0;
            int i8 = bitArray.size;
            if (i7 >= 0) {
                i2 = i7;
            } else if (list.isEmpty()) {
                i2 = 0;
            } else {
                i2 = list.get(list.size() - 1).finderPattern.startEnd[1];
            }
            boolean z3 = list.size() % i6 != 0;
            if (this.startFromEven) {
                z3 = !z3;
            }
            boolean z4 = false;
            while (i2 < i8) {
                z4 = !bitArray.get(i2);
                if (!z4) {
                    break;
                }
                i2++;
            }
            boolean z5 = z4;
            int i9 = 0;
            int i10 = i2;
            while (i2 < i8) {
                if (bitArray.get(i2) ^ z5) {
                    iArr[i9] = iArr[i9] + 1;
                } else {
                    if (i9 == 3) {
                        if (z3) {
                            reverseCounters(iArr);
                        }
                        if (AbstractRSSReader.isFinderPattern(iArr)) {
                            int[] iArr2 = this.startEnd;
                            iArr2[0] = i10;
                            iArr2[1] = i2;
                            if (z) {
                                int i11 = iArr2[0] - 1;
                                while (i11 >= 0 && !bitArray.get(i11)) {
                                    i11--;
                                }
                                int i12 = i11 + 1;
                                int[] iArr3 = this.startEnd;
                                i5 = iArr3[0] - i12;
                                i4 = i12;
                                i3 = iArr3[1];
                            } else {
                                int i13 = iArr2[0];
                                int nextUnset = bitArray.getNextUnset(iArr2[1] + 1);
                                i5 = nextUnset - this.startEnd[1];
                                i3 = nextUnset;
                                i4 = i13;
                            }
                            int[] iArr4 = this.decodeFinderCounters;
                            System.arraycopy(iArr4, 0, iArr4, 1, iArr4.length - 1);
                            iArr4[0] = i5;
                            DataCharacter dataCharacter = null;
                            try {
                                finderPattern = new FinderPattern(AbstractRSSReader.parseFinderValue(iArr4, FINDER_PATTERNS), new int[]{i4, i3}, i4, i3, i);
                            } catch (NotFoundException unused) {
                                finderPattern = null;
                            }
                            if (finderPattern == null) {
                                int i14 = this.startEnd[0];
                                if (bitArray.get(i14)) {
                                    i7 = bitArray.getNextSet(bitArray.getNextUnset(i14));
                                } else {
                                    i7 = bitArray.getNextUnset(bitArray.getNextSet(i14));
                                }
                            } else {
                                z2 = false;
                            }
                            if (!z2) {
                                DataCharacter decodeDataCharacter = decodeDataCharacter(bitArray, finderPattern, z, true);
                                if (!list.isEmpty()) {
                                    if (list.get(list.size() - 1).rightChar == null) {
                                        throw NotFoundException.getNotFoundInstance();
                                    }
                                }
                                try {
                                    dataCharacter = decodeDataCharacter(bitArray, finderPattern, z, false);
                                } catch (NotFoundException unused2) {
                                }
                                return new ExpandedPair(decodeDataCharacter, dataCharacter, finderPattern, true);
                            }
                            i6 = 2;
                        } else {
                            if (z3) {
                                reverseCounters(iArr);
                            }
                            i10 = iArr[0] + iArr[1] + i10;
                            iArr[0] = iArr[2];
                            iArr[1] = iArr[3];
                            iArr[2] = 0;
                            iArr[3] = 0;
                            i9--;
                        }
                    } else {
                        i9++;
                    }
                    iArr[i9] = 1;
                    z5 = !z5;
                }
                i2++;
            }
            throw NotFoundException.getNotFoundInstance();
        }
    }

    public final List<ExpandedPair> checkRows(List<ExpandedRow> list, int i) {
        boolean z;
        while (i < this.rows.size()) {
            ExpandedRow expandedRow = this.rows.get(i);
            this.pairs.clear();
            for (ExpandedRow expandedRow2 : list) {
                this.pairs.addAll(expandedRow2.pairs);
            }
            this.pairs.addAll(expandedRow.pairs);
            List<ExpandedPair> list2 = this.pairs;
            int[][] iArr = FINDER_PATTERN_SEQUENCES;
            int length = iArr.length;
            boolean z2 = false;
            int i2 = 0;
            while (true) {
                if (i2 >= length) {
                    break;
                }
                int[] iArr2 = iArr[i2];
                if (list2.size() <= iArr2.length) {
                    int i3 = 0;
                    while (true) {
                        if (i3 >= list2.size()) {
                            z = true;
                            break;
                        } else if (list2.get(i3).finderPattern.value != iArr2[i3]) {
                            z = false;
                            break;
                        } else {
                            i3++;
                        }
                    }
                    if (z) {
                        z2 = true;
                        break;
                    }
                }
                i2++;
            }
            if (!z2) {
                i++;
            } else if (checkChecksum()) {
                return this.pairs;
            } else {
                ArrayList arrayList = new ArrayList();
                arrayList.addAll(list);
                arrayList.add(expandedRow);
                try {
                    return checkRows(arrayList, i + 1);
                } catch (NotFoundException unused) {
                    continue;
                }
            }
        }
        throw NotFoundException.getNotFoundInstance();
    }
}
