package com.google.zxing.qrcode.decoder;

import com.google.zxing.ChecksumException;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.common.BitSource;
import com.google.zxing.common.CharacterSetECI;
import com.google.zxing.common.DecoderResult;
import com.google.zxing.common.reedsolomon.GenericGF;
import com.google.zxing.common.reedsolomon.ReedSolomonDecoder;
import com.google.zxing.common.reedsolomon.ReedSolomonException;
import com.google.zxing.qrcode.decoder.Version;
import java.util.ArrayList;
import java.util.Map;

public final class Decoder {
    public final ReedSolomonDecoder rsDecoder = new ReedSolomonDecoder(GenericGF.QR_CODE_FIELD_256);

    public DecoderResult decode(BitMatrix bitMatrix, Map<DecodeHintType, ?> map) {
        ChecksumException checksumException;
        FormatException e;
        BitMatrixParser bitMatrixParser = new BitMatrixParser(bitMatrix);
        try {
            return decode(bitMatrixParser, map);
        } catch (FormatException e2) {
            e = e2;
            checksumException = null;
            try {
                bitMatrixParser.remask();
                bitMatrixParser.parsedVersion = null;
                bitMatrixParser.parsedFormatInfo = null;
                bitMatrixParser.mirror = true;
                bitMatrixParser.readVersion();
                bitMatrixParser.readFormatInformation();
                bitMatrixParser.mirror();
                DecoderResult decode = decode(bitMatrixParser, map);
                decode.other = new QRCodeDecoderMetaData(true);
                return decode;
            } catch (ChecksumException | FormatException e3) {
                if (e != null) {
                    throw e;
                } else if (checksumException != null) {
                    throw checksumException;
                } else {
                    throw e3;
                }
            }
        } catch (ChecksumException e4) {
            checksumException = e4;
            e = null;
            bitMatrixParser.remask();
            bitMatrixParser.parsedVersion = null;
            bitMatrixParser.parsedFormatInfo = null;
            bitMatrixParser.mirror = true;
            bitMatrixParser.readVersion();
            bitMatrixParser.readFormatInformation();
            bitMatrixParser.mirror();
            DecoderResult decode2 = decode(bitMatrixParser, map);
            decode2.other = new QRCodeDecoderMetaData(true);
            return decode2;
        }
    }

    public final DecoderResult decode(BitMatrixParser bitMatrixParser, Map<DecodeHintType, ?> map) {
        Mode mode;
        Mode mode2;
        int i;
        int i2;
        int i3;
        int i4;
        BitMatrix bitMatrix;
        Version readVersion = bitMatrixParser.readVersion();
        ErrorCorrectionLevel errorCorrectionLevel = bitMatrixParser.readFormatInformation().errorCorrectionLevel;
        FormatInformation readFormatInformation = bitMatrixParser.readFormatInformation();
        Version readVersion2 = bitMatrixParser.readVersion();
        DataMask dataMask = DataMask.values()[readFormatInformation.dataMask];
        BitMatrix bitMatrix2 = bitMatrixParser.bitMatrix;
        int i5 = bitMatrix2.height;
        dataMask.unmaskBitMatrix(bitMatrix2, i5);
        int dimensionForVersion = readVersion2.getDimensionForVersion();
        BitMatrix bitMatrix3 = new BitMatrix(dimensionForVersion, dimensionForVersion);
        int i6 = 0;
        bitMatrix3.setRegion(0, 0, 9, 9);
        int i7 = dimensionForVersion - 8;
        bitMatrix3.setRegion(i7, 0, 8, 9);
        bitMatrix3.setRegion(0, i7, 9, 8);
        int length = readVersion2.alignmentPatternCenters.length;
        for (int i8 = 0; i8 < length; i8++) {
            int i9 = readVersion2.alignmentPatternCenters[i8] - 2;
            for (int i10 = 0; i10 < length; i10++) {
                if (!((i8 == 0 && (i10 == 0 || i10 == length - 1)) || (i8 == length - 1 && i10 == 0))) {
                    bitMatrix3.setRegion(readVersion2.alignmentPatternCenters[i10] - 2, i9, 5, 5);
                }
            }
        }
        int i11 = dimensionForVersion - 17;
        int i12 = 6;
        bitMatrix3.setRegion(6, 9, 1, i11);
        bitMatrix3.setRegion(9, 6, i11, 1);
        if (readVersion2.versionNumber > 6) {
            int i13 = dimensionForVersion - 11;
            bitMatrix3.setRegion(i13, 0, 3, 6);
            bitMatrix3.setRegion(0, i13, 6, 3);
        }
        int i14 = readVersion2.totalCodewords;
        byte[] bArr = new byte[i14];
        int i15 = i5 - 1;
        int i16 = i15;
        int i17 = 0;
        boolean z = true;
        int i18 = 0;
        int i19 = 0;
        while (i16 > 0) {
            if (i16 == i12) {
                i16--;
            }
            int i20 = 0;
            while (i20 < i5) {
                int i21 = z ? i15 - i20 : i20;
                while (i6 < 2) {
                    int i22 = i16 - i6;
                    if (!bitMatrix3.get(i22, i21)) {
                        bitMatrix = bitMatrix3;
                        int i23 = i18 + 1;
                        int i24 = i19 << 1;
                        i4 = i5;
                        int i25 = bitMatrixParser.bitMatrix.get(i22, i21) ? i24 | 1 : i24;
                        if (i23 == 8) {
                            bArr[i17] = (byte) i25;
                            i17++;
                            i18 = 0;
                            i19 = 0;
                        } else {
                            i18 = i23;
                            i19 = i25;
                        }
                    } else {
                        bitMatrix = bitMatrix3;
                        i4 = i5;
                    }
                    i6++;
                    bitMatrix3 = bitMatrix;
                    i5 = i4;
                }
                i20++;
                i6 = 0;
            }
            z = !z;
            i16 -= 2;
            i6 = 0;
            i12 = 6;
        }
        if (i17 != readVersion2.totalCodewords) {
            throw FormatException.getFormatInstance();
        } else if (i14 == readVersion.totalCodewords) {
            Version.ECBlocks eCBlocks = readVersion.ecBlocks[errorCorrectionLevel.ordinal()];
            Version.ECB[] ecbArr = eCBlocks.ecBlocks;
            int i26 = 0;
            for (Version.ECB ecb : ecbArr) {
                i26 += ecb.count;
            }
            DataBlock[] dataBlockArr = new DataBlock[i26];
            int i27 = 0;
            for (Version.ECB ecb2 : ecbArr) {
                int i28 = 0;
                while (i28 < ecb2.count) {
                    int i29 = ecb2.dataCodewords;
                    dataBlockArr[i27] = new DataBlock(i29, new byte[(eCBlocks.ecCodewordsPerBlock + i29)]);
                    i28++;
                    i27++;
                }
            }
            int length2 = dataBlockArr[0].codewords.length;
            int i30 = i26 - 1;
            while (i30 >= 0 && dataBlockArr[i30].codewords.length != length2) {
                i30--;
            }
            int i31 = i30 + 1;
            int i32 = length2 - eCBlocks.ecCodewordsPerBlock;
            int i33 = 0;
            for (int i34 = 0; i34 < i32; i34++) {
                int i35 = 0;
                while (i35 < i27) {
                    dataBlockArr[i35].codewords[i34] = bArr[i33];
                    i35++;
                    i33++;
                }
            }
            int i36 = i31;
            while (i36 < i27) {
                dataBlockArr[i36].codewords[i32] = bArr[i33];
                i36++;
                i33++;
            }
            int length3 = dataBlockArr[0].codewords.length;
            while (i32 < length3) {
                int i37 = 0;
                while (i37 < i27) {
                    dataBlockArr[i37].codewords[i37 < i31 ? i32 : i32 + 1] = bArr[i33];
                    i37++;
                    i33++;
                }
                i32++;
            }
            int i38 = 0;
            for (int i39 = 0; i39 < i26; i39++) {
                i38 += dataBlockArr[i39].numDataCodewords;
            }
            byte[] bArr2 = new byte[i38];
            int i40 = 0;
            for (int i41 = 0; i41 < i26; i41++) {
                DataBlock dataBlock = dataBlockArr[i41];
                byte[] bArr3 = dataBlock.codewords;
                int i42 = dataBlock.numDataCodewords;
                int length4 = bArr3.length;
                int[] iArr = new int[length4];
                for (int i43 = 0; i43 < length4; i43++) {
                    iArr[i43] = bArr3[i43] & 255;
                }
                try {
                    this.rsDecoder.decode(iArr, bArr3.length - i42);
                    for (int i44 = 0; i44 < i42; i44++) {
                        bArr3[i44] = (byte) iArr[i44];
                    }
                    int i45 = 0;
                    while (i45 < i42) {
                        bArr2[i40] = bArr3[i45];
                        i45++;
                        i40++;
                    }
                } catch (ReedSolomonException unused) {
                    throw ChecksumException.getChecksumInstance();
                }
            }
            char[] cArr = DecodedBitStreamParser.ALPHANUMERIC_CHARS;
            BitSource bitSource = new BitSource(bArr2);
            StringBuilder sb = new StringBuilder(50);
            ArrayList arrayList = new ArrayList(1);
            int i46 = -1;
            int i47 = -1;
            boolean z2 = false;
            CharacterSetECI characterSetECI = null;
            do {
                try {
                    if (bitSource.available() < 4) {
                        mode = Mode.TERMINATOR;
                    } else {
                        mode = Mode.forBits(bitSource.readBits(4));
                    }
                    mode2 = Mode.TERMINATOR;
                    if (mode != mode2) {
                        if (mode != Mode.FNC1_FIRST_POSITION) {
                            if (mode != Mode.FNC1_SECOND_POSITION) {
                                if (mode == Mode.STRUCTURED_APPEND) {
                                    if (bitSource.available() >= 16) {
                                        i46 = bitSource.readBits(8);
                                        i47 = bitSource.readBits(8);
                                    } else {
                                        throw FormatException.getFormatInstance();
                                    }
                                } else if (mode == Mode.ECI) {
                                    int readBits = bitSource.readBits(8);
                                    if ((readBits & 128) == 0) {
                                        i = readBits & 127;
                                    } else {
                                        if ((readBits & 192) == 128) {
                                            i3 = bitSource.readBits(8);
                                            i2 = (readBits & 63) << 8;
                                        } else if ((readBits & 224) == 192) {
                                            i2 = (readBits & 31) << 16;
                                            i3 = bitSource.readBits(16);
                                        } else {
                                            throw FormatException.getFormatInstance();
                                        }
                                        i = i3 | i2;
                                    }
                                    characterSetECI = CharacterSetECI.getCharacterSetECIByValue(i);
                                    if (characterSetECI == null) {
                                        throw FormatException.getFormatInstance();
                                    }
                                } else if (mode == Mode.HANZI) {
                                    int readBits2 = bitSource.readBits(4);
                                    int readBits3 = bitSource.readBits(mode.getCharacterCountBits(readVersion));
                                    if (readBits2 == 1) {
                                        DecodedBitStreamParser.decodeHanziSegment(bitSource, sb, readBits3);
                                        continue;
                                    } else {
                                        continue;
                                    }
                                } else {
                                    int readBits4 = bitSource.readBits(mode.getCharacterCountBits(readVersion));
                                    if (mode == Mode.NUMERIC) {
                                        DecodedBitStreamParser.decodeNumericSegment(bitSource, sb, readBits4);
                                        continue;
                                    } else if (mode == Mode.ALPHANUMERIC) {
                                        DecodedBitStreamParser.decodeAlphanumericSegment(bitSource, sb, readBits4, z2);
                                        continue;
                                    } else if (mode == Mode.BYTE) {
                                        DecodedBitStreamParser.decodeByteSegment(bitSource, sb, readBits4, characterSetECI, arrayList, map);
                                        continue;
                                    } else if (mode == Mode.KANJI) {
                                        DecodedBitStreamParser.decodeKanjiSegment(bitSource, sb, readBits4);
                                        continue;
                                    } else {
                                        throw FormatException.getFormatInstance();
                                    }
                                }
                            }
                        }
                        z2 = true;
                        continue;
                    }
                    continue;
                } catch (IllegalArgumentException unused2) {
                    throw FormatException.getFormatInstance();
                }
            } while (mode != mode2);
            return new DecoderResult(bArr2, sb.toString(), arrayList.isEmpty() ? null : arrayList, errorCorrectionLevel.toString(), i46, i47);
        } else {
            throw new IllegalArgumentException();
        }
    }
}
