package com.google.zxing.qrcode.encoder;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitArray;
import com.google.zxing.qrcode.decoder.ErrorCorrectionLevel;
import com.google.zxing.qrcode.decoder.Version;

public abstract class MatrixUtil {
    public static final int[][] POSITION_ADJUSTMENT_PATTERN = {new int[]{1, 1, 1, 1, 1}, new int[]{1, 0, 0, 0, 1}, new int[]{1, 0, 1, 0, 1}, new int[]{1, 0, 0, 0, 1}, new int[]{1, 1, 1, 1, 1}};
    public static final int[][] POSITION_ADJUSTMENT_PATTERN_COORDINATE_TABLE = {new int[]{-1, -1, -1, -1, -1, -1, -1}, new int[]{6, 18, -1, -1, -1, -1, -1}, new int[]{6, 22, -1, -1, -1, -1, -1}, new int[]{6, 26, -1, -1, -1, -1, -1}, new int[]{6, 30, -1, -1, -1, -1, -1}, new int[]{6, 34, -1, -1, -1, -1, -1}, new int[]{6, 22, 38, -1, -1, -1, -1}, new int[]{6, 24, 42, -1, -1, -1, -1}, new int[]{6, 26, 46, -1, -1, -1, -1}, new int[]{6, 28, 50, -1, -1, -1, -1}, new int[]{6, 30, 54, -1, -1, -1, -1}, new int[]{6, 32, 58, -1, -1, -1, -1}, new int[]{6, 34, 62, -1, -1, -1, -1}, new int[]{6, 26, 46, 66, -1, -1, -1}, new int[]{6, 26, 48, 70, -1, -1, -1}, new int[]{6, 26, 50, 74, -1, -1, -1}, new int[]{6, 30, 54, 78, -1, -1, -1}, new int[]{6, 30, 56, 82, -1, -1, -1}, new int[]{6, 30, 58, 86, -1, -1, -1}, new int[]{6, 34, 62, 90, -1, -1, -1}, new int[]{6, 28, 50, 72, 94, -1, -1}, new int[]{6, 26, 50, 74, 98, -1, -1}, new int[]{6, 30, 54, 78, 102, -1, -1}, new int[]{6, 28, 54, 80, 106, -1, -1}, new int[]{6, 32, 58, 84, 110, -1, -1}, new int[]{6, 30, 58, 86, 114, -1, -1}, new int[]{6, 34, 62, 90, 118, -1, -1}, new int[]{6, 26, 50, 74, 98, 122, -1}, new int[]{6, 30, 54, 78, 102, 126, -1}, new int[]{6, 26, 52, 78, 104, 130, -1}, new int[]{6, 30, 56, 82, 108, 134, -1}, new int[]{6, 34, 60, 86, 112, 138, -1}, new int[]{6, 30, 58, 86, 114, 142, -1}, new int[]{6, 34, 62, 90, 118, 146, -1}, new int[]{6, 30, 54, 78, 102, 126, 150}, new int[]{6, 24, 50, 76, 102, 128, 154}, new int[]{6, 28, 54, 80, 106, 132, 158}, new int[]{6, 32, 58, 84, 110, 136, 162}, new int[]{6, 26, 54, 82, 110, 138, 166}, new int[]{6, 30, 58, 86, 114, 142, 170}};
    public static final int[][] POSITION_DETECTION_PATTERN = {new int[]{1, 1, 1, 1, 1, 1, 1}, new int[]{1, 0, 0, 0, 0, 0, 1}, new int[]{1, 0, 1, 1, 1, 0, 1}, new int[]{1, 0, 1, 1, 1, 0, 1}, new int[]{1, 0, 1, 1, 1, 0, 1}, new int[]{1, 0, 0, 0, 0, 0, 1}, new int[]{1, 1, 1, 1, 1, 1, 1}};
    public static final int[][] TYPE_INFO_COORDINATES = {new int[]{8, 0}, new int[]{8, 1}, new int[]{8, 2}, new int[]{8, 3}, new int[]{8, 4}, new int[]{8, 5}, new int[]{8, 7}, new int[]{8, 8}, new int[]{7, 8}, new int[]{5, 8}, new int[]{4, 8}, new int[]{3, 8}, new int[]{2, 8}, new int[]{1, 8}, new int[]{0, 8}};

    public static void buildMatrix(BitArray bitArray, ErrorCorrectionLevel errorCorrectionLevel, Version version, int i, ByteMatrix byteMatrix) {
        int i2;
        boolean z;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7 = 0;
        while (true) {
            i2 = -1;
            if (i7 >= byteMatrix.height) {
                break;
            }
            for (int i8 = 0; i8 < byteMatrix.width; i8++) {
                byteMatrix.bytes[i7][i8] = -1;
            }
            i7++;
        }
        int length = POSITION_DETECTION_PATTERN[0].length;
        embedPositionDetectionPattern(0, 0, byteMatrix);
        embedPositionDetectionPattern(byteMatrix.width - length, 0, byteMatrix);
        embedPositionDetectionPattern(0, byteMatrix.width - length, byteMatrix);
        embedHorizontalSeparationPattern(0, 7, byteMatrix);
        embedHorizontalSeparationPattern(byteMatrix.width - 8, 7, byteMatrix);
        embedHorizontalSeparationPattern(0, byteMatrix.width - 8, byteMatrix);
        embedVerticalSeparationPattern(7, 0, byteMatrix);
        embedVerticalSeparationPattern((byteMatrix.height - 7) - 1, 0, byteMatrix);
        embedVerticalSeparationPattern(7, byteMatrix.height - 7, byteMatrix);
        if (byteMatrix.get(8, byteMatrix.height - 8) != 0) {
            byteMatrix.set(8, byteMatrix.height - 8, 1);
            int i9 = version.versionNumber;
            int i10 = 5;
            if (i9 >= 2) {
                int i11 = i9 - 1;
                int[][] iArr = POSITION_ADJUSTMENT_PATTERN_COORDINATE_TABLE;
                int[] iArr2 = iArr[i11];
                int length2 = iArr[i11].length;
                int i12 = 0;
                while (i12 < length2) {
                    int i13 = 0;
                    while (i13 < length2) {
                        int i14 = iArr2[i12];
                        int i15 = iArr2[i13];
                        if (!(i15 == i2 || i14 == i2 || !isEmpty(byteMatrix.get(i15, i14)))) {
                            int i16 = i15 - 2;
                            int i17 = i14 - 2;
                            int i18 = 0;
                            while (i18 < i10) {
                                int i19 = 0;
                                while (i19 < i10) {
                                    byteMatrix.set(i16 + i19, i17 + i18, POSITION_ADJUSTMENT_PATTERN[i18][i19]);
                                    i19++;
                                    i10 = 5;
                                }
                                i18++;
                                i10 = 5;
                            }
                        }
                        i13++;
                        i2 = -1;
                        i10 = 5;
                    }
                    i12++;
                    i2 = -1;
                    i10 = 5;
                }
            }
            int i20 = 8;
            while (i20 < byteMatrix.width - 8) {
                int i21 = i20 + 1;
                int i22 = i21 % 2;
                if (isEmpty(byteMatrix.get(i20, 6))) {
                    byteMatrix.set(i20, 6, i22);
                }
                if (isEmpty(byteMatrix.get(6, i20))) {
                    byteMatrix.set(6, i20, i22);
                }
                i20 = i21;
            }
            BitArray bitArray2 = new BitArray();
            if (i >= 0 && i < 8) {
                int bits = (errorCorrectionLevel.getBits() << 3) | i;
                bitArray2.appendBits(bits, 5);
                bitArray2.appendBits(calculateBCHCode(bits, 1335), 10);
                BitArray bitArray3 = new BitArray();
                bitArray3.appendBits(21522, 15);
                if (bitArray2.size == bitArray3.size) {
                    int i23 = 0;
                    while (true) {
                        int[] iArr3 = bitArray2.bits;
                        if (i23 >= iArr3.length) {
                            break;
                        }
                        iArr3[i23] = iArr3[i23] ^ bitArray3.bits[i23];
                        i23++;
                    }
                    if (bitArray2.size == 15) {
                        int i24 = 0;
                        while (true) {
                            int i25 = bitArray2.size;
                            if (i24 >= i25) {
                                break;
                            }
                            boolean z2 = bitArray2.get((i25 - 1) - i24);
                            int[][] iArr4 = TYPE_INFO_COORDINATES;
                            byteMatrix.set(iArr4[i24][0], iArr4[i24][1], z2);
                            if (i24 < 8) {
                                byteMatrix.set((byteMatrix.width - i24) - 1, 8, z2);
                            } else {
                                byteMatrix.set(8, (i24 - 8) + (byteMatrix.height - 7), z2);
                            }
                            i24++;
                        }
                        int i26 = version.versionNumber;
                        if (i26 >= 7) {
                            BitArray bitArray4 = new BitArray();
                            bitArray4.appendBits(i26, 6);
                            bitArray4.appendBits(calculateBCHCode(version.versionNumber, 7973), 12);
                            if (bitArray4.size == 18) {
                                int i27 = 17;
                                for (int i28 = 0; i28 < 6; i28++) {
                                    for (int i29 = 0; i29 < 3; i29++) {
                                        boolean z3 = bitArray4.get(i27);
                                        i27--;
                                        byteMatrix.set(i28, (byteMatrix.height - 11) + i29, z3);
                                        byteMatrix.set((byteMatrix.height - 11) + i29, i28, z3);
                                    }
                                }
                            } else {
                                throw new WriterException("should not happen but we got: " + bitArray4.size);
                            }
                        }
                        int i30 = byteMatrix.width - 1;
                        int i31 = byteMatrix.height - 1;
                        int i32 = 0;
                        int i33 = -1;
                        while (i30 > 0) {
                            if (i30 == 6) {
                                i30--;
                            }
                            while (i31 >= 0 && i31 < byteMatrix.height) {
                                for (int i34 = 0; i34 < 2; i34++) {
                                    int i35 = i30 - i34;
                                    if (isEmpty(byteMatrix.get(i35, i31))) {
                                        if (i32 < bitArray.size) {
                                            z = bitArray.get(i32);
                                            i32++;
                                        } else {
                                            z = false;
                                        }
                                        if (i != -1) {
                                            switch (i) {
                                                case 0:
                                                    i4 = i31 + i35;
                                                    i3 = i4 & 1;
                                                    break;
                                                case 1:
                                                    i4 = i31;
                                                    i3 = i4 & 1;
                                                    break;
                                                case 2:
                                                    i3 = i35 % 3;
                                                    break;
                                                case 3:
                                                    i3 = (i31 + i35) % 3;
                                                    break;
                                                case 4:
                                                    i4 = (i31 / 2) + (i35 / 3);
                                                    i3 = i4 & 1;
                                                    break;
                                                case 5:
                                                    int i36 = i31 * i35;
                                                    i3 = (i36 % 3) + (i36 & 1);
                                                    break;
                                                case 6:
                                                    int i37 = i31 * i35;
                                                    i5 = i37 & 1;
                                                    i6 = i37 % 3;
                                                    i4 = i6 + i5;
                                                    i3 = i4 & 1;
                                                    break;
                                                case 7:
                                                    i6 = (i31 * i35) % 3;
                                                    i5 = (i31 + i35) & 1;
                                                    i4 = i6 + i5;
                                                    i3 = i4 & 1;
                                                    break;
                                                default:
                                                    throw new IllegalArgumentException(GeneratedOutlineSupport.outline10("Invalid mask pattern: ", i));
                                            }
                                            if (i3 == 0) {
                                                z = !z;
                                            }
                                        }
                                        byteMatrix.set(i35, i31, z);
                                    }
                                }
                                i31 += i33;
                            }
                            i33 = -i33;
                            i31 += i33;
                            i30 -= 2;
                        }
                        if (i32 != bitArray.size) {
                            throw new WriterException("Not all bits consumed: " + i32 + '/' + bitArray.size);
                        }
                        return;
                    }
                    throw new WriterException("should not happen but we got: " + bitArray2.size);
                }
                throw new IllegalArgumentException("Sizes don't match");
            }
            throw new WriterException("Invalid mask pattern");
        }
        throw new WriterException();
    }

    public static int calculateBCHCode(int i, int i2) {
        if (i2 != 0) {
            int findMSBSet = findMSBSet(i2);
            int i3 = i << (findMSBSet - 1);
            while (findMSBSet(i3) >= findMSBSet) {
                i3 ^= i2 << (findMSBSet(i3) - findMSBSet);
            }
            return i3;
        }
        throw new IllegalArgumentException("0 polynomial");
    }

    public static void embedHorizontalSeparationPattern(int i, int i2, ByteMatrix byteMatrix) {
        for (int i3 = 0; i3 < 8; i3++) {
            int i4 = i + i3;
            if (isEmpty(byteMatrix.get(i4, i2))) {
                byteMatrix.set(i4, i2, 0);
            } else {
                throw new WriterException();
            }
        }
    }

    public static void embedPositionDetectionPattern(int i, int i2, ByteMatrix byteMatrix) {
        for (int i3 = 0; i3 < 7; i3++) {
            for (int i4 = 0; i4 < 7; i4++) {
                byteMatrix.set(i + i4, i2 + i3, POSITION_DETECTION_PATTERN[i3][i4]);
            }
        }
    }

    public static void embedVerticalSeparationPattern(int i, int i2, ByteMatrix byteMatrix) {
        for (int i3 = 0; i3 < 7; i3++) {
            int i4 = i2 + i3;
            if (isEmpty(byteMatrix.bytes[i4][i])) {
                byteMatrix.bytes[i4][i] = (byte) 0;
            } else {
                throw new WriterException();
            }
        }
    }

    public static int findMSBSet(int i) {
        return 32 - Integer.numberOfLeadingZeros(i);
    }

    public static boolean isEmpty(int i) {
        return i == -1;
    }
}
