package com.squareup.okhttp.internal.http;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.squareup.okhttp.internal.Util;
import java.net.ProtocolException;
import okio.Buffer;
import okio.Sink;
import okio.Timeout;

public final class RetryableSink implements Sink {
    private boolean closed;
    private final Buffer content;
    private final int limit;

    public RetryableSink(int i) {
        this.content = new Buffer();
        this.limit = i;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
    public void close() {
        if (!this.closed) {
            this.closed = true;
            if (this.content.size < ((long) this.limit)) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("content-length promised ");
                outline25.append(this.limit);
                outline25.append(" bytes, but received ");
                outline25.append(this.content.size);
                throw new ProtocolException(outline25.toString());
            }
        }
    }

    public long contentLength() {
        return this.content.size;
    }

    @Override // okio.Sink, java.io.Flushable
    public void flush() {
    }

    @Override // okio.Sink
    public Timeout timeout() {
        return Timeout.NONE;
    }

    @Override // okio.Sink
    public void write(Buffer buffer, long j) {
        if (!this.closed) {
            Util.checkOffsetAndCount(buffer.size, 0, j);
            int i = this.limit;
            if (i == -1 || this.content.size <= ((long) i) - j) {
                this.content.write(buffer, j);
                return;
            }
            throw new ProtocolException(GeneratedOutlineSupport.outline21(GeneratedOutlineSupport.outline25("exceeded content-length limit of "), this.limit, " bytes"));
        }
        throw new IllegalStateException("closed");
    }

    public void writeToSocket(Sink sink) {
        Buffer buffer = new Buffer();
        Buffer buffer2 = this.content;
        buffer2.copyTo(buffer, 0, buffer2.size);
        sink.write(buffer, buffer.size);
    }

    public RetryableSink() {
        this(-1);
    }
}
