package com.squareup.okhttp.internal.http;

import com.squareup.okhttp.Address;
import com.squareup.okhttp.CertificatePinner;
import com.squareup.okhttp.Connection;
import com.squareup.okhttp.ConnectionPool;
import com.squareup.okhttp.ConnectionSpec;
import com.squareup.okhttp.Handshake;
import com.squareup.okhttp.Protocol;
import com.squareup.okhttp.Request;
import com.squareup.okhttp.Response;
import com.squareup.okhttp.Route;
import com.squareup.okhttp.internal.ConnectionSpecSelector;
import com.squareup.okhttp.internal.Platform;
import com.squareup.okhttp.internal.Util;
import com.squareup.okhttp.internal.tls.OkHostnameVerifier;
import java.io.IOException;
import java.net.Proxy;
import java.net.Socket;
import java.net.URL;
import java.security.cert.X509Certificate;
import java.util.List;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSocket;
import okio.Source;

public class SocketConnector {
    private final Connection connection;
    private final ConnectionPool connectionPool;

    public SocketConnector(Connection connection2, ConnectionPool connectionPool2) {
        this.connection = connection2;
        this.connectionPool = connectionPool2;
    }

    private Socket connectRawSocket(int i, int i2, Route route) {
        Socket socket;
        Platform platform = Platform.get();
        try {
            Proxy proxy = route.getProxy();
            Address address = route.getAddress();
            if (proxy.type() != Proxy.Type.DIRECT) {
                if (proxy.type() != Proxy.Type.HTTP) {
                    socket = new Socket(proxy);
                    socket.setSoTimeout(i);
                    platform.connectSocket(socket, route.getSocketAddress(), i2);
                    return socket;
                }
            }
            socket = address.getSocketFactory().createSocket();
            socket.setSoTimeout(i);
            platform.connectSocket(socket, route.getSocketAddress(), i2);
            return socket;
        } catch (IOException e) {
            throw new RouteException(e);
        }
    }

    private void createTunnel(int i, int i2, Request request, Route route, Socket socket) {
        try {
            Request createTunnelRequest = createTunnelRequest(request);
            HttpConnection httpConnection = new HttpConnection(this.connectionPool, this.connection, socket);
            httpConnection.setTimeouts(i, i2);
            URL url = createTunnelRequest.url();
            String str = "CONNECT " + url.getHost() + ":" + Util.getEffectivePort(url) + " HTTP/1.1";
            while (true) {
                httpConnection.writeRequest(createTunnelRequest.headers(), str);
                httpConnection.flush();
                Response build = httpConnection.readResponse().request(createTunnelRequest).build();
                long contentLength = OkHeaders.contentLength(build);
                if (contentLength == -1) {
                    contentLength = 0;
                }
                Source newFixedLengthSource = httpConnection.newFixedLengthSource(contentLength);
                Util.skipAll(newFixedLengthSource, Integer.MAX_VALUE, TimeUnit.MILLISECONDS);
                newFixedLengthSource.close();
                int code = build.code();
                if (code != 200) {
                    if (code == 407) {
                        createTunnelRequest = OkHeaders.processAuthHeader(route.getAddress().getAuthenticator(), build, route.getProxy());
                        if (createTunnelRequest == null) {
                            throw new IOException("Failed to authenticate with proxy");
                        }
                    } else {
                        throw new IOException("Unexpected response code for CONNECT: " + build.code());
                    }
                } else if (httpConnection.bufferSize() > 0) {
                    throw new IOException("TLS tunnel buffered too many bytes!");
                } else {
                    return;
                }
            }
        } catch (IOException e) {
            throw new RouteException(e);
        }
    }

    private Request createTunnelRequest(Request request) {
        String str;
        String host = request.url().getHost();
        int effectivePort = Util.getEffectivePort(request.url());
        if (effectivePort == Util.getDefaultPort("https")) {
            str = host;
        } else {
            str = host + ":" + effectivePort;
        }
        Request.Builder header = new Request.Builder().url(new URL("https", host, effectivePort, "/")).header("Host", str).header("Proxy-Connection", "Keep-Alive");
        String header2 = request.header("User-Agent");
        if (header2 != null) {
            header.header("User-Agent", header2);
        }
        String header3 = request.header("Proxy-Authorization");
        if (header3 != null) {
            header.header("Proxy-Authorization", header3);
        }
        return header.build();
    }

    public ConnectedSocket connectCleartext(int i, int i2, Route route) {
        return new ConnectedSocket(route, connectRawSocket(i2, i, route));
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x0112  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x0118  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x011f A[SYNTHETIC] */
    public ConnectedSocket connectTls(int i, int i2, int i3, Request request, Route route, List<ConnectionSpec> list, boolean z) {
        SSLSocket sSLSocket;
        IOException e;
        boolean z2;
        String selectedProtocol;
        Address address = route.getAddress();
        ConnectionSpecSelector connectionSpecSelector = new ConnectionSpecSelector(list);
        RouteException routeException = null;
        do {
            Socket connectRawSocket = connectRawSocket(i2, i, route);
            if (route.requiresTunnel()) {
                createTunnel(i2, i3, request, route, connectRawSocket);
            }
            try {
                sSLSocket = (SSLSocket) address.getSslSocketFactory().createSocket(connectRawSocket, address.getUriHost(), address.getUriPort(), true);
                try {
                    ConnectionSpec configureSecureSocket = connectionSpecSelector.configureSecureSocket(sSLSocket);
                    Platform platform = Platform.get();
                    try {
                        if (configureSecureSocket.supportsTlsExtensions()) {
                            platform.configureTlsExtensions(sSLSocket, address.getUriHost(), address.getProtocols());
                        }
                        sSLSocket.startHandshake();
                        Handshake handshake = Handshake.get(sSLSocket.getSession());
                        Protocol protocol = (!configureSecureSocket.supportsTlsExtensions() || (selectedProtocol = platform.getSelectedProtocol(sSLSocket)) == null) ? null : Protocol.get(selectedProtocol);
                        platform.afterHandshake(sSLSocket);
                        if (address.getHostnameVerifier().verify(address.getUriHost(), sSLSocket.getSession())) {
                            address.getCertificatePinner().check(address.getUriHost(), handshake.peerCertificates());
                            return new ConnectedSocket(route, sSLSocket, protocol, handshake);
                        }
                        X509Certificate x509Certificate = (X509Certificate) sSLSocket.getSession().getPeerCertificates()[0];
                        throw new SSLPeerUnverifiedException("Hostname " + address.getUriHost() + " not verified:" + "\n    certificate: " + CertificatePinner.pin(x509Certificate) + "\n    DN: " + x509Certificate.getSubjectDN().getName() + "\n    subjectAltNames: " + OkHostnameVerifier.allSubjectAltNames(x509Certificate));
                    } catch (Throwable th) {
                        platform.afterHandshake(sSLSocket);
                        throw th;
                    }
                } catch (IOException e2) {
                    e = e2;
                    z2 = !z && connectionSpecSelector.connectionFailed(e);
                    Util.closeQuietly((Socket) sSLSocket);
                    Util.closeQuietly(connectRawSocket);
                    if (routeException != null) {
                        routeException = new RouteException(e);
                        continue;
                    } else {
                        routeException.addConnectException(e);
                        continue;
                    }
                    if (!z2) {
                        throw routeException;
                    }
                }
            } catch (IOException e3) {
                e = e3;
                sSLSocket = null;
                if (!z) {
                }
                Util.closeQuietly((Socket) sSLSocket);
                Util.closeQuietly(connectRawSocket);
                if (routeException != null) {
                }
                if (!z2) {
                }
            }
        } while (!z2);
        throw routeException;
    }

    public static class ConnectedSocket {
        public final Protocol alpnProtocol;
        public final Handshake handshake;
        public final Route route;
        public final Socket socket;

        public ConnectedSocket(Route route2, Socket socket2) {
            this.route = route2;
            this.socket = socket2;
            this.alpnProtocol = null;
            this.handshake = null;
        }

        public ConnectedSocket(Route route2, SSLSocket sSLSocket, Protocol protocol, Handshake handshake2) {
            this.route = route2;
            this.socket = sSLSocket;
            this.alpnProtocol = protocol;
            this.handshake = handshake2;
        }
    }
}
