package com.squareup.okhttp.internal.huc;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.squareup.okhttp.Handshake;
import com.squareup.okhttp.Headers;
import com.squareup.okhttp.MediaType;
import com.squareup.okhttp.Request;
import com.squareup.okhttp.Response;
import com.squareup.okhttp.ResponseBody;
import com.squareup.okhttp.internal.Util;
import com.squareup.okhttp.internal.http.OkHeaders;
import com.squareup.okhttp.internal.http.StatusLine;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.CacheResponse;
import java.net.HttpURLConnection;
import java.net.SecureCacheResponse;
import java.net.URI;
import java.net.URLConnection;
import java.security.Principal;
import java.security.cert.Certificate;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSocketFactory;
import kotlinx.coroutines.internal.SystemPropsKt;
import okio.BufferedSource;

public final class JavaApiConverter {

    public static final class CacheHttpURLConnection extends HttpURLConnection {
        private final Request request;
        private final Response response;

        public CacheHttpURLConnection(Response response2) {
            super(response2.request().url());
            Request request2 = response2.request();
            this.request = request2;
            this.response = response2;
            boolean z = true;
            ((HttpURLConnection) this).connected = true;
            ((HttpURLConnection) this).doOutput = response2.body() != null ? false : z;
            ((HttpURLConnection) this).method = request2.method();
        }

        public void addRequestProperty(String str, String str2) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        @Override // java.net.URLConnection
        public void connect() {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void disconnect() {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public boolean getAllowUserInteraction() {
            return false;
        }

        public int getConnectTimeout() {
            return 0;
        }

        @Override // java.net.URLConnection
        public Object getContent() {
            throw JavaApiConverter.throwResponseBodyAccessException();
        }

        public boolean getDefaultUseCaches() {
            return super.getDefaultUseCaches();
        }

        public boolean getDoInput() {
            return true;
        }

        public boolean getDoOutput() {
            return this.request.body() != null;
        }

        public InputStream getErrorStream() {
            return null;
        }

        @Override // java.net.HttpURLConnection, java.net.URLConnection
        public String getHeaderField(int i) {
            if (i < 0) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline11("Invalid header index: ", i));
            } else if (i == 0) {
                return StatusLine.get(this.response).toString();
            } else {
                return this.response.headers().value(i - 1);
            }
        }

        public String getHeaderFieldKey(int i) {
            if (i < 0) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline11("Invalid header index: ", i));
            } else if (i == 0) {
                return null;
            } else {
                return this.response.headers().name(i - 1);
            }
        }

        @Override // java.net.URLConnection
        public Map<String, List<String>> getHeaderFields() {
            return OkHeaders.toMultimap(this.response.headers(), StatusLine.get(this.response).toString());
        }

        public long getIfModifiedSince() {
            return 0;
        }

        @Override // java.net.URLConnection
        public InputStream getInputStream() {
            throw JavaApiConverter.throwResponseBodyAccessException();
        }

        public boolean getInstanceFollowRedirects() {
            return super.getInstanceFollowRedirects();
        }

        @Override // java.net.URLConnection
        public OutputStream getOutputStream() {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public int getReadTimeout() {
            return 0;
        }

        public String getRequestMethod() {
            return this.request.method();
        }

        @Override // java.net.URLConnection
        public Map<String, List<String>> getRequestProperties() {
            throw JavaApiConverter.throwRequestHeaderAccessException();
        }

        public String getRequestProperty(String str) {
            return this.request.header(str);
        }

        @Override // java.net.HttpURLConnection
        public int getResponseCode() {
            return this.response.code();
        }

        @Override // java.net.HttpURLConnection
        public String getResponseMessage() {
            return this.response.message();
        }

        public boolean getUseCaches() {
            return super.getUseCaches();
        }

        public void setAllowUserInteraction(boolean z) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setChunkedStreamingMode(int i) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setConnectTimeout(int i) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setDefaultUseCaches(boolean z) {
            super.setDefaultUseCaches(z);
        }

        public void setDoInput(boolean z) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setDoOutput(boolean z) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        @Override // java.net.HttpURLConnection
        public void setFixedLengthStreamingMode(int i) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setIfModifiedSince(long j) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setInstanceFollowRedirects(boolean z) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setReadTimeout(int i) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        @Override // java.net.HttpURLConnection
        public void setRequestMethod(String str) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setRequestProperty(String str, String str2) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public void setUseCaches(boolean z) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        public boolean usingProxy() {
            return false;
        }

        @Override // java.net.URLConnection
        public Object getContent(Class[] clsArr) {
            throw JavaApiConverter.throwResponseBodyAccessException();
        }

        @Override // java.net.HttpURLConnection
        public void setFixedLengthStreamingMode(long j) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        @Override // java.net.URLConnection
        public String getHeaderField(String str) {
            if (str == null) {
                return StatusLine.get(this.response).toString();
            }
            return this.response.headers().get(str);
        }
    }

    public static final class CacheHttpsURLConnection extends DelegatingHttpsURLConnection {
        private final CacheHttpURLConnection delegate;

        public CacheHttpsURLConnection(CacheHttpURLConnection cacheHttpURLConnection) {
            super(cacheHttpURLConnection);
            this.delegate = cacheHttpURLConnection;
        }

        public long getContentLengthLong() {
            return this.delegate.getContentLengthLong();
        }

        public long getHeaderFieldLong(String str, long j) {
            return this.delegate.getHeaderFieldLong(str, j);
        }

        @Override // com.squareup.okhttp.internal.huc.DelegatingHttpsURLConnection
        public HostnameVerifier getHostnameVerifier() {
            throw JavaApiConverter.throwRequestSslAccessException();
        }

        @Override // com.squareup.okhttp.internal.huc.DelegatingHttpsURLConnection
        public SSLSocketFactory getSSLSocketFactory() {
            throw JavaApiConverter.throwRequestSslAccessException();
        }

        @Override // com.squareup.okhttp.internal.huc.DelegatingHttpsURLConnection
        public Handshake handshake() {
            return this.delegate.response.handshake();
        }

        @Override // java.net.HttpURLConnection
        public void setFixedLengthStreamingMode(long j) {
            this.delegate.setFixedLengthStreamingMode(j);
        }

        @Override // com.squareup.okhttp.internal.huc.DelegatingHttpsURLConnection
        public void setHostnameVerifier(HostnameVerifier hostnameVerifier) {
            throw JavaApiConverter.throwRequestModificationException();
        }

        @Override // com.squareup.okhttp.internal.huc.DelegatingHttpsURLConnection
        public void setSSLSocketFactory(SSLSocketFactory sSLSocketFactory) {
            throw JavaApiConverter.throwRequestModificationException();
        }
    }

    private JavaApiConverter() {
    }

    public static CacheResponse createJavaCacheResponse(final Response response) {
        final Headers headers = response.headers();
        final ResponseBody body = response.body();
        if (!response.request().isHttps()) {
            return new CacheResponse() {
                /* class com.squareup.okhttp.internal.huc.JavaApiConverter.AnonymousClass2 */

                @Override // java.net.CacheResponse
                public InputStream getBody() {
                    ResponseBody responseBody = body;
                    if (responseBody == null) {
                        return null;
                    }
                    return responseBody.byteStream();
                }

                @Override // java.net.CacheResponse
                public Map<String, List<String>> getHeaders() {
                    return OkHeaders.toMultimap(headers, StatusLine.get(response).toString());
                }
            };
        }
        final Handshake handshake = response.handshake();
        return new SecureCacheResponse() {
            /* class com.squareup.okhttp.internal.huc.JavaApiConverter.AnonymousClass1 */

            @Override // java.net.CacheResponse
            public InputStream getBody() {
                ResponseBody responseBody = body;
                if (responseBody == null) {
                    return null;
                }
                return responseBody.byteStream();
            }

            public String getCipherSuite() {
                Handshake handshake = handshake;
                if (handshake != null) {
                    return handshake.cipherSuite();
                }
                return null;
            }

            @Override // java.net.CacheResponse
            public Map<String, List<String>> getHeaders() {
                return OkHeaders.toMultimap(headers, StatusLine.get(response).toString());
            }

            @Override // java.net.SecureCacheResponse
            public List<Certificate> getLocalCertificateChain() {
                Handshake handshake = handshake;
                if (handshake == null) {
                    return null;
                }
                List<Certificate> localCertificates = handshake.localCertificates();
                if (localCertificates.size() > 0) {
                    return localCertificates;
                }
                return null;
            }

            public Principal getLocalPrincipal() {
                Handshake handshake = handshake;
                if (handshake == null) {
                    return null;
                }
                return handshake.localPrincipal();
            }

            @Override // java.net.SecureCacheResponse
            public Principal getPeerPrincipal() {
                Handshake handshake = handshake;
                if (handshake == null) {
                    return null;
                }
                return handshake.peerPrincipal();
            }

            @Override // java.net.SecureCacheResponse
            public List<Certificate> getServerCertificateChain() {
                Handshake handshake = handshake;
                if (handshake == null) {
                    return null;
                }
                List<Certificate> peerCertificates = handshake.peerCertificates();
                if (peerCertificates.size() > 0) {
                    return peerCertificates;
                }
                return null;
            }
        };
    }

    public static HttpURLConnection createJavaUrlConnection(Response response) {
        if (response.request().isHttps()) {
            return new CacheHttpsURLConnection(new CacheHttpURLConnection(response));
        }
        return new CacheHttpURLConnection(response);
    }

    private static ResponseBody createOkBody(final Headers headers, InputStream inputStream) {
        final BufferedSource buffer = SystemPropsKt.buffer(SystemPropsKt.source(inputStream));
        return new ResponseBody() {
            /* class com.squareup.okhttp.internal.huc.JavaApiConverter.AnonymousClass3 */

            @Override // com.squareup.okhttp.ResponseBody
            public long contentLength() {
                return OkHeaders.contentLength(headers);
            }

            @Override // com.squareup.okhttp.ResponseBody
            public MediaType contentType() {
                String str = headers.get("Content-Type");
                if (str == null) {
                    return null;
                }
                return MediaType.parse(str);
            }

            @Override // com.squareup.okhttp.ResponseBody
            public BufferedSource source() {
                return buffer;
            }
        };
    }

    public static Request createOkRequest(URI uri, String str, Map<String, List<String>> map) {
        Request.Builder method = new Request.Builder().url(uri.toString()).method(str, null);
        if (map != null) {
            method.headers(extractOkHeaders(map));
        }
        return method.build();
    }

    public static Response createOkResponse(URI uri, URLConnection uRLConnection) {
        HttpURLConnection httpURLConnection = (HttpURLConnection) uRLConnection;
        Response.Builder builder = new Response.Builder();
        Certificate[] certificateArr = null;
        builder.request(createOkRequest(uri, httpURLConnection.getRequestMethod(), null));
        StatusLine parse = StatusLine.parse(extractStatusLine(httpURLConnection));
        builder.protocol(parse.protocol);
        builder.code(parse.code);
        builder.message(parse.message);
        Headers extractOkResponseHeaders = extractOkResponseHeaders(httpURLConnection);
        builder.headers(extractOkResponseHeaders);
        builder.body(createOkBody(extractOkResponseHeaders, uRLConnection.getInputStream()));
        if (httpURLConnection instanceof HttpsURLConnection) {
            HttpsURLConnection httpsURLConnection = (HttpsURLConnection) httpURLConnection;
            try {
                certificateArr = httpsURLConnection.getServerCertificates();
            } catch (SSLPeerUnverifiedException unused) {
            }
            builder.handshake(Handshake.get(httpsURLConnection.getCipherSuite(), nullSafeImmutableList(certificateArr), nullSafeImmutableList(httpsURLConnection.getLocalCertificates())));
        }
        return builder.build();
    }

    public static Map<String, List<String>> extractJavaHeaders(Request request) {
        return OkHeaders.toMultimap(request.headers(), null);
    }

    private static Headers extractOkHeaders(CacheResponse cacheResponse) {
        return extractOkHeaders(cacheResponse.getHeaders());
    }

    private static Headers extractOkResponseHeaders(HttpURLConnection httpURLConnection) {
        return extractOkHeaders(httpURLConnection.getHeaderFields());
    }

    private static String extractStatusLine(HttpURLConnection httpURLConnection) {
        return httpURLConnection.getHeaderField((String) null);
    }

    private static <T> List<T> nullSafeImmutableList(T[] tArr) {
        return tArr == null ? Collections.emptyList() : Util.immutableList(tArr);
    }

    /* access modifiers changed from: private */
    public static RuntimeException throwRequestHeaderAccessException() {
        throw new UnsupportedOperationException("ResponseCache cannot access request headers");
    }

    /* access modifiers changed from: private */
    public static RuntimeException throwRequestModificationException() {
        throw new UnsupportedOperationException("ResponseCache cannot modify the request.");
    }

    /* access modifiers changed from: private */
    public static RuntimeException throwRequestSslAccessException() {
        throw new UnsupportedOperationException("ResponseCache cannot access SSL internals");
    }

    /* access modifiers changed from: private */
    public static RuntimeException throwResponseBodyAccessException() {
        throw new UnsupportedOperationException("ResponseCache cannot access the response body.");
    }

    private static String extractStatusLine(CacheResponse cacheResponse) {
        return extractStatusLine(cacheResponse.getHeaders());
    }

    public static Headers extractOkHeaders(Map<String, List<String>> map) {
        Headers.Builder builder = new Headers.Builder();
        for (Map.Entry<String, List<String>> entry : map.entrySet()) {
            String key = entry.getKey();
            if (key != null) {
                for (String str : entry.getValue()) {
                    builder.add(key, str);
                }
            }
        }
        return builder.build();
    }

    public static String extractStatusLine(Map<String, List<String>> map) {
        List<String> list = map.get(null);
        if (list == null || list.size() == 0) {
            return null;
        }
        return list.get(0);
    }

    public static Response createOkResponse(Request request, CacheResponse cacheResponse) {
        List<Certificate> list;
        Response.Builder builder = new Response.Builder();
        builder.request(request);
        StatusLine parse = StatusLine.parse(extractStatusLine(cacheResponse));
        builder.protocol(parse.protocol);
        builder.code(parse.code);
        builder.message(parse.message);
        Headers extractOkHeaders = extractOkHeaders(cacheResponse);
        builder.headers(extractOkHeaders);
        builder.body(createOkBody(extractOkHeaders, cacheResponse.getBody()));
        if (cacheResponse instanceof SecureCacheResponse) {
            SecureCacheResponse secureCacheResponse = (SecureCacheResponse) cacheResponse;
            try {
                list = secureCacheResponse.getServerCertificateChain();
            } catch (SSLPeerUnverifiedException unused) {
                list = Collections.emptyList();
            }
            List<Certificate> localCertificateChain = secureCacheResponse.getLocalCertificateChain();
            if (localCertificateChain == null) {
                localCertificateChain = Collections.emptyList();
            }
            builder.handshake(Handshake.get(secureCacheResponse.getCipherSuite(), list, localCertificateChain));
        }
        return builder.build();
    }
}
