package com.squareup.okhttp.internal.io;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.logging.Logger;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.SystemPropsKt;
import okio.Okio__JvmOkioKt;
import okio.Sink;
import okio.Source;

public interface FileSystem {
    public static final FileSystem SYSTEM = new FileSystem() {
        /* class com.squareup.okhttp.internal.io.FileSystem.AnonymousClass1 */

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public Sink appendingSink(File file) {
            try {
                Logger logger = Okio__JvmOkioKt.logger;
                Intrinsics.checkNotNullParameter(file, "$this$appendingSink");
                return SystemPropsKt.sink(new FileOutputStream(file, true));
            } catch (FileNotFoundException unused) {
                file.getParentFile().mkdirs();
                Logger logger2 = Okio__JvmOkioKt.logger;
                Intrinsics.checkNotNullParameter(file, "$this$appendingSink");
                return SystemPropsKt.sink(new FileOutputStream(file, true));
            }
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public void delete(File file) {
            if (!file.delete() && file.exists()) {
                throw new IOException("failed to delete " + file);
            }
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public void deleteContents(File file) {
            File[] listFiles = file.listFiles();
            if (listFiles != null) {
                for (File file2 : listFiles) {
                    if (file2.isDirectory()) {
                        deleteContents(file2);
                    }
                    if (!file2.delete()) {
                        throw new IOException("failed to delete " + file2);
                    }
                }
                return;
            }
            throw new IOException("not a readable directory: " + file);
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public boolean exists(File file) {
            return file.exists();
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public void rename(File file, File file2) {
            delete(file2);
            if (!file.renameTo(file2)) {
                throw new IOException("failed to rename " + file + " to " + file2);
            }
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public Sink sink(File file) {
            try {
                Logger logger = Okio__JvmOkioKt.logger;
                Intrinsics.checkNotNullParameter(file, "$this$sink");
                return SystemPropsKt.sink(new FileOutputStream(file, false));
            } catch (FileNotFoundException unused) {
                file.getParentFile().mkdirs();
                Logger logger2 = Okio__JvmOkioKt.logger;
                Intrinsics.checkNotNullParameter(file, "$this$sink");
                return SystemPropsKt.sink(new FileOutputStream(file, false));
            }
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public long size(File file) {
            return file.length();
        }

        @Override // com.squareup.okhttp.internal.io.FileSystem
        public Source source(File file) {
            return SystemPropsKt.source(file);
        }
    };

    Sink appendingSink(File file);

    void delete(File file);

    void deleteContents(File file);

    boolean exists(File file);

    void rename(File file, File file2);

    Sink sink(File file);

    long size(File file);

    Source source(File file);
}
