package com.tencent.mm.opensdk.channel;

import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.tencent.mm.opensdk.channel.a.a;
import com.tencent.mm.opensdk.constants.Build;
import com.tencent.mm.opensdk.constants.ConstantsAPI;
import com.tencent.mm.opensdk.utils.Log;
import com.tencent.mm.opensdk.utils.b;

public class MMessageActV2 {
    public static final String DEFAULT_ENTRY_CLASS_NAME = ".wxapi.WXEntryActivity";
    public static final String MM_ENTRY_PACKAGE_NAME = "com.tencent.mm";
    public static final String MM_MSG_ENTRY_CLASS_NAME = "com.tencent.mm.plugin.base.stub.WXEntryActivity";
    private static final String TAG = "MicroMsg.SDK.MMessageAct";

    public static class Args {
        public static final int INVALID_FLAGS = -1;
        public Bundle bundle;
        public String content;
        public int flags = -1;
        public int launchMode = 2;
        public String targetClassName;
        public String targetPkgName;
        public String token;

        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("targetPkgName:");
            outline25.append(this.targetPkgName);
            outline25.append(", targetClassName:");
            outline25.append(this.targetClassName);
            outline25.append(", content:");
            outline25.append(this.content);
            outline25.append(", flags:");
            outline25.append(this.flags);
            outline25.append(", bundle:");
            outline25.append(this.bundle);
            return outline25.toString();
        }
    }

    public static boolean send(Context context, Args args) {
        String str;
        if (context == null || args == null) {
            str = "send fail, invalid argument";
        } else if (b.b(args.targetPkgName)) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("send fail, invalid targetPkgName, targetPkgName = ");
            outline25.append(args.targetPkgName);
            str = outline25.toString();
        } else {
            if (b.b(args.targetClassName)) {
                args.targetClassName = GeneratedOutlineSupport.outline22(new StringBuilder(), args.targetPkgName, DEFAULT_ENTRY_CLASS_NAME);
            }
            StringBuilder outline252 = GeneratedOutlineSupport.outline25("send, targetPkgName = ");
            outline252.append(args.targetPkgName);
            outline252.append(", targetClassName = ");
            outline252.append(args.targetClassName);
            outline252.append(", launchMode = ");
            outline252.append(args.launchMode);
            Log.d(TAG, outline252.toString());
            Intent intent = new Intent();
            intent.setClassName(args.targetPkgName, args.targetClassName);
            Bundle bundle = args.bundle;
            if (bundle != null) {
                intent.putExtras(bundle);
            }
            String packageName = context.getPackageName();
            intent.putExtra(ConstantsAPI.SDK_VERSION, Build.SDK_INT);
            intent.putExtra(ConstantsAPI.APP_PACKAGE, packageName);
            intent.putExtra(ConstantsAPI.CONTENT, args.content);
            intent.putExtra(ConstantsAPI.CHECK_SUM, a.a(args.content, Build.SDK_INT, packageName));
            intent.putExtra(ConstantsAPI.TOKEN, args.token);
            int i = args.flags;
            if (i == -1) {
                intent.addFlags(268435456).addFlags(134217728);
            } else {
                intent.setFlags(i);
            }
            try {
                if (Build.VERSION.SDK_INT < 29 || args.launchMode != 2) {
                    context.startActivity(intent);
                } else {
                    sendUsingPendingIntent(context, intent);
                }
                Log.d(TAG, "send mm message, intent=" + intent);
                return true;
            } catch (Exception e) {
                StringBuilder outline253 = GeneratedOutlineSupport.outline25("send fail, ex = ");
                outline253.append(e.getMessage());
                str = outline253.toString();
            }
        }
        Log.e(TAG, str);
        return false;
    }

    private static void sendUsingPendingIntent(Context context, Intent intent) {
        try {
            Log.i(TAG, "sendUsingPendingIntent");
            PendingIntent.getActivity(context, 3, intent, 134217728).send(context, 4, null, new PendingIntent.OnFinished() {
                /* class com.tencent.mm.opensdk.channel.MMessageActV2.AnonymousClass1 */

                public void onSendFinished(PendingIntent pendingIntent, Intent intent, int i, String str, Bundle bundle) {
                    Log.i(MMessageActV2.TAG, "sendUsingPendingIntent onSendFinished resultCode: " + i + ", resultData: " + str);
                }
            }, null);
        } catch (Exception e) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("sendUsingPendingIntent fail, ex = ");
            outline25.append(e.getMessage());
            Log.e(TAG, outline25.toString());
            context.startActivity(intent);
        }
    }
}
