package com.yzq.zxinglibrary.android;

import android.app.AlertDialog;
import android.content.ContentUris;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.FeatureInfo;
import android.content.pm.PackageManager;
import android.hardware.Camera;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.os.Message;
import android.os.Vibrator;
import android.provider.DocumentsContract;
import android.provider.MediaStore;
import android.util.Log;
import android.view.SurfaceHolder;
import android.view.SurfaceView;
import android.view.View;
import android.view.Window;
import android.widget.TextView;
import androidx.appcompat.app.AppCompatActivity;
import androidx.appcompat.app.AppCompatDelegate;
import androidx.appcompat.widget.AppCompatImageView;
import androidx.appcompat.widget.LinearLayoutCompat;
import androidx.appcompat.widget.VectorEnabledTintResources;
import androidx.collection.ArraySet;
import androidx.transition.ViewGroupUtilsApi14;
import com.google.zxing.Result;
import com.yzq.zxinglibrary.R$drawable;
import com.yzq.zxinglibrary.R$id;
import com.yzq.zxinglibrary.R$layout;
import com.yzq.zxinglibrary.R$string;
import com.yzq.zxinglibrary.android.CaptureActivityHandler;
import com.yzq.zxinglibrary.bean.ZxingConfig;
import com.yzq.zxinglibrary.camera.AutoFocusManager;
import com.yzq.zxinglibrary.camera.CameraManager;
import com.yzq.zxinglibrary.camera.PreviewCallback;
import com.yzq.zxinglibrary.decode.DecodeImgCallback;
import com.yzq.zxinglibrary.decode.DecodeImgThread;
import com.yzq.zxinglibrary.view.ViewfinderView;
import java.io.IOException;
import java.lang.ref.WeakReference;

public class CaptureActivity extends AppCompatActivity implements SurfaceHolder.Callback, View.OnClickListener {
    public static final String TAG = CaptureActivity.class.getSimpleName();
    public LinearLayoutCompat albumLayout;
    public AppCompatImageView backIv;
    public BeepManager beepManager;
    public LinearLayoutCompat bottomLayout;
    public CameraManager cameraManager;
    public ZxingConfig config;
    public AppCompatImageView flashLightIv;
    public LinearLayoutCompat flashLightLayout;
    public TextView flashLightTv;
    public CaptureActivityHandler handler;
    public boolean hasSurface;
    public InactivityTimer inactivityTimer;
    public SurfaceView previewView;
    public SurfaceHolder surfaceHolder;
    public ViewfinderView viewfinderView;

    static {
        ArraySet<WeakReference<AppCompatDelegate>> arraySet = AppCompatDelegate.sActivityDelegates;
        VectorEnabledTintResources.sCompatVectorFromResourcesEnabled = true;
    }

    public final void displayFrameworkBugMessageAndExit() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setTitle(getString(R$string.title_scan));
        builder.setMessage(getString(R$string.msg_camera_framework_bug));
        builder.setPositiveButton(R$string.button_ok, new FinishListener(this));
        builder.setOnCancelListener(new FinishListener(this));
        builder.show();
    }

    public void handleDecode(Result result) {
        MediaPlayer mediaPlayer;
        this.inactivityTimer.onActivity();
        BeepManager beepManager2 = this.beepManager;
        synchronized (beepManager2) {
            if (beepManager2.playBeep && (mediaPlayer = beepManager2.mediaPlayer) != null) {
                mediaPlayer.start();
            }
            if (beepManager2.vibrate) {
                ((Vibrator) beepManager2.activity.getSystemService("vibrator")).vibrate(200);
            }
        }
        Intent intent = getIntent();
        intent.putExtra("codedContent", result.text);
        setResult(-1, intent);
        finish();
    }

    public final void initCamera(SurfaceHolder surfaceHolder2) {
        boolean z;
        if (surfaceHolder2 != null) {
            CameraManager cameraManager2 = this.cameraManager;
            synchronized (cameraManager2) {
                z = cameraManager2.camera != null;
            }
            if (!z) {
                try {
                    this.cameraManager.openDriver(surfaceHolder2);
                    if (this.handler == null) {
                        this.handler = new CaptureActivityHandler(this, this.cameraManager);
                    }
                } catch (IOException e) {
                    Log.w(TAG, e);
                    displayFrameworkBugMessageAndExit();
                } catch (RuntimeException e2) {
                    Log.w(TAG, "Unexpected error initializing camera", e2);
                    displayFrameworkBugMessageAndExit();
                }
            }
        } else {
            throw new IllegalStateException("No SurfaceHolder provided");
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onActivityResult(int i, int i2, Intent intent) {
        super.onActivityResult(i, i2, intent);
        if (i == 10 && i2 == -1) {
            Uri data = intent.getData();
            String str = null;
            str = null;
            Uri uri = null;
            str = null;
            str = null;
            if (data != null) {
                if (DocumentsContract.isDocumentUri(this, data)) {
                    if ("com.android.externalstorage.documents".equals(data.getAuthority())) {
                        String[] split = DocumentsContract.getDocumentId(data).split(":");
                        if ("primary".equalsIgnoreCase(split[0])) {
                            str = Environment.getExternalStorageDirectory() + "/" + split[1];
                        }
                    } else if ("com.android.providers.downloads.documents".equals(data.getAuthority())) {
                        str = ViewGroupUtilsApi14.getDataColumn(this, ContentUris.withAppendedId(Uri.parse("content://downloads/public_downloads"), Long.valueOf(DocumentsContract.getDocumentId(data)).longValue()), null, null);
                    } else if ("com.android.providers.media.documents".equals(data.getAuthority())) {
                        String[] split2 = DocumentsContract.getDocumentId(data).split(":");
                        String str2 = split2[0];
                        if ("image".equals(str2)) {
                            uri = MediaStore.Images.Media.EXTERNAL_CONTENT_URI;
                        } else if ("video".equals(str2)) {
                            uri = MediaStore.Video.Media.EXTERNAL_CONTENT_URI;
                        } else if ("audio".equals(str2)) {
                            uri = MediaStore.Audio.Media.EXTERNAL_CONTENT_URI;
                        }
                        str = ViewGroupUtilsApi14.getDataColumn(this, uri, "_id=?", new String[]{split2[1]});
                    }
                } else if ("content".equalsIgnoreCase(data.getScheme())) {
                    str = "com.google.android.apps.photos.content".equals(data.getAuthority()) ? data.getLastPathSegment() : ViewGroupUtilsApi14.getDataColumn(this, data, null, null);
                } else if ("file".equalsIgnoreCase(data.getScheme())) {
                    str = data.getPath();
                }
            }
            new DecodeImgThread(str, new DecodeImgCallback() {
                /* class com.yzq.zxinglibrary.android.CaptureActivity.AnonymousClass1 */
            }).run();
        }
    }

    public void onClick(View view) {
        int id = view.getId();
        if (id == R$id.flashLightLayout) {
            CameraManager cameraManager2 = this.cameraManager;
            CaptureActivityHandler captureActivityHandler = this.handler;
            Camera.Parameters parameters = cameraManager2.camera.getParameters();
            Message message = new Message();
            if (parameters.getFlashMode().equals("torch")) {
                parameters.setFlashMode("off");
                message.what = 9;
            } else {
                parameters.setFlashMode("torch");
                message.what = 8;
            }
            cameraManager2.camera.setParameters(parameters);
            captureActivityHandler.sendMessage(message);
        } else if (id == R$id.albumLayout) {
            Intent intent = new Intent();
            intent.setAction("android.intent.action.PICK");
            intent.setType("image/*");
            startActivityForResult(intent, 10);
        } else if (id == R$id.backIv) {
            finish();
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        boolean z;
        FeatureInfo[] systemAvailableFeatures;
        super.onCreate(bundle);
        Window window = getWindow();
        window.addFlags(128);
        window.setStatusBarColor(-16777216);
        try {
            this.config = (ZxingConfig) getIntent().getExtras().get("zxingConfig");
        } catch (Exception e) {
            Log.i("config", e.toString());
        }
        if (this.config == null) {
            this.config = new ZxingConfig();
        }
        setContentView(R$layout.activity_capture);
        SurfaceView surfaceView = (SurfaceView) findViewById(R$id.preview_view);
        this.previewView = surfaceView;
        surfaceView.setOnClickListener(this);
        ViewfinderView viewfinderView2 = (ViewfinderView) findViewById(R$id.viewfinder_view);
        this.viewfinderView = viewfinderView2;
        viewfinderView2.setZxingConfig(this.config);
        AppCompatImageView appCompatImageView = (AppCompatImageView) findViewById(R$id.backIv);
        this.backIv = appCompatImageView;
        appCompatImageView.setOnClickListener(this);
        this.flashLightIv = (AppCompatImageView) findViewById(R$id.flashLightIv);
        this.flashLightTv = (TextView) findViewById(R$id.flashLightTv);
        LinearLayoutCompat linearLayoutCompat = (LinearLayoutCompat) findViewById(R$id.flashLightLayout);
        this.flashLightLayout = linearLayoutCompat;
        linearLayoutCompat.setOnClickListener(this);
        LinearLayoutCompat linearLayoutCompat2 = (LinearLayoutCompat) findViewById(R$id.albumLayout);
        this.albumLayout = linearLayoutCompat2;
        linearLayoutCompat2.setOnClickListener(this);
        LinearLayoutCompat linearLayoutCompat3 = (LinearLayoutCompat) findViewById(R$id.bottomLayout);
        this.bottomLayout = linearLayoutCompat3;
        switchVisibility(linearLayoutCompat3, this.config.isShowbottomLayout());
        switchVisibility(this.flashLightLayout, this.config.isShowFlashLight());
        switchVisibility(this.albumLayout, this.config.isShowAlbum());
        PackageManager packageManager = getPackageManager();
        if (packageManager != null && (systemAvailableFeatures = packageManager.getSystemAvailableFeatures()) != null) {
            int length = systemAvailableFeatures.length;
            int i = 0;
            while (true) {
                if (i < length) {
                    FeatureInfo featureInfo = systemAvailableFeatures[i];
                    if (featureInfo != null && "android.hardware.camera.flash".equals(featureInfo.name)) {
                        z = true;
                        break;
                    }
                    i++;
                } else {
                    break;
                }
            }
        }
        z = false;
        if (z) {
            this.flashLightLayout.setVisibility(0);
        } else {
            this.flashLightLayout.setVisibility(8);
        }
        this.hasSurface = false;
        this.inactivityTimer = new InactivityTimer(this);
        BeepManager beepManager2 = new BeepManager(this);
        this.beepManager = beepManager2;
        beepManager2.playBeep = this.config.isPlayBeep();
        this.beepManager.vibrate = this.config.isShake();
    }

    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onDestroy() {
        this.inactivityTimer.cancel();
        super.onDestroy();
    }

    @Override // androidx.fragment.app.FragmentActivity
    public void onPause() {
        CaptureActivityHandler captureActivityHandler = this.handler;
        if (captureActivityHandler != null) {
            captureActivityHandler.state = CaptureActivityHandler.State.DONE;
            CameraManager cameraManager2 = captureActivityHandler.cameraManager;
            synchronized (cameraManager2) {
                AutoFocusManager autoFocusManager = cameraManager2.autoFocusManager;
                if (autoFocusManager != null) {
                    autoFocusManager.stop();
                    cameraManager2.autoFocusManager = null;
                }
                Camera camera = cameraManager2.camera;
                if (camera != null && cameraManager2.previewing) {
                    camera.stopPreview();
                    PreviewCallback previewCallback = cameraManager2.previewCallback;
                    previewCallback.previewHandler = null;
                    previewCallback.previewMessage = 0;
                    cameraManager2.previewing = false;
                }
            }
            Message.obtain(captureActivityHandler.decodeThread.getHandler(), 5).sendToTarget();
            try {
                captureActivityHandler.decodeThread.join(500);
            } catch (InterruptedException unused) {
            }
            captureActivityHandler.removeMessages(3);
            captureActivityHandler.removeMessages(2);
            this.handler = null;
        }
        InactivityTimer inactivityTimer2 = this.inactivityTimer;
        synchronized (inactivityTimer2) {
            inactivityTimer2.cancel();
            if (inactivityTimer2.registered) {
                inactivityTimer2.activity.unregisterReceiver(inactivityTimer2.powerStatusReceiver);
                inactivityTimer2.registered = false;
            } else {
                Log.w("InactivityTimer", "PowerStatusReceiver was never registered?");
            }
        }
        this.beepManager.close();
        CameraManager cameraManager3 = this.cameraManager;
        synchronized (cameraManager3) {
            Camera camera2 = cameraManager3.camera;
            if (camera2 != null) {
                camera2.release();
                cameraManager3.camera = null;
                cameraManager3.framingRect = null;
                cameraManager3.framingRectInPreview = null;
            }
        }
        if (!this.hasSurface) {
            this.surfaceHolder.removeCallback(this);
        }
        super.onPause();
    }

    @Override // androidx.fragment.app.FragmentActivity
    public void onResume() {
        super.onResume();
        CameraManager cameraManager2 = new CameraManager(getApplication(), this.config);
        this.cameraManager = cameraManager2;
        this.viewfinderView.setCameraManager(cameraManager2);
        this.handler = null;
        SurfaceHolder holder = this.previewView.getHolder();
        this.surfaceHolder = holder;
        if (this.hasSurface) {
            initCamera(holder);
        } else {
            holder.addCallback(this);
        }
        this.beepManager.updatePrefs();
        InactivityTimer inactivityTimer2 = this.inactivityTimer;
        synchronized (inactivityTimer2) {
            if (inactivityTimer2.registered) {
                Log.w("InactivityTimer", "PowerStatusReceiver was already registered?");
            } else {
                inactivityTimer2.activity.registerReceiver(inactivityTimer2.powerStatusReceiver, new IntentFilter("android.intent.action.BATTERY_CHANGED"));
                inactivityTimer2.registered = true;
            }
            inactivityTimer2.onActivity();
        }
    }

    public void surfaceChanged(SurfaceHolder surfaceHolder2, int i, int i2, int i3) {
    }

    public void surfaceCreated(SurfaceHolder surfaceHolder2) {
        if (!this.hasSurface) {
            this.hasSurface = true;
            initCamera(surfaceHolder2);
        }
    }

    public void surfaceDestroyed(SurfaceHolder surfaceHolder2) {
        this.hasSurface = false;
    }

    public void switchFlashImg(int i) {
        if (i == 8) {
            this.flashLightIv.setImageResource(R$drawable.ic_open);
            this.flashLightTv.setText(getString(R$string.close_light));
            return;
        }
        this.flashLightIv.setImageResource(R$drawable.ic_close);
        this.flashLightTv.setText(getString(R$string.open_light));
    }

    public final void switchVisibility(View view, boolean z) {
        if (z) {
            view.setVisibility(0);
        } else {
            view.setVisibility(8);
        }
    }
}
