package com.yzq.zxinglibrary.android;

import android.content.Intent;
import android.hardware.Camera;
import android.os.Handler;
import android.os.Message;
import com.google.zxing.Result;
import com.yzq.zxinglibrary.camera.AutoFocusManager;
import com.yzq.zxinglibrary.camera.CameraManager;
import com.yzq.zxinglibrary.decode.DecodeThread;
import com.yzq.zxinglibrary.view.ViewfinderResultPointCallback;
import com.yzq.zxinglibrary.view.ViewfinderView;
import java.util.Objects;

public final class CaptureActivityHandler extends Handler {
    public final CaptureActivity activity;
    public final CameraManager cameraManager;
    public final DecodeThread decodeThread;
    public State state = State.SUCCESS;

    public enum State {
        PREVIEW,
        SUCCESS,
        DONE
    }

    public CaptureActivityHandler(CaptureActivity captureActivity, CameraManager cameraManager2) {
        this.activity = captureActivity;
        DecodeThread decodeThread2 = new DecodeThread(captureActivity, new ViewfinderResultPointCallback(captureActivity.viewfinderView));
        this.decodeThread = decodeThread2;
        decodeThread2.start();
        this.cameraManager = cameraManager2;
        synchronized (cameraManager2) {
            Camera camera = cameraManager2.camera;
            if (camera != null && !cameraManager2.previewing) {
                camera.startPreview();
                cameraManager2.previewing = true;
                cameraManager2.autoFocusManager = new AutoFocusManager(cameraManager2.camera);
            }
        }
        restartPreviewAndDecode();
    }

    public void handleMessage(Message message) {
        int i = message.what;
        if (i == 2) {
            this.state = State.PREVIEW;
            this.cameraManager.requestPreviewFrame(this.decodeThread.getHandler(), 1);
        } else if (i != 3) {
            switch (i) {
                case 6:
                    restartPreviewAndDecode();
                    return;
                case 7:
                    this.activity.setResult(-1, (Intent) message.obj);
                    this.activity.finish();
                    return;
                case 8:
                    this.activity.switchFlashImg(8);
                    return;
                case 9:
                    this.activity.switchFlashImg(9);
                    return;
                default:
                    return;
            }
        } else {
            this.state = State.SUCCESS;
            this.activity.handleDecode((Result) message.obj);
        }
    }

    public void restartPreviewAndDecode() {
        if (this.state == State.SUCCESS) {
            this.state = State.PREVIEW;
            this.cameraManager.requestPreviewFrame(this.decodeThread.getHandler(), 1);
            ViewfinderView viewfinderView = this.activity.viewfinderView;
            Objects.requireNonNull(viewfinderView);
            viewfinderView.invalidate();
        }
    }
}
