package com.yzq.zxinglibrary.camera;

import android.content.Context;
import android.graphics.Point;
import android.hardware.Camera;
import android.util.Log;
import android.view.Display;
import android.view.WindowManager;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.regex.Pattern;

public final class CameraConfigurationManager {
    public static final Pattern COMMA_PATTERN = Pattern.compile(",");
    public Point cameraResolution;
    public final Context context;
    public Point screenResolution;

    public CameraConfigurationManager(Context context2) {
        this.context = context2;
    }

    public void initFromCameraParameters(Camera camera) {
        Camera.Parameters parameters = camera.getParameters();
        Display defaultDisplay = ((WindowManager) this.context.getSystemService("window")).getDefaultDisplay();
        this.screenResolution = new Point(defaultDisplay.getWidth(), defaultDisplay.getHeight());
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Screen resolution: ");
        outline25.append(this.screenResolution);
        Log.d("CameraConfigurationManager", outline25.toString());
        Point point = new Point();
        Point point2 = this.screenResolution;
        point.x = point2.x;
        point.y = point2.y;
        int i = point2.x;
        int i2 = point2.y;
        if (i < i2) {
            point.x = i2;
            point.y = point2.x;
        }
        String str = parameters.get("preview-size-values");
        if (str == null) {
            str = parameters.get("preview-size-value");
        }
        Point point3 = null;
        if (str != null) {
            Log.d("CameraConfigurationManager", "preview-size-values parameter: " + str);
            String[] split = COMMA_PATTERN.split(str);
            int length = split.length;
            int i3 = Integer.MAX_VALUE;
            int i4 = 0;
            int i5 = 0;
            int i6 = 0;
            while (true) {
                if (i4 >= length) {
                    break;
                }
                String trim = split[i4].trim();
                int indexOf = trim.indexOf(120);
                if (indexOf < 0) {
                    GeneratedOutlineSupport.outline32("Bad preview-size: ", trim, "CameraConfigurationManager");
                } else {
                    try {
                        int parseInt = Integer.parseInt(trim.substring(0, indexOf));
                        int parseInt2 = Integer.parseInt(trim.substring(indexOf + 1));
                        int abs = Math.abs(parseInt2 - point.y) + Math.abs(parseInt - point.x);
                        if (abs == 0) {
                            i6 = parseInt2;
                            i5 = parseInt;
                            break;
                        } else if (abs < i3) {
                            i6 = parseInt2;
                            i3 = abs;
                            i5 = parseInt;
                        }
                    } catch (NumberFormatException unused) {
                        GeneratedOutlineSupport.outline32("Bad preview-size: ", trim, "CameraConfigurationManager");
                    }
                }
                i4++;
            }
            if (i5 > 0 && i6 > 0) {
                point3 = new Point(i5, i6);
            }
        }
        if (point3 == null) {
            point3 = new Point((point.x >> 3) << 3, (point.y >> 3) << 3);
        }
        this.cameraResolution = point3;
    }

    public void setDesiredCameraParameters(Camera camera) {
        Camera.Parameters parameters = camera.getParameters();
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Setting preview size: ");
        outline25.append(this.cameraResolution);
        Log.d("CameraConfigurationManager", outline25.toString());
        Point point = this.cameraResolution;
        parameters.setPreviewSize(point.x, point.y);
        String str = parameters.get("zoom-supported");
        if (str == null || Boolean.parseBoolean(str)) {
            int i = 5;
            String str2 = parameters.get("max-zoom");
            double d = 10.0d;
            if (str2 != null) {
                try {
                    int parseDouble = (int) (Double.parseDouble(str2) * 10.0d);
                    if (5 > parseDouble) {
                        i = parseDouble;
                    }
                } catch (NumberFormatException unused) {
                    GeneratedOutlineSupport.outline32("Bad max-zoom: ", str2, "CameraConfigurationManager");
                }
            }
            String str3 = parameters.get("taking-picture-zoom-max");
            if (str3 != null) {
                try {
                    int parseInt = Integer.parseInt(str3);
                    if (i > parseInt) {
                        i = parseInt;
                    }
                } catch (NumberFormatException unused2) {
                    GeneratedOutlineSupport.outline32("Bad taking-picture-zoom-max: ", str3, "CameraConfigurationManager");
                }
            }
            String str4 = parameters.get("mot-zoom-values");
            if (str4 != null) {
                String[] split = COMMA_PATTERN.split(str4);
                int length = split.length;
                int i2 = 0;
                int i3 = 0;
                while (i2 < length) {
                    try {
                        double parseDouble2 = Double.parseDouble(split[i2].trim());
                        int i4 = (int) (d * parseDouble2);
                        if (Math.abs(((double) i) - parseDouble2) < ((double) Math.abs(i - i3))) {
                            i3 = i4;
                        }
                        i2++;
                        d = 10.0d;
                    } catch (NumberFormatException unused3) {
                    }
                }
                i = i3;
            }
            String str5 = parameters.get("mot-zoom-step");
            if (str5 != null) {
                try {
                    int parseDouble3 = (int) (Double.parseDouble(str5.trim()) * 10.0d);
                    if (parseDouble3 > 1) {
                        i -= i % parseDouble3;
                    }
                } catch (NumberFormatException unused4) {
                }
            }
            if (!(str2 == null && str4 == null)) {
                parameters.set("zoom", String.valueOf(((double) i) / 10.0d));
            }
            if (str3 != null) {
                parameters.set("taking-picture-zoom", i);
            }
        }
        camera.setDisplayOrientation(90);
        camera.setParameters(parameters);
    }
}
