package com.yzq.zxinglibrary.camera;

import android.content.Context;
import android.graphics.Point;
import android.graphics.Rect;
import android.hardware.Camera;
import android.os.Handler;
import android.util.Log;
import android.view.SurfaceHolder;
import com.yzq.zxinglibrary.bean.ZxingConfig;
import java.io.IOException;

public final class CameraManager {
    public AutoFocusManager autoFocusManager;
    public Camera camera;
    public ZxingConfig config;
    public final CameraConfigurationManager configManager;
    public Rect framingRect;
    public Rect framingRectInPreview;
    public boolean initialized;
    public final PreviewCallback previewCallback;
    public boolean previewing;
    public int requestedFramingRectHeight;
    public int requestedFramingRectWidth;

    public CameraManager(Context context, ZxingConfig zxingConfig) {
        CameraConfigurationManager cameraConfigurationManager = new CameraConfigurationManager(context);
        this.configManager = cameraConfigurationManager;
        this.previewCallback = new PreviewCallback(cameraConfigurationManager);
        this.config = zxingConfig;
    }

    public synchronized Rect getFramingRect() {
        if (this.framingRect == null) {
            if (this.camera == null) {
                return null;
            }
            Point point = this.configManager.screenResolution;
            if (point == null) {
                return null;
            }
            int i = point.x;
            int i2 = (int) (((double) i) * 0.6d);
            int i3 = (i - i2) / 2;
            int i4 = (point.y - i2) / 5;
            this.framingRect = new Rect(i3, i4, i3 + i2, i2 + i4);
            Log.d("CameraManager", "Calculated framing rect: " + this.framingRect);
        }
        return this.framingRect;
    }

    public synchronized Rect getFramingRectInPreview() {
        if (this.framingRectInPreview == null) {
            Rect framingRect2 = getFramingRect();
            if (framingRect2 == null) {
                return null;
            }
            Rect rect = new Rect(framingRect2);
            CameraConfigurationManager cameraConfigurationManager = this.configManager;
            Point point = cameraConfigurationManager.cameraResolution;
            Point point2 = cameraConfigurationManager.screenResolution;
            if (point == null || point2 == null) {
                return null;
            }
            int i = rect.left;
            int i2 = point.y;
            int i3 = point2.x;
            rect.left = (i * i2) / i3;
            rect.right = (rect.right * i2) / i3;
            int i4 = rect.top;
            int i5 = point.x;
            int i6 = point2.y;
            rect.top = (i4 * i5) / i6;
            rect.bottom = (rect.bottom * i5) / i6;
            this.framingRectInPreview = rect;
        }
        return this.framingRectInPreview;
    }

    public synchronized void openDriver(SurfaceHolder surfaceHolder) {
        String str;
        int i;
        Camera camera2 = this.camera;
        if (camera2 == null) {
            camera2 = OpenCameraInterface.open(-1);
            if (camera2 != null) {
                this.camera = camera2;
            } else {
                throw new IOException();
            }
        }
        camera2.setPreviewDisplay(surfaceHolder);
        if (!this.initialized) {
            this.initialized = true;
            this.configManager.initFromCameraParameters(camera2);
            int i2 = this.requestedFramingRectWidth;
            if (i2 > 0 && (i = this.requestedFramingRectHeight) > 0) {
                setManualFramingRect(i2, i);
                this.requestedFramingRectWidth = 0;
                this.requestedFramingRectHeight = 0;
            }
        }
        Camera.Parameters parameters = camera2.getParameters();
        if (parameters == null) {
            str = null;
        } else {
            str = parameters.flatten();
        }
        try {
            this.configManager.setDesiredCameraParameters(camera2);
        } catch (RuntimeException unused) {
            Log.w("CameraManager", "Camera rejected parameters. Setting only minimal safe-mode parameters");
            Log.i("CameraManager", "Resetting to saved camera params: " + str);
            if (str != null) {
                Camera.Parameters parameters2 = camera2.getParameters();
                parameters2.unflatten(str);
                try {
                    camera2.setParameters(parameters2);
                    this.configManager.setDesiredCameraParameters(camera2);
                } catch (RuntimeException unused2) {
                    Log.w("CameraManager", "Camera rejected even safe-mode parameters! No configuration");
                }
            }
        }
    }

    public synchronized void requestPreviewFrame(Handler handler, int i) {
        Camera camera2 = this.camera;
        if (camera2 != null && this.previewing) {
            PreviewCallback previewCallback2 = this.previewCallback;
            previewCallback2.previewHandler = handler;
            previewCallback2.previewMessage = i;
            camera2.setOneShotPreviewCallback(previewCallback2);
        }
    }

    public synchronized void setManualFramingRect(int i, int i2) {
        if (this.initialized) {
            Point point = this.configManager.screenResolution;
            int i3 = point.x;
            if (i > i3) {
                i = i3;
            }
            int i4 = point.y;
            if (i2 > i4) {
                i2 = i4;
            }
            int i5 = (i3 - i) / 2;
            int i6 = (i4 - i2) / 2;
            this.framingRect = new Rect(i5, i6, i + i5, i2 + i6);
            Log.d("CameraManager", "Calculated manual framing rect: " + this.framingRect);
            this.framingRectInPreview = null;
        } else {
            this.requestedFramingRectWidth = i;
            this.requestedFramingRectHeight = i2;
        }
    }
}
