package com.yzq.zxinglibrary.decode;

import android.os.Handler;
import android.os.Looper;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.DecodeHintType;
import com.yzq.zxinglibrary.android.CaptureActivity;
import com.yzq.zxinglibrary.view.ViewfinderResultPointCallback;
import java.util.Hashtable;
import java.util.Vector;
import java.util.concurrent.CountDownLatch;

public final class DecodeThread extends Thread {
    public final CaptureActivity activity;
    public final Vector<BarcodeFormat> decodeFormats;
    public Handler handler;
    public final CountDownLatch handlerInitLatch = new CountDownLatch(1);
    public final Hashtable<DecodeHintType, Object> hints;

    public DecodeThread(CaptureActivity captureActivity, ViewfinderResultPointCallback viewfinderResultPointCallback) {
        this.activity = captureActivity;
        Hashtable<DecodeHintType, Object> hashtable = new Hashtable<>();
        this.hints = hashtable;
        Vector<BarcodeFormat> vector = new Vector<>();
        this.decodeFormats = vector;
        if (captureActivity.config.isDecodeBarCode()) {
            vector.addAll(DecodeFormatManager.ONE_D_FORMATS);
        }
        vector.addAll(DecodeFormatManager.QR_CODE_FORMATS);
        vector.addAll(DecodeFormatManager.DATA_MATRIX_FORMATS);
        hashtable.put(DecodeHintType.POSSIBLE_FORMATS, vector);
        hashtable.put(DecodeHintType.CHARACTER_SET, "UTF-8");
        hashtable.put(DecodeHintType.NEED_RESULT_POINT_CALLBACK, viewfinderResultPointCallback);
    }

    public Handler getHandler() {
        try {
            this.handlerInitLatch.await();
        } catch (InterruptedException unused) {
        }
        return this.handler;
    }

    public void run() {
        Looper.prepare();
        this.handler = new DecodeHandler(this.activity, this.hints);
        this.handlerInitLatch.countDown();
        Looper.loop();
    }
}
