package io.github.rockerhieu.emojicon;

import android.content.Context;
import android.os.Bundle;
import android.os.Parcelable;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.GridView;
import android.widget.ListAdapter;
import androidx.fragment.app.Fragment;
import io.github.rockerhieu.emojicon.emoji.Emojicon;
import io.github.rockerhieu.emojicon.emoji.People;
import net.xfkefu.sdk.R;

public class EmojiconGridFragment extends Fragment implements AdapterView.OnItemClickListener {
    public int mEmojiconType;
    public Emojicon[] mEmojicons;
    public OnEmojiconClickedListener mOnEmojiconClickedListener;
    public EmojiconRecents mRecents;
    public boolean mUseSystemDefault = false;

    public interface OnEmojiconClickedListener {
        void onEmojiconClicked(Emojicon emojicon);
    }

    public static EmojiconGridFragment newInstance(int i, EmojiconRecents emojiconRecents, boolean z) {
        EmojiconGridFragment emojiconGridFragment = new EmojiconGridFragment();
        Bundle bundle = new Bundle();
        bundle.putInt("emojiconType", i);
        bundle.putParcelableArray("emojicons", null);
        bundle.putBoolean("useSystemDefaults", z);
        emojiconGridFragment.setArguments(bundle);
        emojiconGridFragment.mRecents = emojiconRecents;
        return emojiconGridFragment;
    }

    @Override // androidx.fragment.app.Fragment
    public void onAttach(Context context) {
        super.onAttach(context);
        if (context instanceof OnEmojiconClickedListener) {
            this.mOnEmojiconClickedListener = (OnEmojiconClickedListener) context;
        } else if (getParentFragment() instanceof OnEmojiconClickedListener) {
            this.mOnEmojiconClickedListener = (OnEmojiconClickedListener) getParentFragment();
        } else {
            throw new IllegalArgumentException(context + " must implement interface " + OnEmojiconClickedListener.class.getSimpleName());
        }
    }

    @Override // androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater layoutInflater, ViewGroup viewGroup, Bundle bundle) {
        return layoutInflater.inflate(R.layout.emojicon_grid, viewGroup, false);
    }

    @Override // androidx.fragment.app.Fragment
    public void onDetach() {
        this.mOnEmojiconClickedListener = null;
        super.onDetach();
    }

    @Override // android.widget.AdapterView.OnItemClickListener
    public void onItemClick(AdapterView<?> adapterView, View view, int i, long j) {
        OnEmojiconClickedListener onEmojiconClickedListener = this.mOnEmojiconClickedListener;
        if (onEmojiconClickedListener != null) {
            onEmojiconClickedListener.onEmojiconClicked((Emojicon) adapterView.getItemAtPosition(i));
        }
        EmojiconRecents emojiconRecents = this.mRecents;
        if (emojiconRecents != null) {
            emojiconRecents.addRecentEmoji(view.getContext(), (Emojicon) adapterView.getItemAtPosition(i));
        }
    }

    @Override // androidx.fragment.app.Fragment
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        bundle.putParcelableArray("emojicons", this.mEmojicons);
    }

    @Override // androidx.fragment.app.Fragment
    public void onViewCreated(View view, Bundle bundle) {
        GridView gridView = (GridView) view.findViewById(R.id.Emoji_GridView);
        Bundle arguments = getArguments();
        if (arguments == null) {
            this.mEmojiconType = 0;
            this.mEmojicons = People.DATA;
            this.mUseSystemDefault = false;
        } else {
            int i = arguments.getInt("emojiconType");
            this.mEmojiconType = i;
            if (i == 0) {
                Parcelable[] parcelableArray = arguments.getParcelableArray("emojicons");
                this.mEmojicons = new Emojicon[parcelableArray.length];
                for (int i2 = 0; i2 < parcelableArray.length; i2++) {
                    this.mEmojicons[i2] = (Emojicon) parcelableArray[i2];
                }
            } else {
                this.mEmojicons = Emojicon.getEmojicons(i);
            }
            this.mUseSystemDefault = arguments.getBoolean("useSystemDefaults");
        }
        gridView.setAdapter((ListAdapter) new EmojiconAdapter(view.getContext(), this.mEmojicons, this.mUseSystemDefault));
        gridView.setOnItemClickListener(this);
    }
}
