package io.github.rockerhieu.emojicon;

import android.content.Context;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.View;
import android.widget.AdapterView;
import android.widget.GridView;
import android.widget.ListAdapter;
import io.github.rockerhieu.emojicon.EmojiconGridFragment;
import io.github.rockerhieu.emojicon.emoji.Emojicon;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import net.xfkefu.sdk.R;

public class EmojiconGridView extends GridView implements AdapterView.OnItemClickListener {
    public Emojicon[] mData;
    public EmojiconAdapter mEmojiAdapter;
    public List<Emojicon> mEmojiList;
    public int mType;
    public boolean mUseSystemDefaults;
    public EmojiconGridFragment.OnEmojiconClickedListener onEmojiconClickedListener;

    public static class SavedState extends View.BaseSavedState {
        public static final Parcelable.Creator<SavedState> CREATOR = new Parcelable.Creator<SavedState>() {
            /* class io.github.rockerhieu.emojicon.EmojiconGridView.SavedState.AnonymousClass1 */

            /* Return type fixed from 'java.lang.Object' to match base method */
            @Override // android.os.Parcelable.Creator
            public SavedState createFromParcel(Parcel parcel) {
                return new SavedState(parcel, null);
            }

            /* Return type fixed from 'java.lang.Object[]' to match base method */
            @Override // android.os.Parcelable.Creator
            public SavedState[] newArray(int i) {
                return new SavedState[i];
            }
        };
        public Emojicon[] data;
        public int scrollX;
        public int scrollY;
        public int type;
        public boolean useSystemDefaults;

        public SavedState(Parcelable parcelable) {
            super(parcelable);
        }

        public void writeToParcel(Parcel parcel, int i) {
            super.writeToParcel(parcel, i);
            parcel.writeInt(this.type);
            parcel.writeParcelableArray(this.data, i);
            parcel.writeInt(this.useSystemDefaults ? 1 : 0);
            parcel.writeInt(this.scrollX);
            parcel.writeInt(this.scrollY);
        }

        public SavedState(Parcel parcel, AnonymousClass1 r2) {
            super(parcel);
            this.type = parcel.readInt();
            this.data = (Emojicon[]) parcel.readParcelableArray(Emojicon.class.getClassLoader());
            this.useSystemDefaults = parcel.readInt() != 0;
            this.scrollX = parcel.readInt();
            this.scrollY = parcel.readInt();
        }
    }

    public EmojiconGridView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet, R.attr.emojiconGridViewStyle);
        setOnItemClickListener(this);
        setSaveEnabled(true);
        this.mEmojiList = new ArrayList();
        EmojiconAdapter emojiconAdapter = new EmojiconAdapter(context, this.mEmojiList);
        this.mEmojiAdapter = emojiconAdapter;
        setAdapter((ListAdapter) emojiconAdapter);
    }

    @Override // android.widget.AdapterView.OnItemClickListener
    public void onItemClick(AdapterView<?> adapterView, View view, int i, long j) {
        EmojiconGridFragment.OnEmojiconClickedListener onEmojiconClickedListener2 = this.onEmojiconClickedListener;
        if (onEmojiconClickedListener2 != null) {
            onEmojiconClickedListener2.onEmojiconClicked((Emojicon) adapterView.getItemAtPosition(i));
        }
    }

    public void onRestoreInstanceState(Parcelable parcelable) {
        if (!(parcelable instanceof SavedState)) {
            super.onRestoreInstanceState(parcelable);
            return;
        }
        SavedState savedState = (SavedState) parcelable;
        super.onRestoreInstanceState(savedState.getSuperState());
        this.mType = savedState.type;
        this.mData = savedState.data;
        this.mUseSystemDefaults = savedState.useSystemDefaults;
        setScrollX(savedState.scrollX);
        setScrollY(savedState.scrollY);
        setEmojiData(this.mType, this.mData, this.mUseSystemDefaults);
    }

    public Parcelable onSaveInstanceState() {
        SavedState savedState = new SavedState(super.onSaveInstanceState());
        savedState.data = this.mData;
        savedState.type = this.mType;
        savedState.useSystemDefaults = this.mUseSystemDefaults;
        savedState.scrollX = getScrollX();
        savedState.scrollY = getScrollY();
        return savedState;
    }

    public void setEmojiData(int i, Emojicon[] emojiconArr, boolean z) {
        this.mType = i;
        if (i != 0) {
            this.mData = Emojicon.getEmojicons(i);
        } else {
            this.mData = emojiconArr;
        }
        this.mUseSystemDefaults = z;
        if (this.mData == null) {
            this.mEmojiList.clear();
        } else {
            this.mEmojiList.clear();
            Collections.addAll(this.mEmojiList, this.mData);
        }
        this.mEmojiAdapter.notifyDataSetChanged();
    }

    public void setOnEmojiconClickedListener(EmojiconGridFragment.OnEmojiconClickedListener onEmojiconClickedListener2) {
        this.onEmojiconClickedListener = onEmojiconClickedListener2;
    }

    public EmojiconGridView(Context context) {
        this(context, null);
    }
}
