package io.github.rockerhieu.emojicon;

import android.content.Context;
import android.content.SharedPreferences;
import io.github.rockerhieu.emojicon.emoji.Emojicon;
import java.util.ArrayList;
import java.util.StringTokenizer;

public class EmojiconRecentsManager extends ArrayList<Emojicon> {
    public static final Object LOCK = new Object();
    public static int maximumSize = 40;
    public static EmojiconRecentsManager sInstance;
    private Context mContext;

    public EmojiconRecentsManager(Context context) {
        this.mContext = context.getApplicationContext();
        StringTokenizer stringTokenizer = new StringTokenizer(getPreferences().getString("recent_emojis", ""), ",");
        while (stringTokenizer.hasMoreTokens()) {
            add(Emojicon.fromChars(stringTokenizer.nextToken()));
        }
    }

    public static EmojiconRecentsManager getInstance(Context context) {
        if (sInstance == null) {
            synchronized (LOCK) {
                if (sInstance == null) {
                    sInstance = new EmojiconRecentsManager(context);
                }
            }
        }
        return sInstance;
    }

    public static void setMaximumSize(int i) {
        maximumSize = i;
    }

    public final SharedPreferences getPreferences() {
        return this.mContext.getSharedPreferences("emojicon", 0);
    }

    public int getRecentPage() {
        return getPreferences().getInt("recent_page", 0);
    }

    public void push(Emojicon emojicon) {
        if (contains(emojicon)) {
            super.remove(emojicon);
        }
        add(0, emojicon);
    }

    @Override // java.util.List, java.util.ArrayList
    public boolean remove(Object obj) {
        boolean remove = super.remove(obj);
        saveRecents();
        return remove;
    }

    public final void saveRecents() {
        StringBuilder sb = new StringBuilder();
        int size = size();
        for (int i = 0; i < size; i++) {
            sb.append(((Emojicon) get(i)).emoji);
            if (i < size - 1) {
                sb.append(",");
            }
        }
        getPreferences().edit().putString("recent_emojis", sb.toString()).commit();
    }

    public void setRecentPage(int i) {
        getPreferences().edit().putInt("recent_page", i).commit();
    }

    public boolean add(Emojicon emojicon) {
        boolean add = super.add((Object) emojicon);
        while (size() > maximumSize) {
            remove(0);
        }
        saveRecents();
        return add;
    }

    public void add(int i, Emojicon emojicon) {
        super.add(i, (Object) emojicon);
        if (i == 0) {
            while (true) {
                int size = size();
                int i2 = maximumSize;
                if (size <= i2) {
                    break;
                }
                remove(i2);
            }
        } else {
            while (size() > maximumSize) {
                remove(0);
            }
        }
        saveRecents();
    }
}
