package io.github.rockerhieu.emojicon;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.SystemClock;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentStatePagerAdapter;
import androidx.viewpager.widget.PagerAdapter;
import androidx.viewpager.widget.ViewPager;
import io.github.rockerhieu.emojicon.emoji.Emojicon;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;
import net.xfkefu.sdk.R;

public class EmojiconsFragment extends Fragment implements ViewPager.OnPageChangeListener, EmojiconRecents {
    public int mEmojiTabLastSelectedIndex = -1;
    public View[] mEmojiTabs;
    public PagerAdapter mEmojisAdapter;
    public OnEmojiconBackspaceClickedListener mOnEmojiconBackspaceClickedListener;
    public EmojiconRecentsManager mRecentsManager;
    public boolean mUseSystemDefault = false;
    public ViewPager mViewPager;

    public static class EmojiconGridFragmentPagerAdapter extends FragmentStatePagerAdapter {
        public List<EmojiconGridFragment> fragments;

        public EmojiconGridFragmentPagerAdapter(FragmentManager fragmentManager, List<EmojiconGridFragment> list) {
            super(fragmentManager);
            this.fragments = list;
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public int getCount() {
            return this.fragments.size();
        }
    }

    public interface OnEmojiconBackspaceClickedListener {
        void onEmojiconBackspaceClicked(View view);
    }

    public static class RepeatListener implements View.OnTouchListener {
        public final View.OnClickListener clickListener;
        public View downView;
        public Handler handler = new Handler();
        public Runnable handlerRunnable = new Runnable() {
            /* class io.github.rockerhieu.emojicon.EmojiconsFragment.RepeatListener.AnonymousClass1 */

            public void run() {
                RepeatListener repeatListener = RepeatListener.this;
                View view = repeatListener.downView;
                if (view != null) {
                    repeatListener.handler.removeCallbacksAndMessages(view);
                    RepeatListener repeatListener2 = RepeatListener.this;
                    repeatListener2.handler.postAtTime(this, repeatListener2.downView, SystemClock.uptimeMillis() + ((long) RepeatListener.this.normalInterval));
                    RepeatListener repeatListener3 = RepeatListener.this;
                    repeatListener3.clickListener.onClick(repeatListener3.downView);
                }
            }
        };
        public int initialInterval;
        public final int normalInterval;

        public RepeatListener(int i, int i2, View.OnClickListener onClickListener) {
            if (i < 0 || i2 < 0) {
                throw new IllegalArgumentException("negative interval");
            }
            this.initialInterval = i;
            this.normalInterval = i2;
            this.clickListener = onClickListener;
        }

        public boolean onTouch(View view, MotionEvent motionEvent) {
            int action = motionEvent.getAction();
            if (action == 0) {
                this.downView = view;
                this.handler.removeCallbacks(this.handlerRunnable);
                this.handler.postAtTime(this.handlerRunnable, this.downView, SystemClock.uptimeMillis() + ((long) this.initialInterval));
                this.clickListener.onClick(view);
                return true;
            } else if (action != 1 && action != 3 && action != 4) {
                return false;
            } else {
                this.handler.removeCallbacksAndMessages(this.downView);
                this.downView = null;
                return true;
            }
        }
    }

    @Override // io.github.rockerhieu.emojicon.EmojiconRecents
    public void addRecentEmoji(Context context, Emojicon emojicon) {
        EmojiconRecentsGridFragment emojiconRecentsGridFragment = (EmojiconRecentsGridFragment) this.mEmojisAdapter.instantiateItem(this.mViewPager, 0);
        Objects.requireNonNull(emojiconRecentsGridFragment);
        EmojiconRecentsManager.getInstance(context).push(emojicon);
        EmojiconAdapter emojiconAdapter = emojiconRecentsGridFragment.mAdapter;
        if (emojiconAdapter != null) {
            emojiconAdapter.notifyDataSetChanged();
        }
    }

    @Override // androidx.fragment.app.Fragment
    public void onAttach(Context context) {
        super.onAttach(context);
        if (getActivity() instanceof OnEmojiconBackspaceClickedListener) {
            this.mOnEmojiconBackspaceClickedListener = (OnEmojiconBackspaceClickedListener) getActivity();
        } else if (getParentFragment() instanceof OnEmojiconBackspaceClickedListener) {
            this.mOnEmojiconBackspaceClickedListener = (OnEmojiconBackspaceClickedListener) getParentFragment();
        } else {
            throw new IllegalArgumentException(context + " must implement interface " + OnEmojiconBackspaceClickedListener.class.getSimpleName());
        }
    }

    @Override // androidx.fragment.app.Fragment
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        if (getArguments() != null) {
            this.mUseSystemDefault = getArguments().getBoolean("useSystemDefaults");
        } else {
            this.mUseSystemDefault = false;
        }
    }

    @Override // androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater layoutInflater, ViewGroup viewGroup, Bundle bundle) {
        View inflate = layoutInflater.inflate(R.layout.emojicons, viewGroup, false);
        ViewPager viewPager = (ViewPager) inflate.findViewById(R.id.emojis_pager);
        this.mViewPager = viewPager;
        viewPager.setOnPageChangeListener(this);
        FragmentManager fragmentManager = getFragmentManager();
        boolean z = this.mUseSystemDefault;
        EmojiconRecentsGridFragment emojiconRecentsGridFragment = new EmojiconRecentsGridFragment();
        Bundle bundle2 = new Bundle();
        bundle2.putBoolean("useSystemDefaults", z);
        emojiconRecentsGridFragment.setArguments(bundle2);
        int i = 1;
        EmojiconGridFragmentPagerAdapter emojiconGridFragmentPagerAdapter = new EmojiconGridFragmentPagerAdapter(fragmentManager, Arrays.asList(emojiconRecentsGridFragment, EmojiconGridFragment.newInstance(1, this, this.mUseSystemDefault), EmojiconGridFragment.newInstance(2, this, this.mUseSystemDefault), EmojiconGridFragment.newInstance(3, this, this.mUseSystemDefault), EmojiconGridFragment.newInstance(4, this, this.mUseSystemDefault), EmojiconGridFragment.newInstance(5, this, this.mUseSystemDefault)));
        this.mEmojisAdapter = emojiconGridFragmentPagerAdapter;
        this.mViewPager.setAdapter(emojiconGridFragmentPagerAdapter);
        View[] viewArr = new View[6];
        this.mEmojiTabs = viewArr;
        viewArr[0] = inflate.findViewById(R.id.emojis_tab_0_recents);
        this.mEmojiTabs[1] = inflate.findViewById(R.id.emojis_tab_1_people);
        this.mEmojiTabs[2] = inflate.findViewById(R.id.emojis_tab_2_nature);
        this.mEmojiTabs[3] = inflate.findViewById(R.id.emojis_tab_3_objects);
        this.mEmojiTabs[4] = inflate.findViewById(R.id.emojis_tab_4_cars);
        this.mEmojiTabs[5] = inflate.findViewById(R.id.emojis_tab_5_punctuation);
        final int i2 = 0;
        while (true) {
            View[] viewArr2 = this.mEmojiTabs;
            if (i2 >= viewArr2.length) {
                break;
            }
            viewArr2[i2].setOnClickListener(new View.OnClickListener() {
                /* class io.github.rockerhieu.emojicon.EmojiconsFragment.AnonymousClass1 */

                public void onClick(View view) {
                    EmojiconsFragment.this.mViewPager.setCurrentItem(i2);
                }
            });
            i2++;
        }
        inflate.findViewById(R.id.emojis_backspace).setOnTouchListener(new RepeatListener(1000, 50, new View.OnClickListener() {
            /* class io.github.rockerhieu.emojicon.EmojiconsFragment.AnonymousClass2 */

            public void onClick(View view) {
                OnEmojiconBackspaceClickedListener onEmojiconBackspaceClickedListener = EmojiconsFragment.this.mOnEmojiconBackspaceClickedListener;
                if (onEmojiconBackspaceClickedListener != null) {
                    onEmojiconBackspaceClickedListener.onEmojiconBackspaceClicked(view);
                }
            }
        }));
        EmojiconRecentsManager instance = EmojiconRecentsManager.getInstance(inflate.getContext());
        this.mRecentsManager = instance;
        int recentPage = instance.getRecentPage();
        if (!(recentPage == 0 && this.mRecentsManager.size() == 0)) {
            i = recentPage;
        }
        if (i == 0) {
            onPageSelected(i);
        } else {
            this.mViewPager.setCurrentItem(i, false);
        }
        return inflate;
    }

    @Override // androidx.fragment.app.Fragment
    public void onDetach() {
        this.mOnEmojiconBackspaceClickedListener = null;
        super.onDetach();
    }

    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
    public void onPageScrollStateChanged(int i) {
    }

    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
    public void onPageScrolled(int i, float f, int i2) {
    }

    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
    public void onPageSelected(int i) {
        int i2 = this.mEmojiTabLastSelectedIndex;
        if (i2 != i) {
            if (i == 0 || i == 1 || i == 2 || i == 3 || i == 4 || i == 5) {
                if (i2 >= 0) {
                    View[] viewArr = this.mEmojiTabs;
                    if (i2 < viewArr.length) {
                        viewArr[i2].setSelected(false);
                    }
                }
                this.mEmojiTabs[i].setSelected(true);
                this.mEmojiTabLastSelectedIndex = i;
                this.mRecentsManager.setRecentPage(i);
            }
        }
    }
}
