package io.github.rockerhieu.emojicon;

import android.content.Context;
import android.os.Bundle;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.LinearLayout;
import androidx.viewpager.widget.PagerAdapter;
import androidx.viewpager.widget.ViewPager;
import io.github.rockerhieu.emojicon.EmojiconGridView;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import net.xfkefu.sdk.R;

public class EmojiconsView extends FrameLayout implements ViewPager.OnPageChangeListener {
    public View mLastTab;
    public View[] mTabs;
    public ViewGroup mTabsContainer;
    public ViewPager mViewPager;

    public static class EmojiconGridViewPagerAdapter extends PagerAdapter {
        public Context context;
        public final List<EmojiconPage> pages;
        public EmojiconGridView.SavedState[] savedStates;

        public EmojiconGridViewPagerAdapter(Context context2, List<EmojiconPage> list) {
            this.context = context2;
            this.pages = list;
            this.savedStates = new EmojiconGridView.SavedState[list.size()];
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public void destroyItem(ViewGroup viewGroup, int i, Object obj) {
            this.savedStates[i] = (EmojiconGridView.SavedState) ((EmojiconGridView) obj).onSaveInstanceState();
            viewGroup.removeView((View) obj);
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public int getCount() {
            return this.pages.size();
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public Object instantiateItem(ViewGroup viewGroup, int i) {
            this.pages.get(i);
            EmojiconGridView emojiconGridView = new EmojiconGridView(this.context);
            emojiconGridView.setId(View.generateViewId());
            viewGroup.addView(emojiconGridView);
            throw null;
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public boolean isViewFromObject(View view, Object obj) {
            return view == obj;
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public void restoreState(Parcelable parcelable, ClassLoader classLoader) {
            if (parcelable != null) {
                Parcelable[] parcelableArray = ((Bundle) parcelable).getParcelableArray("states");
                this.savedStates = new EmojiconGridView.SavedState[parcelableArray.length];
                for (int i = 0; i < parcelableArray.length; i++) {
                    this.savedStates[i] = (EmojiconGridView.SavedState) parcelableArray[i];
                }
            }
        }

        @Override // androidx.viewpager.widget.PagerAdapter
        public Parcelable saveState() {
            Bundle bundle = new Bundle();
            bundle.putParcelableArray("states", this.savedStates);
            return bundle;
        }
    }

    public EmojiconsView(Context context) {
        this(context, null);
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mViewPager.addOnPageChangeListener(this);
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        this.mViewPager.removeOnPageChangeListener(this);
    }

    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
    public void onPageScrollStateChanged(int i) {
    }

    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
    public void onPageScrolled(int i, float f, int i2) {
    }

    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
    public void onPageSelected(int i) {
        View[] viewArr = this.mTabs;
        if (viewArr != null && i < viewArr.length) {
            View view = this.mLastTab;
            if (view != null) {
                view.setSelected(false);
            }
            View view2 = this.mTabs[i];
            this.mLastTab = view2;
            view2.setSelected(true);
        }
    }

    public void setPages(List<EmojiconPage> list) {
        View[] viewArr = this.mTabs;
        if (viewArr == null || viewArr.length != list.size()) {
            this.mTabs = new View[list.size()];
        } else {
            Arrays.fill(this.mTabs, (Object) null);
        }
        for (int i = 0; i < this.mTabsContainer.getChildCount() - 2; i++) {
            this.mTabsContainer.removeViewAt(0);
        }
        Iterator<EmojiconPage> it = list.iterator();
        if (!it.hasNext()) {
            onPageSelected(0);
            this.mViewPager.setAdapter(new EmojiconGridViewPagerAdapter(getContext(), list));
            return;
        }
        it.next();
        ImageButton imageButton = new ImageButton(getContext());
        new LinearLayout.LayoutParams(0, -1).weight = 1.0f;
        imageButton.setBackground(null);
        imageButton.setScaleType(ImageView.ScaleType.CENTER);
        getContext();
        throw null;
    }

    public EmojiconsView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        LayoutInflater.from(context).inflate(R.layout.emojicons_view, this);
        this.mViewPager = (ViewPager) findViewById(R.id.emojis_pager);
        this.mTabsContainer = (ViewGroup) findViewById(R.id.emojis_tab);
    }
}
