package io.netty.buffer.search;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.PlatformDependent;

public class BitapSearchProcessorFactory extends AbstractSearchProcessorFactory {
    private final long[] bitMasks = new long[256];
    private final long successBit;

    public static class Processor implements SearchProcessor {
        private final long[] bitMasks;
        private long currentMask;
        private final long successBit;

        public Processor(long[] jArr, long j) {
            this.bitMasks = jArr;
            this.successBit = j;
        }

        @Override // io.netty.util.ByteProcessor
        public boolean process(byte b) {
            long j = ((this.currentMask << 1) | 1) & PlatformDependent.getLong(this.bitMasks, ((long) b) & 255);
            this.currentMask = j;
            if ((j & this.successBit) == 0) {
                return true;
            }
            return false;
        }

        @Override // io.netty.buffer.search.SearchProcessor
        public void reset() {
            this.currentMask = 0;
        }
    }

    public BitapSearchProcessorFactory(byte[] bArr) {
        if (bArr.length <= 64) {
            long j = 1;
            for (byte b : bArr) {
                long[] jArr = this.bitMasks;
                int i = b & 255;
                jArr[i] = jArr[i] | j;
                j <<= 1;
            }
            this.successBit = 1 << (bArr.length - 1);
            return;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Maximum supported search pattern length is 64, got ");
        outline25.append(bArr.length);
        throw new IllegalArgumentException(outline25.toString());
    }

    @Override // io.netty.buffer.search.SearchProcessorFactory
    public Processor newSearchProcessor() {
        return new Processor(this.bitMasks, this.successBit);
    }
}
