package io.netty.channel;

import io.netty.channel.ChannelFlushPromiseNotifier;
import io.netty.util.concurrent.DefaultPromise;
import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.Promise;
import io.netty.util.internal.ObjectUtil;

public class DefaultChannelPromise extends DefaultPromise<Void> implements ChannelPromise, ChannelFlushPromiseNotifier.FlushCheckpoint {
    private final Channel channel;
    private long checkpoint;

    public DefaultChannelPromise(Channel channel2) {
        this.channel = (Channel) ObjectUtil.checkNotNull(channel2, "channel");
    }

    @Override // io.netty.channel.ChannelPromise, io.netty.channel.ChannelFuture
    public Channel channel() {
        return this.channel;
    }

    @Override // io.netty.util.concurrent.DefaultPromise
    public void checkDeadLock() {
        if (channel().isRegistered()) {
            super.checkDeadLock();
        }
    }

    @Override // io.netty.util.concurrent.DefaultPromise
    public EventExecutor executor() {
        EventExecutor executor = super.executor();
        return executor == null ? channel().eventLoop() : executor;
    }

    @Override // io.netty.channel.ChannelFlushPromiseNotifier.FlushCheckpoint
    public long flushCheckpoint() {
        return this.checkpoint;
    }

    @Override // io.netty.channel.ChannelFuture
    public boolean isVoid() {
        return false;
    }

    @Override // io.netty.channel.ChannelFlushPromiseNotifier.FlushCheckpoint
    public ChannelPromise promise() {
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public boolean trySuccess() {
        return trySuccess(null);
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise unvoid() {
        return this;
    }

    @Override // io.netty.channel.ChannelFlushPromiseNotifier.FlushCheckpoint
    public void flushCheckpoint(long j) {
        this.checkpoint = j;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise
    public Promise<Void> setFailure(Throwable th) {
        super.setFailure(th);
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise setSuccess() {
        return setSuccess((Void) null);
    }

    public DefaultChannelPromise(Channel channel2, EventExecutor eventExecutor) {
        super(eventExecutor);
        this.channel = (Channel) ObjectUtil.checkNotNull(channel2, "channel");
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise setSuccess(Void r1) {
        super.setSuccess((Object) r1);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> addListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        super.addListener((GenericFutureListener) genericFutureListener);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> addListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        super.addListeners((GenericFutureListener[]) genericFutureListenerArr);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> await() {
        super.await();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> awaitUninterruptibly() {
        super.awaitUninterruptibly();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> removeListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        super.removeListener((GenericFutureListener) genericFutureListener);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> removeListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        super.removeListeners((GenericFutureListener[]) genericFutureListenerArr);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> sync() {
        super.sync();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelPromise' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> syncUninterruptibly() {
        super.syncUninterruptibly();
        return this;
    }
}
