package io.netty.channel;

import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;

public final class FailedChannelFuture extends CompleteChannelFuture {
    private final Throwable cause;

    public FailedChannelFuture(Channel channel, EventExecutor eventExecutor, Throwable th) {
        super(channel, eventExecutor);
        this.cause = (Throwable) ObjectUtil.checkNotNull(th, "cause");
    }

    @Override // io.netty.util.concurrent.Future
    public Throwable cause() {
        return this.cause;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean isSuccess() {
        return false;
    }

    /* Return type fixed from 'io.netty.channel.ChannelFuture' to match base method */
    @Override // io.netty.util.concurrent.CompleteFuture, io.netty.util.concurrent.Future, io.netty.channel.CompleteChannelFuture, io.netty.channel.CompleteChannelFuture, io.netty.channel.ChannelFuture
    public Future<Void> sync() {
        PlatformDependent.throwException(this.cause);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.ChannelFuture' to match base method */
    @Override // io.netty.util.concurrent.CompleteFuture, io.netty.util.concurrent.Future, io.netty.channel.CompleteChannelFuture, io.netty.channel.CompleteChannelFuture, io.netty.channel.ChannelFuture
    public Future<Void> syncUninterruptibly() {
        PlatformDependent.throwException(this.cause);
        return this;
    }
}
