package io.netty.channel;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.channel.Channel;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.StringUtil;
import java.lang.reflect.Constructor;

public class ReflectiveChannelFactory<T extends Channel> implements ChannelFactory<T> {
    private final Constructor<? extends T> constructor;

    public ReflectiveChannelFactory(Class<? extends T> cls) {
        ObjectUtil.checkNotNull(cls, "clazz");
        try {
            this.constructor = cls.getConstructor(new Class[0]);
        } catch (NoSuchMethodException e) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Class ");
            outline25.append(StringUtil.simpleClassName((Class<?>) cls));
            outline25.append(" does not have a public non-arg constructor");
            throw new IllegalArgumentException(outline25.toString(), e);
        }
    }

    @Override // io.netty.channel.ChannelFactory, io.netty.bootstrap.ChannelFactory
    public T newChannel() {
        try {
            return (T) ((Channel) this.constructor.newInstance(new Object[0]));
        } catch (Throwable th) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Unable to create Channel from class ");
            outline25.append(this.constructor.getDeclaringClass());
            throw new ChannelException(outline25.toString(), th);
        }
    }

    public String toString() {
        return StringUtil.simpleClassName((Class<?>) ReflectiveChannelFactory.class) + '(' + StringUtil.simpleClassName((Class<?>) this.constructor.getDeclaringClass()) + ".class)";
    }
}
