package io.netty.channel;

import io.netty.util.concurrent.AbstractEventExecutorGroup;
import io.netty.util.concurrent.DefaultPromise;
import io.netty.util.concurrent.DefaultThreadFactory;
import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.FutureListener;
import io.netty.util.concurrent.GlobalEventExecutor;
import io.netty.util.concurrent.Promise;
import io.netty.util.concurrent.ThreadPerTaskExecutor;
import io.netty.util.internal.EmptyArrays;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.ReadOnlyIterator;
import java.util.Collections;
import java.util.Iterator;
import java.util.Queue;
import java.util.Set;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;

@Deprecated
public class ThreadPerChannelEventLoopGroup extends AbstractEventExecutorGroup implements EventLoopGroup {
    public final Set<EventLoop> activeChildren;
    private final Object[] childArgs;
    private final FutureListener<Object> childTerminationListener;
    public final Executor executor;
    public final Queue<EventLoop> idleChildren;
    private final int maxChannels;
    private volatile boolean shuttingDown;
    private final Promise<?> terminationFuture;
    private final ChannelException tooManyChannels;

    public ThreadPerChannelEventLoopGroup() {
        this(0);
    }

    private EventLoop nextChild() {
        if (!this.shuttingDown) {
            EventLoop poll = this.idleChildren.poll();
            if (poll == null) {
                if (this.maxChannels <= 0 || this.activeChildren.size() < this.maxChannels) {
                    poll = newChild(this.childArgs);
                    poll.terminationFuture().addListener(this.childTerminationListener);
                } else {
                    throw this.tooManyChannels;
                }
            }
            this.activeChildren.add(poll);
            return poll;
        }
        throw new RejectedExecutionException("shutting down");
    }

    @Override // java.util.concurrent.ExecutorService
    public boolean awaitTermination(long j, TimeUnit timeUnit) {
        long nanos = timeUnit.toNanos(j) + System.nanoTime();
        for (EventLoop eventLoop : this.activeChildren) {
            while (true) {
                long nanoTime = nanos - System.nanoTime();
                if (nanoTime <= 0) {
                    return isTerminated();
                }
                if (eventLoop.awaitTermination(nanoTime, TimeUnit.NANOSECONDS)) {
                }
            }
        }
        for (EventLoop eventLoop2 : this.idleChildren) {
            while (true) {
                long nanoTime2 = nanos - System.nanoTime();
                if (nanoTime2 <= 0) {
                    return isTerminated();
                }
                if (eventLoop2.awaitTermination(nanoTime2, TimeUnit.NANOSECONDS)) {
                }
            }
        }
        return isTerminated();
    }

    public boolean isShutdown() {
        for (EventLoop eventLoop : this.activeChildren) {
            if (!eventLoop.isShutdown()) {
                return false;
            }
        }
        for (EventLoop eventLoop2 : this.idleChildren) {
            if (!eventLoop2.isShutdown()) {
                return false;
            }
        }
        return true;
    }

    @Override // io.netty.util.concurrent.EventExecutorGroup
    public boolean isShuttingDown() {
        for (EventLoop eventLoop : this.activeChildren) {
            if (!eventLoop.isShuttingDown()) {
                return false;
            }
        }
        for (EventLoop eventLoop2 : this.idleChildren) {
            if (!eventLoop2.isShuttingDown()) {
                return false;
            }
        }
        return true;
    }

    public boolean isTerminated() {
        for (EventLoop eventLoop : this.activeChildren) {
            if (!eventLoop.isTerminated()) {
                return false;
            }
        }
        for (EventLoop eventLoop2 : this.idleChildren) {
            if (!eventLoop2.isTerminated()) {
                return false;
            }
        }
        return true;
    }

    @Override // io.netty.util.concurrent.EventExecutorGroup, java.lang.Iterable
    public Iterator<EventExecutor> iterator() {
        return new ReadOnlyIterator(this.activeChildren.iterator());
    }

    public EventLoop newChild(Object... objArr) {
        return new ThreadPerChannelEventLoop(this);
    }

    @Override // io.netty.channel.EventLoopGroup
    public ChannelFuture register(Channel channel) {
        ObjectUtil.checkNotNull(channel, "channel");
        try {
            EventLoop nextChild = nextChild();
            return nextChild.register(new DefaultChannelPromise(channel, nextChild));
        } catch (Throwable th) {
            return new FailedChannelFuture(channel, GlobalEventExecutor.INSTANCE, th);
        }
    }

    @Override // io.netty.util.concurrent.AbstractEventExecutorGroup, io.netty.util.concurrent.EventExecutorGroup
    @Deprecated
    public void shutdown() {
        this.shuttingDown = true;
        for (EventLoop eventLoop : this.activeChildren) {
            eventLoop.shutdown();
        }
        for (EventLoop eventLoop2 : this.idleChildren) {
            eventLoop2.shutdown();
        }
        if (isTerminated()) {
            this.terminationFuture.trySuccess(null);
        }
    }

    @Override // io.netty.util.concurrent.EventExecutorGroup
    public Future<?> shutdownGracefully(long j, long j2, TimeUnit timeUnit) {
        this.shuttingDown = true;
        for (EventLoop eventLoop : this.activeChildren) {
            eventLoop.shutdownGracefully(j, j2, timeUnit);
        }
        for (EventLoop eventLoop2 : this.idleChildren) {
            eventLoop2.shutdownGracefully(j, j2, timeUnit);
        }
        if (isTerminated()) {
            this.terminationFuture.trySuccess(null);
        }
        return terminationFuture();
    }

    @Override // io.netty.util.concurrent.EventExecutorGroup
    public Future<?> terminationFuture() {
        return this.terminationFuture;
    }

    public ThreadPerChannelEventLoopGroup(int i) {
        this(i, (ThreadFactory) null, new Object[0]);
    }

    @Override // io.netty.channel.EventLoopGroup, io.netty.util.concurrent.EventExecutorGroup
    public EventLoop next() {
        throw new UnsupportedOperationException();
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public ThreadPerChannelEventLoopGroup(int i, ThreadFactory threadFactory, Object... objArr) {
        this(i, threadFactory == null ? null : new ThreadPerTaskExecutor(threadFactory), objArr);
    }

    public ThreadPerChannelEventLoopGroup(int i, Executor executor2, Object... objArr) {
        this.activeChildren = Collections.newSetFromMap(PlatformDependent.newConcurrentHashMap());
        this.idleChildren = new ConcurrentLinkedQueue();
        this.terminationFuture = new DefaultPromise(GlobalEventExecutor.INSTANCE);
        this.childTerminationListener = new FutureListener<Object>() {
            /* class io.netty.channel.ThreadPerChannelEventLoopGroup.AnonymousClass1 */

            @Override // io.netty.util.concurrent.GenericFutureListener
            public void operationComplete(Future<Object> future) {
                if (ThreadPerChannelEventLoopGroup.this.isTerminated()) {
                    ThreadPerChannelEventLoopGroup.this.terminationFuture.trySuccess(null);
                }
            }
        };
        ObjectUtil.checkPositiveOrZero(i, "maxChannels");
        executor2 = executor2 == null ? new ThreadPerTaskExecutor(new DefaultThreadFactory(getClass())) : executor2;
        if (objArr == null) {
            this.childArgs = EmptyArrays.EMPTY_OBJECTS;
        } else {
            this.childArgs = (Object[]) objArr.clone();
        }
        this.maxChannels = i;
        this.executor = executor2;
        this.tooManyChannels = ChannelException.newStatic("too many channels (max: " + i + ')', ThreadPerChannelEventLoopGroup.class, "nextChild()");
    }

    @Override // io.netty.channel.EventLoopGroup
    public ChannelFuture register(ChannelPromise channelPromise) {
        try {
            return nextChild().register(channelPromise);
        } catch (Throwable th) {
            channelPromise.setFailure(th);
            return channelPromise;
        }
    }

    @Override // io.netty.channel.EventLoopGroup
    @Deprecated
    public ChannelFuture register(Channel channel, ChannelPromise channelPromise) {
        ObjectUtil.checkNotNull(channel, "channel");
        try {
            return nextChild().register(channel, channelPromise);
        } catch (Throwable th) {
            channelPromise.setFailure(th);
            return channelPromise;
        }
    }
}
