package io.netty.channel;

import io.netty.util.concurrent.AbstractFuture;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.Promise;
import io.netty.util.internal.ObjectUtil;
import java.util.concurrent.TimeUnit;

public final class VoidChannelPromise extends AbstractFuture<Void> implements ChannelPromise {
    private final Channel channel;
    private final ChannelFutureListener fireExceptionListener;

    public VoidChannelPromise(Channel channel2, boolean z) {
        ObjectUtil.checkNotNull(channel2, "channel");
        this.channel = channel2;
        if (z) {
            this.fireExceptionListener = new ChannelFutureListener() {
                /* class io.netty.channel.VoidChannelPromise.AnonymousClass1 */

                public void operationComplete(ChannelFuture channelFuture) {
                    Throwable cause = channelFuture.cause();
                    if (cause != null) {
                        VoidChannelPromise.this.fireException0(cause);
                    }
                }
            };
        } else {
            this.fireExceptionListener = null;
        }
    }

    private static void fail() {
        throw new IllegalStateException("void future");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireException0(Throwable th) {
        if (this.fireExceptionListener != null && this.channel.isRegistered()) {
            this.channel.pipeline().fireExceptionCaught(th);
        }
    }

    @Override // io.netty.util.concurrent.Future
    public boolean cancel(boolean z) {
        return false;
    }

    @Override // io.netty.util.concurrent.Future
    public Throwable cause() {
        return null;
    }

    @Override // io.netty.channel.ChannelPromise, io.netty.channel.ChannelFuture
    public Channel channel() {
        return this.channel;
    }

    @Override // io.netty.util.concurrent.Future
    public Void getNow() {
        return null;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean isCancellable() {
        return false;
    }

    public boolean isCancelled() {
        return false;
    }

    public boolean isDone() {
        return false;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean isSuccess() {
        return false;
    }

    @Override // io.netty.channel.ChannelFuture
    public boolean isVoid() {
        return true;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> removeListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        return this;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> removeListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public VoidChannelPromise setSuccess() {
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public VoidChannelPromise setSuccess(Void r1) {
        return this;
    }

    @Override // io.netty.util.concurrent.Promise
    public boolean setUncancellable() {
        return true;
    }

    @Override // io.netty.util.concurrent.Promise
    public boolean tryFailure(Throwable th) {
        fireException0(th);
        return false;
    }

    @Override // io.netty.channel.ChannelPromise
    public boolean trySuccess() {
        return false;
    }

    public boolean trySuccess(Void r1) {
        return false;
    }

    @Override // io.netty.channel.ChannelPromise
    public ChannelPromise unvoid() {
        DefaultChannelPromise defaultChannelPromise = new DefaultChannelPromise(this.channel);
        ChannelFutureListener channelFutureListener = this.fireExceptionListener;
        if (channelFutureListener != null) {
            defaultChannelPromise.addListener((GenericFutureListener<? extends Future<? super Void>>) channelFutureListener);
        }
        return defaultChannelPromise;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise
    public Promise<Void> setFailure(Throwable th) {
        fireException0(th);
        return this;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> addListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        fail();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> addListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        fail();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> await() {
        if (!Thread.interrupted()) {
            return this;
        }
        throw new InterruptedException();
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> awaitUninterruptibly() {
        fail();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> sync() {
        fail();
        return this;
    }

    /* Return type fixed from 'io.netty.channel.VoidChannelPromise' to match base method */
    @Override // io.netty.channel.ChannelPromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.Future, io.netty.channel.ChannelFuture
    public Promise<Void> syncUninterruptibly() {
        fail();
        return this;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean awaitUninterruptibly(long j, TimeUnit timeUnit) {
        fail();
        return false;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean await(long j, TimeUnit timeUnit) {
        fail();
        return false;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean awaitUninterruptibly(long j) {
        fail();
        return false;
    }

    @Override // io.netty.util.concurrent.Future
    public boolean await(long j) {
        fail();
        return false;
    }
}
