package io.netty.channel.group;

import io.netty.channel.Channel;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelFutureListener;
import io.netty.util.concurrent.BlockingOperationException;
import io.netty.util.concurrent.DefaultPromise;
import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.ImmediateEventExecutor;
import io.netty.util.concurrent.Promise;
import io.netty.util.internal.ObjectUtil;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

public final class DefaultChannelGroupFuture extends DefaultPromise<Void> implements ChannelGroupFuture {
    private final ChannelFutureListener childListener = new ChannelFutureListener() {
        /* class io.netty.channel.group.DefaultChannelGroupFuture.AnonymousClass1 */
        public static final /* synthetic */ boolean $assertionsDisabled = false;

        public void operationComplete(ChannelFuture channelFuture) {
            boolean z;
            boolean isSuccess = channelFuture.isSuccess();
            synchronized (DefaultChannelGroupFuture.this) {
                if (isSuccess) {
                    DefaultChannelGroupFuture.access$008(DefaultChannelGroupFuture.this);
                } else {
                    DefaultChannelGroupFuture.access$108(DefaultChannelGroupFuture.this);
                }
                z = DefaultChannelGroupFuture.this.successCount + DefaultChannelGroupFuture.this.failureCount == DefaultChannelGroupFuture.this.futures.size();
            }
            if (!z) {
                return;
            }
            if (DefaultChannelGroupFuture.this.failureCount > 0) {
                ArrayList arrayList = new ArrayList(DefaultChannelGroupFuture.this.failureCount);
                for (ChannelFuture channelFuture2 : DefaultChannelGroupFuture.this.futures.values()) {
                    if (!channelFuture2.isSuccess()) {
                        arrayList.add(new DefaultEntry(channelFuture2.channel(), channelFuture2.cause()));
                    }
                }
                DefaultChannelGroupFuture.this.setFailure0((DefaultChannelGroupFuture) new ChannelGroupException(arrayList));
                return;
            }
            DefaultChannelGroupFuture.this.setSuccess0();
        }
    };
    private int failureCount;
    private final Map<Channel, ChannelFuture> futures;
    private final ChannelGroup group;
    private int successCount;

    public static final class DefaultEntry<K, V> implements Map.Entry<K, V> {
        private final K key;
        private final V value;

        public DefaultEntry(K k, V v) {
            this.key = k;
            this.value = v;
        }

        @Override // java.util.Map.Entry
        public K getKey() {
            return this.key;
        }

        @Override // java.util.Map.Entry
        public V getValue() {
            return this.value;
        }

        @Override // java.util.Map.Entry
        public V setValue(V v) {
            throw new UnsupportedOperationException("read-only");
        }
    }

    public DefaultChannelGroupFuture(ChannelGroup channelGroup, Collection<ChannelFuture> collection, EventExecutor eventExecutor) {
        super(eventExecutor);
        this.group = (ChannelGroup) ObjectUtil.checkNotNull(channelGroup, "group");
        ObjectUtil.checkNotNull(collection, "futures");
        LinkedHashMap linkedHashMap = new LinkedHashMap();
        for (ChannelFuture channelFuture : collection) {
            linkedHashMap.put(channelFuture.channel(), channelFuture);
        }
        Map<Channel, ChannelFuture> unmodifiableMap = Collections.unmodifiableMap(linkedHashMap);
        this.futures = unmodifiableMap;
        for (ChannelFuture channelFuture2 : unmodifiableMap.values()) {
            channelFuture2.addListener((GenericFutureListener<? extends Future<? super Void>>) this.childListener);
        }
        if (this.futures.isEmpty()) {
            setSuccess0();
        }
    }

    public static /* synthetic */ int access$008(DefaultChannelGroupFuture defaultChannelGroupFuture) {
        int i = defaultChannelGroupFuture.successCount;
        defaultChannelGroupFuture.successCount = i + 1;
        return i;
    }

    public static /* synthetic */ int access$108(DefaultChannelGroupFuture defaultChannelGroupFuture) {
        int i = defaultChannelGroupFuture.failureCount;
        defaultChannelGroupFuture.failureCount = i + 1;
        return i;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setFailure0(ChannelGroupException channelGroupException) {
        super.setFailure((Throwable) channelGroupException);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setSuccess0() {
        super.setSuccess((Object) null);
    }

    @Override // io.netty.util.concurrent.DefaultPromise
    public void checkDeadLock() {
        EventExecutor executor = executor();
        if (executor != null && executor != ImmediateEventExecutor.INSTANCE && executor.inEventLoop()) {
            throw new BlockingOperationException();
        }
    }

    @Override // io.netty.channel.group.ChannelGroupFuture
    public ChannelFuture find(Channel channel) {
        return this.futures.get(channel);
    }

    @Override // io.netty.channel.group.ChannelGroupFuture
    public ChannelGroup group() {
        return this.group;
    }

    @Override // io.netty.channel.group.ChannelGroupFuture
    public synchronized boolean isPartialFailure() {
        int i;
        i = this.failureCount;
        return (i == 0 || i == this.futures.size()) ? false : true;
    }

    @Override // io.netty.channel.group.ChannelGroupFuture
    public synchronized boolean isPartialSuccess() {
        int i;
        i = this.successCount;
        return (i == 0 || i == this.futures.size()) ? false : true;
    }

    @Override // io.netty.channel.group.ChannelGroupFuture, java.lang.Iterable
    public Iterator<ChannelFuture> iterator() {
        return this.futures.values().iterator();
    }

    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise
    public boolean tryFailure(Throwable th) {
        throw new IllegalStateException();
    }

    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public ChannelGroupException cause() {
        return (ChannelGroupException) super.cause();
    }

    /* Return type fixed from 'io.netty.channel.group.DefaultChannelGroupFuture' to match base method */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise
    public Promise<Void> setFailure(Throwable th) {
        throw new IllegalStateException();
    }

    public DefaultChannelGroupFuture setSuccess(Void r1) {
        throw new IllegalStateException();
    }

    public boolean trySuccess(Void r1) {
        throw new IllegalStateException();
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> addListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        super.addListener((GenericFutureListener) genericFutureListener);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> addListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        super.addListeners((GenericFutureListener[]) genericFutureListenerArr);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> await() {
        super.await();
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> awaitUninterruptibly() {
        super.awaitUninterruptibly();
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> removeListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        super.removeListener((GenericFutureListener) genericFutureListener);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> removeListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        super.removeListeners((GenericFutureListener[]) genericFutureListenerArr);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> sync() {
        super.sync();
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.group.DefaultChannelGroupFuture */
    @Override // io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.Promise, io.netty.channel.group.ChannelGroupFuture, io.netty.util.concurrent.Future
    public Future<Void> syncUninterruptibly() {
        super.syncUninterruptibly();
        return this;
    }

    public DefaultChannelGroupFuture(ChannelGroup channelGroup, Map<Channel, ChannelFuture> map, EventExecutor eventExecutor) {
        super(eventExecutor);
        this.group = channelGroup;
        Map<Channel, ChannelFuture> unmodifiableMap = Collections.unmodifiableMap(map);
        this.futures = unmodifiableMap;
        for (ChannelFuture channelFuture : unmodifiableMap.values()) {
            channelFuture.addListener((GenericFutureListener<? extends Future<? super Void>>) this.childListener);
        }
        if (this.futures.isEmpty()) {
            setSuccess0();
        }
    }
}
