package io.netty.channel.socket.oio;

import io.netty.buffer.ByteBufAllocator;
import io.netty.channel.ChannelException;
import io.netty.channel.ChannelOption;
import io.netty.channel.MessageSizeEstimator;
import io.netty.channel.PreferHeapByteBufAllocator;
import io.netty.channel.RecvByteBufAllocator;
import io.netty.channel.WriteBufferWaterMark;
import io.netty.channel.socket.DatagramChannel;
import io.netty.channel.socket.DefaultDatagramChannelConfig;
import java.io.IOException;
import java.net.DatagramSocket;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.util.Map;

public final class DefaultOioDatagramChannelConfig extends DefaultDatagramChannelConfig implements OioDatagramChannelConfig {
    public DefaultOioDatagramChannelConfig(DatagramChannel datagramChannel, DatagramSocket datagramSocket) {
        super(datagramChannel, datagramSocket);
        setAllocator((ByteBufAllocator) new PreferHeapByteBufAllocator(getAllocator()));
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig
    public <T> T getOption(ChannelOption<T> channelOption) {
        return channelOption == ChannelOption.SO_TIMEOUT ? (T) Integer.valueOf(getSoTimeout()) : (T) super.getOption(channelOption);
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig
    public Map<ChannelOption<?>, Object> getOptions() {
        return getOptions(super.getOptions(), ChannelOption.SO_TIMEOUT);
    }

    @Override // io.netty.channel.socket.oio.OioDatagramChannelConfig
    public int getSoTimeout() {
        try {
            return javaSocket().getSoTimeout();
        } catch (IOException e) {
            throw new ChannelException(e);
        }
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig
    public <T> boolean setOption(ChannelOption<T> channelOption, T t) {
        validate(channelOption, t);
        if (channelOption != ChannelOption.SO_TIMEOUT) {
            return super.setOption(channelOption, t);
        }
        setSoTimeout(t.intValue());
        return true;
    }

    @Override // io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setSoTimeout(int i) {
        try {
            javaSocket().setSoTimeout(i);
            return this;
        } catch (IOException e) {
            throw new ChannelException(e);
        }
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setBroadcast(boolean z) {
        super.setBroadcast(z);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setInterface(InetAddress inetAddress) {
        super.setInterface(inetAddress);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setLoopbackModeDisabled(boolean z) {
        super.setLoopbackModeDisabled(z);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setNetworkInterface(NetworkInterface networkInterface) {
        super.setNetworkInterface(networkInterface);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setReceiveBufferSize(int i) {
        super.setReceiveBufferSize(i);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setReuseAddress(boolean z) {
        super.setReuseAddress(z);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setSendBufferSize(int i) {
        super.setSendBufferSize(i);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setTimeToLive(int i) {
        super.setTimeToLive(i);
        return this;
    }

    @Override // io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setTrafficClass(int i) {
        super.setTrafficClass(i);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setAllocator(ByteBufAllocator byteBufAllocator) {
        super.setAllocator(byteBufAllocator);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setAutoClose(boolean z) {
        super.setAutoClose(z);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setAutoRead(boolean z) {
        super.setAutoRead(z);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setConnectTimeoutMillis(int i) {
        super.setConnectTimeoutMillis(i);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setMaxMessagesPerRead(int i) {
        super.setMaxMessagesPerRead(i);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setMessageSizeEstimator(MessageSizeEstimator messageSizeEstimator) {
        super.setMessageSizeEstimator(messageSizeEstimator);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setRecvByteBufAllocator(RecvByteBufAllocator recvByteBufAllocator) {
        super.setRecvByteBufAllocator(recvByteBufAllocator);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setWriteBufferHighWaterMark(int i) {
        super.setWriteBufferHighWaterMark(i);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setWriteBufferLowWaterMark(int i) {
        super.setWriteBufferLowWaterMark(i);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setWriteBufferWaterMark(WriteBufferWaterMark writeBufferWaterMark) {
        super.setWriteBufferWaterMark(writeBufferWaterMark);
        return this;
    }

    @Override // io.netty.channel.ChannelConfig, io.netty.channel.socket.DatagramChannelConfig, io.netty.channel.DefaultChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.DefaultDatagramChannelConfig, io.netty.channel.socket.oio.OioDatagramChannelConfig
    public OioDatagramChannelConfig setWriteSpinCount(int i) {
        super.setWriteSpinCount(i);
        return this;
    }
}
