package io.netty.handler.codec;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.concurrent.FastThreadLocal;
import io.netty.util.internal.MathUtil;
import io.netty.util.internal.ObjectUtil;
import java.util.AbstractList;
import java.util.RandomAccess;

public final class CodecOutputList extends AbstractList<Object> implements RandomAccess {
    private static final FastThreadLocal<CodecOutputLists> CODEC_OUTPUT_LISTS_POOL = new FastThreadLocal<CodecOutputLists>() {
        /* class io.netty.handler.codec.CodecOutputList.AnonymousClass2 */

        @Override // io.netty.util.concurrent.FastThreadLocal
        public CodecOutputLists initialValue() {
            return new CodecOutputLists(16);
        }
    };
    private static final CodecOutputListRecycler NOOP_RECYCLER = new CodecOutputListRecycler() {
        /* class io.netty.handler.codec.CodecOutputList.AnonymousClass1 */

        @Override // io.netty.handler.codec.CodecOutputList.CodecOutputListRecycler
        public void recycle(CodecOutputList codecOutputList) {
        }
    };
    private Object[] array;
    private boolean insertSinceRecycled;
    private final CodecOutputListRecycler recycler;
    private int size;

    public interface CodecOutputListRecycler {
        void recycle(CodecOutputList codecOutputList);
    }

    public static final class CodecOutputLists implements CodecOutputListRecycler {
        public static final /* synthetic */ boolean $assertionsDisabled = false;
        private int count;
        private int currentIdx;
        private final CodecOutputList[] elements;
        private final int mask;

        public CodecOutputLists(int i) {
            this.elements = new CodecOutputList[MathUtil.safeFindNextPositivePowerOfTwo(i)];
            int i2 = 0;
            while (true) {
                CodecOutputList[] codecOutputListArr = this.elements;
                if (i2 < codecOutputListArr.length) {
                    codecOutputListArr[i2] = new CodecOutputList(this, 16);
                    i2++;
                } else {
                    this.count = codecOutputListArr.length;
                    this.currentIdx = codecOutputListArr.length;
                    this.mask = codecOutputListArr.length - 1;
                    return;
                }
            }
        }

        public CodecOutputList getOrCreate() {
            int i = this.count;
            if (i == 0) {
                return new CodecOutputList(CodecOutputList.NOOP_RECYCLER, 4);
            }
            this.count = i - 1;
            int i2 = (this.currentIdx - 1) & this.mask;
            CodecOutputList codecOutputList = this.elements[i2];
            this.currentIdx = i2;
            return codecOutputList;
        }

        @Override // io.netty.handler.codec.CodecOutputList.CodecOutputListRecycler
        public void recycle(CodecOutputList codecOutputList) {
            int i = this.currentIdx;
            this.elements[i] = codecOutputList;
            this.currentIdx = this.mask & (i + 1);
            this.count++;
        }
    }

    private void checkIndex(int i) {
        if (i >= this.size) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("expected: index < (");
            outline25.append(this.size);
            outline25.append("),but actual is (");
            throw new IndexOutOfBoundsException(GeneratedOutlineSupport.outline21(outline25, this.size, ")"));
        }
    }

    private void expandArray() {
        Object[] objArr = this.array;
        int length = objArr.length << 1;
        if (length >= 0) {
            Object[] objArr2 = new Object[length];
            System.arraycopy(objArr, 0, objArr2, 0, objArr.length);
            this.array = objArr2;
            return;
        }
        throw new OutOfMemoryError();
    }

    private void insert(int i, Object obj) {
        this.array[i] = obj;
        this.insertSinceRecycled = true;
    }

    public static CodecOutputList newInstance() {
        return CODEC_OUTPUT_LISTS_POOL.get().getOrCreate();
    }

    @Override // java.util.AbstractCollection, java.util.List, java.util.Collection, java.util.AbstractList
    public boolean add(Object obj) {
        ObjectUtil.checkNotNull(obj, "element");
        try {
            insert(this.size, obj);
        } catch (IndexOutOfBoundsException unused) {
            expandArray();
            insert(this.size, obj);
        }
        this.size++;
        return true;
    }

    public void clear() {
        this.size = 0;
    }

    @Override // java.util.List, java.util.AbstractList
    public Object get(int i) {
        checkIndex(i);
        return this.array[i];
    }

    public Object getUnsafe(int i) {
        return this.array[i];
    }

    public boolean insertSinceRecycled() {
        return this.insertSinceRecycled;
    }

    public void recycle() {
        for (int i = 0; i < this.size; i++) {
            this.array[i] = null;
        }
        this.size = 0;
        this.insertSinceRecycled = false;
        this.recycler.recycle(this);
    }

    @Override // java.util.List, java.util.AbstractList
    public Object remove(int i) {
        checkIndex(i);
        Object[] objArr = this.array;
        Object obj = objArr[i];
        int i2 = (this.size - i) - 1;
        if (i2 > 0) {
            System.arraycopy(objArr, i + 1, objArr, i, i2);
        }
        Object[] objArr2 = this.array;
        int i3 = this.size - 1;
        this.size = i3;
        objArr2[i3] = null;
        return obj;
    }

    @Override // java.util.List, java.util.AbstractList
    public Object set(int i, Object obj) {
        ObjectUtil.checkNotNull(obj, "element");
        checkIndex(i);
        Object obj2 = this.array[i];
        insert(i, obj);
        return obj2;
    }

    public int size() {
        return this.size;
    }

    private CodecOutputList(CodecOutputListRecycler codecOutputListRecycler, int i) {
        this.recycler = codecOutputListRecycler;
        this.array = new Object[i];
    }

    @Override // java.util.List, java.util.AbstractList
    public void add(int i, Object obj) {
        ObjectUtil.checkNotNull(obj, "element");
        checkIndex(i);
        if (this.size == this.array.length) {
            expandArray();
        }
        int i2 = this.size;
        if (i != i2) {
            Object[] objArr = this.array;
            System.arraycopy(objArr, i, objArr, i + 1, i2 - i);
        }
        insert(i, obj);
        this.size++;
    }
}
