package io.netty.handler.codec.compression;

import com.aayushatharva.brotli4j.encoder.Encoder;
import io.netty.buffer.ByteBuf;
import io.netty.buffer.ByteBufUtil;
import io.netty.buffer.Unpooled;
import io.netty.channel.ChannelHandler;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.MessageToByteEncoder;
import io.netty.util.ReferenceCountUtil;
import io.netty.util.internal.ObjectUtil;

@ChannelHandler.Sharable
public final class BrotliEncoder extends MessageToByteEncoder<ByteBuf> {
    private final Encoder.Parameters parameters;

    public BrotliEncoder() {
        this(BrotliOptions.DEFAULT);
    }

    public void encode(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, ByteBuf byteBuf2) {
    }

    public BrotliEncoder(Encoder.Parameters parameters2) {
        this.parameters = (Encoder.Parameters) ObjectUtil.checkNotNull(parameters2, "Parameters");
    }

    public ByteBuf allocateBuffer(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, boolean z) {
        if (!byteBuf.isReadable()) {
            return Unpooled.EMPTY_BUFFER;
        }
        try {
            byte[] compress = Encoder.compress(ByteBufUtil.getBytes(byteBuf, byteBuf.readerIndex(), byteBuf.readableBytes(), false), this.parameters);
            if (!z) {
                return Unpooled.wrappedBuffer(compress);
            }
            ByteBuf ioBuffer = channelHandlerContext.alloc().ioBuffer(compress.length);
            ioBuffer.writeBytes(compress);
            return ioBuffer;
        } catch (Exception e) {
            ReferenceCountUtil.release(byteBuf);
            throw e;
        }
    }

    public BrotliEncoder(BrotliOptions brotliOptions) {
        this(brotliOptions.parameters());
    }
}
