package io.netty.handler.codec.serialization;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.EOFException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectStreamClass;
import java.io.StreamCorruptedException;

public class CompactObjectInputStream extends ObjectInputStream {
    private final ClassResolver classResolver;

    public CompactObjectInputStream(InputStream inputStream, ClassResolver classResolver2) {
        super(inputStream);
        this.classResolver = classResolver2;
    }

    @Override // java.io.ObjectInputStream
    public ObjectStreamClass readClassDescriptor() {
        int read = read();
        if (read < 0) {
            throw new EOFException();
        } else if (read == 0) {
            return super.readClassDescriptor();
        } else {
            if (read == 1) {
                return ObjectStreamClass.lookupAny(this.classResolver.resolve(readUTF()));
            }
            throw new StreamCorruptedException(GeneratedOutlineSupport.outline11("Unexpected class descriptor type: ", read));
        }
    }

    @Override // java.io.ObjectInputStream
    public void readStreamHeader() {
        int readByte = readByte() & 255;
        if (readByte != 5) {
            throw new StreamCorruptedException(GeneratedOutlineSupport.outline11("Unsupported version: ", readByte));
        }
    }

    @Override // java.io.ObjectInputStream
    public Class<?> resolveClass(ObjectStreamClass objectStreamClass) {
        try {
            return this.classResolver.resolve(objectStreamClass.getName());
        } catch (ClassNotFoundException unused) {
            return super.resolveClass(objectStreamClass);
        }
    }
}
