package io.netty.handler.codec.serialization;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.ObjectUtil;
import java.io.DataInputStream;
import java.io.InputStream;
import java.io.ObjectInput;
import java.io.StreamCorruptedException;

public class ObjectDecoderInputStream extends InputStream implements ObjectInput {
    private final ClassResolver classResolver;
    private final DataInputStream in;
    private final int maxObjectSize;

    public ObjectDecoderInputStream(InputStream inputStream) {
        this(inputStream, (ClassLoader) null);
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public int available() {
        return this.in.available();
    }

    @Override // java.io.Closeable, java.io.ObjectInput, java.lang.AutoCloseable, java.io.InputStream
    public void close() {
        this.in.close();
    }

    public void mark(int i) {
        this.in.mark(i);
    }

    public boolean markSupported() {
        return this.in.markSupported();
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public int read() {
        return this.in.read();
    }

    @Override // java.io.DataInput
    public final boolean readBoolean() {
        return this.in.readBoolean();
    }

    @Override // java.io.DataInput
    public final byte readByte() {
        return this.in.readByte();
    }

    @Override // java.io.DataInput
    public final char readChar() {
        return this.in.readChar();
    }

    @Override // java.io.DataInput
    public final double readDouble() {
        return this.in.readDouble();
    }

    @Override // java.io.DataInput
    public final float readFloat() {
        return this.in.readFloat();
    }

    @Override // java.io.DataInput
    public final void readFully(byte[] bArr, int i, int i2) {
        this.in.readFully(bArr, i, i2);
    }

    @Override // java.io.DataInput
    public final int readInt() {
        return this.in.readInt();
    }

    @Override // java.io.DataInput
    @Deprecated
    public final String readLine() {
        return this.in.readLine();
    }

    @Override // java.io.DataInput
    public final long readLong() {
        return this.in.readLong();
    }

    @Override // java.io.ObjectInput
    public Object readObject() {
        int readInt = readInt();
        if (readInt <= 0) {
            throw new StreamCorruptedException(GeneratedOutlineSupport.outline11("invalid data length: ", readInt));
        } else if (readInt <= this.maxObjectSize) {
            return new CompactObjectInputStream(this.in, this.classResolver).readObject();
        } else {
            throw new StreamCorruptedException(GeneratedOutlineSupport.outline20(GeneratedOutlineSupport.outline26("data length too big: ", readInt, " (max: "), this.maxObjectSize, ')'));
        }
    }

    @Override // java.io.DataInput
    public final short readShort() {
        return this.in.readShort();
    }

    @Override // java.io.DataInput
    public final String readUTF() {
        return this.in.readUTF();
    }

    @Override // java.io.DataInput
    public final int readUnsignedByte() {
        return this.in.readUnsignedByte();
    }

    @Override // java.io.DataInput
    public final int readUnsignedShort() {
        return this.in.readUnsignedShort();
    }

    @Override // java.io.InputStream
    public void reset() {
        this.in.reset();
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public long skip(long j) {
        return this.in.skip(j);
    }

    @Override // java.io.DataInput
    public final int skipBytes(int i) {
        return this.in.skipBytes(i);
    }

    public ObjectDecoderInputStream(InputStream inputStream, ClassLoader classLoader) {
        this(inputStream, classLoader, 1048576);
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public final int read(byte[] bArr, int i, int i2) {
        return this.in.read(bArr, i, i2);
    }

    @Override // java.io.DataInput
    public final void readFully(byte[] bArr) {
        this.in.readFully(bArr);
    }

    public ObjectDecoderInputStream(InputStream inputStream, int i) {
        this(inputStream, null, i);
    }

    @Override // java.io.ObjectInput, java.io.InputStream
    public final int read(byte[] bArr) {
        return this.in.read(bArr);
    }

    public ObjectDecoderInputStream(InputStream inputStream, ClassLoader classLoader, int i) {
        ObjectUtil.checkNotNull(inputStream, "in");
        ObjectUtil.checkPositive(i, "maxObjectSize");
        if (inputStream instanceof DataInputStream) {
            this.in = (DataInputStream) inputStream;
        } else {
            this.in = new DataInputStream(inputStream);
        }
        this.classResolver = ClassResolvers.weakCachingResolver(classLoader);
        this.maxObjectSize = i;
    }
}
