package io.netty.resolver;

import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.FutureListener;
import io.netty.util.concurrent.Promise;
import io.netty.util.internal.PlatformDependent;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class RoundRobinInetAddressResolver extends InetNameResolver {
    private final NameResolver<InetAddress> nameResolver;

    public RoundRobinInetAddressResolver(EventExecutor eventExecutor, NameResolver<InetAddress> nameResolver2) {
        super(eventExecutor);
        this.nameResolver = nameResolver2;
    }

    /* access modifiers changed from: private */
    public static int randomIndex(int i) {
        if (i == 1) {
            return 0;
        }
        return PlatformDependent.threadLocalRandom().nextInt(i);
    }

    @Override // io.netty.resolver.NameResolver, java.io.Closeable, java.lang.AutoCloseable, io.netty.resolver.SimpleNameResolver
    public void close() {
        this.nameResolver.close();
    }

    @Override // io.netty.resolver.SimpleNameResolver
    public void doResolve(final String str, final Promise<InetAddress> promise) {
        this.nameResolver.resolveAll(str).addListener(new FutureListener<List<InetAddress>>() {
            /* class io.netty.resolver.RoundRobinInetAddressResolver.AnonymousClass1 */

            @Override // io.netty.util.concurrent.GenericFutureListener
            public void operationComplete(Future<List<InetAddress>> future) {
                if (future.isSuccess()) {
                    List<InetAddress> now = future.getNow();
                    int size = now.size();
                    if (size > 0) {
                        promise.setSuccess(now.get(RoundRobinInetAddressResolver.randomIndex(size)));
                    } else {
                        promise.setFailure(new UnknownHostException(str));
                    }
                } else {
                    promise.setFailure(future.cause());
                }
            }
        });
    }

    @Override // io.netty.resolver.SimpleNameResolver
    public void doResolveAll(String str, final Promise<List<InetAddress>> promise) {
        this.nameResolver.resolveAll(str).addListener(new FutureListener<List<InetAddress>>() {
            /* class io.netty.resolver.RoundRobinInetAddressResolver.AnonymousClass2 */

            @Override // io.netty.util.concurrent.GenericFutureListener
            public void operationComplete(Future<List<InetAddress>> future) {
                if (future.isSuccess()) {
                    List<InetAddress> now = future.getNow();
                    if (!now.isEmpty()) {
                        ArrayList arrayList = new ArrayList(now);
                        Collections.rotate(arrayList, RoundRobinInetAddressResolver.randomIndex(now.size()));
                        promise.setSuccess(arrayList);
                        return;
                    }
                    promise.setSuccess(now);
                    return;
                }
                promise.setFailure(future.cause());
            }
        });
    }
}
