package io.netty.util.internal;

import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.lang.Thread;
import java.security.SecureRandom;
import java.util.Random;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicLong;

public final class ThreadLocalRandom extends Random {
    private static final long addend = 11;
    private static volatile long initialSeedUniquifier = 0;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(ThreadLocalRandom.class);
    private static final long mask = 281474976710655L;
    private static final long multiplier = 25214903917L;
    private static volatile long seedGeneratorEndTime = 0;
    private static final long seedGeneratorStartTime;
    private static final Thread seedGeneratorThread;
    private static final BlockingQueue<Long> seedQueue;
    private static final AtomicLong seedUniquifier = new AtomicLong();
    private static final long serialVersionUID = -5851777807851030925L;
    public boolean initialized = true;
    private long pad0;
    private long pad1;
    private long pad2;
    private long pad3;
    private long pad4;
    private long pad5;
    private long pad6;
    private long pad7;
    private long rnd;

    static {
        initialSeedUniquifier = SystemPropertyUtil.getLong("io.netty.initialSeedUniquifier", 0);
        if (initialSeedUniquifier != 0) {
            seedGeneratorThread = null;
            seedQueue = null;
            seedGeneratorStartTime = 0;
        } else if (SystemPropertyUtil.getBoolean("java.util.secureRandomSeed", false)) {
            seedQueue = new LinkedBlockingQueue();
            seedGeneratorStartTime = System.nanoTime();
            AnonymousClass1 r0 = new Thread("initialSeedUniquifierGenerator") {
                /* class io.netty.util.internal.ThreadLocalRandom.AnonymousClass1 */

                public void run() {
                    byte[] generateSeed = new SecureRandom().generateSeed(8);
                    long unused = ThreadLocalRandom.seedGeneratorEndTime = System.nanoTime();
                    ThreadLocalRandom.seedQueue.add(Long.valueOf(((((long) generateSeed[0]) & 255) << 56) | ((((long) generateSeed[1]) & 255) << 48) | ((((long) generateSeed[2]) & 255) << 40) | ((((long) generateSeed[3]) & 255) << 32) | ((((long) generateSeed[4]) & 255) << 24) | ((((long) generateSeed[5]) & 255) << 16) | ((((long) generateSeed[6]) & 255) << 8) | (((long) generateSeed[7]) & 255)));
                }
            };
            seedGeneratorThread = r0;
            r0.setDaemon(true);
            r0.setUncaughtExceptionHandler(new Thread.UncaughtExceptionHandler() {
                /* class io.netty.util.internal.ThreadLocalRandom.AnonymousClass2 */

                public void uncaughtException(Thread thread, Throwable th) {
                    ThreadLocalRandom.logger.debug("An exception has been raised by {}", thread.getName(), th);
                }
            });
            r0.start();
        } else {
            initialSeedUniquifier = mix64(System.currentTimeMillis()) ^ mix64(System.nanoTime());
            seedGeneratorThread = null;
            seedQueue = null;
            seedGeneratorStartTime = 0;
        }
    }

    public ThreadLocalRandom() {
        super(newSeed());
    }

    public static ThreadLocalRandom current() {
        return InternalThreadLocalMap.get().random();
    }

    public static long getInitialSeedUniquifier() {
        Long l;
        long j = initialSeedUniquifier;
        if (j != 0) {
            return j;
        }
        synchronized (ThreadLocalRandom.class) {
            long j2 = initialSeedUniquifier;
            if (j2 != 0) {
                return j2;
            }
            long nanos = seedGeneratorStartTime + TimeUnit.SECONDS.toNanos(3);
            boolean z = false;
            while (true) {
                long nanoTime = nanos - System.nanoTime();
                int i = (nanoTime > 0 ? 1 : (nanoTime == 0 ? 0 : -1));
                if (i <= 0) {
                    try {
                        l = seedQueue.poll();
                    } catch (InterruptedException unused) {
                        z = true;
                        logger.warn("Failed to generate a seed from SecureRandom due to an InterruptedException.");
                    }
                } else {
                    l = seedQueue.poll(nanoTime, TimeUnit.NANOSECONDS);
                }
                if (l == null) {
                    if (i <= 0) {
                        seedGeneratorThread.interrupt();
                        logger.warn("Failed to generate a seed from SecureRandom within {} seconds. Not enough entropy?", (Object) 3L);
                        break;
                    }
                } else {
                    j2 = l.longValue();
                    break;
                }
            }
            long reverse = (j2 ^ 3627065505421648153L) ^ Long.reverse(System.nanoTime());
            initialSeedUniquifier = reverse;
            if (z) {
                Thread.currentThread().interrupt();
                seedGeneratorThread.interrupt();
            }
            if (seedGeneratorEndTime == 0) {
                seedGeneratorEndTime = System.nanoTime();
            }
            return reverse;
        }
    }

    private static long mix64(long j) {
        long j2 = (j ^ (j >>> 33)) * -49064778989728563L;
        long j3 = (j2 ^ (j2 >>> 33)) * -4265267296055464877L;
        return j3 ^ (j3 >>> 33);
    }

    private static long newSeed() {
        AtomicLong atomicLong;
        long j;
        int i;
        long j2;
        long j3;
        do {
            atomicLong = seedUniquifier;
            j = atomicLong.get();
            i = (j > 0 ? 1 : (j == 0 ? 0 : -1));
            if (i != 0) {
                j2 = j;
            } else {
                j2 = getInitialSeedUniquifier();
            }
            j3 = 181783497276652981L * j2;
        } while (!atomicLong.compareAndSet(j, j3));
        if (i == 0) {
            InternalLogger internalLogger = logger;
            if (internalLogger.isDebugEnabled()) {
                if (seedGeneratorEndTime != 0) {
                    internalLogger.debug(String.format("-Dio.netty.initialSeedUniquifier: 0x%016x (took %d ms)", Long.valueOf(j2), Long.valueOf(TimeUnit.NANOSECONDS.toMillis(seedGeneratorEndTime - seedGeneratorStartTime))));
                } else {
                    internalLogger.debug(String.format("-Dio.netty.initialSeedUniquifier: 0x%016x", Long.valueOf(j2)));
                }
            }
        }
        return System.nanoTime() ^ j3;
    }

    public static void setInitialSeedUniquifier(long j) {
        initialSeedUniquifier = j;
    }

    public int next(int i) {
        long j = ((this.rnd * multiplier) + addend) & mask;
        this.rnd = j;
        return (int) (j >>> (48 - i));
    }

    public double nextDouble(double d) {
        ObjectUtil.checkPositive(d, "n");
        return nextDouble() * d;
    }

    public int nextInt(int i, int i2) {
        if (i < i2) {
            return nextInt(i2 - i) + i;
        }
        throw new IllegalArgumentException();
    }

    public long nextLong(long j) {
        ObjectUtil.checkPositive(j, "n");
        long j2 = 0;
        while (j >= 2147483647L) {
            int next = next(2);
            long j3 = j >>> 1;
            if ((next & 2) != 0) {
                j3 = j - j3;
            }
            if ((next & 1) == 0) {
                j2 = (j - j3) + j2;
            }
            j = j3;
        }
        return j2 + ((long) nextInt((int) j));
    }

    public void setSeed(long j) {
        if (!this.initialized) {
            this.rnd = (j ^ multiplier) & mask;
            return;
        }
        throw new UnsupportedOperationException();
    }

    public double nextDouble(double d, double d2) {
        if (d < d2) {
            return ((d2 - d) * nextDouble()) + d;
        }
        throw new IllegalArgumentException();
    }

    public long nextLong(long j, long j2) {
        if (j < j2) {
            return nextLong(j2 - j) + j;
        }
        throw new IllegalArgumentException();
    }
}
