package kotlin.collections;

import java.util.Iterator;
import java.util.NoSuchElementException;
import kotlin.io.FileTreeWalk;
import kotlin.jvm.internal.Intrinsics;

/* compiled from: AbstractIterator.kt */
public abstract class AbstractIterator<T> implements Iterator<T> {
    public T nextValue;
    public State state = State.NotReady;

    public boolean hasNext() {
        T t;
        State state2 = this.state;
        State state3 = State.Failed;
        if (state2 != state3) {
            int ordinal = state2.ordinal();
            if (ordinal == 0) {
                return true;
            }
            if (ordinal != 2) {
                this.state = state3;
                FileTreeWalk.FileTreeWalkIterator fileTreeWalkIterator = (FileTreeWalk.FileTreeWalkIterator) this;
                while (true) {
                    FileTreeWalk.WalkState peek = fileTreeWalkIterator.state.peek();
                    if (peek == null) {
                        t = null;
                        break;
                    }
                    t = (T) peek.step();
                    if (t != null) {
                        if (Intrinsics.areEqual(t, peek.root) || !t.isDirectory() || fileTreeWalkIterator.state.size() >= FileTreeWalk.this.maxDepth) {
                            break;
                        }
                        fileTreeWalkIterator.state.push(fileTreeWalkIterator.directoryState(t));
                    } else {
                        fileTreeWalkIterator.state.pop();
                    }
                }
                if (t != null) {
                    fileTreeWalkIterator.nextValue = t;
                    ((AbstractIterator) fileTreeWalkIterator).state = State.Ready;
                } else {
                    ((AbstractIterator) fileTreeWalkIterator).state = State.Done;
                }
                if (this.state == State.Ready) {
                    return true;
                }
            }
            return false;
        }
        throw new IllegalArgumentException("Failed requirement.".toString());
    }

    @Override // java.util.Iterator
    public T next() {
        if (hasNext()) {
            this.state = State.NotReady;
            return this.nextValue;
        }
        throw new NoSuchElementException();
    }

    public void remove() {
        throw new UnsupportedOperationException("Operation is not supported for read-only collection");
    }
}
