package kotlinx.coroutines;

import java.lang.reflect.Method;
import java.util.concurrent.Executor;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;
import kotlin.coroutines.CoroutineContext;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.ConcurrentKt;

/* compiled from: Executors.kt */
public final class ExecutorCoroutineDispatcherImpl extends ExecutorCoroutineDispatcher implements Delay {
    public final Executor executor;
    public boolean removesFutureOnCancellation;

    public ExecutorCoroutineDispatcherImpl(Executor executor2) {
        Method method;
        Intrinsics.checkParameterIsNotNull(executor2, "executor");
        this.executor = executor2;
        Method method2 = ConcurrentKt.REMOVE_FUTURE_ON_CANCEL;
        Intrinsics.checkParameterIsNotNull(executor2, "executor");
        boolean z = false;
        try {
            ScheduledExecutorService scheduledExecutorService = (ScheduledExecutorService) (!(executor2 instanceof ScheduledExecutorService) ? null : executor2);
            if (!(scheduledExecutorService == null || (method = ConcurrentKt.REMOVE_FUTURE_ON_CANCEL) == null)) {
                method.invoke(scheduledExecutorService, Boolean.TRUE);
                z = true;
            }
        } catch (Throwable unused) {
        }
        this.removesFutureOnCancellation = z;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        Executor executor2 = this.executor;
        if (!(executor2 instanceof ExecutorService)) {
            executor2 = null;
        }
        ExecutorService executorService = (ExecutorService) executor2;
        if (executorService != null) {
            executorService.shutdown();
        }
    }

    @Override // kotlinx.coroutines.CoroutineDispatcher
    public void dispatch(CoroutineContext coroutineContext, Runnable runnable) {
        Intrinsics.checkParameterIsNotNull(coroutineContext, "context");
        Intrinsics.checkParameterIsNotNull(runnable, "block");
        try {
            this.executor.execute(runnable);
        } catch (RejectedExecutionException unused) {
            DefaultExecutor.INSTANCE.enqueue(runnable);
        }
    }

    public boolean equals(Object obj) {
        return (obj instanceof ExecutorCoroutineDispatcherImpl) && ((ExecutorCoroutineDispatcherImpl) obj).executor == this.executor;
    }

    public int hashCode() {
        return System.identityHashCode(this.executor);
    }

    @Override // kotlinx.coroutines.Delay
    public DisposableHandle invokeOnTimeout(long j, Runnable runnable) {
        Intrinsics.checkParameterIsNotNull(runnable, "block");
        ScheduledFuture scheduleBlock = this.removesFutureOnCancellation ? scheduleBlock(runnable, j, TimeUnit.MILLISECONDS) : null;
        return scheduleBlock != null ? new DisposableFutureHandle(scheduleBlock) : DefaultExecutor.INSTANCE.invokeOnTimeout(j, runnable);
    }

    public final ScheduledFuture scheduleBlock(Runnable runnable, long j, TimeUnit timeUnit) {
        try {
            Executor executor2 = this.executor;
            if (!(executor2 instanceof ScheduledExecutorService)) {
                executor2 = null;
            }
            ScheduledExecutorService scheduledExecutorService = (ScheduledExecutorService) executor2;
            if (scheduledExecutorService != null) {
                return scheduledExecutorService.schedule(runnable, j, timeUnit);
            }
            return null;
        } catch (RejectedExecutionException unused) {
            return null;
        }
    }

    @Override // kotlinx.coroutines.Delay
    public void scheduleResumeAfterDelay(long j, CancellableContinuation cancellableContinuation) {
        Intrinsics.checkParameterIsNotNull(cancellableContinuation, "continuation");
        ScheduledFuture scheduleBlock = this.removesFutureOnCancellation ? scheduleBlock(new ResumeUndispatchedRunnable(this, cancellableContinuation), j, TimeUnit.MILLISECONDS) : null;
        if (scheduleBlock != null) {
            Intrinsics.checkParameterIsNotNull(cancellableContinuation, "$this$cancelFutureOnCancellation");
            Intrinsics.checkParameterIsNotNull(scheduleBlock, "future");
            ((CancellableContinuationImpl) cancellableContinuation).invokeOnCancellation(new CancelFutureOnCancel(scheduleBlock));
            return;
        }
        DefaultExecutor.INSTANCE.scheduleResumeAfterDelay(j, cancellableContinuation);
    }

    @Override // kotlinx.coroutines.CoroutineDispatcher
    public String toString() {
        return this.executor.toString();
    }
}
