package kotlinx.coroutines.channels;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.concurrent.atomic.AtomicReferenceFieldUpdater;
import kotlin.Result;
import kotlin.TypeCastException;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.CancellableContinuationImpl;
import kotlinx.coroutines.CancellableContinuationImplKt;
import kotlinx.coroutines.DebugKt;
import kotlinx.coroutines.RemoveOnCancel;
import kotlinx.coroutines.internal.LockFreeLinkedListHead;
import kotlinx.coroutines.internal.LockFreeLinkedListNode;
import kotlinx.coroutines.internal.StackTraceRecoveryKt;
import kotlinx.coroutines.internal.Symbol;

/* compiled from: AbstractChannel.kt */
public abstract class AbstractSendChannel<E> implements SendChannel<E> {
    public static final AtomicReferenceFieldUpdater onCloseHandler$FU = AtomicReferenceFieldUpdater.newUpdater(AbstractSendChannel.class, Object.class, "onCloseHandler");
    public volatile Object onCloseHandler = null;
    public final LockFreeLinkedListHead queue = new LockFreeLinkedListHead();

    /* compiled from: AbstractChannel.kt */
    public final class SendBuffered<E> extends Send {
        public final E element;

        public SendBuffered(E e) {
            this.element = e;
        }

        @Override // kotlinx.coroutines.channels.Send
        public void completeResumeSend() {
        }

        @Override // kotlinx.coroutines.channels.Send
        public Object getPollResult() {
            return this.element;
        }

        @Override // kotlinx.coroutines.channels.Send
        public void resumeSendClosed(Closed<?> closed) {
            Intrinsics.checkParameterIsNotNull(closed, "closed");
        }

        @Override // kotlinx.coroutines.internal.LockFreeLinkedListNode
        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("SendBuffered@");
            outline25.append(ViewGroupUtilsApi14.getHexAddress(this));
            outline25.append('(');
            outline25.append((Object) this.element);
            outline25.append(')');
            return outline25.toString();
        }

        @Override // kotlinx.coroutines.channels.Send
        public Symbol tryResumeSend(LockFreeLinkedListNode.PrepareOp prepareOp) {
            return CancellableContinuationImplKt.RESUME_TOKEN;
        }
    }

    public String getBufferDebugString() {
        return "";
    }

    public final Closed<?> getClosedForSend() {
        LockFreeLinkedListNode prevNode = this.queue.getPrevNode();
        if (!(prevNode instanceof Closed)) {
            prevNode = null;
        }
        Closed<?> closed = (Closed) prevNode;
        if (closed == null) {
            return null;
        }
        helpClose(closed);
        return closed;
    }

    public final void helpClose(Closed<?> closed) {
        Object obj = null;
        while (true) {
            LockFreeLinkedListNode prevNode = closed.getPrevNode();
            if (!(prevNode instanceof Receive)) {
                prevNode = null;
            }
            Receive receive = (Receive) prevNode;
            if (receive == null) {
                break;
            } else if (!receive.remove()) {
                receive.helpRemove();
            } else {
                obj = ViewGroupUtilsApi14.m16plusimpl(obj, receive);
            }
        }
        if (obj != null) {
            if (obj instanceof ArrayList) {
                ArrayList arrayList = (ArrayList) obj;
                int size = arrayList.size();
                while (true) {
                    size--;
                    if (size < 0) {
                        break;
                    }
                    ((Receive) arrayList.get(size)).resumeReceiveClosed(closed);
                }
            } else {
                ((Receive) obj).resumeReceiveClosed(closed);
            }
        }
        onClosedIdempotent(closed);
    }

    public abstract boolean isBufferAlwaysFull();

    public abstract boolean isBufferFull();

    @Override // kotlinx.coroutines.channels.SendChannel
    public final boolean offer(E e) {
        Object offerInternal = offerInternal(e);
        if (offerInternal == AbstractChannelKt.OFFER_SUCCESS) {
            return true;
        }
        if (offerInternal == AbstractChannelKt.OFFER_FAILED) {
            Closed<?> closedForSend = getClosedForSend();
            if (closedForSend == null) {
                return false;
            }
            helpClose(closedForSend);
            throw StackTraceRecoveryKt.recoverStackTrace(closedForSend.getSendException());
        } else if (offerInternal instanceof Closed) {
            Closed<?> closed = (Closed) offerInternal;
            helpClose(closed);
            throw StackTraceRecoveryKt.recoverStackTrace(closed.getSendException());
        } else {
            throw new IllegalStateException(GeneratedOutlineSupport.outline17("offerInternal returned ", offerInternal).toString());
        }
    }

    public Object offerInternal(E e) {
        ReceiveOrClosed<E> takeFirstReceiveOrPeekClosed;
        do {
            takeFirstReceiveOrPeekClosed = takeFirstReceiveOrPeekClosed();
            if (takeFirstReceiveOrPeekClosed == null) {
                return AbstractChannelKt.OFFER_FAILED;
            }
        } while (takeFirstReceiveOrPeekClosed.tryResumeReceive(e, null) == null);
        boolean z = DebugKt.DEBUG;
        takeFirstReceiveOrPeekClosed.completeResumeReceive(e);
        return takeFirstReceiveOrPeekClosed.getOfferResult();
    }

    public void onClosedIdempotent(LockFreeLinkedListNode lockFreeLinkedListNode) {
        Intrinsics.checkParameterIsNotNull(lockFreeLinkedListNode, "closed");
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:74:0x0079 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r3v1, types: [java.lang.Object] */
    /* JADX WARN: Type inference failed for: r3v3 */
    /* JADX WARN: Type inference failed for: r3v4 */
    /* JADX WARN: Type inference failed for: r3v5, types: [java.lang.Object] */
    /* JADX WARN: Type inference failed for: r3v7, types: [kotlinx.coroutines.internal.LockFreeLinkedListNode] */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x008e  */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x007b A[SYNTHETIC] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // kotlinx.coroutines.channels.SendChannel
    public final Object send(E e, Continuation<? super Unit> continuation) {
        ?? r3;
        if (offerInternal(e) == AbstractChannelKt.OFFER_SUCCESS) {
            return Unit.INSTANCE;
        }
        CancellableContinuationImpl orCreateCancellableContinuation = ViewGroupUtilsApi14.getOrCreateCancellableContinuation(ViewGroupUtilsApi14.intercepted(continuation));
        while (true) {
            boolean z = false;
            if (!(this.queue.getNextNode() instanceof ReceiveOrClosed) && isBufferFull()) {
                SendElement sendElement = new SendElement(e, orCreateCancellableContinuation);
                if (isBufferAlwaysFull()) {
                    LockFreeLinkedListHead lockFreeLinkedListHead = this.queue;
                    while (true) {
                        Object prev = lockFreeLinkedListHead.getPrev();
                        if (prev != null) {
                            r3 = (LockFreeLinkedListNode) prev;
                            if (!(r3 instanceof ReceiveOrClosed)) {
                                if (r3.addNext(sendElement, lockFreeLinkedListHead)) {
                                    break;
                                }
                            } else {
                                break;
                            }
                        } else {
                            throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
                        }
                    }
                } else {
                    LockFreeLinkedListHead lockFreeLinkedListHead2 = this.queue;
                    AbstractSendChannel$enqueueSend$$inlined$addLastIfPrevAndIf$1 abstractSendChannel$enqueueSend$$inlined$addLastIfPrevAndIf$1 = new AbstractSendChannel$enqueueSend$$inlined$addLastIfPrevAndIf$1(sendElement, sendElement, this);
                    while (true) {
                        Object prev2 = lockFreeLinkedListHead2.getPrev();
                        if (prev2 != null) {
                            LockFreeLinkedListNode lockFreeLinkedListNode = (LockFreeLinkedListNode) prev2;
                            if (!(lockFreeLinkedListNode instanceof ReceiveOrClosed)) {
                                int tryCondAddNext = lockFreeLinkedListNode.tryCondAddNext(sendElement, lockFreeLinkedListHead2, abstractSendChannel$enqueueSend$$inlined$addLastIfPrevAndIf$1);
                                if (tryCondAddNext != 1) {
                                    if (tryCondAddNext == 2) {
                                        break;
                                    }
                                } else {
                                    z = true;
                                    break;
                                }
                            } else {
                                r3 = lockFreeLinkedListNode;
                                break;
                            }
                        } else {
                            throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
                        }
                    }
                    if (!z) {
                        r3 = AbstractChannelKt.ENQUEUE_FAILED;
                    }
                    if (r3 != 0) {
                        Intrinsics.checkParameterIsNotNull(orCreateCancellableContinuation, "$this$removeOnCancellation");
                        Intrinsics.checkParameterIsNotNull(sendElement, "node");
                        orCreateCancellableContinuation.invokeOnCancellation(new RemoveOnCancel(sendElement));
                        break;
                    } else if (r3 instanceof Closed) {
                        Closed<?> closed = (Closed) r3;
                        helpClose(closed);
                        orCreateCancellableContinuation.resumeWith(Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(closed.getSendException())));
                        break;
                    } else if (r3 != AbstractChannelKt.ENQUEUE_FAILED && !(r3 instanceof Receive)) {
                        throw new IllegalStateException(GeneratedOutlineSupport.outline17("enqueueSend returned ", r3).toString());
                    }
                }
                r3 = 0;
                if (r3 != 0) {
                }
            }
            Object offerInternal = offerInternal(e);
            if (offerInternal == AbstractChannelKt.OFFER_SUCCESS) {
                orCreateCancellableContinuation.resumeWith(Result.m133constructorimpl(Unit.INSTANCE));
                break;
            } else if (offerInternal != AbstractChannelKt.OFFER_FAILED) {
                if (offerInternal instanceof Closed) {
                    Closed<?> closed2 = (Closed) offerInternal;
                    helpClose(closed2);
                    orCreateCancellableContinuation.resumeWith(Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(closed2.getSendException())));
                } else {
                    throw new IllegalStateException(GeneratedOutlineSupport.outline17("offerInternal returned ", offerInternal).toString());
                }
            }
        }
        Object result = orCreateCancellableContinuation.getResult();
        CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
        if (result == coroutineSingletons) {
            Intrinsics.checkNotNullParameter(continuation, "frame");
        }
        if (result == coroutineSingletons) {
            return result;
        }
        return Unit.INSTANCE;
    }

    public ReceiveOrClosed<E> takeFirstReceiveOrPeekClosed() {
        LockFreeLinkedListNode lockFreeLinkedListNode;
        LockFreeLinkedListHead lockFreeLinkedListHead = this.queue;
        while (true) {
            Object next = lockFreeLinkedListHead.getNext();
            if (next != null) {
                lockFreeLinkedListNode = (LockFreeLinkedListNode) next;
                if (lockFreeLinkedListNode != lockFreeLinkedListHead && (lockFreeLinkedListNode instanceof ReceiveOrClosed)) {
                    if ((((ReceiveOrClosed) lockFreeLinkedListNode) instanceof Closed) || lockFreeLinkedListNode.remove()) {
                        break;
                    }
                    lockFreeLinkedListNode.helpDelete();
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
            }
        }
        lockFreeLinkedListNode = null;
        return (ReceiveOrClosed) lockFreeLinkedListNode;
    }

    public final Send takeFirstSendOrPeekClosed() {
        LockFreeLinkedListNode lockFreeLinkedListNode;
        LockFreeLinkedListHead lockFreeLinkedListHead = this.queue;
        while (true) {
            Object next = lockFreeLinkedListHead.getNext();
            if (next != null) {
                lockFreeLinkedListNode = (LockFreeLinkedListNode) next;
                if (lockFreeLinkedListNode != lockFreeLinkedListHead && (lockFreeLinkedListNode instanceof Send)) {
                    if ((((Send) lockFreeLinkedListNode) instanceof Closed) || lockFreeLinkedListNode.remove()) {
                        break;
                    }
                    lockFreeLinkedListNode.helpDelete();
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
            }
        }
        lockFreeLinkedListNode = null;
        return (Send) lockFreeLinkedListNode;
    }

    public String toString() {
        String str;
        String str2;
        StringBuilder sb = new StringBuilder();
        sb.append(ViewGroupUtilsApi14.getClassSimpleName(this));
        sb.append('@');
        sb.append(ViewGroupUtilsApi14.getHexAddress(this));
        sb.append('{');
        LockFreeLinkedListNode nextNode = this.queue.getNextNode();
        if (nextNode == this.queue) {
            str = "EmptyQueue";
        } else {
            if (nextNode instanceof Closed) {
                str2 = nextNode.toString();
            } else if (nextNode instanceof Receive) {
                str2 = "ReceiveQueued";
            } else if (nextNode instanceof Send) {
                str2 = "SendQueued";
            } else {
                str2 = "UNEXPECTED:" + nextNode;
            }
            LockFreeLinkedListNode prevNode = this.queue.getPrevNode();
            if (prevNode != nextNode) {
                StringBuilder outline28 = GeneratedOutlineSupport.outline28(str2, ",queueSize=");
                LockFreeLinkedListHead lockFreeLinkedListHead = this.queue;
                Object next = lockFreeLinkedListHead.getNext();
                if (next != null) {
                    int i = 0;
                    for (LockFreeLinkedListNode lockFreeLinkedListNode = (LockFreeLinkedListNode) next; !Intrinsics.areEqual(lockFreeLinkedListNode, lockFreeLinkedListHead); lockFreeLinkedListNode = lockFreeLinkedListNode.getNextNode()) {
                        i++;
                    }
                    outline28.append(i);
                    str = outline28.toString();
                    if (prevNode instanceof Closed) {
                        str = str + ",closedForSend=" + prevNode;
                    }
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
                }
            } else {
                str = str2;
            }
        }
        sb.append(str);
        sb.append('}');
        sb.append(getBufferDebugString());
        return sb.toString();
    }
}
