package kotlinx.coroutines.channels;

import com.android.tools.r8.GeneratedOutlineSupport;
import kotlin.TypeCastException;
import kotlinx.coroutines.channels.AbstractSendChannel;
import kotlinx.coroutines.internal.LockFreeLinkedListHead;
import kotlinx.coroutines.internal.LockFreeLinkedListNode;

/* compiled from: LinkedListChannel.kt */
public class LinkedListChannel<E> extends AbstractChannel<E> {
    @Override // kotlinx.coroutines.channels.AbstractChannel
    public final boolean isBufferAlwaysEmpty() {
        return true;
    }

    @Override // kotlinx.coroutines.channels.AbstractSendChannel
    public final boolean isBufferAlwaysFull() {
        return false;
    }

    @Override // kotlinx.coroutines.channels.AbstractChannel
    public final boolean isBufferEmpty() {
        return true;
    }

    @Override // kotlinx.coroutines.channels.AbstractSendChannel
    public final boolean isBufferFull() {
        return false;
    }

    @Override // kotlinx.coroutines.channels.AbstractSendChannel
    public Object offerInternal(E e) {
        ReceiveOrClosed receiveOrClosed;
        do {
            Object offerInternal = super.offerInternal(e);
            Object obj = AbstractChannelKt.OFFER_SUCCESS;
            if (offerInternal == obj) {
                return obj;
            }
            if (offerInternal == AbstractChannelKt.OFFER_FAILED) {
                LockFreeLinkedListHead lockFreeLinkedListHead = this.queue;
                AbstractSendChannel.SendBuffered sendBuffered = new AbstractSendChannel.SendBuffered(e);
                while (true) {
                    Object prev = lockFreeLinkedListHead.getPrev();
                    if (prev != null) {
                        LockFreeLinkedListNode lockFreeLinkedListNode = (LockFreeLinkedListNode) prev;
                        if (!(lockFreeLinkedListNode instanceof ReceiveOrClosed)) {
                            if (lockFreeLinkedListNode.addNext(sendBuffered, lockFreeLinkedListHead)) {
                                receiveOrClosed = null;
                                break;
                            }
                        } else {
                            receiveOrClosed = (ReceiveOrClosed) lockFreeLinkedListNode;
                            break;
                        }
                    } else {
                        throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
                    }
                }
                if (receiveOrClosed == null) {
                    return AbstractChannelKt.OFFER_SUCCESS;
                }
            } else if (offerInternal instanceof Closed) {
                return offerInternal;
            } else {
                throw new IllegalStateException(GeneratedOutlineSupport.outline17("Invalid offerInternal result ", offerInternal).toString());
            }
        } while (!(receiveOrClosed instanceof Closed));
        return receiveOrClosed;
    }
}
