package kotlinx.coroutines.internal;

import java.lang.Comparable;
import java.util.Arrays;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.DebugKt;
import kotlinx.coroutines.EventLoopImplBase;
import kotlinx.coroutines.EventLoopImplBase.DelayedTask;

/* compiled from: ThreadSafeHeap.kt */
public abstract class ThreadSafeHeap<T extends EventLoopImplBase.DelayedTask & Comparable<? super T>> {
    public volatile int _size = 0;
    public T[] a;

    public final void addImpl(T t) {
        Intrinsics.checkParameterIsNotNull(t, "node");
        boolean z = DebugKt.DEBUG;
        t.setHeap(this);
        T[] tArr = this.a;
        if (tArr == null) {
            tArr = (T[]) new EventLoopImplBase.DelayedTask[4];
            this.a = tArr;
        } else if (this._size >= tArr.length) {
            Object[] copyOf = Arrays.copyOf(tArr, this._size * 2);
            Intrinsics.checkExpressionValueIsNotNull(copyOf, "java.util.Arrays.copyOf(this, newSize)");
            tArr = (T[]) ((EventLoopImplBase.DelayedTask[]) copyOf);
            this.a = tArr;
        }
        int i = this._size;
        this._size = i + 1;
        tArr[i] = t;
        t.index = i;
        siftUpFrom(i);
    }

    public final T firstImpl() {
        T[] tArr = this.a;
        if (tArr != null) {
            return tArr[0];
        }
        return null;
    }

    public final T removeAtImpl(int i) {
        boolean z = DebugKt.DEBUG;
        T[] tArr = this.a;
        if (tArr != null) {
            this._size--;
            if (i < this._size) {
                swap(i, this._size);
                int i2 = (i - 1) / 2;
                if (i > 0) {
                    T t = tArr[i];
                    if (t != null) {
                        T t2 = tArr[i2];
                        if (t2 == null) {
                            Intrinsics.throwNpe();
                            throw null;
                        } else if (t.compareTo(t2) < 0) {
                            swap(i, i2);
                            siftUpFrom(i2);
                        }
                    } else {
                        Intrinsics.throwNpe();
                        throw null;
                    }
                }
                while (true) {
                    int i3 = (i * 2) + 1;
                    if (i3 >= this._size) {
                        break;
                    }
                    T[] tArr2 = this.a;
                    if (tArr2 != null) {
                        int i4 = i3 + 1;
                        if (i4 < this._size) {
                            T t3 = tArr2[i4];
                            if (t3 != null) {
                                T t4 = tArr2[i3];
                                if (t4 == null) {
                                    Intrinsics.throwNpe();
                                    throw null;
                                } else if (t3.compareTo(t4) < 0) {
                                    i3 = i4;
                                }
                            } else {
                                Intrinsics.throwNpe();
                                throw null;
                            }
                        }
                        T t5 = tArr2[i];
                        if (t5 != null) {
                            T t6 = tArr2[i3];
                            if (t6 == null) {
                                Intrinsics.throwNpe();
                                throw null;
                            } else if (t5.compareTo(t6) <= 0) {
                                break;
                            } else {
                                swap(i, i3);
                                i = i3;
                            }
                        } else {
                            Intrinsics.throwNpe();
                            throw null;
                        }
                    } else {
                        Intrinsics.throwNpe();
                        throw null;
                    }
                }
            }
            T t7 = tArr[this._size];
            if (t7 != null) {
                boolean z2 = DebugKt.DEBUG;
                t7.setHeap(null);
                t7.index = -1;
                tArr[this._size] = null;
                return t7;
            }
            Intrinsics.throwNpe();
            throw null;
        }
        Intrinsics.throwNpe();
        throw null;
    }

    public final void siftUpFrom(int i) {
        while (i > 0) {
            T[] tArr = this.a;
            if (tArr != null) {
                int i2 = (i - 1) / 2;
                T t = tArr[i2];
                if (t != null) {
                    T t2 = tArr[i];
                    if (t2 == null) {
                        Intrinsics.throwNpe();
                        throw null;
                    } else if (t.compareTo(t2) > 0) {
                        swap(i, i2);
                        i = i2;
                    } else {
                        return;
                    }
                } else {
                    Intrinsics.throwNpe();
                    throw null;
                }
            } else {
                Intrinsics.throwNpe();
                throw null;
            }
        }
    }

    public final void swap(int i, int i2) {
        T[] tArr = this.a;
        if (tArr != null) {
            T t = tArr[i2];
            if (t != null) {
                T t2 = tArr[i];
                if (t2 != null) {
                    tArr[i] = t;
                    tArr[i2] = t2;
                    t.index = i;
                    t2.index = i2;
                    return;
                }
                Intrinsics.throwNpe();
                throw null;
            }
            Intrinsics.throwNpe();
            throw null;
        }
        Intrinsics.throwNpe();
        throw null;
    }
}
