package net.lucode.hackware.magicindicator;

import android.util.SparseArray;
import android.util.SparseBooleanArray;
import android.view.View;
import android.widget.LinearLayout;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.CommonNavigator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerTitleView;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.model.PositionData;

public class NavigatorHelper {
    public int mCurrentIndex;
    public SparseBooleanArray mDeselectedItems = new SparseBooleanArray();
    public int mLastIndex;
    public float mLastPositionOffsetSum;
    public SparseArray<Float> mLeavedPercents = new SparseArray<>();
    public OnNavigatorScrollListener mNavigatorScrollListener;
    public int mScrollState;
    public boolean mSkimOver;
    public int mTotalCount;

    public interface OnNavigatorScrollListener {
    }

    public final void dispatchOnDeselected(int i) {
        OnNavigatorScrollListener onNavigatorScrollListener = this.mNavigatorScrollListener;
        if (onNavigatorScrollListener != null) {
            int i2 = this.mTotalCount;
            LinearLayout linearLayout = ((CommonNavigator) onNavigatorScrollListener).mTitleContainer;
            if (linearLayout != null) {
                View childAt = linearLayout.getChildAt(i);
                if (childAt instanceof IPagerTitleView) {
                    ((IPagerTitleView) childAt).onDeselected(i, i2);
                }
            }
        }
        this.mDeselectedItems.put(i, true);
    }

    public final void dispatchOnEnter(int i, float f, boolean z, boolean z2) {
        if (this.mSkimOver || i == this.mCurrentIndex || this.mScrollState == 1 || z2) {
            OnNavigatorScrollListener onNavigatorScrollListener = this.mNavigatorScrollListener;
            if (onNavigatorScrollListener != null) {
                int i2 = this.mTotalCount;
                LinearLayout linearLayout = ((CommonNavigator) onNavigatorScrollListener).mTitleContainer;
                if (linearLayout != null) {
                    View childAt = linearLayout.getChildAt(i);
                    if (childAt instanceof IPagerTitleView) {
                        ((IPagerTitleView) childAt).onEnter(i, i2, f, z);
                    }
                }
            }
            this.mLeavedPercents.put(i, Float.valueOf(1.0f - f));
        }
    }

    public final void dispatchOnLeave(int i, float f, boolean z, boolean z2) {
        if (!(this.mSkimOver || i == this.mLastIndex || this.mScrollState == 1)) {
            int i2 = this.mCurrentIndex;
            if ((!(i == i2 - 1 || i == i2 + 1) || this.mLeavedPercents.get(i, Float.valueOf(0.0f)).floatValue() == 1.0f) && !z2) {
                return;
            }
        }
        OnNavigatorScrollListener onNavigatorScrollListener = this.mNavigatorScrollListener;
        if (onNavigatorScrollListener != null) {
            int i3 = this.mTotalCount;
            LinearLayout linearLayout = ((CommonNavigator) onNavigatorScrollListener).mTitleContainer;
            if (linearLayout != null) {
                View childAt = linearLayout.getChildAt(i);
                if (childAt instanceof IPagerTitleView) {
                    ((IPagerTitleView) childAt).onLeave(i, i3, f, z);
                }
            }
        }
        this.mLeavedPercents.put(i, Float.valueOf(f));
    }

    public final void dispatchOnSelected(int i) {
        OnNavigatorScrollListener onNavigatorScrollListener = this.mNavigatorScrollListener;
        if (onNavigatorScrollListener != null) {
            int i2 = this.mTotalCount;
            CommonNavigator commonNavigator = (CommonNavigator) onNavigatorScrollListener;
            LinearLayout linearLayout = commonNavigator.mTitleContainer;
            if (linearLayout != null) {
                View childAt = linearLayout.getChildAt(i);
                if (childAt instanceof IPagerTitleView) {
                    ((IPagerTitleView) childAt).onSelected(i, i2);
                }
                if (!commonNavigator.mAdjustMode && !commonNavigator.mFollowTouch && commonNavigator.mScrollView != null && commonNavigator.mPositionDataList.size() > 0) {
                    PositionData positionData = commonNavigator.mPositionDataList.get(Math.min(commonNavigator.mPositionDataList.size() - 1, i));
                    if (commonNavigator.mEnablePivotScroll) {
                        float horizontalCenter = ((float) positionData.horizontalCenter()) - (((float) commonNavigator.mScrollView.getWidth()) * commonNavigator.mScrollPivotX);
                        if (commonNavigator.mSmoothScroll) {
                            commonNavigator.mScrollView.smoothScrollTo((int) horizontalCenter, 0);
                        } else {
                            commonNavigator.mScrollView.scrollTo((int) horizontalCenter, 0);
                        }
                    } else {
                        int scrollX = commonNavigator.mScrollView.getScrollX();
                        int i3 = positionData.mLeft;
                        if (scrollX <= i3) {
                            int width = commonNavigator.getWidth() + commonNavigator.mScrollView.getScrollX();
                            int i4 = positionData.mRight;
                            if (width < i4) {
                                if (commonNavigator.mSmoothScroll) {
                                    commonNavigator.mScrollView.smoothScrollTo(i4 - commonNavigator.getWidth(), 0);
                                } else {
                                    commonNavigator.mScrollView.scrollTo(i4 - commonNavigator.getWidth(), 0);
                                }
                            }
                        } else if (commonNavigator.mSmoothScroll) {
                            commonNavigator.mScrollView.smoothScrollTo(i3, 0);
                        } else {
                            commonNavigator.mScrollView.scrollTo(i3, 0);
                        }
                    }
                }
            }
        }
        this.mDeselectedItems.put(i, false);
    }

    public void setNavigatorScrollListener(OnNavigatorScrollListener onNavigatorScrollListener) {
        this.mNavigatorScrollListener = onNavigatorScrollListener;
    }

    public void setTotalCount(int i) {
        this.mTotalCount = i;
        this.mDeselectedItems.clear();
        this.mLeavedPercents.clear();
    }
}
