package net.lucode.hackware.magicindicator.buildins.circlenavigator;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PointF;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import java.util.ArrayList;
import java.util.List;
import kotlinx.coroutines.internal.SystemPropsKt;
import net.lucode.hackware.magicindicator.abs.IPagerNavigator;

public class CircleNavigator extends View implements IPagerNavigator {
    public OnCircleClickListener mCircleClickListener;
    public int mCircleColor;
    public List<PointF> mCirclePoints = new ArrayList();
    public int mCircleSpacing;
    public int mCurrentIndex;
    public float mDownX;
    public float mDownY;
    public boolean mFollowTouch = true;
    public float mIndicatorX;
    public Paint mPaint = new Paint(1);
    public int mRadius;
    public Interpolator mStartInterpolator = new LinearInterpolator();
    public int mStrokeWidth;
    public int mTotalCount;
    public int mTouchSlop;
    public boolean mTouchable;

    public interface OnCircleClickListener {
        void onClick(int i);
    }

    public CircleNavigator(Context context) {
        super(context);
        this.mTouchSlop = ViewConfiguration.get(context).getScaledTouchSlop();
        this.mRadius = SystemPropsKt.dip2px(context, 3.0d);
        this.mCircleSpacing = SystemPropsKt.dip2px(context, 8.0d);
        this.mStrokeWidth = SystemPropsKt.dip2px(context, 1.0d);
    }

    public OnCircleClickListener getCircleClickListener() {
        return this.mCircleClickListener;
    }

    public int getCircleColor() {
        return this.mCircleColor;
    }

    public int getCircleCount() {
        return this.mTotalCount;
    }

    public int getCircleSpacing() {
        return this.mCircleSpacing;
    }

    public int getRadius() {
        return this.mRadius;
    }

    public Interpolator getStartInterpolator() {
        return this.mStartInterpolator;
    }

    public int getStrokeWidth() {
        return this.mStrokeWidth;
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onAttachToMagicIndicator() {
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onDetachFromMagicIndicator() {
    }

    public void onDraw(Canvas canvas) {
        this.mPaint.setColor(this.mCircleColor);
        this.mPaint.setStyle(Paint.Style.STROKE);
        this.mPaint.setStrokeWidth((float) this.mStrokeWidth);
        int size = this.mCirclePoints.size();
        for (int i = 0; i < size; i++) {
            PointF pointF = this.mCirclePoints.get(i);
            canvas.drawCircle(pointF.x, pointF.y, (float) this.mRadius, this.mPaint);
        }
        this.mPaint.setStyle(Paint.Style.FILL);
        if (this.mCirclePoints.size() > 0) {
            canvas.drawCircle(this.mIndicatorX, (float) ((int) ((((float) getHeight()) / 2.0f) + 0.5f)), (float) this.mRadius, this.mPaint);
        }
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        prepareCirclePoints();
    }

    public void onMeasure(int i, int i2) {
        int mode = View.MeasureSpec.getMode(i);
        int size = View.MeasureSpec.getSize(i);
        int i3 = 0;
        if (mode == Integer.MIN_VALUE || mode == 0) {
            int i4 = this.mTotalCount;
            size = getPaddingRight() + getPaddingLeft() + ((i4 - 1) * this.mCircleSpacing) + (this.mRadius * i4 * 2) + (this.mStrokeWidth * 2);
        } else if (mode != 1073741824) {
            size = 0;
        }
        int mode2 = View.MeasureSpec.getMode(i2);
        int size2 = View.MeasureSpec.getSize(i2);
        if (mode2 == Integer.MIN_VALUE || mode2 == 0) {
            i3 = getPaddingBottom() + getPaddingTop() + (this.mStrokeWidth * 2) + (this.mRadius * 2);
        } else if (mode2 == 1073741824) {
            i3 = size2;
        }
        setMeasuredDimension(size, i3);
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onPageScrollStateChanged(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onPageScrolled(int i, float f, int i2) {
        if (this.mFollowTouch && !this.mCirclePoints.isEmpty()) {
            int min = Math.min(this.mCirclePoints.size() - 1, i);
            int min2 = Math.min(this.mCirclePoints.size() - 1, i + 1);
            float f2 = this.mCirclePoints.get(min).x;
            this.mIndicatorX = (this.mStartInterpolator.getInterpolation(f) * (this.mCirclePoints.get(min2).x - f2)) + f2;
            invalidate();
        }
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onPageSelected(int i) {
        this.mCurrentIndex = i;
        if (!this.mFollowTouch) {
            this.mIndicatorX = this.mCirclePoints.get(i).x;
            invalidate();
        }
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        float x = motionEvent.getX();
        float y = motionEvent.getY();
        int action = motionEvent.getAction();
        if (action != 0) {
            if (action == 1 && this.mCircleClickListener != null && Math.abs(x - this.mDownX) <= ((float) this.mTouchSlop) && Math.abs(y - this.mDownY) <= ((float) this.mTouchSlop)) {
                float f = Float.MAX_VALUE;
                int i = 0;
                for (int i2 = 0; i2 < this.mCirclePoints.size(); i2++) {
                    float abs = Math.abs(this.mCirclePoints.get(i2).x - x);
                    if (abs < f) {
                        i = i2;
                        f = abs;
                    }
                }
                this.mCircleClickListener.onClick(i);
            }
        } else if (this.mTouchable) {
            this.mDownX = x;
            this.mDownY = y;
            return true;
        }
        return super.onTouchEvent(motionEvent);
    }

    public final void prepareCirclePoints() {
        this.mCirclePoints.clear();
        if (this.mTotalCount > 0) {
            int height = (int) ((((float) getHeight()) / 2.0f) + 0.5f);
            int i = this.mRadius;
            int i2 = (i * 2) + this.mCircleSpacing;
            int paddingLeft = getPaddingLeft() + i + ((int) ((((float) this.mStrokeWidth) / 2.0f) + 0.5f));
            for (int i3 = 0; i3 < this.mTotalCount; i3++) {
                this.mCirclePoints.add(new PointF((float) paddingLeft, (float) height));
                paddingLeft += i2;
            }
            this.mIndicatorX = this.mCirclePoints.get(this.mCurrentIndex).x;
        }
    }

    public void setCircleClickListener(OnCircleClickListener onCircleClickListener) {
        if (!this.mTouchable) {
            this.mTouchable = true;
        }
        this.mCircleClickListener = onCircleClickListener;
    }

    public void setCircleColor(int i) {
        this.mCircleColor = i;
        invalidate();
    }

    public void setCircleCount(int i) {
        this.mTotalCount = i;
    }

    public void setCircleSpacing(int i) {
        this.mCircleSpacing = i;
        prepareCirclePoints();
        invalidate();
    }

    public void setFollowTouch(boolean z) {
        this.mFollowTouch = z;
    }

    public void setRadius(int i) {
        this.mRadius = i;
        prepareCirclePoints();
        invalidate();
    }

    public void setStartInterpolator(Interpolator interpolator) {
        this.mStartInterpolator = interpolator;
        if (interpolator == null) {
            this.mStartInterpolator = new LinearInterpolator();
        }
    }

    public void setStrokeWidth(int i) {
        this.mStrokeWidth = i;
        invalidate();
    }

    public void setTouchable(boolean z) {
        this.mTouchable = z;
    }
}
