package net.lucode.hackware.magicindicator.buildins.commonnavigator;

import android.content.Context;
import android.database.DataSetObserver;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.HorizontalScrollView;
import android.widget.LinearLayout;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.List;
import net.lucode.hackware.magicindicator.NavigatorHelper;
import net.lucode.hackware.magicindicator.R$id;
import net.lucode.hackware.magicindicator.R$layout;
import net.lucode.hackware.magicindicator.abs.IPagerNavigator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.CommonNavigatorAdapter;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IMeasurablePagerTitleView;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerTitleView;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.model.PositionData;

public class CommonNavigator extends FrameLayout implements IPagerNavigator, NavigatorHelper.OnNavigatorScrollListener {
    public CommonNavigatorAdapter mAdapter;
    public boolean mAdjustMode;
    public boolean mEnablePivotScroll;
    public boolean mFollowTouch = true;
    public IPagerIndicator mIndicator;
    public LinearLayout mIndicatorContainer;
    public boolean mIndicatorOnTop;
    public int mLeftPadding;
    public NavigatorHelper mNavigatorHelper;
    public DataSetObserver mObserver = new DataSetObserver() {
        /* class net.lucode.hackware.magicindicator.buildins.commonnavigator.CommonNavigator.AnonymousClass1 */

        public void onChanged() {
            CommonNavigator commonNavigator = CommonNavigator.this;
            commonNavigator.mNavigatorHelper.setTotalCount(commonNavigator.mAdapter.getCount());
            CommonNavigator.this.init();
        }

        public void onInvalidated() {
        }
    };
    public List<PositionData> mPositionDataList = new ArrayList();
    public boolean mReselectWhenLayout = true;
    public int mRightPadding;
    public float mScrollPivotX = 0.5f;
    public HorizontalScrollView mScrollView;
    public boolean mSmoothScroll = true;
    public LinearLayout mTitleContainer;

    public CommonNavigator(Context context) {
        super(context);
        NavigatorHelper navigatorHelper = new NavigatorHelper();
        this.mNavigatorHelper = navigatorHelper;
        navigatorHelper.setNavigatorScrollListener(this);
    }

    public CommonNavigatorAdapter getAdapter() {
        return this.mAdapter;
    }

    public int getLeftPadding() {
        return this.mLeftPadding;
    }

    public IPagerIndicator getPagerIndicator() {
        return this.mIndicator;
    }

    public int getRightPadding() {
        return this.mRightPadding;
    }

    public float getScrollPivotX() {
        return this.mScrollPivotX;
    }

    public LinearLayout getTitleContainer() {
        return this.mTitleContainer;
    }

    public final void init() {
        View view;
        LinearLayout.LayoutParams layoutParams;
        removeAllViews();
        if (this.mAdjustMode) {
            view = LayoutInflater.from(getContext()).inflate(R$layout.pager_navigator_layout_no_scroll, this);
        } else {
            view = LayoutInflater.from(getContext()).inflate(R$layout.pager_navigator_layout, this);
        }
        this.mScrollView = (HorizontalScrollView) view.findViewById(R$id.scroll_view);
        LinearLayout linearLayout = (LinearLayout) view.findViewById(R$id.title_container);
        this.mTitleContainer = linearLayout;
        linearLayout.setPadding(this.mLeftPadding, 0, this.mRightPadding, 0);
        LinearLayout linearLayout2 = (LinearLayout) view.findViewById(R$id.indicator_container);
        this.mIndicatorContainer = linearLayout2;
        if (this.mIndicatorOnTop) {
            linearLayout2.getParent().bringChildToFront(this.mIndicatorContainer);
        }
        int i = this.mNavigatorHelper.mTotalCount;
        for (int i2 = 0; i2 < i; i2++) {
            IPagerTitleView titleView = this.mAdapter.getTitleView(getContext(), i2);
            if (titleView instanceof View) {
                View view2 = (View) titleView;
                if (this.mAdjustMode) {
                    layoutParams = new LinearLayout.LayoutParams(0, -1);
                    layoutParams.weight = this.mAdapter.getTitleWeight(getContext(), i2);
                } else {
                    layoutParams = new LinearLayout.LayoutParams(-2, -1);
                }
                this.mTitleContainer.addView(view2, layoutParams);
            }
        }
        CommonNavigatorAdapter commonNavigatorAdapter = this.mAdapter;
        if (commonNavigatorAdapter != null) {
            IPagerIndicator indicator = commonNavigatorAdapter.getIndicator(getContext());
            this.mIndicator = indicator;
            if (indicator instanceof View) {
                this.mIndicatorContainer.addView((View) this.mIndicator, new FrameLayout.LayoutParams(-1, -1));
            }
        }
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onAttachToMagicIndicator() {
        init();
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onDetachFromMagicIndicator() {
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        if (this.mAdapter != null) {
            this.mPositionDataList.clear();
            int i5 = this.mNavigatorHelper.mTotalCount;
            for (int i6 = 0; i6 < i5; i6++) {
                PositionData positionData = new PositionData();
                View childAt = this.mTitleContainer.getChildAt(i6);
                if (childAt != null) {
                    positionData.mLeft = childAt.getLeft();
                    positionData.mTop = childAt.getTop();
                    positionData.mRight = childAt.getRight();
                    int bottom = childAt.getBottom();
                    positionData.mBottom = bottom;
                    if (childAt instanceof IMeasurablePagerTitleView) {
                        IMeasurablePagerTitleView iMeasurablePagerTitleView = (IMeasurablePagerTitleView) childAt;
                        positionData.mContentLeft = iMeasurablePagerTitleView.getContentLeft();
                        positionData.mContentTop = iMeasurablePagerTitleView.getContentTop();
                        positionData.mContentRight = iMeasurablePagerTitleView.getContentRight();
                        positionData.mContentBottom = iMeasurablePagerTitleView.getContentBottom();
                    } else {
                        positionData.mContentLeft = positionData.mLeft;
                        positionData.mContentTop = positionData.mTop;
                        positionData.mContentRight = positionData.mRight;
                        positionData.mContentBottom = bottom;
                    }
                }
                this.mPositionDataList.add(positionData);
            }
            IPagerIndicator iPagerIndicator = this.mIndicator;
            if (iPagerIndicator != null) {
                iPagerIndicator.onPositionDataProvide(this.mPositionDataList);
            }
            if (this.mReselectWhenLayout) {
                NavigatorHelper navigatorHelper = this.mNavigatorHelper;
                if (navigatorHelper.mScrollState == 0) {
                    onPageSelected(navigatorHelper.mCurrentIndex);
                    onPageScrolled(this.mNavigatorHelper.mCurrentIndex, 0.0f, 0);
                }
            }
        }
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onPageScrollStateChanged(int i) {
        if (this.mAdapter != null) {
            this.mNavigatorHelper.mScrollState = i;
            IPagerIndicator iPagerIndicator = this.mIndicator;
            if (iPagerIndicator != null) {
                iPagerIndicator.onPageScrollStateChanged(i);
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:45:0x00ab  */
    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onPageScrolled(int i, float f, int i2) {
        IPagerIndicator iPagerIndicator;
        boolean z;
        if (this.mAdapter != null) {
            NavigatorHelper navigatorHelper = this.mNavigatorHelper;
            float f2 = ((float) i) + f;
            float f3 = navigatorHelper.mLastPositionOffsetSum;
            boolean z2 = f3 <= f2;
            if (navigatorHelper.mScrollState != 0) {
                if (f2 != f3) {
                    int i3 = i + 1;
                    if (f != 0.0f || !z2) {
                        z = true;
                    } else {
                        i3 = i - 1;
                        z = false;
                    }
                    for (int i4 = 0; i4 < navigatorHelper.mTotalCount; i4++) {
                        if (!(i4 == i || i4 == i3 || navigatorHelper.mLeavedPercents.get(i4, Float.valueOf(0.0f)).floatValue() == 1.0f)) {
                            navigatorHelper.dispatchOnLeave(i4, 1.0f, z2, true);
                        }
                    }
                    if (!z) {
                        float f4 = 1.0f - f;
                        navigatorHelper.dispatchOnLeave(i3, f4, true, false);
                        navigatorHelper.dispatchOnEnter(i, f4, true, false);
                    } else if (z2) {
                        navigatorHelper.dispatchOnLeave(i, f, true, false);
                        navigatorHelper.dispatchOnEnter(i3, f, true, false);
                    } else {
                        float f5 = 1.0f - f;
                        navigatorHelper.dispatchOnLeave(i3, f5, false, false);
                        navigatorHelper.dispatchOnEnter(i, f5, false, false);
                    }
                }
                iPagerIndicator = this.mIndicator;
                if (iPagerIndicator != null) {
                    iPagerIndicator.onPageScrolled(i, f, i2);
                }
                if (this.mScrollView != null && this.mPositionDataList.size() > 0 && i >= 0 && i < this.mPositionDataList.size() && this.mFollowTouch) {
                    int min = Math.min(this.mPositionDataList.size() - 1, i);
                    int min2 = Math.min(this.mPositionDataList.size() - 1, i + 1);
                    float horizontalCenter = ((float) this.mPositionDataList.get(min).horizontalCenter()) - (((float) this.mScrollView.getWidth()) * this.mScrollPivotX);
                    this.mScrollView.scrollTo((int) GeneratedOutlineSupport.outline0(((float) this.mPositionDataList.get(min2).horizontalCenter()) - (((float) this.mScrollView.getWidth()) * this.mScrollPivotX), horizontalCenter, f, horizontalCenter), 0);
                    return;
                }
                return;
            }
            for (int i5 = 0; i5 < navigatorHelper.mTotalCount; i5++) {
                if (i5 != navigatorHelper.mCurrentIndex) {
                    if (!navigatorHelper.mDeselectedItems.get(i5)) {
                        navigatorHelper.dispatchOnDeselected(i5);
                    }
                    if (navigatorHelper.mLeavedPercents.get(i5, Float.valueOf(0.0f)).floatValue() != 1.0f) {
                        navigatorHelper.dispatchOnLeave(i5, 1.0f, false, true);
                    }
                }
            }
            navigatorHelper.dispatchOnEnter(navigatorHelper.mCurrentIndex, 1.0f, false, true);
            navigatorHelper.dispatchOnSelected(navigatorHelper.mCurrentIndex);
            navigatorHelper.mLastPositionOffsetSum = f2;
            iPagerIndicator = this.mIndicator;
            if (iPagerIndicator != null) {
            }
            if (this.mScrollView != null) {
            }
        }
    }

    @Override // net.lucode.hackware.magicindicator.abs.IPagerNavigator
    public void onPageSelected(int i) {
        if (this.mAdapter != null) {
            NavigatorHelper navigatorHelper = this.mNavigatorHelper;
            navigatorHelper.mLastIndex = navigatorHelper.mCurrentIndex;
            navigatorHelper.mCurrentIndex = i;
            navigatorHelper.dispatchOnSelected(i);
            for (int i2 = 0; i2 < navigatorHelper.mTotalCount; i2++) {
                if (i2 != navigatorHelper.mCurrentIndex && !navigatorHelper.mDeselectedItems.get(i2)) {
                    navigatorHelper.dispatchOnDeselected(i2);
                }
            }
            IPagerIndicator iPagerIndicator = this.mIndicator;
            if (iPagerIndicator != null) {
                iPagerIndicator.onPageSelected(i);
            }
        }
    }

    public void setAdapter(CommonNavigatorAdapter commonNavigatorAdapter) {
        CommonNavigatorAdapter commonNavigatorAdapter2 = this.mAdapter;
        if (commonNavigatorAdapter2 != commonNavigatorAdapter) {
            if (commonNavigatorAdapter2 != null) {
                commonNavigatorAdapter2.mDataSetObservable.unregisterObserver(this.mObserver);
            }
            this.mAdapter = commonNavigatorAdapter;
            if (commonNavigatorAdapter != null) {
                commonNavigatorAdapter.mDataSetObservable.registerObserver(this.mObserver);
                this.mNavigatorHelper.setTotalCount(this.mAdapter.getCount());
                if (this.mTitleContainer != null) {
                    this.mAdapter.mDataSetObservable.notifyChanged();
                    return;
                }
                return;
            }
            this.mNavigatorHelper.setTotalCount(0);
            init();
        }
    }

    public void setAdjustMode(boolean z) {
        this.mAdjustMode = z;
    }

    public void setEnablePivotScroll(boolean z) {
        this.mEnablePivotScroll = z;
    }

    public void setFollowTouch(boolean z) {
        this.mFollowTouch = z;
    }

    public void setIndicatorOnTop(boolean z) {
        this.mIndicatorOnTop = z;
    }

    public void setLeftPadding(int i) {
        this.mLeftPadding = i;
    }

    public void setReselectWhenLayout(boolean z) {
        this.mReselectWhenLayout = z;
    }

    public void setRightPadding(int i) {
        this.mRightPadding = i;
    }

    public void setScrollPivotX(float f) {
        this.mScrollPivotX = f;
    }

    public void setSkimOver(boolean z) {
        this.mNavigatorHelper.mSkimOver = z;
    }

    public void setSmoothScroll(boolean z) {
        this.mSmoothScroll = z;
    }
}
