package net.lucode.hackware.magicindicator.buildins.commonnavigator.indicators;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.view.View;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.Interpolator;
import java.util.Arrays;
import java.util.List;
import kotlinx.coroutines.internal.SystemPropsKt;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.model.PositionData;

public class BezierPagerIndicator extends View implements IPagerIndicator {
    public List<Integer> mColors;
    public Interpolator mEndInterpolator = new DecelerateInterpolator();
    public float mLeftCircleRadius;
    public float mLeftCircleX;
    public float mMaxCircleRadius;
    public float mMinCircleRadius;
    public Paint mPaint;
    public Path mPath = new Path();
    public List<PositionData> mPositionDataList;
    public float mRightCircleRadius;
    public float mRightCircleX;
    public Interpolator mStartInterpolator = new AccelerateInterpolator();
    public float mYOffset;

    public BezierPagerIndicator(Context context) {
        super(context);
        Paint paint = new Paint(1);
        this.mPaint = paint;
        paint.setStyle(Paint.Style.FILL);
        this.mMaxCircleRadius = (float) SystemPropsKt.dip2px(context, 3.5d);
        this.mMinCircleRadius = (float) SystemPropsKt.dip2px(context, 2.0d);
        this.mYOffset = (float) SystemPropsKt.dip2px(context, 1.5d);
    }

    public float getMaxCircleRadius() {
        return this.mMaxCircleRadius;
    }

    public float getMinCircleRadius() {
        return this.mMinCircleRadius;
    }

    public float getYOffset() {
        return this.mYOffset;
    }

    public void onDraw(Canvas canvas) {
        canvas.drawCircle(this.mLeftCircleX, (((float) getHeight()) - this.mYOffset) - this.mMaxCircleRadius, this.mLeftCircleRadius, this.mPaint);
        canvas.drawCircle(this.mRightCircleX, (((float) getHeight()) - this.mYOffset) - this.mMaxCircleRadius, this.mRightCircleRadius, this.mPaint);
        this.mPath.reset();
        float height = (((float) getHeight()) - this.mYOffset) - this.mMaxCircleRadius;
        this.mPath.moveTo(this.mRightCircleX, height);
        this.mPath.lineTo(this.mRightCircleX, height - this.mRightCircleRadius);
        Path path = this.mPath;
        float f = this.mRightCircleX;
        float f2 = this.mLeftCircleX;
        path.quadTo(((f2 - f) / 2.0f) + f, height, f2, height - this.mLeftCircleRadius);
        this.mPath.lineTo(this.mLeftCircleX, this.mLeftCircleRadius + height);
        Path path2 = this.mPath;
        float f3 = this.mRightCircleX;
        path2.quadTo(((this.mLeftCircleX - f3) / 2.0f) + f3, height, f3, this.mRightCircleRadius + height);
        this.mPath.close();
        canvas.drawPath(this.mPath, this.mPaint);
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrollStateChanged(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrolled(int i, float f, int i2) {
        List<PositionData> list = this.mPositionDataList;
        if (list != null && !list.isEmpty()) {
            List<Integer> list2 = this.mColors;
            if (list2 != null && list2.size() > 0) {
                this.mPaint.setColor(SystemPropsKt.eval(f, this.mColors.get(Math.abs(i) % this.mColors.size()).intValue(), this.mColors.get(Math.abs(i + 1) % this.mColors.size()).intValue()));
            }
            PositionData imitativePositionData = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i);
            PositionData imitativePositionData2 = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i + 1);
            int i3 = imitativePositionData.mLeft;
            float f2 = (float) (((imitativePositionData.mRight - i3) / 2) + i3);
            int i4 = imitativePositionData2.mLeft;
            float f3 = ((float) (((imitativePositionData2.mRight - i4) / 2) + i4)) - f2;
            this.mLeftCircleX = (this.mStartInterpolator.getInterpolation(f) * f3) + f2;
            this.mRightCircleX = (this.mEndInterpolator.getInterpolation(f) * f3) + f2;
            float f4 = this.mMaxCircleRadius;
            this.mLeftCircleRadius = (this.mEndInterpolator.getInterpolation(f) * (this.mMinCircleRadius - f4)) + f4;
            float f5 = this.mMinCircleRadius;
            this.mRightCircleRadius = (this.mStartInterpolator.getInterpolation(f) * (this.mMaxCircleRadius - f5)) + f5;
            invalidate();
        }
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageSelected(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPositionDataProvide(List<PositionData> list) {
        this.mPositionDataList = list;
    }

    public void setColors(Integer... numArr) {
        this.mColors = Arrays.asList(numArr);
    }

    public void setEndInterpolator(Interpolator interpolator) {
        this.mEndInterpolator = interpolator;
        if (interpolator == null) {
            this.mEndInterpolator = new DecelerateInterpolator();
        }
    }

    public void setMaxCircleRadius(float f) {
        this.mMaxCircleRadius = f;
    }

    public void setMinCircleRadius(float f) {
        this.mMinCircleRadius = f;
    }

    public void setStartInterpolator(Interpolator interpolator) {
        this.mStartInterpolator = interpolator;
        if (interpolator == null) {
            this.mStartInterpolator = new AccelerateInterpolator();
        }
    }

    public void setYOffset(float f) {
        this.mYOffset = f;
    }
}
