package net.lucode.hackware.magicindicator.buildins.commonnavigator.indicators;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.view.View;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.Arrays;
import java.util.List;
import kotlinx.coroutines.internal.SystemPropsKt;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.model.PositionData;

public class LinePagerIndicator extends View implements IPagerIndicator {
    public List<Integer> mColors;
    public Interpolator mEndInterpolator = new LinearInterpolator();
    public float mLineHeight;
    public RectF mLineRect = new RectF();
    public float mLineWidth;
    public int mMode;
    public Paint mPaint;
    public List<PositionData> mPositionDataList;
    public float mRoundRadius;
    public Interpolator mStartInterpolator = new LinearInterpolator();
    public float mXOffset;
    public float mYOffset;

    public LinePagerIndicator(Context context) {
        super(context);
        Paint paint = new Paint(1);
        this.mPaint = paint;
        paint.setStyle(Paint.Style.FILL);
        this.mLineHeight = (float) SystemPropsKt.dip2px(context, 3.0d);
        this.mLineWidth = (float) SystemPropsKt.dip2px(context, 10.0d);
    }

    public List<Integer> getColors() {
        return this.mColors;
    }

    public Interpolator getEndInterpolator() {
        return this.mEndInterpolator;
    }

    public float getLineHeight() {
        return this.mLineHeight;
    }

    public float getLineWidth() {
        return this.mLineWidth;
    }

    public int getMode() {
        return this.mMode;
    }

    public Paint getPaint() {
        return this.mPaint;
    }

    public float getRoundRadius() {
        return this.mRoundRadius;
    }

    public Interpolator getStartInterpolator() {
        return this.mStartInterpolator;
    }

    public float getXOffset() {
        return this.mXOffset;
    }

    public float getYOffset() {
        return this.mYOffset;
    }

    public void onDraw(Canvas canvas) {
        RectF rectF = this.mLineRect;
        float f = this.mRoundRadius;
        canvas.drawRoundRect(rectF, f, f, this.mPaint);
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrollStateChanged(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrolled(int i, float f, int i2) {
        float f2;
        float f3;
        float f4;
        float f5;
        float f6;
        int i3;
        List<PositionData> list = this.mPositionDataList;
        if (list != null && !list.isEmpty()) {
            List<Integer> list2 = this.mColors;
            if (list2 != null && list2.size() > 0) {
                this.mPaint.setColor(SystemPropsKt.eval(f, this.mColors.get(Math.abs(i) % this.mColors.size()).intValue(), this.mColors.get(Math.abs(i + 1) % this.mColors.size()).intValue()));
            }
            PositionData imitativePositionData = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i);
            PositionData imitativePositionData2 = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i + 1);
            int i4 = this.mMode;
            if (i4 == 0) {
                f6 = this.mXOffset;
                f5 = ((float) imitativePositionData.mLeft) + f6;
                f4 = ((float) imitativePositionData2.mLeft) + f6;
                f2 = ((float) imitativePositionData.mRight) - f6;
                i3 = imitativePositionData2.mRight;
            } else if (i4 == 1) {
                f6 = this.mXOffset;
                f5 = ((float) imitativePositionData.mContentLeft) + f6;
                f4 = ((float) imitativePositionData2.mContentLeft) + f6;
                f2 = ((float) imitativePositionData.mContentRight) - f6;
                i3 = imitativePositionData2.mContentRight;
            } else {
                f5 = ((float) imitativePositionData.mLeft) + ((((float) imitativePositionData.width()) - this.mLineWidth) / 2.0f);
                float width = ((float) imitativePositionData2.mLeft) + ((((float) imitativePositionData2.width()) - this.mLineWidth) / 2.0f);
                f2 = ((((float) imitativePositionData.width()) + this.mLineWidth) / 2.0f) + ((float) imitativePositionData.mLeft);
                f3 = ((((float) imitativePositionData2.width()) + this.mLineWidth) / 2.0f) + ((float) imitativePositionData2.mLeft);
                f4 = width;
                this.mLineRect.left = (this.mStartInterpolator.getInterpolation(f) * (f4 - f5)) + f5;
                this.mLineRect.right = (this.mEndInterpolator.getInterpolation(f) * (f3 - f2)) + f2;
                this.mLineRect.top = (((float) getHeight()) - this.mLineHeight) - this.mYOffset;
                this.mLineRect.bottom = ((float) getHeight()) - this.mYOffset;
                invalidate();
            }
            f3 = ((float) i3) - f6;
            this.mLineRect.left = (this.mStartInterpolator.getInterpolation(f) * (f4 - f5)) + f5;
            this.mLineRect.right = (this.mEndInterpolator.getInterpolation(f) * (f3 - f2)) + f2;
            this.mLineRect.top = (((float) getHeight()) - this.mLineHeight) - this.mYOffset;
            this.mLineRect.bottom = ((float) getHeight()) - this.mYOffset;
            invalidate();
        }
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageSelected(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPositionDataProvide(List<PositionData> list) {
        this.mPositionDataList = list;
    }

    public void setColors(Integer... numArr) {
        this.mColors = Arrays.asList(numArr);
    }

    public void setEndInterpolator(Interpolator interpolator) {
        this.mEndInterpolator = interpolator;
        if (interpolator == null) {
            this.mEndInterpolator = new LinearInterpolator();
        }
    }

    public void setLineHeight(float f) {
        this.mLineHeight = f;
    }

    public void setLineWidth(float f) {
        this.mLineWidth = f;
    }

    public void setMode(int i) {
        if (i == 2 || i == 0 || i == 1) {
            this.mMode = i;
            return;
        }
        throw new IllegalArgumentException(GeneratedOutlineSupport.outline12("mode ", i, " not supported."));
    }

    public void setRoundRadius(float f) {
        this.mRoundRadius = f;
    }

    public void setStartInterpolator(Interpolator interpolator) {
        this.mStartInterpolator = interpolator;
        if (interpolator == null) {
            this.mStartInterpolator = new LinearInterpolator();
        }
    }

    public void setXOffset(float f) {
        this.mXOffset = f;
    }

    public void setYOffset(float f) {
        this.mYOffset = f;
    }
}
