package net.lucode.hackware.magicindicator.buildins.commonnavigator.indicators;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.view.View;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import java.util.List;
import kotlinx.coroutines.internal.SystemPropsKt;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.model.PositionData;

public class TriangularPagerIndicator extends View implements IPagerIndicator {
    public float mAnchorX;
    public int mLineColor;
    public int mLineHeight;
    public Paint mPaint;
    public Path mPath = new Path();
    public List<PositionData> mPositionDataList;
    public boolean mReverse;
    public Interpolator mStartInterpolator = new LinearInterpolator();
    public int mTriangleHeight;
    public int mTriangleWidth;
    public float mYOffset;

    public TriangularPagerIndicator(Context context) {
        super(context);
        Paint paint = new Paint(1);
        this.mPaint = paint;
        paint.setStyle(Paint.Style.FILL);
        this.mLineHeight = SystemPropsKt.dip2px(context, 3.0d);
        this.mTriangleWidth = SystemPropsKt.dip2px(context, 14.0d);
        this.mTriangleHeight = SystemPropsKt.dip2px(context, 8.0d);
    }

    public int getLineColor() {
        return this.mLineColor;
    }

    public int getLineHeight() {
        return this.mLineHeight;
    }

    public Interpolator getStartInterpolator() {
        return this.mStartInterpolator;
    }

    public int getTriangleHeight() {
        return this.mTriangleHeight;
    }

    public int getTriangleWidth() {
        return this.mTriangleWidth;
    }

    public float getYOffset() {
        return this.mYOffset;
    }

    public void onDraw(Canvas canvas) {
        this.mPaint.setColor(this.mLineColor);
        if (this.mReverse) {
            canvas.drawRect(0.0f, (((float) getHeight()) - this.mYOffset) - ((float) this.mTriangleHeight), (float) getWidth(), ((((float) getHeight()) - this.mYOffset) - ((float) this.mTriangleHeight)) + ((float) this.mLineHeight), this.mPaint);
        } else {
            canvas.drawRect(0.0f, ((float) (getHeight() - this.mLineHeight)) - this.mYOffset, (float) getWidth(), ((float) getHeight()) - this.mYOffset, this.mPaint);
        }
        this.mPath.reset();
        if (this.mReverse) {
            this.mPath.moveTo(this.mAnchorX - ((float) (this.mTriangleWidth / 2)), (((float) getHeight()) - this.mYOffset) - ((float) this.mTriangleHeight));
            this.mPath.lineTo(this.mAnchorX, ((float) getHeight()) - this.mYOffset);
            this.mPath.lineTo(this.mAnchorX + ((float) (this.mTriangleWidth / 2)), (((float) getHeight()) - this.mYOffset) - ((float) this.mTriangleHeight));
        } else {
            this.mPath.moveTo(this.mAnchorX - ((float) (this.mTriangleWidth / 2)), ((float) getHeight()) - this.mYOffset);
            this.mPath.lineTo(this.mAnchorX, ((float) (getHeight() - this.mTriangleHeight)) - this.mYOffset);
            this.mPath.lineTo(this.mAnchorX + ((float) (this.mTriangleWidth / 2)), ((float) getHeight()) - this.mYOffset);
        }
        this.mPath.close();
        canvas.drawPath(this.mPath, this.mPaint);
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrollStateChanged(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrolled(int i, float f, int i2) {
        List<PositionData> list = this.mPositionDataList;
        if (list != null && !list.isEmpty()) {
            PositionData imitativePositionData = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i);
            PositionData imitativePositionData2 = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i + 1);
            int i3 = imitativePositionData.mLeft;
            float f2 = (float) (((imitativePositionData.mRight - i3) / 2) + i3);
            int i4 = imitativePositionData2.mLeft;
            this.mAnchorX = (this.mStartInterpolator.getInterpolation(f) * (((float) (((imitativePositionData2.mRight - i4) / 2) + i4)) - f2)) + f2;
            invalidate();
        }
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageSelected(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPositionDataProvide(List<PositionData> list) {
        this.mPositionDataList = list;
    }

    public void setLineColor(int i) {
        this.mLineColor = i;
    }

    public void setLineHeight(int i) {
        this.mLineHeight = i;
    }

    public void setReverse(boolean z) {
        this.mReverse = z;
    }

    public void setStartInterpolator(Interpolator interpolator) {
        this.mStartInterpolator = interpolator;
        if (interpolator == null) {
            this.mStartInterpolator = new LinearInterpolator();
        }
    }

    public void setTriangleHeight(int i) {
        this.mTriangleHeight = i;
    }

    public void setTriangleWidth(int i) {
        this.mTriangleWidth = i;
    }

    public void setYOffset(float f) {
        this.mYOffset = f;
    }
}
