package net.lucode.hackware.magicindicator.buildins.commonnavigator.indicators;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.view.View;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import java.util.List;
import kotlinx.coroutines.internal.SystemPropsKt;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator;
import net.lucode.hackware.magicindicator.buildins.commonnavigator.model.PositionData;

public class WrapPagerIndicator extends View implements IPagerIndicator {
    public Interpolator mEndInterpolator = new LinearInterpolator();
    public int mFillColor;
    public int mHorizontalPadding;
    public Paint mPaint;
    public List<PositionData> mPositionDataList;
    public RectF mRect = new RectF();
    public float mRoundRadius;
    public boolean mRoundRadiusSet;
    public Interpolator mStartInterpolator = new LinearInterpolator();
    public int mVerticalPadding;

    public WrapPagerIndicator(Context context) {
        super(context);
        Paint paint = new Paint(1);
        this.mPaint = paint;
        paint.setStyle(Paint.Style.FILL);
        this.mVerticalPadding = SystemPropsKt.dip2px(context, 6.0d);
        this.mHorizontalPadding = SystemPropsKt.dip2px(context, 10.0d);
    }

    public Interpolator getEndInterpolator() {
        return this.mEndInterpolator;
    }

    public int getFillColor() {
        return this.mFillColor;
    }

    public int getHorizontalPadding() {
        return this.mHorizontalPadding;
    }

    public Paint getPaint() {
        return this.mPaint;
    }

    public float getRoundRadius() {
        return this.mRoundRadius;
    }

    public Interpolator getStartInterpolator() {
        return this.mStartInterpolator;
    }

    public int getVerticalPadding() {
        return this.mVerticalPadding;
    }

    public void onDraw(Canvas canvas) {
        this.mPaint.setColor(this.mFillColor);
        RectF rectF = this.mRect;
        float f = this.mRoundRadius;
        canvas.drawRoundRect(rectF, f, f, this.mPaint);
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrollStateChanged(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageScrolled(int i, float f, int i2) {
        List<PositionData> list = this.mPositionDataList;
        if (list != null && !list.isEmpty()) {
            PositionData imitativePositionData = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i);
            PositionData imitativePositionData2 = SystemPropsKt.getImitativePositionData(this.mPositionDataList, i + 1);
            RectF rectF = this.mRect;
            int i3 = imitativePositionData.mContentLeft;
            rectF.left = (this.mEndInterpolator.getInterpolation(f) * ((float) (imitativePositionData2.mContentLeft - i3))) + ((float) (i3 - this.mHorizontalPadding));
            RectF rectF2 = this.mRect;
            rectF2.top = (float) (imitativePositionData.mContentTop - this.mVerticalPadding);
            int i4 = imitativePositionData.mContentRight;
            rectF2.right = (this.mStartInterpolator.getInterpolation(f) * ((float) (imitativePositionData2.mContentRight - i4))) + ((float) (this.mHorizontalPadding + i4));
            RectF rectF3 = this.mRect;
            rectF3.bottom = (float) (imitativePositionData.mContentBottom + this.mVerticalPadding);
            if (!this.mRoundRadiusSet) {
                this.mRoundRadius = rectF3.height() / 2.0f;
            }
            invalidate();
        }
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPageSelected(int i) {
    }

    @Override // net.lucode.hackware.magicindicator.buildins.commonnavigator.abs.IPagerIndicator
    public void onPositionDataProvide(List<PositionData> list) {
        this.mPositionDataList = list;
    }

    public void setEndInterpolator(Interpolator interpolator) {
        this.mEndInterpolator = interpolator;
        if (interpolator == null) {
            this.mEndInterpolator = new LinearInterpolator();
        }
    }

    public void setFillColor(int i) {
        this.mFillColor = i;
    }

    public void setHorizontalPadding(int i) {
        this.mHorizontalPadding = i;
    }

    public void setRoundRadius(float f) {
        this.mRoundRadius = f;
        this.mRoundRadiusSet = true;
    }

    public void setStartInterpolator(Interpolator interpolator) {
        this.mStartInterpolator = interpolator;
        if (interpolator == null) {
            this.mStartInterpolator = new LinearInterpolator();
        }
    }

    public void setVerticalPadding(int i) {
        this.mVerticalPadding = i;
    }
}
