package net.sqlcipher;

import android.database.CharArrayBuffer;
import android.os.IBinder;
import android.os.Parcel;
import android.os.Parcelable;

public class CursorWindow extends android.database.CursorWindow implements Parcelable {
    public static final Parcelable.Creator<CursorWindow> CREATOR = new Parcelable.Creator<CursorWindow>() {
        /* class net.sqlcipher.CursorWindow.AnonymousClass1 */

        /* Return type fixed from 'java.lang.Object' to match base method */
        @Override // android.os.Parcelable.Creator
        public CursorWindow createFromParcel(Parcel parcel) {
            return new CursorWindow(parcel);
        }

        /* Return type fixed from 'java.lang.Object[]' to match base method */
        @Override // android.os.Parcelable.Creator
        public CursorWindow[] newArray(int i) {
            return new CursorWindow[i];
        }
    };
    public int mStartPos;

    public CursorWindow(Parcel parcel) {
        super(true);
        IBinder readStrongBinder = parcel.readStrongBinder();
        this.mStartPos = parcel.readInt();
        native_init(readStrongBinder);
    }

    public boolean allocRow() {
        acquireReference();
        try {
            return allocRow_native();
        } finally {
            releaseReference();
        }
    }

    public final native boolean allocRow_native();

    public void clear() {
        acquireReference();
        try {
            this.mStartPos = 0;
            native_clear();
        } finally {
            releaseReference();
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        releaseReference();
    }

    public final native void close_native();

    public void copyStringToBuffer(int i, int i2, CharArrayBuffer charArrayBuffer) {
        if (charArrayBuffer != null) {
            if (charArrayBuffer.data == null) {
                charArrayBuffer.data = new char[64];
            }
            acquireReference();
            try {
                char[] copyStringToBuffer_native = copyStringToBuffer_native(i - this.mStartPos, i2, charArrayBuffer.data.length, charArrayBuffer);
                if (copyStringToBuffer_native != null) {
                    charArrayBuffer.data = copyStringToBuffer_native;
                }
            } finally {
                releaseReference();
            }
        } else {
            throw new IllegalArgumentException("CharArrayBuffer should not be null");
        }
    }

    public final native char[] copyStringToBuffer_native(int i, int i2, int i3, CharArrayBuffer charArrayBuffer);

    public int describeContents() {
        return 0;
    }

    @Override // android.database.CursorWindow, java.lang.Object
    public void finalize() {
    }

    public void freeLastRow() {
        acquireReference();
        try {
            freeLastRow_native();
        } finally {
            releaseReference();
        }
    }

    public final native void freeLastRow_native();

    public byte[] getBlob(int i, int i2) {
        acquireReference();
        try {
            return getBlob_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native byte[] getBlob_native(int i, int i2);

    public double getDouble(int i, int i2) {
        acquireReference();
        try {
            return getDouble_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native double getDouble_native(int i, int i2);

    public float getFloat(int i, int i2) {
        acquireReference();
        try {
            return (float) getDouble_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public int getInt(int i, int i2) {
        acquireReference();
        try {
            return (int) getLong_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public long getLong(int i, int i2) {
        acquireReference();
        try {
            return getLong_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native long getLong_native(int i, int i2);

    public int getNumRows() {
        acquireReference();
        try {
            return getNumRows_native();
        } finally {
            releaseReference();
        }
    }

    public final native int getNumRows_native();

    public short getShort(int i, int i2) {
        acquireReference();
        try {
            return (short) ((int) getLong_native(i - this.mStartPos, i2));
        } finally {
            releaseReference();
        }
    }

    public int getStartPosition() {
        return this.mStartPos;
    }

    public String getString(int i, int i2) {
        acquireReference();
        try {
            return getString_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native String getString_native(int i, int i2);

    public int getType(int i, int i2) {
        acquireReference();
        try {
            return getType_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native int getType_native(int i, int i2);

    public boolean isBlob(int i, int i2) {
        acquireReference();
        try {
            return isBlob_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean isBlob_native(int i, int i2);

    public boolean isFloat(int i, int i2) {
        acquireReference();
        try {
            return isFloat_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean isFloat_native(int i, int i2);

    public final native boolean isInteger_native(int i, int i2);

    public boolean isLong(int i, int i2) {
        acquireReference();
        try {
            return isInteger_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public boolean isNull(int i, int i2) {
        acquireReference();
        try {
            return isNull_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean isNull_native(int i, int i2);

    public boolean isString(int i, int i2) {
        acquireReference();
        try {
            return isString_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean isString_native(int i, int i2);

    public final native void native_clear();

    public final native IBinder native_getBinder();

    public final native void native_init(IBinder iBinder);

    public void onAllReferencesReleased() {
        close_native();
        super.onAllReferencesReleased();
    }

    public boolean putBlob(byte[] bArr, int i, int i2) {
        acquireReference();
        try {
            return putBlob_native(bArr, i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean putBlob_native(byte[] bArr, int i, int i2);

    public boolean putDouble(double d, int i, int i2) {
        acquireReference();
        try {
            return putDouble_native(d, i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean putDouble_native(double d, int i, int i2);

    public boolean putLong(long j, int i, int i2) {
        acquireReference();
        try {
            return putLong_native(j, i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean putLong_native(long j, int i, int i2);

    public boolean putNull(int i, int i2) {
        acquireReference();
        try {
            return putNull_native(i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean putNull_native(int i, int i2);

    public boolean putString(String str, int i, int i2) {
        acquireReference();
        try {
            return putString_native(str, i - this.mStartPos, i2);
        } finally {
            releaseReference();
        }
    }

    public final native boolean putString_native(String str, int i, int i2);

    public boolean setNumColumns(int i) {
        acquireReference();
        try {
            return setNumColumns_native(i);
        } finally {
            releaseReference();
        }
    }

    public final native boolean setNumColumns_native(int i);

    public void setStartPosition(int i) {
        this.mStartPos = i;
    }

    public void writeToParcel(Parcel parcel, int i) {
        parcel.writeStrongBinder(native_getBinder());
        parcel.writeInt(this.mStartPos);
    }
}
