package net.xfkefu.sdk.adapter;

import android.content.Context;
import android.graphics.Color;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import androidx.recyclerview.widget.RecyclerView;
import java.util.List;
import net.xfkefu.sdk.R;
import net.xfkefu.sdk.a.XfStoreMerchant;
import net.xfkefu.sdk.a.XfToast;
import net.xfkefu.sdk.a.Z;
import net.xfkefu.sdk.entity.Lang;
import net.xfkefu.sdk.model.ChatRoomModel;
import net.xfkefu.sdk.retrofit.ApiCallback;

public class LangRecyclerViewAdapter extends RecyclerView.Adapter<ViewHolder> {
    private static final String TAG = "LangRecyclerViewAdapter";
    private final Context context;
    private final List<Lang> dataList;
    private final String lang;
    private final Listener listener;

    public interface Listener {
        void onSuccess();
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {
        private final Listener listener;
        private final TextView tvName;

        public ViewHolder(View view, Listener listener2) {
            super(view);
            this.listener = listener2;
            this.tvName = (TextView) view.findViewById(R.id.tv_name);
        }

        public void onBindViewHolder(final Context context, final Lang lang, String str) {
            this.tvName.setText(lang.name);
            if (lang.code.equals(str)) {
                this.tvName.setTextColor(Color.parseColor("#348FEA"));
            } else {
                this.tvName.setTextColor(Color.parseColor("#000000"));
            }
            this.tvName.setOnClickListener(new View.OnClickListener() {
                /* class net.xfkefu.sdk.adapter.LangRecyclerViewAdapter.ViewHolder.AnonymousClass1 */

                public void onClick(View view) {
                    new ChatRoomModel().changeRoomLang(Z.MERCHANT_ID, XfStoreMerchant.getString(XfStoreMerchant.USER_INFO), lang.code, new ApiCallback<String>() {
                        /* class net.xfkefu.sdk.adapter.LangRecyclerViewAdapter.ViewHolder.AnonymousClass1.AnonymousClass1 */

                        @Override // net.xfkefu.sdk.retrofit.ApiCallback
                        public void onFailed(String str, final String str2) {
                            ViewHolder.this.tvName.post(new Runnable() {
                                /* class net.xfkefu.sdk.adapter.LangRecyclerViewAdapter.ViewHolder.AnonymousClass1.AnonymousClass1.AnonymousClass2 */

                                public void run() {
                                    XfToast.show(context, str2);
                                }
                            });
                        }

                        public void onSuccess(String str) {
                            XfStoreMerchant.setString(XfStoreMerchant.LANG, lang.code);
                            if (ViewHolder.this.listener != null) {
                                ViewHolder.this.tvName.post(new Runnable() {
                                    /* class net.xfkefu.sdk.adapter.LangRecyclerViewAdapter.ViewHolder.AnonymousClass1.AnonymousClass1.AnonymousClass1 */

                                    public void run() {
                                        ViewHolder.this.listener.onSuccess();
                                    }
                                });
                            }
                        }
                    });
                }
            });
        }
    }

    public LangRecyclerViewAdapter(Context context2, List<Lang> list, String str, Listener listener2) {
        this.context = context2;
        this.dataList = list;
        this.lang = str;
        this.listener = listener2;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        List<Lang> list = this.dataList;
        if (list == null) {
            return 0;
        }
        return list.size();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public long getItemId(int i) {
        return (long) i;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemViewType(int i) {
        return i;
    }

    public void onBindViewHolder(ViewHolder viewHolder, int i) {
        viewHolder.onBindViewHolder(this.context, this.dataList.get(i), this.lang);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        return new ViewHolder(LayoutInflater.from(this.context).inflate(R.layout.kefu_item_lang, viewGroup, false), this.listener);
    }
}
