package net.xfkefu.sdk.encrypt;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.ByteArrayOutputStream;
import java.security.KeyFactory;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.NoSuchAlgorithmException;
import java.security.interfaces.RSAPrivateKey;
import java.security.interfaces.RSAPublicKey;
import java.security.spec.PKCS8EncodedKeySpec;
import java.security.spec.X509EncodedKeySpec;
import java.util.HashMap;
import java.util.Map;
import javax.crypto.Cipher;

public class RSAUtilsAndroid {
    public static final String CHARSET = "UTF-8";
    public static final String COMMON_RSA = "RSA/ECB/PKCS1Padding";
    public static final String RSA_ALGORITHM = "RSA";

    public static Map<String, String> createKeys(int i) {
        try {
            KeyPairGenerator instance = KeyPairGenerator.getInstance("RSA");
            instance.initialize(i);
            KeyPair generateKeyPair = instance.generateKeyPair();
            String encode = Base64Utils.encode(generateKeyPair.getPublic().getEncoded());
            String encode2 = Base64Utils.encode(generateKeyPair.getPrivate().getEncoded());
            HashMap hashMap = new HashMap();
            hashMap.put("publicKey", encode);
            hashMap.put("privateKey", encode2);
            return hashMap;
        } catch (NoSuchAlgorithmException unused) {
            throw new IllegalArgumentException("No such algorithm-->[RSA]");
        }
    }

    public static Map<String, String> genKeyPair() {
        return createKeys(1024);
    }

    public static RSAPrivateKey getPrivateKey(String str) {
        return (RSAPrivateKey) KeyFactory.getInstance("RSA").generatePrivate(new PKCS8EncodedKeySpec(Base64Utils.decode(str)));
    }

    public static RSAPublicKey getPublicKey(String str) {
        return (RSAPublicKey) KeyFactory.getInstance("RSA").generatePublic(new X509EncodedKeySpec(Base64Utils.decode(str)));
    }

    public static String privateDecrypt(String str, String str2) {
        try {
            return privateDecrypt(str, getPrivateKey(str2));
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("解密字符串[", str, "]时遇到异常"), e);
        }
    }

    public static String privateEncrypt(String str, String str2) {
        try {
            return privateEncrypt(str, getPrivateKey(str2));
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("加密字符串[", str, "]时遇到异常"), e);
        }
    }

    public static String publicDecrypt(String str, String str2) {
        try {
            return publicDecrypt(str, getPublicKey(str2));
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("解密字符串[", str, "]时遇到异常"), e);
        }
    }

    public static String publicEncrypt(String str, String str2) {
        try {
            return publicEncrypt(str, getPublicKey(str2));
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("加密字符串[", str, "]时遇到异常"), e);
        }
    }

    private static byte[] rsaSplitCodec(Cipher cipher, int i, byte[] bArr, int i2) {
        int i3;
        byte[] bArr2;
        if (i == 2) {
            i3 = i2 / 8;
        } else {
            i3 = (i2 / 8) - 11;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        int i4 = 0;
        int i5 = 0;
        while (bArr.length > i4) {
            try {
                if (bArr.length - i4 > i3) {
                    bArr2 = cipher.doFinal(bArr, i4, i3);
                } else {
                    bArr2 = cipher.doFinal(bArr, i4, bArr.length - i4);
                }
                byteArrayOutputStream.write(bArr2, 0, bArr2.length);
                i5++;
                i4 = i5 * i3;
            } catch (Exception e) {
                throw new RuntimeException(GeneratedOutlineSupport.outline12("加解密阀值为[", i3, "]的数据时发生异常"), e);
            }
        }
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        try {
            byteArrayOutputStream.flush();
            byteArrayOutputStream.close();
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        return byteArray;
    }

    public static String privateDecrypt(String str, RSAPrivateKey rSAPrivateKey) {
        try {
            Cipher instance = Cipher.getInstance(COMMON_RSA);
            instance.init(2, rSAPrivateKey);
            return new String(rsaSplitCodec(instance, 2, Base64Utils.decode(str), rSAPrivateKey.getModulus().bitLength()), "UTF-8");
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("解密字符串[", str, "]时遇到异常"), e);
        }
    }

    public static String privateEncrypt(String str, RSAPrivateKey rSAPrivateKey) {
        try {
            Cipher instance = Cipher.getInstance(COMMON_RSA);
            instance.init(1, rSAPrivateKey);
            return Base64Utils.encode(rsaSplitCodec(instance, 1, str.getBytes("UTF-8"), rSAPrivateKey.getModulus().bitLength()));
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("加密字符串[", str, "]时遇到异常"), e);
        }
    }

    public static String publicDecrypt(String str, RSAPublicKey rSAPublicKey) {
        try {
            Cipher instance = Cipher.getInstance(COMMON_RSA);
            instance.init(2, rSAPublicKey);
            return new String(rsaSplitCodec(instance, 2, Base64Utils.decode(str), rSAPublicKey.getModulus().bitLength()), "UTF-8");
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("解密字符串[", str, "]时遇到异常"), e);
        }
    }

    private static String publicEncrypt(String str, RSAPublicKey rSAPublicKey) {
        try {
            Cipher instance = Cipher.getInstance(COMMON_RSA);
            instance.init(1, rSAPublicKey);
            return Base64Utils.encode(rsaSplitCodec(instance, 1, str.getBytes("UTF-8"), rSAPublicKey.getModulus().bitLength()));
        } catch (Exception e) {
            throw new RuntimeException(GeneratedOutlineSupport.outline19("加密字符串[", str, "]时遇到异常"), e);
        }
    }
}
