package net.xfkefu.sdk.socket;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.etc.commons.im.protobuf.ProtocolBase;
import io.netty.bootstrap.Bootstrap;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelInboundHandlerAdapter;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelOption;
import io.netty.channel.ChannelOutboundHandlerAdapter;
import io.netty.channel.ChannelPipeline;
import io.netty.channel.ChannelPromise;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioSocketChannel;
import io.netty.handler.codec.protobuf.ProtobufDecoder;
import io.netty.handler.codec.protobuf.ProtobufEncoder;
import io.netty.handler.codec.protobuf.ProtobufVarint32FrameDecoder;
import io.netty.handler.codec.protobuf.ProtobufVarint32LengthFieldPrepender;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import java.net.InetSocketAddress;
import java.util.Timer;
import java.util.TimerTask;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import net.xfkefu.sdk.a.XfLog;
import net.xfkefu.sdk.a.XfStoreMerchant;
import net.xfkefu.sdk.a.Z;
import net.xfkefu.sdk.im.MessageBuilderHelper;

public class SocketClient implements INettyClient {
    private static final String TAG;
    private final Bootstrap bootstrap;
    private ChannelHandlerContext channelHandlerContext;
    private final ExecutorService executor = Executors.newSingleThreadExecutor();
    private final NioEventLoopGroup group;
    private String host;
    private final int port;
    private final INettyResponse response;
    private final String tag;

    public class NettyClientInboundHandler extends ChannelInboundHandlerAdapter {
        public final TimerTask task;
        public Timer timer;

        private NettyClientInboundHandler() {
            this.task = new TimerTask() {
                /* class net.xfkefu.sdk.socket.SocketClient.NettyClientInboundHandler.AnonymousClass1 */

                public void run() {
                    String string = XfStoreMerchant.getString(XfStoreMerchant.USER_INFO);
                    if (string != null) {
                        SocketClient.this.sendMessage(MessageBuilderHelper.buildKeepAliveRequest(SocketManager.DEVICE_ID, SocketManager.SDK_VERSION, XfStoreMerchant.getLong(XfStoreMerchant.DATA_CENTER_ID), Z.MERCHANT_ID, string));
                    }
                }
            };
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelActive(ChannelHandlerContext channelHandlerContext) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Inbound channelActive 连接成功 ");
            outline25.append(channelHandlerContext.channel().isOpen());
            XfLog.debug(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
            channelHandlerContext.channel().config().setWriteBufferHighWaterMark(10485760);
            SocketClient.this.channelHandlerContext = channelHandlerContext;
            SocketClient.this.response.connected();
            Timer timer2 = new Timer();
            this.timer = timer2;
            timer2.schedule(this.task, 0, 15000);
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelInactive(ChannelHandlerContext channelHandlerContext) {
            super.channelInactive(channelHandlerContext);
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Inbound channelInactive 连接断开 ");
            outline25.append(channelHandlerContext.channel().isOpen());
            XfLog.debug(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
            Timer timer2 = this.timer;
            if (timer2 != null) {
                timer2.cancel();
            }
            SocketClient.this.response.disconnected();
            SocketClient.this.channelHandlerContext = null;
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelRead(ChannelHandlerContext channelHandlerContext, Object obj) {
            final ProtocolBase.Message message = (ProtocolBase.Message) obj;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Inbound recvMessage cmd=");
            outline25.append(message.getCmd());
            outline25.append(" sequence=");
            outline25.append(message.getSequence());
            outline25.append(" uuid=");
            outline25.append(message.getMessageUUID());
            outline25.append(" msgId=");
            outline25.append(message.getMessageId());
            outline25.append(" isOpen=");
            outline25.append(SocketClient.this.isOpen());
            XfLog.debug(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
            SocketClient.this.executor.execute(new Runnable() {
                /* class net.xfkefu.sdk.socket.SocketClient.NettyClientInboundHandler.AnonymousClass2 */

                public void run() {
                    SocketClient.this.response.recvMessage(message);
                }
            });
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelReadComplete(ChannelHandlerContext channelHandlerContext) {
            super.channelReadComplete(channelHandlerContext);
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelRegistered(ChannelHandlerContext channelHandlerContext) {
            super.channelRegistered(channelHandlerContext);
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelUnregistered(ChannelHandlerContext channelHandlerContext) {
            super.channelUnregistered(channelHandlerContext);
        }

        @Override // io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler
        public void channelWritabilityChanged(ChannelHandlerContext channelHandlerContext) {
            super.channelWritabilityChanged(channelHandlerContext);
        }

        @Override // io.netty.channel.ChannelHandlerAdapter, io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler, io.netty.channel.ChannelHandler
        public void exceptionCaught(ChannelHandlerContext channelHandlerContext, Throwable th) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Inbound exceptionCaught ");
            outline25.append(th.getMessage());
            XfLog.error(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
            super.exceptionCaught(channelHandlerContext, th);
            channelHandlerContext.close();
        }
    }

    public class NettyClientInitializer extends ChannelInitializer<SocketChannel> {
        private NettyClientInitializer() {
        }

        @Override // io.netty.channel.ChannelInitializer, io.netty.channel.ChannelHandlerAdapter, io.netty.channel.ChannelInboundHandlerAdapter, io.netty.channel.ChannelInboundHandler, io.netty.channel.ChannelHandler
        public void exceptionCaught(ChannelHandlerContext channelHandlerContext, Throwable th) {
            super.exceptionCaught(channelHandlerContext, th);
        }

        public void initChannel(SocketChannel socketChannel) {
            ChannelPipeline pipeline = socketChannel.pipeline();
            pipeline.addLast(new ProtobufVarint32FrameDecoder());
            pipeline.addLast(new ProtobufDecoder(ProtocolBase.Message.getDefaultInstance()));
            pipeline.addLast(new NettyClientInboundHandler());
            pipeline.addLast(new ProtobufVarint32LengthFieldPrepender());
            pipeline.addLast(new ProtobufEncoder());
            pipeline.addLast(new NettyClientOutboundHandler());
        }
    }

    public class NettyClientOutboundHandler extends ChannelOutboundHandlerAdapter {
        private NettyClientOutboundHandler() {
        }

        @Override // io.netty.channel.ChannelOutboundHandlerAdapter, io.netty.channel.ChannelOutboundHandler
        public void flush(ChannelHandlerContext channelHandlerContext) {
            super.flush(channelHandlerContext);
            XfLog.debug(SocketClient.TAG + SocketClient.this.tag, "Outbound flush ");
        }

        @Override // io.netty.channel.ChannelOutboundHandlerAdapter, io.netty.channel.ChannelOutboundHandler
        public void write(ChannelHandlerContext channelHandlerContext, Object obj, ChannelPromise channelPromise) {
            super.write(channelHandlerContext, obj, channelPromise);
            ProtocolBase.Message message = (ProtocolBase.Message) obj;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Outbound sendMessage cmd=");
            outline25.append(message.getCmd());
            outline25.append(" sequence=");
            outline25.append(message.getSequence());
            outline25.append(" uuid=");
            outline25.append(message.getMessageUUID());
            XfLog.debug(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
        }
    }

    static {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Netty_");
        outline25.append(SocketClient.class.getSimpleName());
        TAG = outline25.toString();
    }

    public SocketClient(String str, String str2, int i, INettyResponse iNettyResponse) {
        this.tag = str;
        this.host = str2;
        this.port = i;
        this.response = iNettyResponse;
        NioEventLoopGroup nioEventLoopGroup = new NioEventLoopGroup();
        this.group = nioEventLoopGroup;
        Bootstrap bootstrap2 = (Bootstrap) new Bootstrap().group(nioEventLoopGroup);
        this.bootstrap = bootstrap2;
        bootstrap2.channel(NioSocketChannel.class);
        ChannelOption<Boolean> channelOption = ChannelOption.SO_REUSEADDR;
        Boolean bool = Boolean.TRUE;
        bootstrap2.option(channelOption, bool);
        bootstrap2.option(ChannelOption.TCP_NODELAY, bool);
        bootstrap2.option(ChannelOption.SO_KEEPALIVE, bool);
        bootstrap2.option(ChannelOption.SO_RCVBUF, 10485760);
        bootstrap2.option(ChannelOption.SO_SNDBUF, 10485760);
        bootstrap2.handler(new NettyClientInitializer());
    }

    @Override // net.xfkefu.sdk.socket.INettyClient
    public void close() {
        try {
            Thread.sleep(500);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        this.channelHandlerContext.channel().close();
    }

    public void connect() {
        if (this.host != null) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("connect ");
            outline25.append(this.host);
            XfLog.debug(TAG + this.tag, outline25.toString());
            new Thread() {
                /* class net.xfkefu.sdk.socket.SocketClient.AnonymousClass2 */

                /* JADX WARN: Type inference failed for: r1v4, types: [io.netty.channel.ChannelFuture] */
                /* JADX WARNING: Unknown variable types count: 1 */
                public void run() {
                    try {
                        InetSocketAddress inetSocketAddress = new InetSocketAddress(SocketClient.this.host, SocketClient.this.port);
                        XfLog.error(SocketClient.TAG + SocketClient.this.tag, "connect " + inetSocketAddress.toString());
                        SocketClient.this.bootstrap.connect(inetSocketAddress).sync().await();
                    } catch (Exception e) {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("connect ");
                        outline25.append(e.getMessage());
                        XfLog.error(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
                        SocketClient.this.response.disconnected();
                    }
                }
            }.start();
        }
    }

    @Override // net.xfkefu.sdk.socket.INettyClient
    public boolean isOpen() {
        ChannelHandlerContext channelHandlerContext2 = this.channelHandlerContext;
        if (channelHandlerContext2 != null) {
            return channelHandlerContext2.channel().isActive();
        }
        return false;
    }

    @Override // net.xfkefu.sdk.socket.INettyClient
    public void sendMessage(final ProtocolBase.Message message) {
        String str = TAG + this.tag;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("sendMessage cmd=");
        outline25.append(message.getCmd());
        outline25.append(" sequence=");
        outline25.append(message.getSequence());
        outline25.append(" uuid=");
        outline25.append(message.getMessageUUID());
        outline25.append(" isOpen=");
        outline25.append(isOpen());
        outline25.append(" isWritable=");
        ChannelHandlerContext channelHandlerContext2 = this.channelHandlerContext;
        outline25.append(channelHandlerContext2 != null && channelHandlerContext2.channel().isWritable());
        XfLog.debug(str, outline25.toString());
        ChannelHandlerContext channelHandlerContext3 = this.channelHandlerContext;
        if (channelHandlerContext3 != null && channelHandlerContext3.channel().isWritable() && isOpen()) {
            this.channelHandlerContext.channel().writeAndFlush(message).addListener((GenericFutureListener<? extends Future<? super Void>>) new ChannelFutureListener() {
                /* class net.xfkefu.sdk.socket.SocketClient.AnonymousClass1 */

                public void operationComplete(ChannelFuture channelFuture) {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("sendMessage cmd=");
                    outline25.append(message.getCmd());
                    outline25.append(" sequence=");
                    outline25.append(message.getSequence());
                    outline25.append(" uuid=");
                    outline25.append(message.getMessageUUID());
                    outline25.append(" isSuccess=");
                    outline25.append(channelFuture.isSuccess());
                    XfLog.debug(SocketClient.TAG + SocketClient.this.tag, outline25.toString());
                }
            });
        }
    }

    public void shutdown() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("shutdown group.isShutdown()=");
        outline25.append(this.group.isShutdown());
        XfLog.error(TAG + this.tag, outline25.toString());
        if (!this.group.isShutdown()) {
            this.group.shutdownGracefully();
        }
        this.host = null;
    }

    public void start() {
        XfLog.debug(TAG + this.tag, "start");
        connect();
    }
}
