package net.xfkefu.sdk.viewholder;

import android.content.Intent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.TextView;
import androidx.fragment.app.FragmentActivity;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import net.xfkefu.sdk.R;
import net.xfkefu.sdk.a.Z;
import net.xfkefu.sdk.adapter.CommonProblemListViewAdapter;
import net.xfkefu.sdk.entity.ChatMessage;
import net.xfkefu.sdk.entity.CommonProblem;
import net.xfkefu.sdk.model.CommonProblemModel;
import net.xfkefu.sdk.ui.WebViewActivity;

public class CommonProblemViewHolder extends MessageItemViewHolder {
    private final ListView lvProblem;
    private final TextView tvTitle;

    public CommonProblemViewHolder(View view) {
        super(view);
        this.tvTitle = (TextView) view.findViewById(R.id.tv_title);
        this.lvProblem = (ListView) view.findViewById(R.id.lv_problem);
    }

    @Override // net.xfkefu.sdk.viewholder.MessageItemViewHolder
    public void onBindViewHolder(final FragmentActivity fragmentActivity, ChatMessage chatMessage, boolean z) {
        long j;
        final CommonProblemListViewAdapter commonProblemListViewAdapter = new CommonProblemListViewAdapter(fragmentActivity);
        this.lvProblem.setAdapter((ListAdapter) commonProblemListViewAdapter);
        this.lvProblem.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            /* class net.xfkefu.sdk.viewholder.CommonProblemViewHolder.AnonymousClass1 */

            @Override // android.widget.AdapterView.OnItemClickListener
            public void onItemClick(AdapterView<?> adapterView, View view, int i, long j) {
                CommonProblem item = commonProblemListViewAdapter.getItem(i);
                if (item.hasChild) {
                    Intent intent = new Intent(Z.COMMON_PROBLEM_ACTION);
                    intent.putExtra("parent", item.id);
                    LocalBroadcastManager.getInstance(fragmentActivity).sendBroadcast(intent);
                    return;
                }
                FragmentActivity fragmentActivity = fragmentActivity;
                fragmentActivity.startActivity(WebViewActivity.getIntent(fragmentActivity, item.link));
            }
        });
        CommonProblemModel commonProblemModel = new CommonProblemModel();
        try {
            j = Long.parseLong(chatMessage.content);
        } catch (NumberFormatException unused) {
            j = 0;
        }
        if (j == 0) {
            this.tvTitle.setText("猜你想问（热门问题）");
        } else {
            this.tvTitle.setText(commonProblemModel.getById(j).question);
        }
        commonProblemListViewAdapter.setData(commonProblemModel.listByParent(j));
        setListViewHeight(this.lvProblem);
    }

    public void setListViewHeight(ListView listView) {
        ListAdapter adapter = listView.getAdapter();
        if (adapter != null) {
            int i = 0;
            for (int i2 = 0; i2 < adapter.getCount(); i2++) {
                View view = adapter.getView(i2, null, listView);
                view.measure(0, 0);
                i += view.getMeasuredHeight();
            }
            ViewGroup.LayoutParams layoutParams = listView.getLayoutParams();
            layoutParams.height = ((adapter.getCount() - 1) * listView.getDividerHeight()) + i;
            listView.setLayoutParams(layoutParams);
        }
    }
}
