package net.xfkefu.sdk.viewmodel;

import android.content.Context;
import androidx.lifecycle.MutableLiveData;
import java.util.List;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import net.xfkefu.sdk.a.ChatRoomHelper;
import net.xfkefu.sdk.a.XfLog;
import net.xfkefu.sdk.a.XfStoreMerchant;
import net.xfkefu.sdk.a.Z;
import net.xfkefu.sdk.entity.ChatMessage;
import net.xfkefu.sdk.entity.ChatRoom;
import net.xfkefu.sdk.entity.KefuInfo;
import net.xfkefu.sdk.entity.MerchantInfo;
import net.xfkefu.sdk.entity.MerchantSetting;
import net.xfkefu.sdk.entity.QuestionAnswer;
import net.xfkefu.sdk.entity.Skill;
import net.xfkefu.sdk.model.ChatMessageModel;
import net.xfkefu.sdk.model.ChatRoomModel;
import net.xfkefu.sdk.model.CommonProblemModel;
import net.xfkefu.sdk.model.KefuModel;
import net.xfkefu.sdk.model.MerchantModel;
import net.xfkefu.sdk.model.QuestionModel;
import net.xfkefu.sdk.retrofit.ApiCallback;
import net.xfkefu.sdk.service.SocketService;
import net.xfkefu.sdk.socket.SocketManager;

public class KefuViewModel extends BaseViewModel {
    private static final String TAG = "KefuViewModel";
    private final ChatMessageModel chatMessageModel = new ChatMessageModel();
    private final ChatRoomModel chatRoomModel = new ChatRoomModel();
    private final CommonProblemModel commonProblemModel = new CommonProblemModel();
    private final ExecutorService executorService = Executors.newSingleThreadExecutor();
    public MutableLiveData<ChatRoom> initLiveData = new MutableLiveData<>();
    public MutableLiveData<KefuInfo> kefuInfoLiveData = new MutableLiveData<>();
    private final KefuModel kefuModel = new KefuModel();
    public MutableLiveData<List<Skill>> kefuTypeLiveData = new MutableLiveData<>();
    private final MerchantModel merchantModel = new MerchantModel();
    public MutableLiveData<List<ChatMessage>> messageLiveData = new MutableLiveData<>();
    public MutableLiveData<List<QuestionAnswer>> questionBarLiveData = new MutableLiveData<>();
    public MutableLiveData<QuestionAnswer> questionLiveData = new MutableLiveData<>();
    private final QuestionModel questionModel = new QuestionModel();
    public MutableLiveData<MerchantSetting> settingLiveData = new MutableLiveData<>();

    public boolean addChatMessage(ChatMessage chatMessage) {
        return this.chatMessageModel.dbAddChatMessage(chatMessage);
    }

    public void changeMessageStatus(String str, int i) {
        this.chatMessageModel.dbUpdateStatus(str, i);
    }

    public void getHistoryMessage(String str) {
        this.messageLiveData.postValue(this.chatMessageModel.dbGetByRoom(str));
    }

    public void getKefuInfo(long j, String str) {
        this.kefuModel.kefuInfo(j, str, new ApiCallback<KefuInfo>() {
            /* class net.xfkefu.sdk.viewmodel.KefuViewModel.AnonymousClass3 */

            @Override // net.xfkefu.sdk.retrofit.ApiCallback
            public void onFailed(String str, String str2) {
            }

            public void onSuccess(KefuInfo kefuInfo) {
                KefuViewModel.this.kefuInfoLiveData.postValue(kefuInfo);
            }
        });
    }

    public void getKefuTypeList(long j) {
        this.kefuModel.skillList(j, new ApiCallback<List<Skill>>() {
            /* class net.xfkefu.sdk.viewmodel.KefuViewModel.AnonymousClass4 */

            @Override // net.xfkefu.sdk.retrofit.ApiCallback
            public void onFailed(String str, String str2) {
            }

            public void onSuccess(List<Skill> list) {
                KefuViewModel.this.kefuTypeLiveData.postValue(list);
            }
        });
    }

    public void getQuestionList(long j, long j2, final long j3, final String str) {
        this.questionModel.getQuestion(j, j2, j3, new ApiCallback<List<QuestionAnswer>>() {
            /* class net.xfkefu.sdk.viewmodel.KefuViewModel.AnonymousClass5 */

            @Override // net.xfkefu.sdk.retrofit.ApiCallback
            public void onFailed(String str, String str2) {
                XfLog.error(str, str2);
            }

            public void onSuccess(List<QuestionAnswer> list) {
                if (!list.isEmpty()) {
                    QuestionAnswer questionAnswer = new QuestionAnswer();
                    questionAnswer.id = j3;
                    questionAnswer.question = str;
                    questionAnswer.childs = list;
                    KefuViewModel.this.questionLiveData.postValue(questionAnswer);
                }
            }
        });
    }

    public void getSettingByMchId(long j) {
        this.merchantModel.getSettingByMchId(j, new ApiCallback<MerchantSetting>() {
            /* class net.xfkefu.sdk.viewmodel.KefuViewModel.AnonymousClass1 */

            @Override // net.xfkefu.sdk.retrofit.ApiCallback
            public void onFailed(String str, String str2) {
            }

            public void onSuccess(MerchantSetting merchantSetting) {
                KefuViewModel.this.settingLiveData.postValue(merchantSetting);
            }
        });
    }

    public void getSettingByMchKey(String str) {
        this.merchantModel.getSettingByMchKey(str, new ApiCallback<MerchantSetting>() {
            /* class net.xfkefu.sdk.viewmodel.KefuViewModel.AnonymousClass2 */

            @Override // net.xfkefu.sdk.retrofit.ApiCallback
            public void onFailed(String str, String str2) {
            }

            public void onSuccess(MerchantSetting merchantSetting) {
                KefuViewModel.this.settingLiveData.postValue(merchantSetting);
            }
        });
    }

    public void init(Context context) {
        String string = XfStoreMerchant.getString(XfStoreMerchant.MERCHANT_KEY);
        String string2 = XfStoreMerchant.getString(XfStoreMerchant.USER_INFO);
        XfStoreMerchant.getString(XfStoreMerchant.USER_NAME);
        this.executorService.execute(new Runnable(string, string2, context) {
            /* class net.xfkefu.sdk.viewmodel.$$Lambda$KefuViewModel$dDVKpaK8d9JjcQE1GzGmy8jc3f8 */
            public final /* synthetic */ String f$1;
            public final /* synthetic */ String f$2;
            public final /* synthetic */ Context f$3;

            {
                this.f$1 = r2;
                this.f$2 = r3;
                this.f$3 = r4;
            }

            public final void run() {
                KefuViewModel.this.lambda$init$0$KefuViewModel(this.f$1, this.f$2, this.f$3);
            }
        });
    }

    public /* synthetic */ void lambda$init$0$KefuViewModel(String str, String str2, Context context) {
        MerchantInfo info = this.merchantModel.getInfo(str);
        if (info == null) {
            this.initLiveData.postValue(null);
            return;
        }
        long j = info.merchantId;
        Z.MERCHANT_ID = j;
        XfStoreMerchant.setLong(XfStoreMerchant.DATA_CENTER_ID, info.dataCenterId);
        XfStoreMerchant.setString(XfStoreMerchant.INTRODUCE, info.meetWord);
        ChatRoom queryChatRoom = this.chatRoomModel.queryChatRoom(ChatRoomHelper.genRoomCode(info.dataCenterId, j, str2));
        if (queryChatRoom != null) {
            XfStoreMerchant.setRoomCode(queryChatRoom.chatRoomCode);
            XfStoreMerchant.setString(XfStoreMerchant.KEFU_INFO, queryChatRoom.customerInfo);
            XfStoreMerchant.setLong(XfStoreMerchant.KEFU_TYPE, (long) queryChatRoom.userTypeLong);
        } else {
            XfStoreMerchant.setString(XfStoreMerchant.KEFU_INFO, null);
            XfStoreMerchant.setLong(XfStoreMerchant.KEFU_TYPE, 0);
            queryChatRoom = new ChatRoom();
        }
        SocketManager.init(XfStoreMerchant.getString(XfStoreMerchant.DEVICE_ID), Z.SDK_VERSION);
        context.startService(SocketService.getIntent(context));
        this.initLiveData.postValue(queryChatRoom);
    }
}
