package okhttp3;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.net.Proxy;
import java.net.ProxySelector;
import java.util.List;
import java.util.Objects;
import javax.net.SocketFactory;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLSocketFactory;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.HttpUrl;
import okhttp3.internal.Util;

/* compiled from: Address.kt */
public final class Address {
    public final CertificatePinner certificatePinner;
    public final List<ConnectionSpec> connectionSpecs;
    public final Dns dns;
    public final HostnameVerifier hostnameVerifier;
    public final List<Protocol> protocols;
    public final Proxy proxy = null;
    public final Authenticator proxyAuthenticator;
    public final ProxySelector proxySelector;
    public final SocketFactory socketFactory;
    public final SSLSocketFactory sslSocketFactory;
    public final HttpUrl url;

    public Address(String str, int i, Dns dns2, SocketFactory socketFactory2, SSLSocketFactory sSLSocketFactory, HostnameVerifier hostnameVerifier2, CertificatePinner certificatePinner2, Authenticator authenticator, Proxy proxy2, List<? extends Protocol> list, List<ConnectionSpec> list2, ProxySelector proxySelector2) {
        Intrinsics.checkNotNullParameter(str, "uriHost");
        Intrinsics.checkNotNullParameter(dns2, "dns");
        Intrinsics.checkNotNullParameter(socketFactory2, "socketFactory");
        Intrinsics.checkNotNullParameter(authenticator, "proxyAuthenticator");
        Intrinsics.checkNotNullParameter(list, "protocols");
        Intrinsics.checkNotNullParameter(list2, "connectionSpecs");
        Intrinsics.checkNotNullParameter(proxySelector2, "proxySelector");
        this.dns = dns2;
        this.socketFactory = socketFactory2;
        this.sslSocketFactory = sSLSocketFactory;
        this.hostnameVerifier = hostnameVerifier2;
        this.certificatePinner = certificatePinner2;
        this.proxyAuthenticator = authenticator;
        this.proxySelector = proxySelector2;
        HttpUrl.Builder builder = new HttpUrl.Builder();
        String str2 = sSLSocketFactory != null ? "https" : "http";
        Intrinsics.checkNotNullParameter(str2, "scheme");
        boolean z = true;
        if (StringsKt__IndentKt.equals(str2, "http", true)) {
            builder.scheme = "http";
        } else if (StringsKt__IndentKt.equals(str2, "https", true)) {
            builder.scheme = "https";
        } else {
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("unexpected scheme: ", str2));
        }
        Intrinsics.checkNotNullParameter(str, "host");
        String canonicalHost = SystemPropsKt.toCanonicalHost(HttpUrl.Companion.percentDecode$okhttp$default(HttpUrl.Companion, str, 0, 0, false, 7));
        if (canonicalHost != null) {
            builder.host = canonicalHost;
            if ((1 > i || 65535 < i) ? false : z) {
                builder.port = i;
                this.url = builder.build();
                this.protocols = Util.toImmutableList(list);
                this.connectionSpecs = Util.toImmutableList(list2);
                return;
            }
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline11("unexpected port: ", i).toString());
        }
        throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("unexpected host: ", str));
    }

    public boolean equals(Object obj) {
        if (obj instanceof Address) {
            Address address = (Address) obj;
            return Intrinsics.areEqual(this.url, address.url) && equalsNonHost$okhttp(address);
        }
    }

    public final boolean equalsNonHost$okhttp(Address address) {
        Intrinsics.checkNotNullParameter(address, "that");
        return Intrinsics.areEqual(this.dns, address.dns) && Intrinsics.areEqual(this.proxyAuthenticator, address.proxyAuthenticator) && Intrinsics.areEqual(this.protocols, address.protocols) && Intrinsics.areEqual(this.connectionSpecs, address.connectionSpecs) && Intrinsics.areEqual(this.proxySelector, address.proxySelector) && Intrinsics.areEqual(this.proxy, address.proxy) && Intrinsics.areEqual(this.sslSocketFactory, address.sslSocketFactory) && Intrinsics.areEqual(this.hostnameVerifier, address.hostnameVerifier) && Intrinsics.areEqual(this.certificatePinner, address.certificatePinner) && this.url.port == address.url.port;
    }

    public int hashCode() {
        int hashCode = this.dns.hashCode();
        int hashCode2 = this.proxyAuthenticator.hashCode();
        int hashCode3 = this.protocols.hashCode();
        int hashCode4 = this.connectionSpecs.hashCode();
        int hashCode5 = this.proxySelector.hashCode();
        int hashCode6 = Objects.hashCode(this.proxy);
        int hashCode7 = Objects.hashCode(this.sslSocketFactory);
        int hashCode8 = Objects.hashCode(this.hostnameVerifier);
        return Objects.hashCode(this.certificatePinner) + ((hashCode8 + ((hashCode7 + ((hashCode6 + ((hashCode5 + ((hashCode4 + ((hashCode3 + ((hashCode2 + ((hashCode + ((this.url.hashCode() + 527) * 31)) * 31)) * 31)) * 31)) * 31)) * 31)) * 31)) * 31)) * 31);
    }

    public String toString() {
        Object obj;
        StringBuilder sb;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Address{");
        outline25.append(this.url.host);
        outline25.append(':');
        outline25.append(this.url.port);
        outline25.append(", ");
        if (this.proxy != null) {
            sb = GeneratedOutlineSupport.outline25("proxy=");
            obj = this.proxy;
        } else {
            sb = GeneratedOutlineSupport.outline25("proxySelector=");
            obj = this.proxySelector;
        }
        sb.append(obj);
        outline25.append(sb.toString());
        outline25.append("}");
        return outline25.toString();
    }
}
