package okhttp3;

import androidx.transition.ViewGroupUtilsApi14;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import kotlin.Pair;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.ranges.IntProgression;
import kotlin.ranges.RangesKt___RangesKt;
import kotlin.text.StringsKt__IndentKt;
import okhttp3.internal.Util;

/* compiled from: Headers.kt */
public final class Headers implements Iterable<Pair<? extends String, ? extends String>> {
    public static final Companion Companion = new Companion(null);
    public final String[] namesAndValues;

    /* compiled from: Headers.kt */
    public final class Builder {
        public final List<String> namesAndValues = new ArrayList(20);

        public final Builder addLenient$okhttp(String str, String str2) {
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            Intrinsics.checkNotNullParameter(str2, "value");
            this.namesAndValues.add(str);
            this.namesAndValues.add(StringsKt__IndentKt.trim(str2).toString());
            return this;
        }

        public final Headers build() {
            Object[] array = this.namesAndValues.toArray(new String[0]);
            Objects.requireNonNull(array, "null cannot be cast to non-null type kotlin.Array<T>");
            return new Headers((String[]) array, null);
        }

        public final Builder removeAll(String str) {
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            int i = 0;
            while (i < this.namesAndValues.size()) {
                if (StringsKt__IndentKt.equals(str, this.namesAndValues.get(i), true)) {
                    this.namesAndValues.remove(i);
                    this.namesAndValues.remove(i);
                    i -= 2;
                }
                i += 2;
            }
            return this;
        }
    }

    /* compiled from: Headers.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }

        public final void checkName(String str) {
            if (str.length() > 0) {
                int length = str.length();
                for (int i = 0; i < length; i++) {
                    char charAt = str.charAt(i);
                    if (!('!' <= charAt && '~' >= charAt)) {
                        throw new IllegalArgumentException(Util.format("Unexpected char %#04x at %d in header name: %s", Integer.valueOf(charAt), Integer.valueOf(i), str).toString());
                    }
                }
                return;
            }
            throw new IllegalArgumentException("name is empty".toString());
        }

        public final void checkValue(String str, String str2) {
            int length = str.length();
            for (int i = 0; i < length; i++) {
                char charAt = str.charAt(i);
                if (!(charAt == '\t' || (' ' <= charAt && '~' >= charAt))) {
                    throw new IllegalArgumentException(Util.format("Unexpected char %#04x at %d in %s value: %s", Integer.valueOf(charAt), Integer.valueOf(i), str2, str).toString());
                }
            }
        }

        public final Headers of(String... strArr) {
            Intrinsics.checkNotNullParameter(strArr, "namesAndValues");
            if (strArr.length % 2 == 0) {
                Object clone = strArr.clone();
                Objects.requireNonNull(clone, "null cannot be cast to non-null type kotlin.Array<kotlin.String>");
                String[] strArr2 = (String[]) clone;
                int length = strArr2.length;
                for (int i = 0; i < length; i++) {
                    if (strArr2[i] != null) {
                        String str = strArr2[i];
                        Objects.requireNonNull(str, "null cannot be cast to non-null type kotlin.CharSequence");
                        strArr2[i] = StringsKt__IndentKt.trim(str).toString();
                    } else {
                        throw new IllegalArgumentException("Headers cannot be null".toString());
                    }
                }
                IntProgression step = RangesKt___RangesKt.step(RangesKt___RangesKt.until(0, strArr2.length), 2);
                int i2 = step.first;
                int i3 = step.last;
                int i4 = step.step;
                if (i4 < 0 ? i2 >= i3 : i2 <= i3) {
                    while (true) {
                        String str2 = strArr2[i2];
                        String str3 = strArr2[i2 + 1];
                        checkName(str2);
                        checkValue(str3, str2);
                        if (i2 == i3) {
                            break;
                        }
                        i2 += i4;
                    }
                }
                return new Headers(strArr2, null);
            }
            throw new IllegalArgumentException("Expected alternating header names and values".toString());
        }
    }

    public Headers(String[] strArr, DefaultConstructorMarker defaultConstructorMarker) {
        this.namesAndValues = strArr;
    }

    public boolean equals(Object obj) {
        return (obj instanceof Headers) && Arrays.equals(this.namesAndValues, ((Headers) obj).namesAndValues);
    }

    public final String get(String str) {
        Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
        String[] strArr = this.namesAndValues;
        IntProgression step = RangesKt___RangesKt.step(RangesKt___RangesKt.downTo(strArr.length - 2, 0), 2);
        int i = step.first;
        int i2 = step.last;
        int i3 = step.step;
        if (i3 < 0 ? i >= i2 : i <= i2) {
            while (!StringsKt__IndentKt.equals(str, strArr[i], true)) {
                if (i != i2) {
                    i += i3;
                }
            }
            return strArr[i + 1];
        }
        return null;
    }

    public int hashCode() {
        return Arrays.hashCode(this.namesAndValues);
    }

    /* Return type fixed from 'java.util.Iterator<kotlin.Pair<java.lang.String, java.lang.String>>' to match base method */
    @Override // java.lang.Iterable
    public Iterator<Pair<? extends String, ? extends String>> iterator() {
        int size = size();
        Pair[] pairArr = new Pair[size];
        for (int i = 0; i < size; i++) {
            pairArr[i] = new Pair(name(i), value(i));
        }
        return ViewGroupUtilsApi14.iterator(pairArr);
    }

    public final String name(int i) {
        return this.namesAndValues[i * 2];
    }

    public final Builder newBuilder() {
        Builder builder = new Builder();
        List<String> list = builder.namesAndValues;
        String[] strArr = this.namesAndValues;
        Intrinsics.checkNotNullParameter(list, "$this$addAll");
        Intrinsics.checkNotNullParameter(strArr, "elements");
        list.addAll(ArraysKt___ArraysKt.asList(strArr));
        return builder;
    }

    public final int size() {
        return this.namesAndValues.length / 2;
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        int size = size();
        for (int i = 0; i < size; i++) {
            sb.append(name(i));
            sb.append(": ");
            sb.append(value(i));
            sb.append("\n");
        }
        String sb2 = sb.toString();
        Intrinsics.checkNotNullExpressionValue(sb2, "StringBuilder().apply(builderAction).toString()");
        return sb2;
    }

    public final String value(int i) {
        return this.namesAndValues[(i * 2) + 1];
    }
}
