package okhttp3;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.net.ProxySelector;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import javax.net.SocketFactory;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.X509TrustManager;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.internal.Util;
import okhttp3.internal.Util$asFactory$1;
import okhttp3.internal.connection.RealCall;
import okhttp3.internal.connection.RouteDatabase;
import okhttp3.internal.platform.Platform;
import okhttp3.internal.proxy.NullProxySelector;
import okhttp3.internal.tls.CertificateChainCleaner;
import okhttp3.internal.tls.OkHostnameVerifier;

/* compiled from: OkHttpClient.kt */
public class OkHttpClient implements Cloneable {
    public static final Companion Companion = new Companion(null);
    public static final List<ConnectionSpec> DEFAULT_CONNECTION_SPECS = Util.immutableListOf(ConnectionSpec.MODERN_TLS, ConnectionSpec.CLEARTEXT);
    public static final List<Protocol> DEFAULT_PROTOCOLS = Util.immutableListOf(Protocol.HTTP_2, Protocol.HTTP_1_1);
    public final Authenticator authenticator;
    public final CertificateChainCleaner certificateChainCleaner;
    public final CertificatePinner certificatePinner;
    public final int connectTimeoutMillis;
    public final ConnectionPool connectionPool;
    public final List<ConnectionSpec> connectionSpecs;
    public final CookieJar cookieJar;
    public final Dispatcher dispatcher;
    public final Dns dns;
    public final Util$asFactory$1 eventListenerFactory;
    public final boolean followRedirects;
    public final boolean followSslRedirects;
    public final HostnameVerifier hostnameVerifier;
    public final List<Interceptor> interceptors;
    public final List<Interceptor> networkInterceptors;
    public final List<Protocol> protocols;
    public final Authenticator proxyAuthenticator;
    public final ProxySelector proxySelector;
    public final int readTimeoutMillis;
    public final boolean retryOnConnectionFailure;
    public final RouteDatabase routeDatabase;
    public final SocketFactory socketFactory;
    public final SSLSocketFactory sslSocketFactoryOrNull;
    public final int writeTimeoutMillis;
    public final X509TrustManager x509TrustManager;

    /* compiled from: OkHttpClient.kt */
    public static final class Builder {
        public Authenticator authenticator;
        public CertificatePinner certificatePinner;
        public int connectTimeout;
        public ConnectionPool connectionPool = new ConnectionPool();
        public List<ConnectionSpec> connectionSpecs;
        public CookieJar cookieJar;
        public Dispatcher dispatcher = new Dispatcher();
        public Dns dns;
        public Util$asFactory$1 eventListenerFactory;
        public boolean followRedirects;
        public boolean followSslRedirects;
        public HostnameVerifier hostnameVerifier;
        public final List<Interceptor> interceptors = new ArrayList();
        public long minWebSocketMessageToCompress;
        public final List<Interceptor> networkInterceptors = new ArrayList();
        public List<? extends Protocol> protocols;
        public Authenticator proxyAuthenticator;
        public int readTimeout;
        public boolean retryOnConnectionFailure;
        public SocketFactory socketFactory;
        public int writeTimeout;

        public Builder() {
            EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = EventListener$Companion$NONE$1.NONE;
            Intrinsics.checkNotNullParameter(eventListener$Companion$NONE$1, "$this$asFactory");
            this.eventListenerFactory = new Util$asFactory$1(eventListener$Companion$NONE$1);
            this.retryOnConnectionFailure = true;
            Authenticator authenticator2 = Authenticator.NONE;
            this.authenticator = authenticator2;
            this.followRedirects = true;
            this.followSslRedirects = true;
            this.cookieJar = CookieJar.NO_COOKIES;
            this.dns = Dns.SYSTEM;
            this.proxyAuthenticator = authenticator2;
            SocketFactory socketFactory2 = SocketFactory.getDefault();
            Intrinsics.checkNotNullExpressionValue(socketFactory2, "SocketFactory.getDefault()");
            this.socketFactory = socketFactory2;
            Companion companion = OkHttpClient.Companion;
            this.connectionSpecs = OkHttpClient.DEFAULT_CONNECTION_SPECS;
            this.protocols = OkHttpClient.DEFAULT_PROTOCOLS;
            this.hostnameVerifier = OkHostnameVerifier.INSTANCE;
            this.certificatePinner = CertificatePinner.DEFAULT;
            this.connectTimeout = 10000;
            this.readTimeout = 10000;
            this.writeTimeout = 10000;
            this.minWebSocketMessageToCompress = 1024;
        }

        public final Builder addInterceptor(Interceptor interceptor) {
            Intrinsics.checkNotNullParameter(interceptor, "interceptor");
            this.interceptors.add(interceptor);
            return this;
        }
    }

    /* compiled from: OkHttpClient.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }
    }

    /* JADX DEBUG: Type inference failed for r1v0. Raw type applied. Possible types: java.util.List<? extends okhttp3.Protocol>, java.util.List<okhttp3.Protocol> */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0094  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x009f  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x00de  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x0111  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x015f  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x01a9  */
    public OkHttpClient(Builder builder) {
        boolean z;
        List<Interceptor> list;
        boolean z2;
        Intrinsics.checkNotNullParameter(builder, "builder");
        this.dispatcher = builder.dispatcher;
        this.connectionPool = builder.connectionPool;
        this.interceptors = Util.toImmutableList(builder.interceptors);
        this.networkInterceptors = Util.toImmutableList(builder.networkInterceptors);
        this.eventListenerFactory = builder.eventListenerFactory;
        this.retryOnConnectionFailure = builder.retryOnConnectionFailure;
        this.authenticator = builder.authenticator;
        this.followRedirects = builder.followRedirects;
        this.followSslRedirects = builder.followSslRedirects;
        this.cookieJar = builder.cookieJar;
        this.dns = builder.dns;
        ProxySelector proxySelector2 = ProxySelector.getDefault();
        this.proxySelector = proxySelector2 == null ? NullProxySelector.INSTANCE : proxySelector2;
        this.proxyAuthenticator = builder.proxyAuthenticator;
        this.socketFactory = builder.socketFactory;
        List<ConnectionSpec> list2 = builder.connectionSpecs;
        this.connectionSpecs = list2;
        this.protocols = builder.protocols;
        this.hostnameVerifier = builder.hostnameVerifier;
        this.connectTimeoutMillis = builder.connectTimeout;
        this.readTimeoutMillis = builder.readTimeout;
        this.writeTimeoutMillis = builder.writeTimeout;
        this.routeDatabase = new RouteDatabase();
        boolean z3 = false;
        if (!(list2 instanceof Collection) || !list2.isEmpty()) {
            Iterator<T> it = list2.iterator();
            while (true) {
                if (it.hasNext()) {
                    if (it.next().isTls) {
                        z = false;
                        break;
                    }
                } else {
                    break;
                }
            }
            if (!z) {
                this.sslSocketFactoryOrNull = null;
                this.certificateChainCleaner = null;
                this.x509TrustManager = null;
                this.certificatePinner = CertificatePinner.DEFAULT;
            } else {
                Platform.Companion companion = Platform.Companion;
                X509TrustManager platformTrustManager = Platform.platform.platformTrustManager();
                this.x509TrustManager = platformTrustManager;
                Platform platform = Platform.platform;
                Intrinsics.checkNotNull(platformTrustManager);
                this.sslSocketFactoryOrNull = platform.newSslSocketFactory(platformTrustManager);
                Intrinsics.checkNotNull(platformTrustManager);
                Intrinsics.checkNotNullParameter(platformTrustManager, "trustManager");
                CertificateChainCleaner buildCertificateChainCleaner = Platform.platform.buildCertificateChainCleaner(platformTrustManager);
                this.certificateChainCleaner = buildCertificateChainCleaner;
                CertificatePinner certificatePinner2 = builder.certificatePinner;
                Intrinsics.checkNotNull(buildCertificateChainCleaner);
                this.certificatePinner = certificatePinner2.withCertificateChainCleaner$okhttp(buildCertificateChainCleaner);
            }
            list = this.interceptors;
            Objects.requireNonNull(list, "null cannot be cast to non-null type kotlin.collections.List<okhttp3.Interceptor?>");
            if (!(!list.contains(null))) {
                List<Interceptor> list3 = this.networkInterceptors;
                Objects.requireNonNull(list3, "null cannot be cast to non-null type kotlin.collections.List<okhttp3.Interceptor?>");
                if (!list3.contains(null)) {
                    List<ConnectionSpec> list4 = this.connectionSpecs;
                    if (!(list4 instanceof Collection) || !list4.isEmpty()) {
                        Iterator<T> it2 = list4.iterator();
                        while (true) {
                            if (it2.hasNext()) {
                                if (it2.next().isTls) {
                                    z2 = false;
                                    break;
                                }
                            } else {
                                break;
                            }
                        }
                        if (!z2) {
                            if (this.sslSocketFactoryOrNull == null) {
                                if (this.certificateChainCleaner == null) {
                                    if (!(this.x509TrustManager == null ? true : z3)) {
                                        throw new IllegalStateException("Check failed.".toString());
                                    } else if (!Intrinsics.areEqual(this.certificatePinner, CertificatePinner.DEFAULT)) {
                                        throw new IllegalStateException("Check failed.".toString());
                                    } else {
                                        return;
                                    }
                                } else {
                                    throw new IllegalStateException("Check failed.".toString());
                                }
                            } else {
                                throw new IllegalStateException("Check failed.".toString());
                            }
                        } else if (this.sslSocketFactoryOrNull == null) {
                            throw new IllegalStateException("sslSocketFactory == null".toString());
                        } else if (this.certificateChainCleaner == null) {
                            throw new IllegalStateException("certificateChainCleaner == null".toString());
                        } else if (this.x509TrustManager == null) {
                            throw new IllegalStateException("x509TrustManager == null".toString());
                        } else {
                            return;
                        }
                    }
                    z2 = true;
                    if (!z2) {
                    }
                } else {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Null network interceptor: ");
                    outline25.append(this.networkInterceptors);
                    throw new IllegalStateException(outline25.toString().toString());
                }
            } else {
                StringBuilder outline252 = GeneratedOutlineSupport.outline25("Null interceptor: ");
                outline252.append(this.interceptors);
                throw new IllegalStateException(outline252.toString().toString());
            }
        }
        z = true;
        if (!z) {
        }
        list = this.interceptors;
        Objects.requireNonNull(list, "null cannot be cast to non-null type kotlin.collections.List<okhttp3.Interceptor?>");
        if (!(!list.contains(null))) {
        }
    }

    @Override // java.lang.Object
    public Object clone() {
        return super.clone();
    }

    public Call newCall(Request request) {
        Intrinsics.checkNotNullParameter(request, "request");
        return new RealCall(this, request, false);
    }
}
