package okhttp3;

import com.allpayx.sdk.util.HttpUtil;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;
import kotlin.Pair;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.internal.Util;
import okhttp3.internal.http.HttpMethod;

/* compiled from: Request.kt */
public final class Request {
    public final RequestBody body;
    public final Headers headers;
    public CacheControl lazyCacheControl;
    public final String method;
    public final Map<Class<?>, Object> tags;
    public final HttpUrl url;

    /* compiled from: Request.kt */
    public static class Builder {
        public RequestBody body;
        public Headers.Builder headers;
        public String method;
        public Map<Class<?>, Object> tags;
        public HttpUrl url;

        public Builder() {
            this.tags = new LinkedHashMap();
            this.method = HttpUtil.METHOD_GET;
            this.headers = new Headers.Builder();
        }

        public Builder addHeader(String str, String str2) {
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            Intrinsics.checkNotNullParameter(str2, "value");
            Headers.Builder builder = this.headers;
            Objects.requireNonNull(builder);
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            Intrinsics.checkNotNullParameter(str2, "value");
            Headers.Companion companion = Headers.Companion;
            companion.checkName(str);
            companion.checkValue(str2, str);
            builder.addLenient$okhttp(str, str2);
            return this;
        }

        public Request build() {
            Map map;
            HttpUrl httpUrl = this.url;
            if (httpUrl != null) {
                String str = this.method;
                Headers build = this.headers.build();
                RequestBody requestBody = this.body;
                Map<Class<?>, Object> map2 = this.tags;
                byte[] bArr = Util.EMPTY_BYTE_ARRAY;
                Intrinsics.checkNotNullParameter(map2, "$this$toImmutableMap");
                if (map2.isEmpty()) {
                    map = ArraysKt___ArraysKt.emptyMap();
                } else {
                    map = Collections.unmodifiableMap(new LinkedHashMap(map2));
                    Intrinsics.checkNotNullExpressionValue(map, "Collections.unmodifiableMap(LinkedHashMap(this))");
                }
                return new Request(httpUrl, str, build, requestBody, map);
            }
            throw new IllegalStateException("url == null".toString());
        }

        public Builder header(String str, String str2) {
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            Intrinsics.checkNotNullParameter(str2, "value");
            Headers.Builder builder = this.headers;
            Objects.requireNonNull(builder);
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            Intrinsics.checkNotNullParameter(str2, "value");
            Headers.Companion companion = Headers.Companion;
            companion.checkName(str);
            companion.checkValue(str2, str);
            builder.removeAll(str);
            builder.addLenient$okhttp(str, str2);
            return this;
        }

        public Builder method(String str, RequestBody requestBody) {
            Intrinsics.checkNotNullParameter(str, "method");
            boolean z = false;
            if (str.length() > 0) {
                if (requestBody == null) {
                    Intrinsics.checkNotNullParameter(str, "method");
                    if (Intrinsics.areEqual(str, HttpUtil.METHOD_POST) || Intrinsics.areEqual(str, HttpUtil.METHOD_PUT) || Intrinsics.areEqual(str, "PATCH") || Intrinsics.areEqual(str, "PROPPATCH") || Intrinsics.areEqual(str, "REPORT")) {
                        z = true;
                    }
                    if (!(!z)) {
                        throw new IllegalArgumentException(GeneratedOutlineSupport.outline19("method ", str, " must have a request body.").toString());
                    }
                } else if (!HttpMethod.permitsRequestBody(str)) {
                    throw new IllegalArgumentException(GeneratedOutlineSupport.outline19("method ", str, " must not have a request body.").toString());
                }
                this.method = str;
                this.body = requestBody;
                return this;
            }
            throw new IllegalArgumentException("method.isEmpty() == true".toString());
        }

        public Builder post(RequestBody requestBody) {
            Intrinsics.checkNotNullParameter(requestBody, "body");
            method(HttpUtil.METHOD_POST, requestBody);
            return this;
        }

        public Builder removeHeader(String str) {
            Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
            this.headers.removeAll(str);
            return this;
        }

        public Builder url(HttpUrl httpUrl) {
            Intrinsics.checkNotNullParameter(httpUrl, "url");
            this.url = httpUrl;
            return this;
        }

        public Builder url(String str) {
            Intrinsics.checkNotNullParameter(str, "url");
            if (StringsKt__IndentKt.startsWith(str, "ws:", true)) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("http:");
                String substring = str.substring(3);
                Intrinsics.checkNotNullExpressionValue(substring, "(this as java.lang.String).substring(startIndex)");
                outline25.append(substring);
                str = outline25.toString();
            } else if (StringsKt__IndentKt.startsWith(str, "wss:", true)) {
                StringBuilder outline252 = GeneratedOutlineSupport.outline25("https:");
                String substring2 = str.substring(4);
                Intrinsics.checkNotNullExpressionValue(substring2, "(this as java.lang.String).substring(startIndex)");
                outline252.append(substring2);
                str = outline252.toString();
            }
            Intrinsics.checkNotNullParameter(str, "$this$toHttpUrl");
            HttpUrl.Builder builder = new HttpUrl.Builder();
            builder.parse$okhttp(null, str);
            url(builder.build());
            return this;
        }

        public Builder(Request request) {
            LinkedHashMap linkedHashMap;
            Intrinsics.checkNotNullParameter(request, "request");
            this.tags = new LinkedHashMap();
            this.url = request.url;
            this.method = request.method;
            this.body = request.body;
            if (request.tags.isEmpty()) {
                linkedHashMap = new LinkedHashMap();
            } else {
                Map<Class<?>, Object> map = request.tags;
                Intrinsics.checkNotNullParameter(map, "$this$toMutableMap");
                linkedHashMap = new LinkedHashMap(map);
            }
            this.tags = linkedHashMap;
            this.headers = request.headers.newBuilder();
        }
    }

    public Request(HttpUrl httpUrl, String str, Headers headers2, RequestBody requestBody, Map<Class<?>, ? extends Object> map) {
        Intrinsics.checkNotNullParameter(httpUrl, "url");
        Intrinsics.checkNotNullParameter(str, "method");
        Intrinsics.checkNotNullParameter(headers2, "headers");
        Intrinsics.checkNotNullParameter(map, "tags");
        this.url = httpUrl;
        this.method = str;
        this.headers = headers2;
        this.body = requestBody;
        this.tags = map;
    }

    public final CacheControl cacheControl() {
        CacheControl cacheControl = this.lazyCacheControl;
        if (cacheControl != null) {
            return cacheControl;
        }
        CacheControl parse = CacheControl.Companion.parse(this.headers);
        this.lazyCacheControl = parse;
        return parse;
    }

    public final String header(String str) {
        Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
        return this.headers.get(str);
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Request{method=");
        outline25.append(this.method);
        outline25.append(", url=");
        outline25.append(this.url);
        if (this.headers.size() != 0) {
            outline25.append(", headers=[");
            int i = 0;
            for (Object obj : this.headers) {
                int i2 = i + 1;
                if (i >= 0) {
                    Pair pair = (Pair) obj;
                    String str = (String) pair.component1();
                    String str2 = (String) pair.component2();
                    if (i > 0) {
                        outline25.append(", ");
                    }
                    outline25.append(str);
                    outline25.append(':');
                    outline25.append(str2);
                    i = i2;
                } else {
                    ArraysKt___ArraysKt.throwIndexOverflow();
                    throw null;
                }
            }
            outline25.append(']');
        }
        if (!this.tags.isEmpty()) {
            outline25.append(", tags=");
            outline25.append(this.tags);
        }
        outline25.append('}');
        String sb = outline25.toString();
        Intrinsics.checkNotNullExpressionValue(sb, "StringBuilder().apply(builderAction).toString()");
        return sb;
    }
}
