package okhttp3;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.io.Closeable;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.Headers;
import okhttp3.internal.connection.Exchange;

/* compiled from: Response.kt */
public final class Response implements Closeable {
    public final ResponseBody body;
    public final Response cacheResponse;
    public final int code;
    public final Exchange exchange;
    public final Handshake handshake;
    public final Headers headers;
    public final String message;
    public final Response networkResponse;
    public final Response priorResponse;
    public final Protocol protocol;
    public final long receivedResponseAtMillis;
    public final Request request;
    public final long sentRequestAtMillis;

    public Response(Request request2, Protocol protocol2, String str, int i, Handshake handshake2, Headers headers2, ResponseBody responseBody, Response response, Response response2, Response response3, long j, long j2, Exchange exchange2) {
        Intrinsics.checkNotNullParameter(request2, "request");
        Intrinsics.checkNotNullParameter(protocol2, "protocol");
        Intrinsics.checkNotNullParameter(str, "message");
        Intrinsics.checkNotNullParameter(headers2, "headers");
        this.request = request2;
        this.protocol = protocol2;
        this.message = str;
        this.code = i;
        this.handshake = handshake2;
        this.headers = headers2;
        this.body = responseBody;
        this.networkResponse = response;
        this.cacheResponse = response2;
        this.priorResponse = response3;
        this.sentRequestAtMillis = j;
        this.receivedResponseAtMillis = j2;
        this.exchange = exchange2;
    }

    public static String header$default(Response response, String str, String str2, int i) {
        int i2 = i & 2;
        Objects.requireNonNull(response);
        Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
        String str3 = response.headers.get(str);
        if (str3 != null) {
            return str3;
        }
        return null;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        ResponseBody responseBody = this.body;
        if (responseBody != null) {
            responseBody.close();
            return;
        }
        throw new IllegalStateException("response is not eligible for a body and must not be closed".toString());
    }

    public final boolean isSuccessful() {
        int i = this.code;
        return 200 <= i && 299 >= i;
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Response{protocol=");
        outline25.append(this.protocol);
        outline25.append(", code=");
        outline25.append(this.code);
        outline25.append(", message=");
        outline25.append(this.message);
        outline25.append(", url=");
        outline25.append(this.request.url);
        outline25.append('}');
        return outline25.toString();
    }

    /* compiled from: Response.kt */
    public static class Builder {
        public ResponseBody body;
        public Response cacheResponse;
        public int code;
        public Exchange exchange;
        public Handshake handshake;
        public Headers.Builder headers;
        public String message;
        public Response networkResponse;
        public Response priorResponse;
        public Protocol protocol;
        public long receivedResponseAtMillis;
        public Request request;
        public long sentRequestAtMillis;

        public Builder() {
            this.code = -1;
            this.headers = new Headers.Builder();
        }

        public Response build() {
            int i = this.code;
            if (i >= 0) {
                Request request2 = this.request;
                if (request2 != null) {
                    Protocol protocol2 = this.protocol;
                    if (protocol2 != null) {
                        String str = this.message;
                        if (str != null) {
                            return new Response(request2, protocol2, str, i, this.handshake, this.headers.build(), this.body, this.networkResponse, this.cacheResponse, this.priorResponse, this.sentRequestAtMillis, this.receivedResponseAtMillis, this.exchange);
                        }
                        throw new IllegalStateException("message == null".toString());
                    }
                    throw new IllegalStateException("protocol == null".toString());
                }
                throw new IllegalStateException("request == null".toString());
            }
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("code < 0: ");
            outline25.append(this.code);
            throw new IllegalStateException(outline25.toString().toString());
        }

        public Builder cacheResponse(Response response) {
            checkSupportResponse("cacheResponse", response);
            this.cacheResponse = response;
            return this;
        }

        public final void checkSupportResponse(String str, Response response) {
            if (response != null) {
                boolean z = false;
                if (response.body == null) {
                    if (response.networkResponse == null) {
                        if (response.cacheResponse == null) {
                            if (response.priorResponse == null) {
                                z = true;
                            }
                            if (!z) {
                                throw new IllegalArgumentException(GeneratedOutlineSupport.outline18(str, ".priorResponse != null").toString());
                            }
                            return;
                        }
                        throw new IllegalArgumentException(GeneratedOutlineSupport.outline18(str, ".cacheResponse != null").toString());
                    }
                    throw new IllegalArgumentException(GeneratedOutlineSupport.outline18(str, ".networkResponse != null").toString());
                }
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline18(str, ".body != null").toString());
            }
        }

        public Builder headers(Headers headers2) {
            Intrinsics.checkNotNullParameter(headers2, "headers");
            this.headers = headers2.newBuilder();
            return this;
        }

        public Builder message(String str) {
            Intrinsics.checkNotNullParameter(str, "message");
            this.message = str;
            return this;
        }

        public Builder protocol(Protocol protocol2) {
            Intrinsics.checkNotNullParameter(protocol2, "protocol");
            this.protocol = protocol2;
            return this;
        }

        public Builder request(Request request2) {
            Intrinsics.checkNotNullParameter(request2, "request");
            this.request = request2;
            return this;
        }

        public Builder(Response response) {
            Intrinsics.checkNotNullParameter(response, "response");
            this.code = -1;
            this.request = response.request;
            this.protocol = response.protocol;
            this.code = response.code;
            this.message = response.message;
            this.handshake = response.handshake;
            this.headers = response.headers.newBuilder();
            this.body = response.body;
            this.networkResponse = response.networkResponse;
            this.cacheResponse = response.cacheResponse;
            this.priorResponse = response.priorResponse;
            this.sentRequestAtMillis = response.sentRequestAtMillis;
            this.receivedResponseAtMillis = response.receivedResponseAtMillis;
            this.exchange = response.exchange;
        }
    }
}
