package okhttp3.internal.cache;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import com.squareup.okhttp.internal.DiskLruCache;
import java.util.ArrayList;
import java.util.Objects;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import okhttp3.Cache;
import okhttp3.Handshake;
import okhttp3.Headers;
import okhttp3.Interceptor;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.Util;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.connection.RealCall;
import okhttp3.internal.http.RealInterceptorChain;

/* compiled from: CacheInterceptor.kt */
public final class CacheInterceptor implements Interceptor {
    public static final Companion Companion = new Companion(null);

    /* compiled from: CacheInterceptor.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }

        public static final Response access$stripBody(Companion companion, Response response) {
            if ((response != null ? response.body : null) == null) {
                return response;
            }
            Objects.requireNonNull(response);
            Intrinsics.checkNotNullParameter(response, "response");
            Request request = response.request;
            Protocol protocol = response.protocol;
            int i = response.code;
            String str = response.message;
            Handshake handshake = response.handshake;
            Headers.Builder newBuilder = response.headers.newBuilder();
            Response response2 = response.networkResponse;
            Response response3 = response.cacheResponse;
            Response response4 = response.priorResponse;
            long j = response.sentRequestAtMillis;
            long j2 = response.receivedResponseAtMillis;
            Exchange exchange = response.exchange;
            if (!(i >= 0)) {
                throw new IllegalStateException(GeneratedOutlineSupport.outline11("code < 0: ", i).toString());
            } else if (request == null) {
                throw new IllegalStateException("request == null".toString());
            } else if (protocol == null) {
                throw new IllegalStateException("protocol == null".toString());
            } else if (str != null) {
                return new Response(request, protocol, str, i, handshake, newBuilder.build(), null, response2, response3, response4, j, j2, exchange);
            } else {
                throw new IllegalStateException("message == null".toString());
            }
        }

        public final boolean isContentSpecificHeader(String str) {
            if (StringsKt__IndentKt.equals("Content-Length", str, true) || StringsKt__IndentKt.equals("Content-Encoding", str, true) || StringsKt__IndentKt.equals("Content-Type", str, true)) {
                return true;
            }
            return false;
        }

        public final boolean isEndToEnd(String str) {
            if (StringsKt__IndentKt.equals("Connection", str, true) || StringsKt__IndentKt.equals("Keep-Alive", str, true) || StringsKt__IndentKt.equals("Proxy-Authenticate", str, true) || StringsKt__IndentKt.equals("Proxy-Authorization", str, true) || StringsKt__IndentKt.equals("TE", str, true) || StringsKt__IndentKt.equals("Trailers", str, true) || StringsKt__IndentKt.equals("Transfer-Encoding", str, true) || StringsKt__IndentKt.equals("Upgrade", str, true)) {
                return false;
            }
            return true;
        }
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) {
        Headers headers;
        Intrinsics.checkNotNullParameter(chain, "chain");
        RealInterceptorChain realInterceptorChain = (RealInterceptorChain) chain;
        RealCall realCall = realInterceptorChain.call;
        System.currentTimeMillis();
        Request request = realInterceptorChain.request;
        Intrinsics.checkNotNullParameter(request, "request");
        CacheStrategy cacheStrategy = new CacheStrategy(request, null);
        if (request != null && request.cacheControl().onlyIfCached) {
            cacheStrategy = new CacheStrategy(null, null);
        }
        Request request2 = cacheStrategy.networkRequest;
        Response response = cacheStrategy.cacheResponse;
        if (!(realCall instanceof RealCall)) {
        }
        if (request2 == null && response == null) {
            Response.Builder builder = new Response.Builder();
            builder.request(realInterceptorChain.request);
            builder.protocol(Protocol.HTTP_1_1);
            builder.code = 504;
            builder.message("Unsatisfiable Request (only-if-cached)");
            builder.body = Util.EMPTY_RESPONSE;
            builder.sentRequestAtMillis = -1;
            builder.receivedResponseAtMillis = System.currentTimeMillis();
            Response build = builder.build();
            Intrinsics.checkNotNullParameter(realCall, "call");
            Intrinsics.checkNotNullParameter(build, "response");
            return build;
        } else if (request2 == null) {
            Intrinsics.checkNotNull(response);
            Response.Builder builder2 = new Response.Builder(response);
            builder2.cacheResponse(Companion.access$stripBody(Companion, response));
            Response build2 = builder2.build();
            Intrinsics.checkNotNullParameter(realCall, "call");
            Intrinsics.checkNotNullParameter(build2, "response");
            return build2;
        } else {
            if (response != null) {
                Intrinsics.checkNotNullParameter(realCall, "call");
                Intrinsics.checkNotNullParameter(response, "cachedResponse");
            }
            Response proceed = ((RealInterceptorChain) chain).proceed(request2);
            if (response != null) {
                if (proceed.code == 304) {
                    Response.Builder builder3 = new Response.Builder(response);
                    Companion companion = Companion;
                    Headers headers2 = response.headers;
                    Headers headers3 = proceed.headers;
                    ArrayList arrayList = new ArrayList(20);
                    int size = headers2.size();
                    int i = 0;
                    while (i < size) {
                        String name = headers2.name(i);
                        String value = headers2.value(i);
                        if (StringsKt__IndentKt.equals("Warning", name, true)) {
                            headers = headers2;
                            if (StringsKt__IndentKt.startsWith$default(value, DiskLruCache.VERSION_1, false, 2)) {
                                i++;
                                headers2 = headers;
                            }
                        } else {
                            headers = headers2;
                        }
                        if (companion.isContentSpecificHeader(name) || !companion.isEndToEnd(name) || headers3.get(name) == null) {
                            Intrinsics.checkNotNullParameter(name, VpnProfileDataSource.KEY_NAME);
                            Intrinsics.checkNotNullParameter(value, "value");
                            arrayList.add(name);
                            arrayList.add(StringsKt__IndentKt.trim(value).toString());
                            i++;
                            headers2 = headers;
                        } else {
                            i++;
                            headers2 = headers;
                        }
                    }
                    int size2 = headers3.size();
                    for (int i2 = 0; i2 < size2; i2++) {
                        String name2 = headers3.name(i2);
                        if (!companion.isContentSpecificHeader(name2) && companion.isEndToEnd(name2)) {
                            String value2 = headers3.value(i2);
                            Intrinsics.checkNotNullParameter(name2, VpnProfileDataSource.KEY_NAME);
                            Intrinsics.checkNotNullParameter(value2, "value");
                            arrayList.add(name2);
                            arrayList.add(StringsKt__IndentKt.trim(value2).toString());
                        }
                    }
                    Object[] array = arrayList.toArray(new String[0]);
                    Objects.requireNonNull(array, "null cannot be cast to non-null type kotlin.Array<T>");
                    builder3.headers(new Headers((String[]) array, null));
                    builder3.sentRequestAtMillis = proceed.sentRequestAtMillis;
                    builder3.receivedResponseAtMillis = proceed.receivedResponseAtMillis;
                    Companion companion2 = Companion;
                    builder3.cacheResponse(Companion.access$stripBody(companion2, response));
                    Response access$stripBody = Companion.access$stripBody(companion2, proceed);
                    builder3.checkSupportResponse("networkResponse", access$stripBody);
                    builder3.networkResponse = access$stripBody;
                    builder3.build();
                    ResponseBody responseBody = proceed.body;
                    Intrinsics.checkNotNull(responseBody);
                    responseBody.close();
                    Cache cache = null;
                    Intrinsics.checkNotNull(null);
                    cache.trackConditionalCacheHit$okhttp();
                    throw null;
                }
                ResponseBody responseBody2 = response.body;
                if (responseBody2 != null) {
                    Util.closeQuietly(responseBody2);
                }
            }
            Intrinsics.checkNotNull(proceed);
            Response.Builder builder4 = new Response.Builder(proceed);
            Companion companion3 = Companion;
            builder4.cacheResponse(Companion.access$stripBody(companion3, response));
            Response access$stripBody2 = Companion.access$stripBody(companion3, proceed);
            builder4.checkSupportResponse("networkResponse", access$stripBody2);
            builder4.networkResponse = access$stripBody2;
            return builder4.build();
        }
    }
}
