package okhttp3.internal.concurrent;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.RejectedExecutionException;
import java.util.logging.Level;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.TaskRunner;

/* compiled from: TaskQueue.kt */
public final class TaskQueue {
    public Task activeTask;
    public boolean cancelActiveTask;
    public final List<Task> futureTasks = new ArrayList();
    public final String name;
    public boolean shutdown;
    public final TaskRunner taskRunner;

    public TaskQueue(TaskRunner taskRunner2, String str) {
        Intrinsics.checkNotNullParameter(taskRunner2, "taskRunner");
        Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
        this.taskRunner = taskRunner2;
        this.name = str;
    }

    public final void cancelAll() {
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        synchronized (this.taskRunner) {
            if (cancelAllAndDecide$okhttp()) {
                this.taskRunner.kickCoordinator$okhttp(this);
            }
        }
    }

    public final boolean cancelAllAndDecide$okhttp() {
        Task task = this.activeTask;
        if (task != null) {
            Intrinsics.checkNotNull(task);
            if (task.cancelable) {
                this.cancelActiveTask = true;
            }
        }
        boolean z = false;
        for (int size = this.futureTasks.size() - 1; size >= 0; size--) {
            if (this.futureTasks.get(size).cancelable) {
                Task task2 = this.futureTasks.get(size);
                Objects.requireNonNull(TaskRunner.Companion);
                if (TaskRunner.logger.isLoggable(Level.FINE)) {
                    SystemPropsKt.access$log(task2, this, "canceled");
                }
                this.futureTasks.remove(size);
                z = true;
            }
        }
        return z;
    }

    public final void schedule(Task task, long j) {
        Intrinsics.checkNotNullParameter(task, "task");
        synchronized (this.taskRunner) {
            if (!this.shutdown) {
                if (scheduleAndDecide$okhttp(task, j, false)) {
                    this.taskRunner.kickCoordinator$okhttp(this);
                }
            } else if (task.cancelable) {
                Objects.requireNonNull(TaskRunner.Companion);
                if (TaskRunner.logger.isLoggable(Level.FINE)) {
                    SystemPropsKt.access$log(task, this, "schedule canceled (queue is shutdown)");
                }
            } else {
                Objects.requireNonNull(TaskRunner.Companion);
                if (TaskRunner.logger.isLoggable(Level.FINE)) {
                    SystemPropsKt.access$log(task, this, "schedule failed (queue is shutdown)");
                }
                throw new RejectedExecutionException();
            }
        }
    }

    public final boolean scheduleAndDecide$okhttp(Task task, long j, boolean z) {
        String str;
        Intrinsics.checkNotNullParameter(task, "task");
        Intrinsics.checkNotNullParameter(this, "queue");
        TaskQueue taskQueue = task.queue;
        if (taskQueue != this) {
            if (taskQueue == null) {
                task.queue = this;
            } else {
                throw new IllegalStateException("task is in multiple queues".toString());
            }
        }
        Objects.requireNonNull(this.taskRunner.backend);
        long nanoTime = System.nanoTime();
        long j2 = nanoTime + j;
        int indexOf = this.futureTasks.indexOf(task);
        if (indexOf != -1) {
            if (task.nextExecuteNanoTime <= j2) {
                TaskRunner.Companion companion = TaskRunner.Companion;
                if (TaskRunner.logger.isLoggable(Level.FINE)) {
                    SystemPropsKt.access$log(task, this, "already scheduled");
                }
                return false;
            }
            this.futureTasks.remove(indexOf);
        }
        task.nextExecuteNanoTime = j2;
        TaskRunner.Companion companion2 = TaskRunner.Companion;
        if (TaskRunner.logger.isLoggable(Level.FINE)) {
            if (z) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("run again after ");
                outline25.append(SystemPropsKt.formatDuration(j2 - nanoTime));
                str = outline25.toString();
            } else {
                StringBuilder outline252 = GeneratedOutlineSupport.outline25("scheduled after ");
                outline252.append(SystemPropsKt.formatDuration(j2 - nanoTime));
                str = outline252.toString();
            }
            SystemPropsKt.access$log(task, this, str);
        }
        Iterator<Task> it = this.futureTasks.iterator();
        int i = 0;
        while (true) {
            if (!it.hasNext()) {
                i = -1;
                break;
            }
            if (it.next().nextExecuteNanoTime - nanoTime > j) {
                break;
            }
            i++;
        }
        if (i == -1) {
            i = this.futureTasks.size();
        }
        this.futureTasks.add(i, task);
        if (i == 0) {
            return true;
        }
        return false;
    }

    public final void shutdown() {
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        synchronized (this.taskRunner) {
            this.shutdown = true;
            if (cancelAllAndDecide$okhttp()) {
                this.taskRunner.kickCoordinator$okhttp(this);
            }
        }
    }

    public String toString() {
        return this.name;
    }
}
