package okhttp3.internal.concurrent;

import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.logging.Logger;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.internal.Util;
import okhttp3.internal.Util$threadFactory$1;

/* compiled from: TaskRunner.kt */
public final class TaskRunner {
    public static final Companion Companion = new Companion(null);
    public static final TaskRunner INSTANCE;
    public static final Logger logger;
    public final RealBackend backend;
    public final List<TaskQueue> busyQueues = new ArrayList();
    public boolean coordinatorWaiting;
    public long coordinatorWakeUpAt;
    public int nextQueueName = 10000;
    public final List<TaskQueue> readyQueues = new ArrayList();
    public final Runnable runnable = new TaskRunner$runnable$1(this);

    /* compiled from: TaskRunner.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }
    }

    /* compiled from: TaskRunner.kt */
    public final class RealBackend {
        public final ThreadPoolExecutor executor;

        public RealBackend(ThreadFactory threadFactory) {
            Intrinsics.checkNotNullParameter(threadFactory, "threadFactory");
            this.executor = new ThreadPoolExecutor(0, Integer.MAX_VALUE, 60, TimeUnit.SECONDS, new SynchronousQueue(), threadFactory);
        }

        public void execute(Runnable runnable) {
            Intrinsics.checkNotNullParameter(runnable, "runnable");
            this.executor.execute(runnable);
        }
    }

    static {
        String str = Util.okHttpName + " TaskRunner";
        Intrinsics.checkNotNullParameter(str, VpnProfileDataSource.KEY_NAME);
        INSTANCE = new TaskRunner(new RealBackend(new Util$threadFactory$1(str, true)));
        Logger logger2 = Logger.getLogger(TaskRunner.class.getName());
        Intrinsics.checkNotNullExpressionValue(logger2, "Logger.getLogger(TaskRunner::class.java.name)");
        logger = logger2;
    }

    public TaskRunner(RealBackend realBackend) {
        Intrinsics.checkNotNullParameter(realBackend, "backend");
        this.backend = realBackend;
    }

    public static final void access$runTask(TaskRunner taskRunner, Task task) {
        Objects.requireNonNull(taskRunner);
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        Thread currentThread = Thread.currentThread();
        Intrinsics.checkNotNullExpressionValue(currentThread, "currentThread");
        String name = currentThread.getName();
        currentThread.setName(task.name);
        try {
            long runOnce = task.runOnce();
            synchronized (taskRunner) {
                taskRunner.afterRun(task, runOnce);
            }
            currentThread.setName(name);
        } catch (Throwable th) {
            synchronized (taskRunner) {
                taskRunner.afterRun(task, -1);
                currentThread.setName(name);
                throw th;
            }
        }
    }

    public final void afterRun(Task task, long j) {
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        TaskQueue taskQueue = task.queue;
        Intrinsics.checkNotNull(taskQueue);
        if (taskQueue.activeTask == task) {
            boolean z = taskQueue.cancelActiveTask;
            taskQueue.cancelActiveTask = false;
            taskQueue.activeTask = null;
            this.busyQueues.remove(taskQueue);
            if (j != -1 && !z && !taskQueue.shutdown) {
                taskQueue.scheduleAndDecide$okhttp(task, j, true);
            }
            if (!taskQueue.futureTasks.isEmpty()) {
                this.readyQueues.add(taskQueue);
                return;
            }
            return;
        }
        throw new IllegalStateException("Check failed.".toString());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:37:0x00c4, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:?, code lost:
        cancelAll();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x00cd, code lost:
        r15.coordinatorWaiting = false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00cf, code lost:
        throw r0;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:38:0x00c6 */
    public final Task awaitTaskToRun() {
        boolean z;
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        while (!this.readyQueues.isEmpty()) {
            Objects.requireNonNull(this.backend);
            long nanoTime = System.nanoTime();
            long j = Long.MAX_VALUE;
            Iterator<TaskQueue> it = this.readyQueues.iterator();
            Task task = null;
            while (true) {
                if (!it.hasNext()) {
                    z = false;
                    break;
                }
                Task task2 = it.next().futureTasks.get(0);
                long max = Math.max(0L, task2.nextExecuteNanoTime - nanoTime);
                if (max > 0) {
                    j = Math.min(max, j);
                } else if (task != null) {
                    z = true;
                    break;
                } else {
                    task = task2;
                }
            }
            if (task != null) {
                byte[] bArr2 = Util.EMPTY_BYTE_ARRAY;
                task.nextExecuteNanoTime = -1;
                TaskQueue taskQueue = task.queue;
                Intrinsics.checkNotNull(taskQueue);
                taskQueue.futureTasks.remove(task);
                this.readyQueues.remove(taskQueue);
                taskQueue.activeTask = task;
                this.busyQueues.add(taskQueue);
                if (z || (!this.coordinatorWaiting && (!this.readyQueues.isEmpty()))) {
                    this.backend.execute(this.runnable);
                }
                return task;
            } else if (this.coordinatorWaiting) {
                if (j < this.coordinatorWakeUpAt - nanoTime) {
                    Objects.requireNonNull(this.backend);
                    Intrinsics.checkNotNullParameter(this, "taskRunner");
                    notify();
                }
                return null;
            } else {
                this.coordinatorWaiting = true;
                this.coordinatorWakeUpAt = nanoTime + j;
                Objects.requireNonNull(this.backend);
                Intrinsics.checkNotNullParameter(this, "taskRunner");
                long j2 = j / 1000000;
                Long.signum(j2);
                long j3 = j - (1000000 * j2);
                if (j2 > 0 || j > 0) {
                    wait(j2, (int) j3);
                    this.coordinatorWaiting = false;
                } else {
                    this.coordinatorWaiting = false;
                }
            }
        }
        return null;
    }

    public final void cancelAll() {
        for (int size = this.busyQueues.size() - 1; size >= 0; size--) {
            this.busyQueues.get(size).cancelAllAndDecide$okhttp();
        }
        for (int size2 = this.readyQueues.size() - 1; size2 >= 0; size2--) {
            TaskQueue taskQueue = this.readyQueues.get(size2);
            taskQueue.cancelAllAndDecide$okhttp();
            if (taskQueue.futureTasks.isEmpty()) {
                this.readyQueues.remove(size2);
            }
        }
    }

    public final void kickCoordinator$okhttp(TaskQueue taskQueue) {
        Intrinsics.checkNotNullParameter(taskQueue, "taskQueue");
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        if (taskQueue.activeTask == null) {
            if (!taskQueue.futureTasks.isEmpty()) {
                List<TaskQueue> list = this.readyQueues;
                Intrinsics.checkNotNullParameter(list, "$this$addIfAbsent");
                if (!list.contains(taskQueue)) {
                    list.add(taskQueue);
                }
            } else {
                this.readyQueues.remove(taskQueue);
            }
        }
        if (this.coordinatorWaiting) {
            Objects.requireNonNull(this.backend);
            Intrinsics.checkNotNullParameter(this, "taskRunner");
            notify();
            return;
        }
        this.backend.execute(this.runnable);
    }

    public final TaskQueue newQueue() {
        int i;
        synchronized (this) {
            i = this.nextQueueName;
            this.nextQueueName = i + 1;
        }
        StringBuilder sb = new StringBuilder();
        sb.append('Q');
        sb.append(i);
        return new TaskQueue(this, sb.toString());
    }
}
