package okhttp3.internal.connection;

import com.allpayx.sdk.util.HttpUtil;
import java.io.IOException;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.Interceptor;
import okhttp3.OkHttpClient;
import okhttp3.Response;
import okhttp3.internal.http.RealInterceptorChain;

/* compiled from: ConnectInterceptor.kt */
public final class ConnectInterceptor implements Interceptor {
    public static final ConnectInterceptor INSTANCE = new ConnectInterceptor();

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) {
        Intrinsics.checkNotNullParameter(chain, "chain");
        RealInterceptorChain realInterceptorChain = (RealInterceptorChain) chain;
        RealCall realCall = realInterceptorChain.call;
        Objects.requireNonNull(realCall);
        Intrinsics.checkNotNullParameter(realInterceptorChain, "chain");
        synchronized (realCall) {
            if (!realCall.expectMoreExchanges) {
                throw new IllegalStateException("released".toString());
            } else if (!(!realCall.responseBodyOpen)) {
                throw new IllegalStateException("Check failed.".toString());
            } else if (!(!realCall.requestBodyOpen)) {
                throw new IllegalStateException("Check failed.".toString());
            }
        }
        ExchangeFinder exchangeFinder = realCall.exchangeFinder;
        Intrinsics.checkNotNull(exchangeFinder);
        OkHttpClient okHttpClient = realCall.client;
        Intrinsics.checkNotNullParameter(okHttpClient, "client");
        Intrinsics.checkNotNullParameter(realInterceptorChain, "chain");
        try {
            Exchange exchange = new Exchange(realCall, realCall.eventListener, exchangeFinder, exchangeFinder.findHealthyConnection(realInterceptorChain.connectTimeoutMillis, realInterceptorChain.readTimeoutMillis, realInterceptorChain.writeTimeoutMillis, 0, okHttpClient.retryOnConnectionFailure, !Intrinsics.areEqual(realInterceptorChain.request.method, HttpUtil.METHOD_GET)).newCodec$okhttp(okHttpClient, realInterceptorChain));
            realCall.interceptorScopedExchange = exchange;
            realCall.exchange = exchange;
            synchronized (realCall) {
                realCall.requestBodyOpen = true;
                realCall.responseBodyOpen = true;
            }
            if (!realCall.canceled) {
                return RealInterceptorChain.copy$okhttp$default(realInterceptorChain, 0, exchange, null, 0, 0, 0, 61).proceed(realInterceptorChain.request);
            }
            throw new IOException("Canceled");
        } catch (RouteException e) {
            exchangeFinder.trackFailure(e.getLastConnectException());
            throw e;
        } catch (IOException e2) {
            exchangeFinder.trackFailure(e2);
            throw new RouteException(e2);
        }
    }
}
