package okhttp3.internal.connection;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.net.UnknownServiceException;
import java.util.Arrays;
import java.util.Comparator;
import java.util.List;
import javax.net.ssl.SSLSocket;
import kotlin.comparisons.NaturalOrderComparator;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.CipherSuite;
import okhttp3.CipherSuite$Companion$ORDER_BY_NAME$1;
import okhttp3.ConnectionSpec;
import okhttp3.internal.Util;

/* compiled from: ConnectionSpecSelector.kt */
public final class ConnectionSpecSelector {
    public final List<ConnectionSpec> connectionSpecs;
    public boolean isFallback;
    public boolean isFallbackPossible;
    public int nextModeIndex;

    public ConnectionSpecSelector(List<ConnectionSpec> list) {
        Intrinsics.checkNotNullParameter(list, "connectionSpecs");
        this.connectionSpecs = list;
    }

    public final ConnectionSpec configureSecureSocket(SSLSocket sSLSocket) {
        ConnectionSpec connectionSpec;
        boolean z;
        String[] strArr;
        String[] strArr2;
        Intrinsics.checkNotNullParameter(sSLSocket, "sslSocket");
        int i = this.nextModeIndex;
        int size = this.connectionSpecs.size();
        while (true) {
            if (i >= size) {
                connectionSpec = null;
                break;
            }
            connectionSpec = this.connectionSpecs.get(i);
            if (connectionSpec.isCompatible(sSLSocket)) {
                this.nextModeIndex = i + 1;
                break;
            }
            i++;
        }
        if (connectionSpec != null) {
            int i2 = this.nextModeIndex;
            int size2 = this.connectionSpecs.size();
            while (true) {
                if (i2 >= size2) {
                    z = false;
                    break;
                } else if (this.connectionSpecs.get(i2).isCompatible(sSLSocket)) {
                    z = true;
                    break;
                } else {
                    i2++;
                }
            }
            this.isFallbackPossible = z;
            boolean z2 = this.isFallback;
            Intrinsics.checkNotNullParameter(sSLSocket, "sslSocket");
            if (connectionSpec.cipherSuitesAsString != null) {
                String[] enabledCipherSuites = sSLSocket.getEnabledCipherSuites();
                Intrinsics.checkNotNullExpressionValue(enabledCipherSuites, "sslSocket.enabledCipherSuites");
                String[] strArr3 = connectionSpec.cipherSuitesAsString;
                CipherSuite.Companion companion = CipherSuite.Companion;
                Comparator<String> comparator = CipherSuite.ORDER_BY_NAME;
                strArr = Util.intersect(enabledCipherSuites, strArr3, CipherSuite.ORDER_BY_NAME);
            } else {
                strArr = sSLSocket.getEnabledCipherSuites();
            }
            if (connectionSpec.tlsVersionsAsString != null) {
                String[] enabledProtocols = sSLSocket.getEnabledProtocols();
                Intrinsics.checkNotNullExpressionValue(enabledProtocols, "sslSocket.enabledProtocols");
                strArr2 = Util.intersect(enabledProtocols, connectionSpec.tlsVersionsAsString, NaturalOrderComparator.INSTANCE);
            } else {
                strArr2 = sSLSocket.getEnabledProtocols();
            }
            String[] supportedCipherSuites = sSLSocket.getSupportedCipherSuites();
            Intrinsics.checkNotNullExpressionValue(supportedCipherSuites, "supportedCipherSuites");
            CipherSuite.Companion companion2 = CipherSuite.Companion;
            Comparator<String> comparator2 = CipherSuite.ORDER_BY_NAME;
            Comparator<String> comparator3 = CipherSuite.ORDER_BY_NAME;
            byte[] bArr = Util.EMPTY_BYTE_ARRAY;
            Intrinsics.checkNotNullParameter(supportedCipherSuites, "$this$indexOf");
            Intrinsics.checkNotNullParameter("TLS_FALLBACK_SCSV", "value");
            Intrinsics.checkNotNullParameter(comparator3, "comparator");
            int length = supportedCipherSuites.length;
            int i3 = 0;
            while (true) {
                if (i3 >= length) {
                    i3 = -1;
                    break;
                }
                if (((CipherSuite$Companion$ORDER_BY_NAME$1) comparator3).compare(supportedCipherSuites[i3], "TLS_FALLBACK_SCSV") == 0) {
                    break;
                }
                i3++;
            }
            if (z2 && i3 != -1) {
                Intrinsics.checkNotNullExpressionValue(strArr, "cipherSuitesIntersection");
                String str = supportedCipherSuites[i3];
                Intrinsics.checkNotNullExpressionValue(str, "supportedCipherSuites[indexOfFallbackScsv]");
                Intrinsics.checkNotNullParameter(strArr, "$this$concat");
                Intrinsics.checkNotNullParameter(str, "value");
                Object[] copyOf = Arrays.copyOf(strArr, strArr.length + 1);
                Intrinsics.checkNotNullExpressionValue(copyOf, "java.util.Arrays.copyOf(this, newSize)");
                strArr = (String[]) copyOf;
                Intrinsics.checkNotNullParameter(strArr, "$this$lastIndex");
                strArr[strArr.length - 1] = str;
            }
            ConnectionSpec.Builder builder = new ConnectionSpec.Builder(connectionSpec);
            Intrinsics.checkNotNullExpressionValue(strArr, "cipherSuitesIntersection");
            builder.cipherSuites((String[]) Arrays.copyOf(strArr, strArr.length));
            Intrinsics.checkNotNullExpressionValue(strArr2, "tlsVersionsIntersection");
            builder.tlsVersions((String[]) Arrays.copyOf(strArr2, strArr2.length));
            ConnectionSpec build = builder.build();
            if (build.tlsVersions() != null) {
                sSLSocket.setEnabledProtocols(build.tlsVersionsAsString);
            }
            if (build.cipherSuites() != null) {
                sSLSocket.setEnabledCipherSuites(build.cipherSuitesAsString);
            }
            return connectionSpec;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Unable to find acceptable protocols. isFallback=");
        outline25.append(this.isFallback);
        outline25.append(StringUtil.COMMA);
        outline25.append(" modes=");
        outline25.append(this.connectionSpecs);
        outline25.append(StringUtil.COMMA);
        outline25.append(" supported protocols=");
        String[] enabledProtocols2 = sSLSocket.getEnabledProtocols();
        Intrinsics.checkNotNull(enabledProtocols2);
        String arrays = Arrays.toString(enabledProtocols2);
        Intrinsics.checkNotNullExpressionValue(arrays, "java.util.Arrays.toString(this)");
        outline25.append(arrays);
        throw new UnknownServiceException(outline25.toString());
    }
}
