package okhttp3.internal.http;

import java.util.Objects;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.collections.EmptyList;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.Cookie;
import okhttp3.CookieJar;
import okhttp3.CookieJar$Companion$NoCookies;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.Util;
import okio.GzipSource;

/* compiled from: BridgeInterceptor.kt */
public final class BridgeInterceptor implements Interceptor {
    public final CookieJar cookieJar;

    public BridgeInterceptor(CookieJar cookieJar2) {
        Intrinsics.checkNotNullParameter(cookieJar2, "cookieJar");
        this.cookieJar = cookieJar2;
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) {
        boolean z;
        ResponseBody responseBody;
        Intrinsics.checkNotNullParameter(chain, "chain");
        RealInterceptorChain realInterceptorChain = (RealInterceptorChain) chain;
        Request request = realInterceptorChain.request;
        Objects.requireNonNull(request);
        Request.Builder builder = new Request.Builder(request);
        RequestBody requestBody = request.body;
        if (requestBody != null) {
            MediaType contentType = requestBody.contentType();
            if (contentType != null) {
                builder.header("Content-Type", contentType.mediaType);
            }
            long contentLength = requestBody.contentLength();
            if (contentLength != -1) {
                builder.header("Content-Length", String.valueOf(contentLength));
                builder.removeHeader("Transfer-Encoding");
            } else {
                builder.header("Transfer-Encoding", "chunked");
                builder.removeHeader("Content-Length");
            }
        }
        int i = 0;
        if (request.header("Host") == null) {
            builder.header("Host", Util.toHostHeader(request.url, false));
        }
        if (request.header("Connection") == null) {
            builder.header("Connection", "Keep-Alive");
        }
        if (request.header("Accept-Encoding") == null && request.header("Range") == null) {
            builder.header("Accept-Encoding", "gzip");
            z = true;
        } else {
            z = false;
        }
        CookieJar cookieJar2 = this.cookieJar;
        HttpUrl httpUrl = request.url;
        Objects.requireNonNull((CookieJar$Companion$NoCookies) cookieJar2);
        Intrinsics.checkNotNullParameter(httpUrl, "url");
        EmptyList emptyList = EmptyList.INSTANCE;
        if (!emptyList.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            for (Object obj : emptyList) {
                int i2 = i + 1;
                if (i >= 0) {
                    Cookie cookie = (Cookie) obj;
                    if (i > 0) {
                        sb.append("; ");
                    }
                    sb.append(cookie.name);
                    sb.append('=');
                    sb.append(cookie.value);
                    i = i2;
                } else {
                    ArraysKt___ArraysKt.throwIndexOverflow();
                    throw null;
                }
            }
            String sb2 = sb.toString();
            Intrinsics.checkNotNullExpressionValue(sb2, "StringBuilder().apply(builderAction).toString()");
            builder.header("Cookie", sb2);
        }
        if (request.header("User-Agent") == null) {
            builder.header("User-Agent", "okhttp/4.9.1");
        }
        Response proceed = realInterceptorChain.proceed(builder.build());
        HttpHeaders.receiveHeaders(this.cookieJar, request.url, proceed.headers);
        Response.Builder builder2 = new Response.Builder(proceed);
        builder2.request(request);
        if (z && StringsKt__IndentKt.equals("gzip", Response.header$default(proceed, "Content-Encoding", null, 2), true) && HttpHeaders.promisesBody(proceed) && (responseBody = proceed.body) != null) {
            GzipSource gzipSource = new GzipSource(responseBody.source());
            Headers.Builder newBuilder = proceed.headers.newBuilder();
            newBuilder.removeAll("Content-Encoding");
            newBuilder.removeAll("Content-Length");
            builder2.headers(newBuilder.build());
            builder2.body = new RealResponseBody(Response.header$default(proceed, "Content-Type", null, 2), -1, SystemPropsKt.buffer(gzipSource));
        }
        return builder2.build();
    }
}
