package okhttp3.internal.http;

import com.allpayx.sdk.constants.AllPayConst;
import com.allpayx.sdk.util.HttpUtil;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.net.ProtocolException;
import java.net.Proxy;
import java.net.SocketTimeoutException;
import java.security.cert.CertificateException;
import java.util.ArrayList;
import java.util.Objects;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLHandshakeException;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSocketFactory;
import kotlin.collections.EmptyList;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.Regex;
import okhttp3.Address;
import okhttp3.CertificatePinner;
import okhttp3.Handshake;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.Interceptor;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.Route;
import okhttp3.internal.Util;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.connection.ExchangeFinder;
import okhttp3.internal.connection.RealCall;
import okhttp3.internal.connection.RealConnection;
import okhttp3.internal.connection.RealConnectionPool;
import okhttp3.internal.connection.RouteException;
import okhttp3.internal.connection.RouteSelector;
import okhttp3.internal.http2.ConnectionShutdownException;

/* compiled from: RetryAndFollowUpInterceptor.kt */
public final class RetryAndFollowUpInterceptor implements Interceptor {
    public final OkHttpClient client;

    public RetryAndFollowUpInterceptor(OkHttpClient okHttpClient) {
        Intrinsics.checkNotNullParameter(okHttpClient, "client");
        this.client = okHttpClient;
    }

    public final Request followUpRequest(Response response, Exchange exchange) {
        String header$default;
        HttpUrl.Builder builder;
        RealConnection realConnection;
        RequestBody requestBody = null;
        Route route = (exchange == null || (realConnection = exchange.connection) == null) ? null : realConnection.route;
        int i = response.code;
        String str = response.request.method;
        boolean z = false;
        if (!(i == 307 || i == 308)) {
            if (i == 401) {
                return this.client.authenticator.authenticate(route, response);
            }
            if (i != 421) {
                if (i == 503) {
                    Response response2 = response.priorResponse;
                    if ((response2 == null || response2.code != 503) && retryAfter(response, Integer.MAX_VALUE) == 0) {
                        return response.request;
                    }
                    return null;
                } else if (i == 407) {
                    Intrinsics.checkNotNull(route);
                    if (route.proxy.type() == Proxy.Type.HTTP) {
                        return this.client.proxyAuthenticator.authenticate(route, response);
                    }
                    throw new ProtocolException("Received HTTP_PROXY_AUTH (407) code while not using proxy");
                } else if (i != 408) {
                    switch (i) {
                        case AllPayConst.MSG_VTPAY_PAY_START_AP:
                        case 301:
                        case 302:
                        case 303:
                            break;
                        default:
                            return null;
                    }
                } else if (!this.client.retryOnConnectionFailure) {
                    return null;
                } else {
                    Response response3 = response.priorResponse;
                    if ((response3 == null || response3.code != 408) && retryAfter(response, 0) <= 0) {
                        return response.request;
                    }
                    return null;
                }
            } else if (exchange == null || !(!Intrinsics.areEqual(exchange.finder.address.url.host, exchange.connection.route.address.url.host))) {
                return null;
            } else {
                RealConnection realConnection2 = exchange.connection;
                synchronized (realConnection2) {
                    realConnection2.noCoalescedConnections = true;
                }
                return response.request;
            }
        }
        if (!this.client.followRedirects || (header$default = Response.header$default(response, "Location", null, 2)) == null) {
            return null;
        }
        HttpUrl httpUrl = response.request.url;
        Objects.requireNonNull(httpUrl);
        Intrinsics.checkNotNullParameter(header$default, "link");
        Intrinsics.checkNotNullParameter(header$default, "link");
        try {
            builder = new HttpUrl.Builder();
            builder.parse$okhttp(httpUrl, header$default);
        } catch (IllegalArgumentException unused) {
            builder = null;
        }
        HttpUrl build = builder != null ? builder.build() : null;
        if (build == null) {
            return null;
        }
        if (!Intrinsics.areEqual(build.scheme, response.request.url.scheme) && !this.client.followSslRedirects) {
            return null;
        }
        Request request = response.request;
        Objects.requireNonNull(request);
        Request.Builder builder2 = new Request.Builder(request);
        if (HttpMethod.permitsRequestBody(str)) {
            int i2 = response.code;
            Intrinsics.checkNotNullParameter(str, "method");
            if (Intrinsics.areEqual(str, "PROPFIND") || i2 == 308 || i2 == 307) {
                z = true;
            }
            Intrinsics.checkNotNullParameter(str, "method");
            if (!(true ^ Intrinsics.areEqual(str, "PROPFIND")) || i2 == 308 || i2 == 307) {
                if (z) {
                    requestBody = response.request.body;
                }
                builder2.method(str, requestBody);
            } else {
                builder2.method(HttpUtil.METHOD_GET, null);
            }
            if (!z) {
                builder2.removeHeader("Transfer-Encoding");
                builder2.removeHeader("Content-Length");
                builder2.removeHeader("Content-Type");
            }
        }
        if (!Util.canReuseConnectionFor(response.request.url, build)) {
            builder2.removeHeader("Authorization");
        }
        builder2.url(build);
        return builder2.build();
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v9, resolved type: java.util.ArrayList */
    /* JADX DEBUG: Multi-variable search result rejected for r0v29, resolved type: java.util.ArrayList */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) {
        RealCall realCall;
        Throwable th;
        int i;
        EmptyList emptyList;
        RealCall realCall2;
        Throwable th2;
        RealInterceptorChain realInterceptorChain;
        RealCall realCall3;
        Request request;
        Protocol protocol;
        int i2;
        String str;
        Handshake handshake;
        Headers.Builder newBuilder;
        ResponseBody responseBody;
        Response response;
        Response response2;
        long j;
        CertificatePinner certificatePinner;
        HostnameVerifier hostnameVerifier;
        SSLSocketFactory sSLSocketFactory;
        RetryAndFollowUpInterceptor retryAndFollowUpInterceptor = this;
        Intrinsics.checkNotNullParameter(chain, "chain");
        RealInterceptorChain realInterceptorChain2 = (RealInterceptorChain) chain;
        Request request2 = realInterceptorChain2.request;
        RealCall realCall4 = realInterceptorChain2.call;
        boolean z = true;
        EmptyList emptyList2 = EmptyList.INSTANCE;
        int i3 = 0;
        Response response3 = null;
        Request request3 = request2;
        boolean z2 = true;
        while (true) {
            Objects.requireNonNull(realCall4);
            Intrinsics.checkNotNullParameter(request3, "request");
            if (realCall4.interceptorScopedExchange == null) {
                synchronized (realCall4) {
                    try {
                        if (!(realCall4.responseBodyOpen ^ z)) {
                            throw new IllegalStateException("cannot make a new request because the previous response is still open: please call response.close()".toString());
                        } else if (!(realCall4.requestBodyOpen ^ z)) {
                            realCall = realCall4;
                            try {
                                throw new IllegalStateException("Check failed.".toString());
                            } catch (Throwable th3) {
                                th = th3;
                                throw th;
                            }
                        }
                    } catch (Throwable th4) {
                        th = th4;
                        realCall = realCall4;
                        throw th;
                    }
                }
                if (z2) {
                    RealConnectionPool realConnectionPool = realCall4.connectionPool;
                    HttpUrl httpUrl = request3.url;
                    if (httpUrl.isHttps) {
                        OkHttpClient okHttpClient = realCall4.client;
                        SSLSocketFactory sSLSocketFactory2 = okHttpClient.sslSocketFactoryOrNull;
                        if (sSLSocketFactory2 != null) {
                            HostnameVerifier hostnameVerifier2 = okHttpClient.hostnameVerifier;
                            certificatePinner = okHttpClient.certificatePinner;
                            sSLSocketFactory = sSLSocketFactory2;
                            hostnameVerifier = hostnameVerifier2;
                        } else {
                            throw new IllegalStateException("CLEARTEXT-only client");
                        }
                    } else {
                        sSLSocketFactory = null;
                        hostnameVerifier = null;
                        certificatePinner = null;
                    }
                    String str2 = httpUrl.host;
                    int i4 = httpUrl.port;
                    OkHttpClient okHttpClient2 = realCall4.client;
                    emptyList = emptyList2;
                    i = i3;
                    realCall4.exchangeFinder = new ExchangeFinder(realConnectionPool, new Address(str2, i4, okHttpClient2.dns, okHttpClient2.socketFactory, sSLSocketFactory, hostnameVerifier, certificatePinner, okHttpClient2.proxyAuthenticator, null, okHttpClient2.protocols, okHttpClient2.connectionSpecs, okHttpClient2.proxySelector), realCall4, realCall4.eventListener);
                } else {
                    emptyList = emptyList2;
                    i = i3;
                }
                try {
                    if (!realCall4.canceled) {
                        try {
                            Response proceed = realInterceptorChain2.proceed(request3);
                            if (response3 != null) {
                                try {
                                    Intrinsics.checkNotNullParameter(proceed, "response");
                                    request = proceed.request;
                                    protocol = proceed.protocol;
                                    i2 = proceed.code;
                                    str = proceed.message;
                                    handshake = proceed.handshake;
                                    newBuilder = proceed.headers.newBuilder();
                                    responseBody = proceed.body;
                                    response = proceed.networkResponse;
                                    response2 = proceed.cacheResponse;
                                    j = proceed.sentRequestAtMillis;
                                    realCall3 = realCall4;
                                } catch (Throwable th5) {
                                    th2 = th5;
                                    realCall3 = realCall4;
                                    realCall2 = realCall3;
                                    realCall2.exitNetworkInterceptorExchange$okhttp(true);
                                    throw th2;
                                }
                                try {
                                    long j2 = proceed.receivedResponseAtMillis;
                                    Exchange exchange = proceed.exchange;
                                    realInterceptorChain = realInterceptorChain2;
                                    Intrinsics.checkNotNullParameter(response3, "response");
                                    Request request4 = response3.request;
                                    Protocol protocol2 = response3.protocol;
                                    int i5 = response3.code;
                                    String str3 = response3.message;
                                    Handshake handshake2 = response3.handshake;
                                    Headers.Builder newBuilder2 = response3.headers.newBuilder();
                                    Response response4 = response3.networkResponse;
                                    Response response5 = response3.cacheResponse;
                                    Response response6 = response3.priorResponse;
                                    long j3 = response3.sentRequestAtMillis;
                                    long j4 = response3.receivedResponseAtMillis;
                                    Exchange exchange2 = response3.exchange;
                                    if (!(i5 >= 0)) {
                                        throw new IllegalStateException(("code < 0: " + i5).toString());
                                    } else if (request4 == null) {
                                        throw new IllegalStateException("request == null".toString());
                                    } else if (protocol2 == null) {
                                        throw new IllegalStateException("protocol == null".toString());
                                    } else if (str3 != null) {
                                        Response response7 = new Response(request4, protocol2, str3, i5, handshake2, newBuilder2.build(), null, response4, response5, response6, j3, j4, exchange2);
                                        if (response7.body == null) {
                                            if (!(i2 >= 0)) {
                                                throw new IllegalStateException(("code < 0: " + i2).toString());
                                            } else if (request == null) {
                                                throw new IllegalStateException("request == null".toString());
                                            } else if (protocol == null) {
                                                throw new IllegalStateException("protocol == null".toString());
                                            } else if (str != null) {
                                                proceed = new Response(request, protocol, str, i2, handshake, newBuilder.build(), responseBody, response, response2, response7, j, j2, exchange);
                                            } else {
                                                throw new IllegalStateException("message == null".toString());
                                            }
                                        } else {
                                            throw new IllegalArgumentException("priorResponse.body != null".toString());
                                        }
                                    } else {
                                        throw new IllegalStateException("message == null".toString());
                                    }
                                } catch (Throwable th6) {
                                    th2 = th6;
                                    realCall2 = realCall3;
                                    realCall2.exitNetworkInterceptorExchange$okhttp(true);
                                    throw th2;
                                }
                            } else {
                                realInterceptorChain = realInterceptorChain2;
                                realCall3 = realCall4;
                            }
                            response3 = proceed;
                            realCall2 = realCall3;
                        } catch (RouteException e) {
                            if (recover(e.getLastConnectException(), realCall4, request3, false)) {
                                IOException firstConnectException = e.getFirstConnectException();
                                Intrinsics.checkNotNullParameter(emptyList, "$this$plus");
                                ArrayList arrayList = new ArrayList(emptyList.size() + 1);
                                arrayList.addAll(emptyList);
                                arrayList.add(firstConnectException);
                                realCall4.exitNetworkInterceptorExchange$okhttp(true);
                                emptyList2 = arrayList;
                                i3 = i;
                                z2 = false;
                                z = true;
                                realCall4 = realCall4;
                                retryAndFollowUpInterceptor = this;
                                realInterceptorChain2 = realInterceptorChain2;
                            } else {
                                IOException firstConnectException2 = e.getFirstConnectException();
                                Util.withSuppressed(firstConnectException2, emptyList);
                                throw firstConnectException2;
                            }
                        } catch (IOException e2) {
                            if (recover(e2, realCall4, request3, !(e2 instanceof ConnectionShutdownException))) {
                                Intrinsics.checkNotNullParameter(emptyList, "$this$plus");
                                z = true;
                                ArrayList arrayList2 = new ArrayList(emptyList.size() + 1);
                                arrayList2.addAll(emptyList);
                                arrayList2.add(e2);
                                realCall4.exitNetworkInterceptorExchange$okhttp(true);
                                emptyList2 = arrayList2;
                                realCall4 = realCall4;
                                retryAndFollowUpInterceptor = this;
                                realInterceptorChain2 = realInterceptorChain2;
                                i3 = i;
                                z2 = false;
                            } else {
                                Util.withSuppressed(e2, emptyList);
                                throw e2;
                            }
                        }
                        try {
                            Exchange exchange3 = realCall2.interceptorScopedExchange;
                            try {
                                request3 = followUpRequest(response3, exchange3);
                                if (request3 == null) {
                                    if (exchange3 != null && exchange3.isDuplex) {
                                        if (!realCall2.timeoutEarlyExit) {
                                            realCall2.timeoutEarlyExit = true;
                                            realCall2.timeout.exit();
                                        } else {
                                            throw new IllegalStateException("Check failed.".toString());
                                        }
                                    }
                                    realCall2.exitNetworkInterceptorExchange$okhttp(false);
                                    return response3;
                                }
                                ResponseBody responseBody2 = response3.body;
                                if (responseBody2 != null) {
                                    Util.closeQuietly(responseBody2);
                                }
                                i3 = i + 1;
                                if (i3 <= 20) {
                                    realCall2.exitNetworkInterceptorExchange$okhttp(true);
                                    realCall4 = realCall2;
                                    retryAndFollowUpInterceptor = this;
                                    realInterceptorChain2 = realInterceptorChain;
                                    emptyList2 = emptyList;
                                    z2 = true;
                                    z = true;
                                } else {
                                    throw new ProtocolException("Too many follow-up requests: " + i3);
                                }
                            } catch (Throwable th7) {
                                th2 = th7;
                                realCall2.exitNetworkInterceptorExchange$okhttp(true);
                                throw th2;
                            }
                        } catch (Throwable th8) {
                            th2 = th8;
                            realCall2.exitNetworkInterceptorExchange$okhttp(true);
                            throw th2;
                        }
                    } else {
                        throw new IOException("Canceled");
                    }
                } catch (Throwable th9) {
                    th2 = th9;
                    realCall2 = realCall4;
                    realCall2.exitNetworkInterceptorExchange$okhttp(true);
                    throw th2;
                }
            } else {
                throw new IllegalStateException("Check failed.".toString());
            }
        }
    }

    public final boolean recover(IOException iOException, RealCall realCall, Request request, boolean z) {
        boolean z2;
        RouteSelector routeSelector;
        RealConnection realConnection;
        if (!this.client.retryOnConnectionFailure) {
            return false;
        }
        if (z && (iOException instanceof FileNotFoundException)) {
            return false;
        }
        if (!(!(iOException instanceof ProtocolException) && (!(iOException instanceof InterruptedIOException) ? (!(iOException instanceof SSLHandshakeException) || !(iOException.getCause() instanceof CertificateException)) && !(iOException instanceof SSLPeerUnverifiedException) : (iOException instanceof SocketTimeoutException) && !z))) {
            return false;
        }
        ExchangeFinder exchangeFinder = realCall.exchangeFinder;
        Intrinsics.checkNotNull(exchangeFinder);
        int i = exchangeFinder.refusedStreamCount;
        if (i == 0 && exchangeFinder.connectionShutdownCount == 0 && exchangeFinder.otherFailureCount == 0) {
            z2 = false;
        } else {
            if (exchangeFinder.nextRouteToTry == null) {
                Route route = null;
                if (i <= 1 && exchangeFinder.connectionShutdownCount <= 1 && exchangeFinder.otherFailureCount <= 0 && (realConnection = exchangeFinder.call.connection) != null) {
                    synchronized (realConnection) {
                        if (realConnection.routeFailureCount == 0) {
                            if (Util.canReuseConnectionFor(realConnection.route.address.url, exchangeFinder.address.url)) {
                                route = realConnection.route;
                            }
                        }
                    }
                }
                if (route != null) {
                    exchangeFinder.nextRouteToTry = route;
                } else {
                    RouteSelector.Selection selection = exchangeFinder.routeSelection;
                    if ((selection == null || !selection.hasNext()) && (routeSelector = exchangeFinder.routeSelector) != null) {
                        z2 = routeSelector.hasNext();
                    }
                }
            }
            z2 = true;
        }
        if (!z2) {
            return false;
        }
        return true;
    }

    public final int retryAfter(Response response, int i) {
        String header$default = Response.header$default(response, "Retry-After", null, 2);
        if (header$default == null) {
            return i;
        }
        if (!new Regex("\\d+").matches(header$default)) {
            return Integer.MAX_VALUE;
        }
        Integer valueOf = Integer.valueOf(header$default);
        Intrinsics.checkNotNullExpressionValue(valueOf, "Integer.valueOf(header)");
        return valueOf.intValue();
    }
}
