package okhttp3.internal.http;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.net.ProtocolException;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import okhttp3.Protocol;

/* compiled from: StatusLine.kt */
public final class StatusLine {
    public final int code;
    public final String message;
    public final Protocol protocol;

    public StatusLine(Protocol protocol2, int i, String str) {
        Intrinsics.checkNotNullParameter(protocol2, "protocol");
        Intrinsics.checkNotNullParameter(str, "message");
        this.protocol = protocol2;
        this.code = i;
        this.message = str;
    }

    public static final StatusLine parse(String str) {
        Protocol protocol2;
        String str2;
        Intrinsics.checkNotNullParameter(str, "statusLine");
        int i = 9;
        if (StringsKt__IndentKt.startsWith$default(str, "HTTP/1.", false, 2)) {
            if (str.length() < 9 || str.charAt(8) != ' ') {
                throw new ProtocolException(GeneratedOutlineSupport.outline18("Unexpected status line: ", str));
            }
            int charAt = str.charAt(7) - '0';
            if (charAt == 0) {
                protocol2 = Protocol.HTTP_1_0;
            } else if (charAt == 1) {
                protocol2 = Protocol.HTTP_1_1;
            } else {
                throw new ProtocolException(GeneratedOutlineSupport.outline18("Unexpected status line: ", str));
            }
        } else if (StringsKt__IndentKt.startsWith$default(str, "ICY ", false, 2)) {
            protocol2 = Protocol.HTTP_1_0;
            i = 4;
        } else {
            throw new ProtocolException(GeneratedOutlineSupport.outline18("Unexpected status line: ", str));
        }
        int i2 = i + 3;
        if (str.length() >= i2) {
            try {
                String substring = str.substring(i, i2);
                Intrinsics.checkNotNullExpressionValue(substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
                int parseInt = Integer.parseInt(substring);
                if (str.length() <= i2) {
                    str2 = "";
                } else if (str.charAt(i2) == ' ') {
                    str2 = str.substring(i + 4);
                    Intrinsics.checkNotNullExpressionValue(str2, "(this as java.lang.String).substring(startIndex)");
                } else {
                    throw new ProtocolException(GeneratedOutlineSupport.outline18("Unexpected status line: ", str));
                }
                return new StatusLine(protocol2, parseInt, str2);
            } catch (NumberFormatException unused) {
                throw new ProtocolException(GeneratedOutlineSupport.outline18("Unexpected status line: ", str));
            }
        } else {
            throw new ProtocolException(GeneratedOutlineSupport.outline18("Unexpected status line: ", str));
        }
    }

    public String toString() {
        StringBuilder sb = new StringBuilder();
        if (this.protocol == Protocol.HTTP_1_0) {
            sb.append("HTTP/1.0");
        } else {
            sb.append("HTTP/1.1");
        }
        sb.append(StringUtil.SPACE);
        sb.append(this.code);
        sb.append(StringUtil.SPACE);
        sb.append(this.message);
        String sb2 = sb.toString();
        Intrinsics.checkNotNullExpressionValue(sb2, "StringBuilder().apply(builderAction).toString()");
        return sb2;
    }
}
