package okhttp3.internal.http1;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.io.EOFException;
import java.io.IOException;
import java.net.ProtocolException;
import java.net.Proxy;
import java.net.Socket;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import okhttp3.CookieJar;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.connection.RealConnection;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.http.StatusLine;
import okio.Buffer;
import okio.BufferedSink;
import okio.BufferedSource;
import okio.ForwardingTimeout;
import okio.Sink;
import okio.Source;
import okio.Timeout;

/* compiled from: Http1ExchangeCodec.kt */
public final class Http1ExchangeCodec implements ExchangeCodec {
    public final OkHttpClient client;
    public final RealConnection connection;
    public final HeadersReader headersReader;
    public final BufferedSink sink;
    public final BufferedSource source;
    public int state;
    public Headers trailers;

    /* compiled from: Http1ExchangeCodec.kt */
    public abstract class AbstractSource implements Source {
        public boolean closed;
        public final ForwardingTimeout timeout;

        public AbstractSource() {
            this.timeout = new ForwardingTimeout(Http1ExchangeCodec.this.source.timeout());
        }

        @Override // okio.Source
        public long read(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "sink");
            try {
                return Http1ExchangeCodec.this.source.read(buffer, j);
            } catch (IOException e) {
                Http1ExchangeCodec.this.connection.noNewExchanges$okhttp();
                responseBodyComplete();
                throw e;
            }
        }

        public final void responseBodyComplete() {
            Http1ExchangeCodec http1ExchangeCodec = Http1ExchangeCodec.this;
            int i = http1ExchangeCodec.state;
            if (i != 6) {
                if (i == 5) {
                    Http1ExchangeCodec.access$detachTimeout(http1ExchangeCodec, this.timeout);
                    Http1ExchangeCodec.this.state = 6;
                    return;
                }
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
                outline25.append(Http1ExchangeCodec.this.state);
                throw new IllegalStateException(outline25.toString());
            }
        }

        @Override // okio.Source
        public Timeout timeout() {
            return this.timeout;
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class ChunkedSink implements Sink {
        public boolean closed;
        public final ForwardingTimeout timeout;

        public ChunkedSink() {
            this.timeout = new ForwardingTimeout(Http1ExchangeCodec.this.sink.timeout());
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
        public synchronized void close() {
            if (!this.closed) {
                this.closed = true;
                Http1ExchangeCodec.this.sink.writeUtf8("0\r\n\r\n");
                Http1ExchangeCodec.access$detachTimeout(Http1ExchangeCodec.this, this.timeout);
                Http1ExchangeCodec.this.state = 3;
            }
        }

        @Override // okio.Sink, java.io.Flushable
        public synchronized void flush() {
            if (!this.closed) {
                Http1ExchangeCodec.this.sink.flush();
            }
        }

        @Override // okio.Sink
        public Timeout timeout() {
            return this.timeout;
        }

        @Override // okio.Sink
        public void write(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "source");
            if (!(!this.closed)) {
                throw new IllegalStateException("closed".toString());
            } else if (j != 0) {
                Http1ExchangeCodec.this.sink.writeHexadecimalUnsignedLong(j);
                Http1ExchangeCodec.this.sink.writeUtf8("\r\n");
                Http1ExchangeCodec.this.sink.write(buffer, j);
                Http1ExchangeCodec.this.sink.writeUtf8("\r\n");
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class ChunkedSource extends AbstractSource {
        public long bytesRemainingInChunk = -1;
        public boolean hasMoreChunks = true;
        public final /* synthetic */ Http1ExchangeCodec this$0;
        public final HttpUrl url;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public ChunkedSource(Http1ExchangeCodec http1ExchangeCodec, HttpUrl httpUrl) {
            super();
            Intrinsics.checkNotNullParameter(httpUrl, "url");
            this.this$0 = http1ExchangeCodec;
            this.url = httpUrl;
        }

        @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                if (this.hasMoreChunks && !Util.discard(this, 100, TimeUnit.MILLISECONDS)) {
                    this.this$0.connection.noNewExchanges$okhttp();
                    responseBodyComplete();
                }
                this.closed = true;
            }
        }

        @Override // okio.Source, okhttp3.internal.http1.Http1ExchangeCodec.AbstractSource
        public long read(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "sink");
            boolean z = true;
            if (!(j >= 0)) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j).toString());
            } else if (!(!this.closed)) {
                throw new IllegalStateException("closed".toString());
            } else if (!this.hasMoreChunks) {
                return -1;
            } else {
                long j2 = this.bytesRemainingInChunk;
                if (j2 == 0 || j2 == -1) {
                    if (j2 != -1) {
                        this.this$0.source.readUtf8LineStrict();
                    }
                    try {
                        this.bytesRemainingInChunk = this.this$0.source.readHexadecimalUnsignedLong();
                        String readUtf8LineStrict = this.this$0.source.readUtf8LineStrict();
                        if (readUtf8LineStrict != null) {
                            String obj = StringsKt__IndentKt.trim(readUtf8LineStrict).toString();
                            if (this.bytesRemainingInChunk >= 0) {
                                if (obj.length() <= 0) {
                                    z = false;
                                }
                                if (!z || StringsKt__IndentKt.startsWith$default(obj, ";", false, 2)) {
                                    if (this.bytesRemainingInChunk == 0) {
                                        this.hasMoreChunks = false;
                                        Http1ExchangeCodec http1ExchangeCodec = this.this$0;
                                        http1ExchangeCodec.trailers = http1ExchangeCodec.headersReader.readHeaders();
                                        OkHttpClient okHttpClient = this.this$0.client;
                                        Intrinsics.checkNotNull(okHttpClient);
                                        CookieJar cookieJar = okHttpClient.cookieJar;
                                        HttpUrl httpUrl = this.url;
                                        Headers headers = this.this$0.trailers;
                                        Intrinsics.checkNotNull(headers);
                                        HttpHeaders.receiveHeaders(cookieJar, httpUrl, headers);
                                        responseBodyComplete();
                                    }
                                    if (!this.hasMoreChunks) {
                                        return -1;
                                    }
                                }
                            }
                            throw new ProtocolException("expected chunk size and optional extensions" + " but was \"" + this.bytesRemainingInChunk + obj + StringUtil.DOUBLE_QUOTE);
                        }
                        throw new NullPointerException("null cannot be cast to non-null type kotlin.CharSequence");
                    } catch (NumberFormatException e) {
                        throw new ProtocolException(e.getMessage());
                    }
                }
                long read = super.read(buffer, Math.min(j, this.bytesRemainingInChunk));
                if (read != -1) {
                    this.bytesRemainingInChunk -= read;
                    return read;
                }
                this.this$0.connection.noNewExchanges$okhttp();
                ProtocolException protocolException = new ProtocolException("unexpected end of stream");
                responseBodyComplete();
                throw protocolException;
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class FixedLengthSource extends AbstractSource {
        public long bytesRemaining;

        public FixedLengthSource(long j) {
            super();
            this.bytesRemaining = j;
            if (j == 0) {
                responseBodyComplete();
            }
        }

        @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                if (this.bytesRemaining != 0 && !Util.discard(this, 100, TimeUnit.MILLISECONDS)) {
                    Http1ExchangeCodec.this.connection.noNewExchanges$okhttp();
                    responseBodyComplete();
                }
                this.closed = true;
            }
        }

        @Override // okio.Source, okhttp3.internal.http1.Http1ExchangeCodec.AbstractSource
        public long read(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "sink");
            if (!(j >= 0)) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j).toString());
            } else if (!this.closed) {
                long j2 = this.bytesRemaining;
                if (j2 == 0) {
                    return -1;
                }
                long read = super.read(buffer, Math.min(j2, j));
                if (read != -1) {
                    long j3 = this.bytesRemaining - read;
                    this.bytesRemaining = j3;
                    if (j3 == 0) {
                        responseBodyComplete();
                    }
                    return read;
                }
                Http1ExchangeCodec.this.connection.noNewExchanges$okhttp();
                ProtocolException protocolException = new ProtocolException("unexpected end of stream");
                responseBodyComplete();
                throw protocolException;
            } else {
                throw new IllegalStateException("closed".toString());
            }
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class KnownLengthSink implements Sink {
        public boolean closed;
        public final ForwardingTimeout timeout;

        public KnownLengthSink() {
            this.timeout = new ForwardingTimeout(Http1ExchangeCodec.this.sink.timeout());
        }

        @Override // java.io.Closeable, java.lang.AutoCloseable, okio.Sink
        public void close() {
            if (!this.closed) {
                this.closed = true;
                Http1ExchangeCodec.access$detachTimeout(Http1ExchangeCodec.this, this.timeout);
                Http1ExchangeCodec.this.state = 3;
            }
        }

        @Override // okio.Sink, java.io.Flushable
        public void flush() {
            if (!this.closed) {
                Http1ExchangeCodec.this.sink.flush();
            }
        }

        @Override // okio.Sink
        public Timeout timeout() {
            return this.timeout;
        }

        @Override // okio.Sink
        public void write(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "source");
            if (!this.closed) {
                Util.checkOffsetAndCount(buffer.size, 0, j);
                Http1ExchangeCodec.this.sink.write(buffer, j);
                return;
            }
            throw new IllegalStateException("closed".toString());
        }
    }

    /* compiled from: Http1ExchangeCodec.kt */
    public final class UnknownLengthSource extends AbstractSource {
        public boolean inputExhausted;

        public UnknownLengthSource(Http1ExchangeCodec http1ExchangeCodec) {
            super();
        }

        @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                if (!this.inputExhausted) {
                    responseBodyComplete();
                }
                this.closed = true;
            }
        }

        @Override // okio.Source, okhttp3.internal.http1.Http1ExchangeCodec.AbstractSource
        public long read(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "sink");
            if (!(j >= 0)) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j).toString());
            } else if (!(!this.closed)) {
                throw new IllegalStateException("closed".toString());
            } else if (this.inputExhausted) {
                return -1;
            } else {
                long read = super.read(buffer, j);
                if (read != -1) {
                    return read;
                }
                this.inputExhausted = true;
                responseBodyComplete();
                return -1;
            }
        }
    }

    public Http1ExchangeCodec(OkHttpClient okHttpClient, RealConnection realConnection, BufferedSource bufferedSource, BufferedSink bufferedSink) {
        Intrinsics.checkNotNullParameter(realConnection, "connection");
        Intrinsics.checkNotNullParameter(bufferedSource, "source");
        Intrinsics.checkNotNullParameter(bufferedSink, "sink");
        this.client = okHttpClient;
        this.connection = realConnection;
        this.source = bufferedSource;
        this.sink = bufferedSink;
        this.headersReader = new HeadersReader(bufferedSource);
    }

    public static final void access$detachTimeout(Http1ExchangeCodec http1ExchangeCodec, ForwardingTimeout forwardingTimeout) {
        Objects.requireNonNull(http1ExchangeCodec);
        Timeout timeout = forwardingTimeout.delegate;
        Timeout timeout2 = Timeout.NONE;
        Intrinsics.checkNotNullParameter(timeout2, "delegate");
        forwardingTimeout.delegate = timeout2;
        timeout.clearDeadline();
        timeout.clearTimeout();
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void cancel() {
        Socket socket = this.connection.rawSocket;
        if (socket != null) {
            Util.closeQuietly(socket);
        }
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public Sink createRequestBody(Request request, long j) {
        Intrinsics.checkNotNullParameter(request, "request");
        boolean z = true;
        if (StringsKt__IndentKt.equals("chunked", request.header("Transfer-Encoding"), true)) {
            if (this.state != 1) {
                z = false;
            }
            if (z) {
                this.state = 2;
                return new ChunkedSink();
            }
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
            outline25.append(this.state);
            throw new IllegalStateException(outline25.toString().toString());
        } else if (j != -1) {
            if (this.state != 1) {
                z = false;
            }
            if (z) {
                this.state = 2;
                return new KnownLengthSink();
            }
            StringBuilder outline252 = GeneratedOutlineSupport.outline25("state: ");
            outline252.append(this.state);
            throw new IllegalStateException(outline252.toString().toString());
        } else {
            throw new IllegalStateException("Cannot stream a request body without chunked encoding or a known content length!");
        }
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void finishRequest() {
        this.sink.flush();
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void flushRequest() {
        this.sink.flush();
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public RealConnection getConnection() {
        return this.connection;
    }

    public final Source newFixedLengthSource(long j) {
        if (this.state == 4) {
            this.state = 5;
            return new FixedLengthSource(j);
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString().toString());
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public Source openResponseBodySource(Response response) {
        Intrinsics.checkNotNullParameter(response, "response");
        if (!HttpHeaders.promisesBody(response)) {
            return newFixedLengthSource(0);
        }
        boolean z = true;
        if (StringsKt__IndentKt.equals("chunked", Response.header$default(response, "Transfer-Encoding", null, 2), true)) {
            HttpUrl httpUrl = response.request.url;
            if (this.state != 4) {
                z = false;
            }
            if (z) {
                this.state = 5;
                return new ChunkedSource(this, httpUrl);
            }
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
            outline25.append(this.state);
            throw new IllegalStateException(outline25.toString().toString());
        }
        long headersContentLength = Util.headersContentLength(response);
        if (headersContentLength != -1) {
            return newFixedLengthSource(headersContentLength);
        }
        if (this.state != 4) {
            z = false;
        }
        if (z) {
            this.state = 5;
            this.connection.noNewExchanges$okhttp();
            return new UnknownLengthSource(this);
        }
        StringBuilder outline252 = GeneratedOutlineSupport.outline25("state: ");
        outline252.append(this.state);
        throw new IllegalStateException(outline252.toString().toString());
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public Response.Builder readResponseHeaders(boolean z) {
        int i = this.state;
        boolean z2 = true;
        if (!(i == 1 || i == 3)) {
            z2 = false;
        }
        if (z2) {
            try {
                StatusLine parse = StatusLine.parse(this.headersReader.readLine());
                Response.Builder builder = new Response.Builder();
                builder.protocol(parse.protocol);
                builder.code = parse.code;
                builder.message(parse.message);
                builder.headers(this.headersReader.readHeaders());
                if (z && parse.code == 100) {
                    return null;
                }
                if (parse.code == 100) {
                    this.state = 3;
                    return builder;
                }
                this.state = 4;
                return builder;
            } catch (EOFException e) {
                throw new IOException(GeneratedOutlineSupport.outline18("unexpected end of stream on ", this.connection.route.address.url.redact()), e);
            }
        } else {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
            outline25.append(this.state);
            throw new IllegalStateException(outline25.toString().toString());
        }
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public long reportedContentLength(Response response) {
        Intrinsics.checkNotNullParameter(response, "response");
        if (!HttpHeaders.promisesBody(response)) {
            return 0;
        }
        if (StringsKt__IndentKt.equals("chunked", Response.header$default(response, "Transfer-Encoding", null, 2), true)) {
            return -1;
        }
        return Util.headersContentLength(response);
    }

    public final void writeRequest(Headers headers, String str) {
        Intrinsics.checkNotNullParameter(headers, "headers");
        Intrinsics.checkNotNullParameter(str, "requestLine");
        if (this.state == 0) {
            this.sink.writeUtf8(str).writeUtf8("\r\n");
            int size = headers.size();
            for (int i = 0; i < size; i++) {
                this.sink.writeUtf8(headers.name(i)).writeUtf8(": ").writeUtf8(headers.value(i)).writeUtf8("\r\n");
            }
            this.sink.writeUtf8("\r\n");
            this.state = 1;
            return;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("state: ");
        outline25.append(this.state);
        throw new IllegalStateException(outline25.toString().toString());
    }

    @Override // okhttp3.internal.http.ExchangeCodec
    public void writeRequestHeaders(Request request) {
        Intrinsics.checkNotNullParameter(request, "request");
        Proxy.Type type = this.connection.route.proxy.type();
        Intrinsics.checkNotNullExpressionValue(type, "connection.route().proxy.type()");
        Intrinsics.checkNotNullParameter(request, "request");
        Intrinsics.checkNotNullParameter(type, "proxyType");
        StringBuilder sb = new StringBuilder();
        sb.append(request.method);
        sb.append(StringUtil.SPACE);
        HttpUrl httpUrl = request.url;
        if (!httpUrl.isHttps && type == Proxy.Type.HTTP) {
            sb.append(httpUrl);
        } else {
            Intrinsics.checkNotNullParameter(httpUrl, "url");
            String encodedPath = httpUrl.encodedPath();
            String encodedQuery = httpUrl.encodedQuery();
            if (encodedQuery != null) {
                encodedPath = encodedPath + '?' + encodedQuery;
            }
            sb.append(encodedPath);
        }
        sb.append(" HTTP/1.1");
        String sb2 = sb.toString();
        Intrinsics.checkNotNullExpressionValue(sb2, "StringBuilder().apply(builderAction).toString()");
        writeRequest(request.headers, sb2);
    }
}
