package okhttp3.internal.http2;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.Closeable;
import java.io.EOFException;
import java.io.IOException;
import java.util.List;
import java.util.Objects;
import java.util.logging.Level;
import java.util.logging.Logger;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.ranges.IntProgression;
import kotlin.ranges.RangesKt___RangesKt;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.TaskQueue;
import okhttp3.internal.http2.Hpack;
import okhttp3.internal.http2.Http2Connection;
import okhttp3.internal.http2.Http2Stream;
import okio.Buffer;
import okio.BufferedSource;
import okio.ByteString;
import okio.Source;
import okio.Timeout;

/* compiled from: Http2Reader.kt */
public final class Http2Reader implements Closeable {
    public static final Http2Reader Companion = null;
    public static final Logger logger;
    public final boolean client;
    public final ContinuationSource continuation;
    public final Hpack.Reader hpackReader;
    public final BufferedSource source;

    /* compiled from: Http2Reader.kt */
    public final class ContinuationSource implements Source {
        public int flags;
        public int left;
        public int length;
        public int padding;
        public final BufferedSource source;
        public int streamId;

        public ContinuationSource(BufferedSource bufferedSource) {
            Intrinsics.checkNotNullParameter(bufferedSource, "source");
            this.source = bufferedSource;
        }

        @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
        }

        @Override // okio.Source
        public long read(Buffer buffer, long j) {
            int i;
            int readInt;
            Intrinsics.checkNotNullParameter(buffer, "sink");
            do {
                int i2 = this.left;
                if (i2 == 0) {
                    this.source.skip((long) this.padding);
                    this.padding = 0;
                    if ((this.flags & 4) != 0) {
                        return -1;
                    }
                    i = this.streamId;
                    int readMedium = Util.readMedium(this.source);
                    this.left = readMedium;
                    this.length = readMedium;
                    int readByte = this.source.readByte() & 255;
                    this.flags = this.source.readByte() & 255;
                    Http2Reader http2Reader = Http2Reader.Companion;
                    Logger logger = Http2Reader.logger;
                    if (logger.isLoggable(Level.FINE)) {
                        logger.fine(Http2.INSTANCE.frameLog(true, this.streamId, this.length, readByte, this.flags));
                    }
                    readInt = this.source.readInt() & Integer.MAX_VALUE;
                    this.streamId = readInt;
                    if (readByte != 9) {
                        throw new IOException(readByte + " != TYPE_CONTINUATION");
                    }
                } else {
                    long read = this.source.read(buffer, Math.min(j, (long) i2));
                    if (read == -1) {
                        return -1;
                    }
                    this.left -= (int) read;
                    return read;
                }
            } while (readInt == i);
            throw new IOException("TYPE_CONTINUATION streamId changed");
        }

        @Override // okio.Source
        public Timeout timeout() {
            return this.source.timeout();
        }
    }

    static {
        Logger logger2 = Logger.getLogger(Http2.class.getName());
        Intrinsics.checkNotNullExpressionValue(logger2, "Logger.getLogger(Http2::class.java.name)");
        logger = logger2;
    }

    public Http2Reader(BufferedSource bufferedSource, boolean z) {
        Intrinsics.checkNotNullParameter(bufferedSource, "source");
        this.source = bufferedSource;
        this.client = z;
        ContinuationSource continuationSource = new ContinuationSource(bufferedSource);
        this.continuation = continuationSource;
        this.hpackReader = new Hpack.Reader(continuationSource, 4096, 0, 4);
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        this.source.close();
    }

    public final boolean nextFrame(boolean z, Http2Connection.ReaderRunnable readerRunnable) {
        int i;
        boolean z2;
        boolean z3;
        long j;
        Http2Connection http2Connection;
        Throwable th;
        int readInt;
        Intrinsics.checkNotNullParameter(readerRunnable, "handler");
        int i2 = 0;
        try {
            this.source.require(9);
            int readMedium = Util.readMedium(this.source);
            if (readMedium <= 16384) {
                int readByte = this.source.readByte() & 255;
                int readByte2 = this.source.readByte() & 255;
                int readInt2 = this.source.readInt() & Integer.MAX_VALUE;
                Logger logger2 = logger;
                if (logger2.isLoggable(Level.FINE)) {
                    logger2.fine(Http2.INSTANCE.frameLog(true, readInt2, readMedium, readByte, readByte2));
                }
                if (!z || readByte == 4) {
                    switch (readByte) {
                        case 0:
                            if (readInt2 != 0) {
                                boolean z4 = (readByte2 & 1) != 0;
                                if (!((readByte2 & 32) != 0)) {
                                    int i3 = readByte2 & 8;
                                    if (i3 != 0) {
                                        byte readByte3 = this.source.readByte();
                                        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
                                        i = readByte3 & 255;
                                    } else {
                                        i = 0;
                                    }
                                    if (i3 != 0) {
                                        readMedium--;
                                    }
                                    if (i <= readMedium) {
                                        int i4 = readMedium - i;
                                        BufferedSource bufferedSource = this.source;
                                        Intrinsics.checkNotNullParameter(bufferedSource, "source");
                                        if (readerRunnable.this$0.pushedStream$okhttp(readInt2)) {
                                            Http2Connection http2Connection2 = readerRunnable.this$0;
                                            Objects.requireNonNull(http2Connection2);
                                            Intrinsics.checkNotNullParameter(bufferedSource, "source");
                                            Buffer buffer = new Buffer();
                                            long j2 = (long) i4;
                                            bufferedSource.require(j2);
                                            bufferedSource.read(buffer, j2);
                                            String str = http2Connection2.connectionName + '[' + readInt2 + "] onData";
                                            http2Connection2.pushQueue.schedule(new Http2Connection$pushDataLater$$inlined$execute$1(str, true, str, true, http2Connection2, readInt2, buffer, i4, z4), 0);
                                        } else {
                                            Http2Stream stream = readerRunnable.this$0.getStream(readInt2);
                                            if (stream == null) {
                                                readerRunnable.this$0.writeSynResetLater$okhttp(readInt2, ErrorCode.PROTOCOL_ERROR);
                                                long j3 = (long) i4;
                                                readerRunnable.this$0.updateConnectionFlowControl$okhttp(j3);
                                                bufferedSource.skip(j3);
                                            } else {
                                                Intrinsics.checkNotNullParameter(bufferedSource, "source");
                                                byte[] bArr2 = Util.EMPTY_BYTE_ARRAY;
                                                Http2Stream.FramingSource framingSource = stream.source;
                                                long j4 = (long) i4;
                                                Objects.requireNonNull(framingSource);
                                                Intrinsics.checkNotNullParameter(bufferedSource, "source");
                                                while (true) {
                                                    if (j4 > 0) {
                                                        synchronized (Http2Stream.this) {
                                                            z2 = framingSource.finished;
                                                            z3 = framingSource.readBuffer.size + j4 > framingSource.maxByteCount;
                                                        }
                                                        if (z3) {
                                                            bufferedSource.skip(j4);
                                                            Http2Stream.this.closeLater(ErrorCode.FLOW_CONTROL_ERROR);
                                                        } else if (z2) {
                                                            bufferedSource.skip(j4);
                                                        } else {
                                                            long read = bufferedSource.read(framingSource.receiveBuffer, j4);
                                                            if (read != -1) {
                                                                j4 -= read;
                                                                synchronized (Http2Stream.this) {
                                                                    if (framingSource.closed) {
                                                                        Buffer buffer2 = framingSource.receiveBuffer;
                                                                        j = buffer2.size;
                                                                        buffer2.skip(j);
                                                                    } else {
                                                                        Buffer buffer3 = framingSource.readBuffer;
                                                                        boolean z5 = buffer3.size == 0;
                                                                        buffer3.writeAll(framingSource.receiveBuffer);
                                                                        if (z5) {
                                                                            Http2Stream http2Stream = Http2Stream.this;
                                                                            if (http2Stream != null) {
                                                                                http2Stream.notifyAll();
                                                                            } else {
                                                                                throw new NullPointerException("null cannot be cast to non-null type java.lang.Object");
                                                                            }
                                                                        }
                                                                        j = 0;
                                                                    }
                                                                }
                                                                if (j > 0) {
                                                                    framingSource.updateConnectionFlowControl(j);
                                                                }
                                                            } else {
                                                                throw new EOFException();
                                                            }
                                                        }
                                                    }
                                                }
                                                if (z4) {
                                                    stream.receiveHeaders(Util.EMPTY_HEADERS, true);
                                                }
                                            }
                                        }
                                        this.source.skip((long) i);
                                        return true;
                                    }
                                    throw new IOException(GeneratedOutlineSupport.outline13("PROTOCOL_ERROR padding ", i, " > remaining length ", readMedium));
                                }
                                throw new IOException("PROTOCOL_ERROR: FLAG_COMPRESSED without SETTINGS_COMPRESS_DATA");
                            }
                            throw new IOException("PROTOCOL_ERROR: TYPE_DATA streamId == 0");
                        case 1:
                            if (readInt2 != 0) {
                                boolean z6 = (readByte2 & 1) != 0;
                                int i5 = readByte2 & 8;
                                if (i5 != 0) {
                                    byte readByte4 = this.source.readByte();
                                    byte[] bArr3 = Util.EMPTY_BYTE_ARRAY;
                                    i2 = readByte4 & 255;
                                }
                                if ((readByte2 & 32) != 0) {
                                    readPriority(readerRunnable, readInt2);
                                    readMedium -= 5;
                                }
                                if (i5 != 0) {
                                    readMedium--;
                                }
                                if (i2 <= readMedium) {
                                    List<Header> readHeaderBlock = readHeaderBlock(readMedium - i2, i2, readByte2, readInt2);
                                    Intrinsics.checkNotNullParameter(readHeaderBlock, "headerBlock");
                                    if (readerRunnable.this$0.pushedStream$okhttp(readInt2)) {
                                        Http2Connection http2Connection3 = readerRunnable.this$0;
                                        Objects.requireNonNull(http2Connection3);
                                        Intrinsics.checkNotNullParameter(readHeaderBlock, "requestHeaders");
                                        String str2 = http2Connection3.connectionName + '[' + readInt2 + "] onHeaders";
                                        http2Connection3.pushQueue.schedule(new Http2Connection$pushHeadersLater$$inlined$execute$1(str2, true, str2, true, http2Connection3, readInt2, readHeaderBlock, z6), 0);
                                        return true;
                                    }
                                    Http2Connection http2Connection4 = readerRunnable.this$0;
                                    synchronized (http2Connection4) {
                                        try {
                                            Http2Stream stream2 = readerRunnable.this$0.getStream(readInt2);
                                            if (stream2 == null) {
                                                Http2Connection http2Connection5 = readerRunnable.this$0;
                                                if (http2Connection5.isShutdown) {
                                                    return true;
                                                }
                                                if (readInt2 <= http2Connection5.lastGoodStreamId) {
                                                    return true;
                                                }
                                                if (readInt2 % 2 == http2Connection5.nextStreamId % 2) {
                                                    return true;
                                                }
                                                Http2Stream http2Stream2 = new Http2Stream(readInt2, readerRunnable.this$0, false, z6, Util.toHeaders(readHeaderBlock));
                                                Http2Connection http2Connection6 = readerRunnable.this$0;
                                                http2Connection6.lastGoodStreamId = readInt2;
                                                http2Connection6.streams.put(Integer.valueOf(readInt2), http2Stream2);
                                                String str3 = readerRunnable.this$0.connectionName + '[' + readInt2 + "] onStream";
                                                http2Connection = http2Connection4;
                                                try {
                                                    readerRunnable.this$0.taskRunner.newQueue().schedule(new Http2Connection$ReaderRunnable$headers$$inlined$synchronized$lambda$1(str3, true, str3, true, http2Stream2, readerRunnable, stream2, readInt2, readHeaderBlock, z6), 0);
                                                    return true;
                                                } catch (Throwable th2) {
                                                    th = th2;
                                                    throw th;
                                                }
                                            } else {
                                                stream2.receiveHeaders(Util.toHeaders(readHeaderBlock), z6);
                                                return true;
                                            }
                                        } catch (Throwable th3) {
                                            th = th3;
                                            http2Connection = http2Connection4;
                                            throw th;
                                        }
                                    }
                                } else {
                                    throw new IOException(GeneratedOutlineSupport.outline13("PROTOCOL_ERROR padding ", i2, " > remaining length ", readMedium));
                                }
                            } else {
                                throw new IOException("PROTOCOL_ERROR: TYPE_HEADERS streamId == 0");
                            }
                        case 2:
                            if (readMedium != 5) {
                                throw new IOException(GeneratedOutlineSupport.outline12("TYPE_PRIORITY length: ", readMedium, " != 5"));
                            } else if (readInt2 != 0) {
                                readPriority(readerRunnable, readInt2);
                                return true;
                            } else {
                                throw new IOException("TYPE_PRIORITY streamId == 0");
                            }
                        case 3:
                            if (readMedium != 4) {
                                throw new IOException(GeneratedOutlineSupport.outline12("TYPE_RST_STREAM length: ", readMedium, " != 4"));
                            } else if (readInt2 != 0) {
                                int readInt3 = this.source.readInt();
                                ErrorCode fromHttp2 = ErrorCode.Companion.fromHttp2(readInt3);
                                if (fromHttp2 != null) {
                                    Intrinsics.checkNotNullParameter(fromHttp2, "errorCode");
                                    if (readerRunnable.this$0.pushedStream$okhttp(readInt2)) {
                                        Http2Connection http2Connection7 = readerRunnable.this$0;
                                        Objects.requireNonNull(http2Connection7);
                                        Intrinsics.checkNotNullParameter(fromHttp2, "errorCode");
                                        String str4 = http2Connection7.connectionName + '[' + readInt2 + "] onReset";
                                        http2Connection7.pushQueue.schedule(new Http2Connection$pushResetLater$$inlined$execute$1(str4, true, str4, true, http2Connection7, readInt2, fromHttp2), 0);
                                        return true;
                                    }
                                    Http2Stream removeStream$okhttp = readerRunnable.this$0.removeStream$okhttp(readInt2);
                                    if (removeStream$okhttp == null) {
                                        return true;
                                    }
                                    removeStream$okhttp.receiveRstStream(fromHttp2);
                                    return true;
                                }
                                throw new IOException(GeneratedOutlineSupport.outline11("TYPE_RST_STREAM unexpected error code: ", readInt3));
                            } else {
                                throw new IOException("TYPE_RST_STREAM streamId == 0");
                            }
                        case 4:
                            if (readInt2 != 0) {
                                throw new IOException("TYPE_SETTINGS streamId != 0");
                            } else if ((readByte2 & 1) != 0) {
                                if (readMedium == 0) {
                                    return true;
                                }
                                throw new IOException("FRAME_SIZE_ERROR ack frame should be empty!");
                            } else if (readMedium % 6 == 0) {
                                Settings settings = new Settings();
                                IntProgression step = RangesKt___RangesKt.step(RangesKt___RangesKt.until(0, readMedium), 6);
                                int i6 = step.first;
                                int i7 = step.last;
                                int i8 = step.step;
                                if (i8 < 0 ? i6 >= i7 : i6 <= i7) {
                                    while (true) {
                                        short readShort = this.source.readShort();
                                        byte[] bArr4 = Util.EMPTY_BYTE_ARRAY;
                                        int i9 = readShort & 65535;
                                        readInt = this.source.readInt();
                                        if (i9 != 2) {
                                            if (i9 == 3) {
                                                i9 = 4;
                                            } else if (i9 == 4) {
                                                i9 = 7;
                                                if (readInt < 0) {
                                                    throw new IOException("PROTOCOL_ERROR SETTINGS_INITIAL_WINDOW_SIZE > 2^31 - 1");
                                                }
                                            } else if (i9 == 5 && (readInt < 16384 || readInt > 16777215)) {
                                            }
                                        } else if (!(readInt == 0 || readInt == 1)) {
                                            throw new IOException("PROTOCOL_ERROR SETTINGS_ENABLE_PUSH != 0 or 1");
                                        }
                                        settings.set(i9, readInt);
                                        if (i6 != i7) {
                                            i6 += i8;
                                        }
                                    }
                                    throw new IOException(GeneratedOutlineSupport.outline11("PROTOCOL_ERROR SETTINGS_MAX_FRAME_SIZE: ", readInt));
                                }
                                Intrinsics.checkNotNullParameter(settings, "settings");
                                TaskQueue taskQueue = readerRunnable.this$0.writerQueue;
                                String outline22 = GeneratedOutlineSupport.outline22(new StringBuilder(), readerRunnable.this$0.connectionName, " applyAndAckSettings");
                                taskQueue.schedule(new Http2Connection$ReaderRunnable$settings$$inlined$execute$1(outline22, true, outline22, true, readerRunnable, false, settings), 0);
                                return true;
                            } else {
                                throw new IOException(GeneratedOutlineSupport.outline11("TYPE_SETTINGS length % 6 != 0: ", readMedium));
                            }
                        case 5:
                            if (readInt2 != 0) {
                                int i10 = readByte2 & 8;
                                if (i10 != 0) {
                                    byte readByte5 = this.source.readByte();
                                    byte[] bArr5 = Util.EMPTY_BYTE_ARRAY;
                                    i2 = readByte5 & 255;
                                }
                                int readInt4 = this.source.readInt() & Integer.MAX_VALUE;
                                int i11 = readMedium - 4;
                                if (i10 != 0) {
                                    i11--;
                                }
                                if (i2 <= i11) {
                                    List<Header> readHeaderBlock2 = readHeaderBlock(i11 - i2, i2, readByte2, readInt2);
                                    Intrinsics.checkNotNullParameter(readHeaderBlock2, "requestHeaders");
                                    Http2Connection http2Connection8 = readerRunnable.this$0;
                                    Objects.requireNonNull(http2Connection8);
                                    Intrinsics.checkNotNullParameter(readHeaderBlock2, "requestHeaders");
                                    synchronized (http2Connection8) {
                                        if (http2Connection8.currentPushRequests.contains(Integer.valueOf(readInt4))) {
                                            http2Connection8.writeSynResetLater$okhttp(readInt4, ErrorCode.PROTOCOL_ERROR);
                                            return true;
                                        }
                                        http2Connection8.currentPushRequests.add(Integer.valueOf(readInt4));
                                        String str5 = http2Connection8.connectionName + '[' + readInt4 + "] onRequest";
                                        http2Connection8.pushQueue.schedule(new Http2Connection$pushRequestLater$$inlined$execute$1(str5, true, str5, true, http2Connection8, readInt4, readHeaderBlock2), 0);
                                        return true;
                                    }
                                }
                                throw new IOException(GeneratedOutlineSupport.outline13("PROTOCOL_ERROR padding ", i2, " > remaining length ", i11));
                            }
                            throw new IOException("PROTOCOL_ERROR: TYPE_PUSH_PROMISE streamId == 0");
                        case 6:
                            readPing(readerRunnable, readMedium, readByte2, readInt2);
                            return true;
                        case 7:
                            readGoAway(readerRunnable, readMedium, readInt2);
                            return true;
                        case 8:
                            readWindowUpdate(readerRunnable, readMedium, readInt2);
                            return true;
                        default:
                            this.source.skip((long) readMedium);
                            return true;
                    }
                } else {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Expected a SETTINGS frame but was ");
                    outline25.append(Http2.INSTANCE.formattedType$okhttp(readByte));
                    throw new IOException(outline25.toString());
                }
            } else {
                throw new IOException(GeneratedOutlineSupport.outline11("FRAME_SIZE_ERROR: ", readMedium));
            }
        } catch (EOFException unused) {
            return false;
        }
    }

    public final void readConnectionPreface(Http2Connection.ReaderRunnable readerRunnable) {
        Intrinsics.checkNotNullParameter(readerRunnable, "handler");
        if (!this.client) {
            BufferedSource bufferedSource = this.source;
            ByteString byteString = Http2.CONNECTION_PREFACE;
            ByteString readByteString = bufferedSource.readByteString((long) byteString.size());
            Logger logger2 = logger;
            if (logger2.isLoggable(Level.FINE)) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("<< CONNECTION ");
                outline25.append(readByteString.hex());
                logger2.fine(Util.format(outline25.toString(), new Object[0]));
            }
            if (!Intrinsics.areEqual(byteString, readByteString)) {
                StringBuilder outline252 = GeneratedOutlineSupport.outline25("Expected a connection header but was ");
                outline252.append(readByteString.utf8());
                throw new IOException(outline252.toString());
            }
        } else if (!nextFrame(true, readerRunnable)) {
            throw new IOException("Required SETTINGS preface not received");
        }
    }

    public final void readGoAway(Http2Connection.ReaderRunnable readerRunnable, int i, int i2) {
        int i3;
        Http2Stream[] http2StreamArr;
        if (i < 8) {
            throw new IOException(GeneratedOutlineSupport.outline11("TYPE_GOAWAY length < 8: ", i));
        } else if (i2 == 0) {
            int readInt = this.source.readInt();
            int readInt2 = this.source.readInt();
            int i4 = i - 8;
            ErrorCode fromHttp2 = ErrorCode.Companion.fromHttp2(readInt2);
            if (fromHttp2 != null) {
                ByteString byteString = ByteString.EMPTY;
                if (i4 > 0) {
                    byteString = this.source.readByteString((long) i4);
                }
                Objects.requireNonNull(readerRunnable);
                Intrinsics.checkNotNullParameter(fromHttp2, "errorCode");
                Intrinsics.checkNotNullParameter(byteString, "debugData");
                byteString.size();
                synchronized (readerRunnable.this$0) {
                    Object[] array = readerRunnable.this$0.streams.values().toArray(new Http2Stream[0]);
                    if (array != null) {
                        http2StreamArr = (Http2Stream[]) array;
                        readerRunnable.this$0.isShutdown = true;
                    } else {
                        throw new NullPointerException("null cannot be cast to non-null type kotlin.Array<T>");
                    }
                }
                for (Http2Stream http2Stream : http2StreamArr) {
                    if (http2Stream.id > readInt && http2Stream.isLocallyInitiated()) {
                        http2Stream.receiveRstStream(ErrorCode.REFUSED_STREAM);
                        readerRunnable.this$0.removeStream$okhttp(http2Stream.id);
                    }
                }
                return;
            }
            throw new IOException(GeneratedOutlineSupport.outline11("TYPE_GOAWAY unexpected error code: ", readInt2));
        } else {
            throw new IOException("TYPE_GOAWAY streamId != 0");
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x004c  */
    public final List<Header> readHeaderBlock(int i, int i2, int i3, int i4) {
        boolean z;
        ContinuationSource continuationSource = this.continuation;
        continuationSource.left = i;
        continuationSource.length = i;
        continuationSource.padding = i2;
        continuationSource.flags = i3;
        continuationSource.streamId = i4;
        Hpack.Reader reader = this.hpackReader;
        while (!reader.source.exhausted()) {
            byte readByte = reader.source.readByte();
            byte[] bArr = Util.EMPTY_BYTE_ARRAY;
            int i5 = readByte & 255;
            if (i5 == 128) {
                throw new IOException("index == 0");
            } else if ((i5 & 128) == 128) {
                int readInt = reader.readInt(i5, 127) - 1;
                if (readInt >= 0) {
                    Hpack hpack = Hpack.INSTANCE;
                    if (readInt <= Hpack.STATIC_HEADER_TABLE.length - 1) {
                        z = true;
                        if (!z) {
                            Hpack hpack2 = Hpack.INSTANCE;
                            reader.headerList.add(Hpack.STATIC_HEADER_TABLE[readInt]);
                        } else {
                            Hpack hpack3 = Hpack.INSTANCE;
                            int dynamicTableIndex = reader.dynamicTableIndex(readInt - Hpack.STATIC_HEADER_TABLE.length);
                            if (dynamicTableIndex >= 0) {
                                Header[] headerArr = reader.dynamicTable;
                                if (dynamicTableIndex < headerArr.length) {
                                    List<Header> list = reader.headerList;
                                    Header header = headerArr[dynamicTableIndex];
                                    Intrinsics.checkNotNull(header);
                                    list.add(header);
                                }
                            }
                            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Header index too large ");
                            outline25.append(readInt + 1);
                            throw new IOException(outline25.toString());
                        }
                    }
                }
                z = false;
                if (!z) {
                }
            } else if (i5 == 64) {
                Hpack hpack4 = Hpack.INSTANCE;
                ByteString readByteString = reader.readByteString();
                hpack4.checkLowercase(readByteString);
                reader.insertIntoDynamicTable(-1, new Header(readByteString, reader.readByteString()));
            } else if ((i5 & 64) == 64) {
                reader.insertIntoDynamicTable(-1, new Header(reader.getName(reader.readInt(i5, 63) - 1), reader.readByteString()));
            } else if ((i5 & 32) == 32) {
                int readInt2 = reader.readInt(i5, 31);
                reader.maxDynamicTableByteCount = readInt2;
                if (readInt2 < 0 || readInt2 > reader.headerTableSizeSetting) {
                    StringBuilder outline252 = GeneratedOutlineSupport.outline25("Invalid dynamic table size update ");
                    outline252.append(reader.maxDynamicTableByteCount);
                    throw new IOException(outline252.toString());
                }
                int i6 = reader.dynamicTableByteCount;
                if (readInt2 < i6) {
                    if (readInt2 == 0) {
                        reader.clearDynamicTable();
                    } else {
                        reader.evictToRecoverBytes(i6 - readInt2);
                    }
                }
            } else if (i5 == 16 || i5 == 0) {
                Hpack hpack5 = Hpack.INSTANCE;
                ByteString readByteString2 = reader.readByteString();
                hpack5.checkLowercase(readByteString2);
                reader.headerList.add(new Header(readByteString2, reader.readByteString()));
            } else {
                reader.headerList.add(new Header(reader.getName(reader.readInt(i5, 15) - 1), reader.readByteString()));
            }
        }
        Hpack.Reader reader2 = this.hpackReader;
        List<Header> list2 = ArraysKt___ArraysKt.toList(reader2.headerList);
        reader2.headerList.clear();
        return list2;
    }

    public final void readPing(Http2Connection.ReaderRunnable readerRunnable, int i, int i2, int i3) {
        if (i != 8) {
            throw new IOException(GeneratedOutlineSupport.outline11("TYPE_PING length != 8: ", i));
        } else if (i3 == 0) {
            int readInt = this.source.readInt();
            int readInt2 = this.source.readInt();
            if ((i2 & 1) != 0) {
                synchronized (readerRunnable.this$0) {
                    if (readInt == 1) {
                        readerRunnable.this$0.intervalPongsReceived++;
                    } else if (readInt == 2) {
                        readerRunnable.this$0.degradedPongsReceived++;
                    } else if (readInt == 3) {
                        Http2Connection http2Connection = readerRunnable.this$0;
                        http2Connection.awaitPongsReceived++;
                        http2Connection.notifyAll();
                    }
                }
                return;
            }
            TaskQueue taskQueue = readerRunnable.this$0.writerQueue;
            String outline22 = GeneratedOutlineSupport.outline22(new StringBuilder(), readerRunnable.this$0.connectionName, " ping");
            taskQueue.schedule(new Http2Connection$ReaderRunnable$ping$$inlined$execute$1(outline22, true, outline22, true, readerRunnable, readInt, readInt2), 0);
        } else {
            throw new IOException("TYPE_PING streamId != 0");
        }
    }

    public final void readPriority(Http2Connection.ReaderRunnable readerRunnable, int i) {
        int readInt = this.source.readInt() & ((int) 2147483648L);
        this.source.readByte();
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        Objects.requireNonNull(readerRunnable);
    }

    public final void readWindowUpdate(Http2Connection.ReaderRunnable readerRunnable, int i, int i2) {
        if (i == 4) {
            int readInt = this.source.readInt();
            byte[] bArr = Util.EMPTY_BYTE_ARRAY;
            long j = 2147483647L & ((long) readInt);
            int i3 = (j > 0 ? 1 : (j == 0 ? 0 : -1));
            if (i3 == 0) {
                throw new IOException("windowSizeIncrement was 0");
            } else if (i2 == 0) {
                synchronized (readerRunnable.this$0) {
                    Http2Connection http2Connection = readerRunnable.this$0;
                    http2Connection.writeBytesMaximum += j;
                    http2Connection.notifyAll();
                }
            } else {
                Http2Stream stream = readerRunnable.this$0.getStream(i2);
                if (stream != null) {
                    synchronized (stream) {
                        stream.writeBytesMaximum += j;
                        if (i3 > 0) {
                            stream.notifyAll();
                        }
                    }
                }
            }
        } else {
            throw new IOException(GeneratedOutlineSupport.outline11("TYPE_WINDOW_UPDATE length !=4: ", i));
        }
    }
}
