package okhttp3.internal.http2;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.Closeable;
import java.io.IOException;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.internal.Util;
import okhttp3.internal.http2.Hpack;
import okio.Buffer;
import okio.BufferedSink;
import org.xbill.DNS.KEYRecord;

/* compiled from: Http2Writer.kt */
public final class Http2Writer implements Closeable {
    public static final Logger logger = Logger.getLogger(Http2.class.getName());
    public final boolean client;
    public boolean closed;
    public final Buffer hpackBuffer;
    public final Hpack.Writer hpackWriter;
    public int maxFrameSize = 16384;
    public final BufferedSink sink;

    public Http2Writer(BufferedSink bufferedSink, boolean z) {
        Intrinsics.checkNotNullParameter(bufferedSink, "sink");
        this.sink = bufferedSink;
        this.client = z;
        Buffer buffer = new Buffer();
        this.hpackBuffer = buffer;
        this.hpackWriter = new Hpack.Writer(0, false, buffer, 3);
    }

    public final synchronized void applyAndAckSettings(Settings settings) {
        Intrinsics.checkNotNullParameter(settings, "peerSettings");
        if (!this.closed) {
            int i = this.maxFrameSize;
            int i2 = settings.set;
            if ((i2 & 32) != 0) {
                i = settings.values[5];
            }
            this.maxFrameSize = i;
            int i3 = i2 & 2;
            int i4 = -1;
            if ((i3 != 0 ? settings.values[1] : -1) != -1) {
                Hpack.Writer writer = this.hpackWriter;
                if (i3 != 0) {
                    i4 = settings.values[1];
                }
                writer.headerTableSizeSetting = i4;
                int min = Math.min(i4, 16384);
                int i5 = writer.maxDynamicTableByteCount;
                if (i5 != min) {
                    if (min < i5) {
                        writer.smallestHeaderTableSizeSetting = Math.min(writer.smallestHeaderTableSizeSetting, min);
                    }
                    writer.emitDynamicTableSizeUpdate = true;
                    writer.maxDynamicTableByteCount = min;
                    int i6 = writer.dynamicTableByteCount;
                    if (min < i6) {
                        if (min == 0) {
                            writer.clearDynamicTable();
                        } else {
                            writer.evictToRecoverBytes(i6 - min);
                        }
                    }
                }
            }
            frameHeader(0, 0, 4, 1);
            this.sink.flush();
        } else {
            throw new IOException("closed");
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public synchronized void close() {
        this.closed = true;
        this.sink.close();
    }

    public final synchronized void data(boolean z, int i, Buffer buffer, int i2) {
        if (!this.closed) {
            frameHeader(i, i2, 0, z ? 1 : 0);
            if (i2 > 0) {
                BufferedSink bufferedSink = this.sink;
                Intrinsics.checkNotNull(buffer);
                bufferedSink.write(buffer, (long) i2);
            }
        } else {
            throw new IOException("closed");
        }
    }

    public final synchronized void flush() {
        if (!this.closed) {
            this.sink.flush();
        } else {
            throw new IOException("closed");
        }
    }

    public final void frameHeader(int i, int i2, int i3, int i4) {
        Logger logger2 = logger;
        if (logger2.isLoggable(Level.FINE)) {
            logger2.fine(Http2.INSTANCE.frameLog(false, i, i2, i3, i4));
        }
        boolean z = true;
        if (i2 <= this.maxFrameSize) {
            if ((((int) 2147483648L) & i) != 0) {
                z = false;
            }
            if (z) {
                BufferedSink bufferedSink = this.sink;
                byte[] bArr = Util.EMPTY_BYTE_ARRAY;
                Intrinsics.checkNotNullParameter(bufferedSink, "$this$writeMedium");
                bufferedSink.writeByte((i2 >>> 16) & KEYRecord.PROTOCOL_ANY);
                bufferedSink.writeByte((i2 >>> 8) & KEYRecord.PROTOCOL_ANY);
                bufferedSink.writeByte(i2 & KEYRecord.PROTOCOL_ANY);
                this.sink.writeByte(i3 & KEYRecord.PROTOCOL_ANY);
                this.sink.writeByte(i4 & KEYRecord.PROTOCOL_ANY);
                this.sink.writeInt(i & Integer.MAX_VALUE);
                return;
            }
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline11("reserved bit set: ", i).toString());
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("FRAME_SIZE_ERROR length > ");
        outline25.append(this.maxFrameSize);
        outline25.append(": ");
        outline25.append(i2);
        throw new IllegalArgumentException(outline25.toString().toString());
    }

    public final synchronized void goAway(int i, ErrorCode errorCode, byte[] bArr) {
        Intrinsics.checkNotNullParameter(errorCode, "errorCode");
        Intrinsics.checkNotNullParameter(bArr, "debugData");
        if (!this.closed) {
            boolean z = false;
            if (errorCode.getHttpCode() != -1) {
                frameHeader(0, bArr.length + 8, 7, 0);
                this.sink.writeInt(i);
                this.sink.writeInt(errorCode.getHttpCode());
                if (bArr.length == 0) {
                    z = true;
                }
                if (!z) {
                    this.sink.write(bArr);
                }
                this.sink.flush();
            } else {
                throw new IllegalArgumentException("errorCode.httpCode == -1".toString());
            }
        } else {
            throw new IOException("closed");
        }
    }

    public final synchronized void headers(boolean z, int i, List<Header> list) {
        Intrinsics.checkNotNullParameter(list, "headerBlock");
        if (!this.closed) {
            this.hpackWriter.writeHeaders(list);
            long j = this.hpackBuffer.size;
            long min = Math.min((long) this.maxFrameSize, j);
            int i2 = (j > min ? 1 : (j == min ? 0 : -1));
            int i3 = i2 == 0 ? 4 : 0;
            if (z) {
                i3 |= 1;
            }
            frameHeader(i, (int) min, 1, i3);
            this.sink.write(this.hpackBuffer, min);
            if (i2 > 0) {
                writeContinuationFrames(i, j - min);
            }
        } else {
            throw new IOException("closed");
        }
    }

    public final synchronized void ping(boolean z, int i, int i2) {
        if (!this.closed) {
            frameHeader(0, 8, 6, z ? 1 : 0);
            this.sink.writeInt(i);
            this.sink.writeInt(i2);
            this.sink.flush();
        } else {
            throw new IOException("closed");
        }
    }

    public final synchronized void rstStream(int i, ErrorCode errorCode) {
        Intrinsics.checkNotNullParameter(errorCode, "errorCode");
        if (!this.closed) {
            if (errorCode.getHttpCode() != -1) {
                frameHeader(i, 4, 3, 0);
                this.sink.writeInt(errorCode.getHttpCode());
                this.sink.flush();
            } else {
                throw new IllegalArgumentException("Failed requirement.".toString());
            }
        } else {
            throw new IOException("closed");
        }
    }

    public final synchronized void windowUpdate(int i, long j) {
        if (!this.closed) {
            if (j != 0 && j <= 2147483647L) {
                frameHeader(i, 4, 8, 0);
                this.sink.writeInt((int) j);
                this.sink.flush();
            } else {
                throw new IllegalArgumentException(("windowSizeIncrement == 0 || windowSizeIncrement > 0x7fffffffL: " + j).toString());
            }
        } else {
            throw new IOException("closed");
        }
    }

    public final void writeContinuationFrames(int i, long j) {
        while (j > 0) {
            long min = Math.min((long) this.maxFrameSize, j);
            j -= min;
            frameHeader(i, (int) min, 9, j == 0 ? 4 : 0);
            this.sink.write(this.hpackBuffer, min);
        }
    }
}
