package okhttp3.internal.publicsuffix;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.IOException;
import java.io.InputStream;
import java.io.InterruptedIOException;
import java.net.IDN;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.Objects;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.atomic.AtomicBoolean;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.collections.EmptyList;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.sequences.Sequence;
import kotlin.sequences.SequencesKt;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.internal.Util;
import okhttp3.internal.platform.Platform;
import okio.BufferedSource;
import okio.GzipSource;

/* compiled from: PublicSuffixDatabase.kt */
public final class PublicSuffixDatabase {
    public static final Companion Companion = new Companion(null);
    public static final List<String> PREVAILING_RULE = ViewGroupUtilsApi14.listOf("*");
    public static final byte[] WILDCARD_LABEL = {(byte) 42};
    public static final PublicSuffixDatabase instance = new PublicSuffixDatabase();
    public final AtomicBoolean listRead = new AtomicBoolean(false);
    public byte[] publicSuffixExceptionListBytes;
    public byte[] publicSuffixListBytes;
    public final CountDownLatch readCompleteLatch = new CountDownLatch(1);

    /* compiled from: PublicSuffixDatabase.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }

        public static final String access$binarySearch(Companion companion, byte[] bArr, byte[][] bArr2, int i) {
            int i2;
            boolean z;
            int i3;
            int i4;
            int length = bArr.length;
            int i5 = 0;
            while (i5 < length) {
                int i6 = (i5 + length) / 2;
                while (i6 > -1 && bArr[i6] != ((byte) 10)) {
                    i6--;
                }
                int i7 = i6 + 1;
                int i8 = 1;
                while (true) {
                    i2 = i7 + i8;
                    if (bArr[i2] == ((byte) 10)) {
                        break;
                    }
                    i8++;
                }
                int i9 = i2 - i7;
                int i10 = i;
                boolean z2 = false;
                int i11 = 0;
                int i12 = 0;
                while (true) {
                    if (z2) {
                        i3 = 46;
                        z = false;
                    } else {
                        byte b = bArr2[i10][i11];
                        byte[] bArr3 = Util.EMPTY_BYTE_ARRAY;
                        int i13 = b & 255;
                        z = z2;
                        i3 = i13;
                    }
                    byte b2 = bArr[i7 + i12];
                    byte[] bArr4 = Util.EMPTY_BYTE_ARRAY;
                    i4 = i3 - (b2 & 255);
                    if (i4 != 0) {
                        break;
                    }
                    i12++;
                    i11++;
                    if (i12 == i9) {
                        break;
                    } else if (bArr2[i10].length != i11) {
                        z2 = z;
                    } else if (i10 == bArr2.length - 1) {
                        break;
                    } else {
                        i10++;
                        z2 = true;
                        i11 = -1;
                    }
                }
                if (i4 >= 0) {
                    if (i4 <= 0) {
                        int i14 = i9 - i12;
                        int length2 = bArr2[i10].length - i11;
                        int length3 = bArr2.length;
                        for (int i15 = i10 + 1; i15 < length3; i15++) {
                            length2 += bArr2[i15].length;
                        }
                        if (length2 >= i14) {
                            if (length2 <= i14) {
                                Charset charset = StandardCharsets.UTF_8;
                                Intrinsics.checkNotNullExpressionValue(charset, "UTF_8");
                                return new String(bArr, i7, i9, charset);
                            }
                        }
                    }
                    i5 = i2 + 1;
                }
                length = i7 - 1;
            }
            return null;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0038, code lost:
        if (r1 == false) goto L_0x005e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x003a, code lost:
        java.lang.Thread.currentThread().interrupt();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:7:0x0028, code lost:
        if (r1 != false) goto L_0x003a;
     */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00d3  */
    /* JADX WARNING: Removed duplicated region for block: B:66:0x00f5  */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x010d  */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x015c  */
    /* JADX WARNING: Removed duplicated region for block: B:87:0x0165  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x01c2  */
    public final String getEffectiveTldPlusOne(String str) {
        String str2;
        String str3;
        String str4;
        List<String> list;
        int i;
        int i2;
        List<String> list2;
        Intrinsics.checkNotNullParameter(str, "domain");
        String unicode = IDN.toUnicode(str);
        Intrinsics.checkNotNullExpressionValue(unicode, "unicodeDomain");
        List<String> splitDomain = splitDomain(unicode);
        int i3 = 0;
        if (this.listRead.get() || !this.listRead.compareAndSet(false, true)) {
            try {
                this.readCompleteLatch.await();
            } catch (InterruptedException unused) {
                Thread.currentThread().interrupt();
            }
        } else {
            boolean z = false;
            while (true) {
                try {
                    readTheList();
                    break;
                } catch (InterruptedIOException unused2) {
                    Thread.interrupted();
                    z = true;
                } catch (IOException e) {
                    Platform.Companion companion = Platform.Companion;
                    Platform.platform.log("Failed to read public suffix list", 5, e);
                } catch (Throwable th) {
                    if (z) {
                        Thread.currentThread().interrupt();
                    }
                    throw th;
                }
            }
        }
        if (this.publicSuffixListBytes != null) {
            int size = splitDomain.size();
            byte[][] bArr = new byte[size][];
            for (int i4 = 0; i4 < size; i4++) {
                String str5 = splitDomain.get(i4);
                Charset charset = StandardCharsets.UTF_8;
                Intrinsics.checkNotNullExpressionValue(charset, "UTF_8");
                Objects.requireNonNull(str5, "null cannot be cast to non-null type java.lang.String");
                byte[] bytes = str5.getBytes(charset);
                Intrinsics.checkNotNullExpressionValue(bytes, "(this as java.lang.String).getBytes(charset)");
                bArr[i4] = bytes;
            }
            int i5 = 0;
            while (true) {
                if (i5 >= size) {
                    str2 = null;
                    break;
                }
                Companion companion2 = Companion;
                byte[] bArr2 = this.publicSuffixListBytes;
                if (bArr2 != null) {
                    str2 = Companion.access$binarySearch(companion2, bArr2, bArr, i5);
                    if (str2 != null) {
                        break;
                    }
                    i5++;
                } else {
                    Intrinsics.throwUninitializedPropertyAccessException("publicSuffixListBytes");
                    throw null;
                }
            }
            if (size > 1) {
                byte[][] bArr3 = (byte[][]) bArr.clone();
                int length = bArr3.length - 1;
                int i6 = 0;
                while (true) {
                    if (i6 >= length) {
                        break;
                    }
                    bArr3[i6] = WILDCARD_LABEL;
                    Companion companion3 = Companion;
                    byte[] bArr4 = this.publicSuffixListBytes;
                    if (bArr4 != null) {
                        str3 = Companion.access$binarySearch(companion3, bArr4, bArr3, i6);
                        if (str3 != null) {
                            break;
                        }
                        i6++;
                    } else {
                        Intrinsics.throwUninitializedPropertyAccessException("publicSuffixListBytes");
                        throw null;
                    }
                }
                if (str3 != null) {
                    int i7 = size - 1;
                    int i8 = 0;
                    while (true) {
                        if (i8 >= i7) {
                            break;
                        }
                        Companion companion4 = Companion;
                        byte[] bArr5 = this.publicSuffixExceptionListBytes;
                        if (bArr5 != null) {
                            str4 = Companion.access$binarySearch(companion4, bArr5, bArr, i8);
                            if (str4 != null) {
                                break;
                            }
                            i8++;
                        } else {
                            Intrinsics.throwUninitializedPropertyAccessException("publicSuffixExceptionListBytes");
                            throw null;
                        }
                    }
                }
                str4 = null;
                if (str4 == null) {
                    list = StringsKt__IndentKt.split$default((CharSequence) ('!' + str4), new char[]{'.'}, false, 0, 6);
                } else if (str2 == null && str3 == null) {
                    list = PREVAILING_RULE;
                } else {
                    if (str2 != null) {
                        list2 = StringsKt__IndentKt.split$default((CharSequence) str2, new char[]{'.'}, false, 0, 6);
                    } else {
                        list2 = EmptyList.INSTANCE;
                    }
                    if (str3 != null) {
                        list = StringsKt__IndentKt.split$default((CharSequence) str3, new char[]{'.'}, false, 0, 6);
                    } else {
                        list = EmptyList.INSTANCE;
                    }
                    if (list2.size() > list.size()) {
                        list = list2;
                    }
                }
                if (!(splitDomain.size() == list.size() || list.get(0).charAt(0) == '!')) {
                    return null;
                }
                if (list.get(0).charAt(0) != '!') {
                    i2 = splitDomain.size();
                    i = list.size();
                } else {
                    i2 = splitDomain.size();
                    i = list.size() + 1;
                }
                Sequence drop = SequencesKt.drop(ArraysKt___ArraysKt.asSequence(splitDomain(str)), i2 - i);
                Intrinsics.checkNotNullParameter(drop, "$this$joinToString");
                Intrinsics.checkNotNullParameter(".", "separator");
                Intrinsics.checkNotNullParameter("", "prefix");
                Intrinsics.checkNotNullParameter("", "postfix");
                Intrinsics.checkNotNullParameter("...", "truncated");
                StringBuilder sb = new StringBuilder();
                Intrinsics.checkNotNullParameter(drop, "$this$joinTo");
                Intrinsics.checkNotNullParameter(sb, "buffer");
                Intrinsics.checkNotNullParameter(".", "separator");
                Intrinsics.checkNotNullParameter("", "prefix");
                Intrinsics.checkNotNullParameter("", "postfix");
                Intrinsics.checkNotNullParameter("...", "truncated");
                sb.append((CharSequence) "");
                for (Object obj : drop) {
                    i3++;
                    if (i3 > 1) {
                        sb.append((CharSequence) ".");
                    }
                    ViewGroupUtilsApi14.appendElement(sb, obj, null);
                }
                sb.append((CharSequence) "");
                String sb2 = sb.toString();
                Intrinsics.checkNotNullExpressionValue(sb2, "joinTo(StringBuilder(), …ed, transform).toString()");
                return sb2;
            }
            str3 = null;
            if (str3 != null) {
            }
            str4 = null;
            if (str4 == null) {
            }
            if (splitDomain.size() == list.size()) {
            }
            if (list.get(0).charAt(0) != '!') {
            }
            Sequence drop2 = SequencesKt.drop(ArraysKt___ArraysKt.asSequence(splitDomain(str)), i2 - i);
            Intrinsics.checkNotNullParameter(drop2, "$this$joinToString");
            Intrinsics.checkNotNullParameter(".", "separator");
            Intrinsics.checkNotNullParameter("", "prefix");
            Intrinsics.checkNotNullParameter("", "postfix");
            Intrinsics.checkNotNullParameter("...", "truncated");
            StringBuilder sb3 = new StringBuilder();
            Intrinsics.checkNotNullParameter(drop2, "$this$joinTo");
            Intrinsics.checkNotNullParameter(sb3, "buffer");
            Intrinsics.checkNotNullParameter(".", "separator");
            Intrinsics.checkNotNullParameter("", "prefix");
            Intrinsics.checkNotNullParameter("", "postfix");
            Intrinsics.checkNotNullParameter("...", "truncated");
            sb3.append((CharSequence) "");
            while (r14.hasNext()) {
            }
            sb3.append((CharSequence) "");
            String sb22 = sb3.toString();
            Intrinsics.checkNotNullExpressionValue(sb22, "joinTo(StringBuilder(), …ed, transform).toString()");
            return sb22;
        }
        throw new IllegalStateException("Unable to load publicsuffixes.gz resource from the classpath.".toString());
    }

    /* JADX WARNING: Code restructure failed: missing block: B:18:0x0044, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x0045, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r0, r1);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0048, code lost:
        throw r2;
     */
    public final void readTheList() {
        InputStream resourceAsStream = PublicSuffixDatabase.class.getResourceAsStream("publicsuffixes.gz");
        if (resourceAsStream != null) {
            BufferedSource buffer = SystemPropsKt.buffer(new GzipSource(SystemPropsKt.source(resourceAsStream)));
            byte[] readByteArray = buffer.readByteArray((long) buffer.readInt());
            byte[] readByteArray2 = buffer.readByteArray((long) buffer.readInt());
            ViewGroupUtilsApi14.closeFinally(buffer, null);
            synchronized (this) {
                Intrinsics.checkNotNull(readByteArray);
                this.publicSuffixListBytes = readByteArray;
                Intrinsics.checkNotNull(readByteArray2);
                this.publicSuffixExceptionListBytes = readByteArray2;
            }
            this.readCompleteLatch.countDown();
        }
    }

    public final List<String> splitDomain(String str) {
        int i = 0;
        List<String> split$default = StringsKt__IndentKt.split$default((CharSequence) str, new char[]{'.'}, false, 0, 6);
        Intrinsics.checkNotNullParameter(split$default, "$this$last");
        if (split$default.isEmpty()) {
            throw new NoSuchElementException("List is empty.");
        } else if (!Intrinsics.areEqual(split$default.get(ArraysKt___ArraysKt.getLastIndex(split$default)), "")) {
            return split$default;
        } else {
            Intrinsics.checkNotNullParameter(split$default, "$this$dropLast");
            int size = split$default.size() - 1;
            if (size < 0) {
                size = 0;
            }
            Intrinsics.checkNotNullParameter(split$default, "$this$take");
            if (!(size >= 0)) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline12("Requested element count ", size, " is less than zero.").toString());
            } else if (size == 0) {
                return EmptyList.INSTANCE;
            } else {
                if (size >= split$default.size()) {
                    return ArraysKt___ArraysKt.toList(split$default);
                }
                if (size == 1) {
                    Intrinsics.checkNotNullParameter(split$default, "$this$first");
                    return ViewGroupUtilsApi14.listOf(ArraysKt___ArraysKt.first(split$default));
                }
                ArrayList arrayList = new ArrayList(size);
                Iterator<T> it = split$default.iterator();
                while (it.hasNext()) {
                    arrayList.add(it.next());
                    i++;
                    if (i == size) {
                        break;
                    }
                }
                return ArraysKt___ArraysKt.optimizeReadOnlyList(arrayList);
            }
        }
    }
}
