package okio;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.shadowsocks.tcpip.TCPHeader;
import java.io.EOFException;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.OutputStream;
import java.io.Serializable;
import java.lang.reflect.Field;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.security.InvalidKeyException;
import java.security.MessageDigest;
import java.util.Arrays;
import java.util.Objects;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.Charsets;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okio.internal.ByteStringKt;

/* compiled from: ByteString.kt */
public class ByteString implements Serializable, Comparable<ByteString> {
    public static final Companion Companion = new Companion(null);
    public static final ByteString EMPTY = new ByteString(new byte[0]);
    private static final long serialVersionUID = 1;
    private final byte[] data;
    public transient int hashCode;
    public transient String utf8;

    /* compiled from: ByteString.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }

        public final ByteString decodeHex(String str) {
            Intrinsics.checkNotNullParameter(str, "$this$decodeHex");
            if (str.length() % 2 == 0) {
                int length = str.length() / 2;
                byte[] bArr = new byte[length];
                for (int i = 0; i < length; i++) {
                    int i2 = i * 2;
                    bArr[i] = (byte) (ByteStringKt.access$decodeHexDigit(str.charAt(i2 + 1)) + (ByteStringKt.access$decodeHexDigit(str.charAt(i2)) << 4));
                }
                return new ByteString(bArr);
            }
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline18("Unexpected hex string: ", str).toString());
        }

        public final ByteString encodeString(String str, Charset charset) {
            Intrinsics.checkNotNullParameter(str, "$this$encode");
            Intrinsics.checkNotNullParameter(charset, "charset");
            byte[] bytes = str.getBytes(charset);
            Intrinsics.checkNotNullExpressionValue(bytes, "(this as java.lang.String).getBytes(charset)");
            return new ByteString(bytes);
        }

        public final ByteString encodeUtf8(String str) {
            Intrinsics.checkNotNullParameter(str, "$this$encodeUtf8");
            Intrinsics.checkNotNullParameter(str, "$this$asUtf8ToByteArray");
            byte[] bytes = str.getBytes(Charsets.UTF_8);
            Intrinsics.checkNotNullExpressionValue(bytes, "(this as java.lang.String).getBytes(charset)");
            ByteString byteString = new ByteString(bytes);
            byteString.setUtf8$okio(str);
            return byteString;
        }

        public final ByteString of(byte[] bArr, int i, int i2) {
            Intrinsics.checkNotNullParameter(bArr, "$this$toByteString");
            SystemPropsKt.checkOffsetAndCount((long) bArr.length, (long) i, (long) i2);
            return new ByteString(ArraysKt___ArraysKt.copyOfRange(bArr, i, i2 + i));
        }

        public final ByteString read(InputStream inputStream, int i) {
            Intrinsics.checkNotNullParameter(inputStream, "$this$readByteString");
            int i2 = 0;
            if (i >= 0) {
                byte[] bArr = new byte[i];
                while (i2 < i) {
                    int read = inputStream.read(bArr, i2, i - i2);
                    if (read != -1) {
                        i2 += read;
                    } else {
                        throw new EOFException();
                    }
                }
                return new ByteString(bArr);
            }
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline11("byteCount < 0: ", i).toString());
        }
    }

    public ByteString(byte[] bArr) {
        Intrinsics.checkNotNullParameter(bArr, "data");
        this.data = bArr;
    }

    public static final ByteString decodeBase64(String str) {
        int i;
        int i2;
        Objects.requireNonNull(Companion);
        Intrinsics.checkNotNullParameter(str, "$this$decodeBase64");
        byte[] bArr = Base64.BASE64;
        Intrinsics.checkNotNullParameter(str, "$this$decodeBase64ToArray");
        int length = str.length();
        while (length > 0 && ((r6 = str.charAt(length - 1)) == '=' || r6 == '\n' || r6 == '\r' || r6 == ' ' || r6 == '\t')) {
            length = i2;
        }
        int i3 = (int) ((((long) length) * 6) / 8);
        byte[] bArr2 = new byte[i3];
        int i4 = 0;
        int i5 = 0;
        int i6 = 0;
        int i7 = 0;
        while (true) {
            if (i4 < length) {
                char charAt = str.charAt(i4);
                if ('A' <= charAt && 'Z' >= charAt) {
                    i = charAt - 'A';
                } else if ('a' <= charAt && 'z' >= charAt) {
                    i = charAt - 'G';
                } else if ('0' <= charAt && '9' >= charAt) {
                    i = charAt + 4;
                } else if (charAt == '+' || charAt == '-') {
                    i = 62;
                } else if (charAt == '/' || charAt == '_') {
                    i = 63;
                } else {
                    if (!(charAt == '\n' || charAt == '\r' || charAt == ' ' || charAt == '\t')) {
                        break;
                    }
                    i4++;
                }
                i6 = (i6 << 6) | i;
                i5++;
                if (i5 % 4 == 0) {
                    int i8 = i7 + 1;
                    bArr2[i7] = (byte) (i6 >> 16);
                    int i9 = i8 + 1;
                    bArr2[i8] = (byte) (i6 >> 8);
                    bArr2[i9] = (byte) i6;
                    i7 = i9 + 1;
                }
                i4++;
            } else {
                int i10 = i5 % 4;
                if (i10 != 1) {
                    if (i10 == 2) {
                        bArr2[i7] = (byte) ((i6 << 12) >> 16);
                        i7++;
                    } else if (i10 == 3) {
                        int i11 = i6 << 6;
                        int i12 = i7 + 1;
                        bArr2[i7] = (byte) (i11 >> 16);
                        i7 = i12 + 1;
                        bArr2[i12] = (byte) (i11 >> 8);
                    }
                    if (i7 != i3) {
                        bArr2 = Arrays.copyOf(bArr2, i7);
                        Intrinsics.checkNotNullExpressionValue(bArr2, "java.util.Arrays.copyOf(this, newSize)");
                    }
                }
            }
        }
        bArr2 = null;
        if (bArr2 != null) {
            return new ByteString(bArr2);
        }
        return null;
    }

    public static final ByteString decodeHex(String str) {
        return Companion.decodeHex(str);
    }

    public static final ByteString encodeString(String str, Charset charset) {
        return Companion.encodeString(str, charset);
    }

    public static final ByteString encodeUtf8(String str) {
        return Companion.encodeUtf8(str);
    }

    public static /* synthetic */ int indexOf$default(ByteString byteString, ByteString byteString2, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = 0;
            }
            return byteString.indexOf(byteString2, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: indexOf");
    }

    public static /* synthetic */ int indexOf$default(ByteString byteString, byte[] bArr, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = 0;
            }
            return byteString.indexOf(bArr, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: indexOf");
    }

    public static /* synthetic */ int lastIndexOf$default(ByteString byteString, ByteString byteString2, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = byteString.size();
            }
            return byteString.lastIndexOf(byteString2, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: lastIndexOf");
    }

    public static /* synthetic */ int lastIndexOf$default(ByteString byteString, byte[] bArr, int i, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = byteString.size();
            }
            return byteString.lastIndexOf(bArr, i);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: lastIndexOf");
    }

    public static final ByteString of(ByteBuffer byteBuffer) {
        Objects.requireNonNull(Companion);
        Intrinsics.checkNotNullParameter(byteBuffer, "$this$toByteString");
        byte[] bArr = new byte[byteBuffer.remaining()];
        byteBuffer.get(bArr);
        return new ByteString(bArr);
    }

    public static final ByteString of(byte[] bArr, int i, int i2) {
        return Companion.of(bArr, i, i2);
    }

    public static final ByteString read(InputStream inputStream, int i) {
        return Companion.read(inputStream, i);
    }

    private final void readObject(ObjectInputStream objectInputStream) {
        ByteString read = Companion.read(objectInputStream, objectInputStream.readInt());
        Field declaredField = ByteString.class.getDeclaredField("data");
        Intrinsics.checkNotNullExpressionValue(declaredField, "field");
        declaredField.setAccessible(true);
        declaredField.set(this, read.data);
    }

    public static /* synthetic */ ByteString substring$default(ByteString byteString, int i, int i2, int i3, Object obj) {
        if (obj == null) {
            if ((i3 & 1) != 0) {
                i = 0;
            }
            if ((i3 & 2) != 0) {
                i2 = byteString.size();
            }
            return byteString.substring(i, i2);
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: substring");
    }

    private final void writeObject(ObjectOutputStream objectOutputStream) {
        objectOutputStream.writeInt(this.data.length);
        objectOutputStream.write(this.data);
    }

    /* renamed from: -deprecated_getByte  reason: not valid java name */
    public final byte m143deprecated_getByte(int i) {
        return getByte(i);
    }

    /* renamed from: -deprecated_size  reason: not valid java name */
    public final int m144deprecated_size() {
        return size();
    }

    public ByteBuffer asByteBuffer() {
        ByteBuffer asReadOnlyBuffer = ByteBuffer.wrap(this.data).asReadOnlyBuffer();
        Intrinsics.checkNotNullExpressionValue(asReadOnlyBuffer, "ByteBuffer.wrap(data).asReadOnlyBuffer()");
        return asReadOnlyBuffer;
    }

    public String base64() {
        return Base64.encodeBase64(getData$okio(), Base64.BASE64);
    }

    public String base64Url() {
        return Base64.encodeBase64(getData$okio(), Base64.BASE64_URL_SAFE);
    }

    public ByteString digest$okio(String str) {
        Intrinsics.checkNotNullParameter(str, "algorithm");
        byte[] digest = MessageDigest.getInstance(str).digest(this.data);
        Intrinsics.checkNotNullExpressionValue(digest, "MessageDigest.getInstance(algorithm).digest(data)");
        return new ByteString(digest);
    }

    public final boolean endsWith(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, "suffix");
        return rangeEquals(size() - byteString.size(), byteString, 0, byteString.size());
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj instanceof ByteString) {
            ByteString byteString = (ByteString) obj;
            return byteString.size() == getData$okio().length && byteString.rangeEquals(0, getData$okio(), 0, getData$okio().length);
        }
    }

    public final byte getByte(int i) {
        return internalGet$okio(i);
    }

    public final byte[] getData$okio() {
        return this.data;
    }

    public final int getHashCode$okio() {
        return this.hashCode;
    }

    public int getSize$okio() {
        return getData$okio().length;
    }

    public final String getUtf8$okio() {
        return this.utf8;
    }

    public int hashCode() {
        int hashCode$okio = getHashCode$okio();
        if (hashCode$okio != 0) {
            return hashCode$okio;
        }
        int hashCode2 = Arrays.hashCode(getData$okio());
        setHashCode$okio(hashCode2);
        return hashCode2;
    }

    public String hex() {
        char[] cArr = new char[(getData$okio().length * 2)];
        byte[] data$okio = getData$okio();
        int i = 0;
        for (byte b : data$okio) {
            int i2 = i + 1;
            char[] cArr2 = ByteStringKt.HEX_DIGIT_CHARS;
            cArr[i] = cArr2[(b >> 4) & 15];
            i = i2 + 1;
            cArr[i2] = cArr2[b & 15];
        }
        return new String(cArr);
    }

    public ByteString hmac$okio(String str, ByteString byteString) {
        Intrinsics.checkNotNullParameter(str, "algorithm");
        Intrinsics.checkNotNullParameter(byteString, "key");
        try {
            Mac instance = Mac.getInstance(str);
            instance.init(new SecretKeySpec(byteString.toByteArray(), str));
            byte[] doFinal = instance.doFinal(this.data);
            Intrinsics.checkNotNullExpressionValue(doFinal, "mac.doFinal(data)");
            return new ByteString(doFinal);
        } catch (InvalidKeyException e) {
            throw new IllegalArgumentException(e);
        }
    }

    public ByteString hmacSha1(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, "key");
        return hmac$okio("HmacSHA1", byteString);
    }

    public ByteString hmacSha256(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, "key");
        return hmac$okio("HmacSHA256", byteString);
    }

    public ByteString hmacSha512(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, "key");
        return hmac$okio("HmacSHA512", byteString);
    }

    public final int indexOf(ByteString byteString) {
        return indexOf$default(this, byteString, 0, 2, (Object) null);
    }

    public final int indexOf(ByteString byteString, int i) {
        Intrinsics.checkNotNullParameter(byteString, "other");
        return indexOf(byteString.internalArray$okio(), i);
    }

    public final int indexOf(byte[] bArr) {
        return indexOf$default(this, bArr, 0, 2, (Object) null);
    }

    public byte[] internalArray$okio() {
        return getData$okio();
    }

    public byte internalGet$okio(int i) {
        return getData$okio()[i];
    }

    public final int lastIndexOf(ByteString byteString) {
        return lastIndexOf$default(this, byteString, 0, 2, (Object) null);
    }

    public final int lastIndexOf(ByteString byteString, int i) {
        Intrinsics.checkNotNullParameter(byteString, "other");
        return lastIndexOf(byteString.internalArray$okio(), i);
    }

    public final int lastIndexOf(byte[] bArr) {
        return lastIndexOf$default(this, bArr, 0, 2, (Object) null);
    }

    public ByteString md5() {
        return digest$okio("MD5");
    }

    public boolean rangeEquals(int i, ByteString byteString, int i2, int i3) {
        Intrinsics.checkNotNullParameter(byteString, "other");
        return byteString.rangeEquals(i2, getData$okio(), i, i3);
    }

    public final void setHashCode$okio(int i) {
        this.hashCode = i;
    }

    public final void setUtf8$okio(String str) {
        this.utf8 = str;
    }

    public ByteString sha1() {
        return digest$okio("SHA-1");
    }

    public ByteString sha256() {
        return digest$okio("SHA-256");
    }

    public ByteString sha512() {
        return digest$okio("SHA-512");
    }

    public final int size() {
        return getSize$okio();
    }

    public final boolean startsWith(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, "prefix");
        return rangeEquals(0, byteString, 0, byteString.size());
    }

    public String string(Charset charset) {
        Intrinsics.checkNotNullParameter(charset, "charset");
        return new String(this.data, charset);
    }

    public final ByteString substring() {
        return substring$default(this, 0, 0, 3, null);
    }

    public final ByteString substring(int i) {
        return substring$default(this, i, 0, 2, null);
    }

    public ByteString substring(int i, int i2) {
        boolean z = true;
        if (i >= 0) {
            if (i2 <= getData$okio().length) {
                if (i2 - i < 0) {
                    z = false;
                }
                if (z) {
                    return (i == 0 && i2 == getData$okio().length) ? this : new ByteString(ArraysKt___ArraysKt.copyOfRange(getData$okio(), i, i2));
                }
                throw new IllegalArgumentException("endIndex < beginIndex".toString());
            }
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline20(GeneratedOutlineSupport.outline25("endIndex > length("), getData$okio().length, ')').toString());
        }
        throw new IllegalArgumentException("beginIndex < 0".toString());
    }

    public ByteString toAsciiLowercase() {
        byte b;
        for (int i = 0; i < getData$okio().length; i++) {
            byte b2 = getData$okio()[i];
            byte b3 = (byte) 65;
            if (b2 >= b3 && b2 <= (b = (byte) 90)) {
                byte[] data$okio = getData$okio();
                byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
                Intrinsics.checkNotNullExpressionValue(copyOf, "java.util.Arrays.copyOf(this, size)");
                copyOf[i] = (byte) (b2 + 32);
                for (int i2 = i + 1; i2 < copyOf.length; i2++) {
                    byte b4 = copyOf[i2];
                    if (b4 >= b3 && b4 <= b) {
                        copyOf[i2] = (byte) (b4 + 32);
                    }
                }
                return new ByteString(copyOf);
            }
        }
        return this;
    }

    public ByteString toAsciiUppercase() {
        byte b;
        for (int i = 0; i < getData$okio().length; i++) {
            byte b2 = getData$okio()[i];
            byte b3 = (byte) 97;
            if (b2 >= b3 && b2 <= (b = (byte) 122)) {
                byte[] data$okio = getData$okio();
                byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
                Intrinsics.checkNotNullExpressionValue(copyOf, "java.util.Arrays.copyOf(this, size)");
                copyOf[i] = (byte) (b2 - 32);
                for (int i2 = i + 1; i2 < copyOf.length; i2++) {
                    byte b4 = copyOf[i2];
                    if (b4 >= b3 && b4 <= b) {
                        copyOf[i2] = (byte) (b4 - 32);
                    }
                }
                return new ByteString(copyOf);
            }
        }
        return this;
    }

    public byte[] toByteArray() {
        byte[] data$okio = getData$okio();
        byte[] copyOf = Arrays.copyOf(data$okio, data$okio.length);
        Intrinsics.checkNotNullExpressionValue(copyOf, "java.util.Arrays.copyOf(this, size)");
        return copyOf;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:100:0x0121, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:125:0x015d, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:131:0x0170, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:137:0x0181, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:143:0x0190, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:146:0x01a6, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:149:0x01ae, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:152:0x01b5, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:174:0x01e8, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:175:0x01eb, code lost:
        r4 = -1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:51:0x008d, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:0x009e, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x00a9, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x00e4, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:88:0x00f7, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:94:0x0106, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:97:0x0118, code lost:
        if (r3 == 64) goto L_0x01ec;
     */
    public String toString() {
        ByteString byteString;
        if (getData$okio().length == 0) {
            return "[size=0]";
        }
        byte[] data$okio = getData$okio();
        int length = data$okio.length;
        int i = 0;
        int i2 = 0;
        int i3 = 0;
        loop0:
        while (true) {
            if (i >= length) {
                break;
            }
            byte b = data$okio[i];
            if (b >= 0) {
                int i4 = i2 + 1;
                if (i2 == 64) {
                    break;
                }
                if (!(b == 10 || b == 13)) {
                    if ((b >= 0 && 31 >= b) || (Byte.MAX_VALUE <= b && 159 >= b)) {
                        break;
                    }
                }
                if (b == 65533) {
                    break;
                }
                i3 += b < 65536 ? 1 : 2;
                i++;
                while (true) {
                    i2 = i4;
                    if (i >= length || data$okio[i] < 0) {
                        break;
                    }
                    int i5 = i + 1;
                    byte b2 = data$okio[i];
                    i4 = i2 + 1;
                    if (i2 == 64) {
                        break loop0;
                    }
                    if (!(b2 == 10 || b2 == 13)) {
                        if ((b2 >= 0 && 31 >= b2) || (Byte.MAX_VALUE <= b2 && 159 >= b2)) {
                            break loop0;
                        }
                    }
                    if (b2 == 65533) {
                        break loop0;
                    }
                    i3 += b2 < 65536 ? 1 : 2;
                    i = i5;
                }
            } else if ((b >> 5) == -2) {
                int i6 = i + 1;
                if (length > i6) {
                    byte b3 = data$okio[i];
                    byte b4 = data$okio[i6];
                    if ((b4 & 192) == 128) {
                        int i7 = (b4 ^ 3968) ^ (b3 << 6);
                        if (i7 >= 128) {
                            int i8 = i2 + 1;
                            if (i2 == 64) {
                                break;
                            }
                            if (!(i7 == 10 || i7 == 13)) {
                                if ((i7 >= 0 && 31 >= i7) || (127 <= i7 && 159 >= i7)) {
                                    break;
                                }
                            }
                            if (i7 == 65533) {
                                break;
                            }
                            i3 += i7 < 65536 ? 1 : 2;
                            i += 2;
                            i2 = i8;
                        }
                    }
                }
            } else if ((b >> 4) == -2) {
                int i9 = i + 2;
                if (length > i9) {
                    byte b5 = data$okio[i];
                    byte b6 = data$okio[i + 1];
                    if ((b6 & 192) == 128) {
                        byte b7 = data$okio[i9];
                        if ((b7 & 192) == 128) {
                            int i10 = ((b7 ^ -123008) ^ (b6 << 6)) ^ (b5 << TCPHeader.offset_lenres);
                            if (i10 >= 2048) {
                                if (55296 > i10 || 57343 < i10) {
                                    int i11 = i2 + 1;
                                    if (i2 == 64) {
                                        break;
                                    }
                                    if (!(i10 == 10 || i10 == 13)) {
                                        if ((i10 >= 0 && 31 >= i10) || (127 <= i10 && 159 >= i10)) {
                                            break;
                                        }
                                    }
                                    if (i10 == 65533) {
                                        break;
                                    }
                                    i3 += i10 < 65536 ? 1 : 2;
                                    i += 3;
                                    i2 = i11;
                                }
                            }
                        }
                    }
                }
            } else if ((b >> 3) == -2) {
                int i12 = i + 3;
                if (length > i12) {
                    byte b8 = data$okio[i];
                    byte b9 = data$okio[i + 1];
                    if ((b9 & 192) == 128) {
                        byte b10 = data$okio[i + 2];
                        if ((b10 & 192) == 128) {
                            byte b11 = data$okio[i12];
                            if ((b11 & 192) == 128) {
                                int i13 = (((b11 ^ 3678080) ^ (b10 << 6)) ^ (b9 << TCPHeader.offset_lenres)) ^ (b8 << 18);
                                if (i13 <= 1114111) {
                                    if (55296 > i13 || 57343 < i13) {
                                        if (i13 >= 65536) {
                                            int i14 = i2 + 1;
                                            if (i2 == 64) {
                                                break;
                                            }
                                            if (!(i13 == 10 || i13 == 13)) {
                                                if ((i13 >= 0 && 31 >= i13) || (127 <= i13 && 159 >= i13)) {
                                                    break;
                                                }
                                            }
                                            if (i13 == 65533) {
                                                break;
                                            }
                                            i3 += i13 < 65536 ? 1 : 2;
                                            i += 4;
                                            i2 = i14;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
        if (i3 != -1) {
            String utf82 = utf8();
            Objects.requireNonNull(utf82, "null cannot be cast to non-null type java.lang.String");
            String substring = utf82.substring(0, i3);
            Intrinsics.checkNotNullExpressionValue(substring, "(this as java.lang.Strin…ing(startIndex, endIndex)");
            String replace$default = StringsKt__IndentKt.replace$default(StringsKt__IndentKt.replace$default(StringsKt__IndentKt.replace$default(substring, "\\", "\\\\", false, 4), "\n", "\\n", false, 4), "\r", "\\r", false, 4);
            if (i3 < utf82.length()) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("[size=");
                outline25.append(getData$okio().length);
                outline25.append(" text=");
                outline25.append(replace$default);
                outline25.append("…]");
                return outline25.toString();
            }
            return "[text=" + replace$default + ']';
        } else if (getData$okio().length <= 64) {
            StringBuilder outline252 = GeneratedOutlineSupport.outline25("[hex=");
            outline252.append(hex());
            outline252.append(']');
            return outline252.toString();
        } else {
            StringBuilder outline253 = GeneratedOutlineSupport.outline25("[size=");
            outline253.append(getData$okio().length);
            outline253.append(" hex=");
            if (64 <= getData$okio().length) {
                if (64 == getData$okio().length) {
                    byteString = this;
                } else {
                    byteString = new ByteString(ArraysKt___ArraysKt.copyOfRange(getData$okio(), 0, 64));
                }
                outline253.append(byteString.hex());
                outline253.append("…]");
                return outline253.toString();
            }
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline20(GeneratedOutlineSupport.outline25("endIndex > length("), getData$okio().length, ')').toString());
        }
    }

    public String utf8() {
        String utf8$okio = getUtf8$okio();
        if (utf8$okio != null) {
            return utf8$okio;
        }
        byte[] internalArray$okio = internalArray$okio();
        Intrinsics.checkNotNullParameter(internalArray$okio, "$this$toUtf8String");
        String str = new String(internalArray$okio, Charsets.UTF_8);
        setUtf8$okio(str);
        return str;
    }

    public void write(OutputStream outputStream) {
        Intrinsics.checkNotNullParameter(outputStream, "out");
        outputStream.write(this.data);
    }

    public void write$okio(Buffer buffer, int i, int i2) {
        Intrinsics.checkNotNullParameter(buffer, "buffer");
        Intrinsics.checkNotNullParameter(this, "$this$commonWrite");
        Intrinsics.checkNotNullParameter(buffer, "buffer");
        buffer.write(getData$okio(), i, i2);
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0032 A[ORIG_RETURN, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x0030 A[RETURN, SYNTHETIC] */
    public int compareTo(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, "other");
        int size = size();
        int size2 = byteString.size();
        int min = Math.min(size, size2);
        for (int i = 0; i < min; i++) {
            int i2 = getByte(i) & 255;
            int i3 = byteString.getByte(i) & 255;
            if (i2 != i3) {
                return i2 < i3 ? -1 : 1;
            }
        }
        if (size == size2) {
            return 0;
        }
        if (size < size2) {
        }
    }

    public final boolean endsWith(byte[] bArr) {
        Intrinsics.checkNotNullParameter(bArr, "suffix");
        return rangeEquals(size() - bArr.length, bArr, 0, bArr.length);
    }

    public int indexOf(byte[] bArr, int i) {
        Intrinsics.checkNotNullParameter(bArr, "other");
        int length = getData$okio().length - bArr.length;
        int max = Math.max(i, 0);
        if (max <= length) {
            while (!SystemPropsKt.arrayRangeEquals(getData$okio(), max, bArr, 0, bArr.length)) {
                if (max != length) {
                    max++;
                }
            }
            return max;
        }
        return -1;
    }

    public int lastIndexOf(byte[] bArr, int i) {
        Intrinsics.checkNotNullParameter(bArr, "other");
        for (int min = Math.min(i, getData$okio().length - bArr.length); min >= 0; min--) {
            if (SystemPropsKt.arrayRangeEquals(getData$okio(), min, bArr, 0, bArr.length)) {
                return min;
            }
        }
        return -1;
    }

    public boolean rangeEquals(int i, byte[] bArr, int i2, int i3) {
        Intrinsics.checkNotNullParameter(bArr, "other");
        return i >= 0 && i <= getData$okio().length - i3 && i2 >= 0 && i2 <= bArr.length - i3 && SystemPropsKt.arrayRangeEquals(getData$okio(), i, bArr, i2, i3);
    }

    public final boolean startsWith(byte[] bArr) {
        Intrinsics.checkNotNullParameter(bArr, "prefix");
        return rangeEquals(0, bArr, 0, bArr.length);
    }

    public static final ByteString of(byte... bArr) {
        Objects.requireNonNull(Companion);
        Intrinsics.checkNotNullParameter(bArr, "data");
        byte[] copyOf = Arrays.copyOf(bArr, bArr.length);
        Intrinsics.checkNotNullExpressionValue(copyOf, "java.util.Arrays.copyOf(this, size)");
        return new ByteString(copyOf);
    }
}
