package okio;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.IOException;
import java.net.Socket;
import java.net.SocketTimeoutException;
import java.util.logging.Level;
import java.util.logging.Logger;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.SystemPropsKt;

/* compiled from: JvmOkio.kt */
public final class SocketAsyncTimeout extends AsyncTimeout {
    public final Socket socket;

    public SocketAsyncTimeout(Socket socket2) {
        Intrinsics.checkNotNullParameter(socket2, "socket");
        this.socket = socket2;
    }

    @Override // okio.AsyncTimeout
    public IOException newTimeoutException(IOException iOException) {
        SocketTimeoutException socketTimeoutException = new SocketTimeoutException("timeout");
        if (iOException != null) {
            socketTimeoutException.initCause(iOException);
        }
        return socketTimeoutException;
    }

    @Override // okio.AsyncTimeout
    public void timedOut() {
        try {
            this.socket.close();
        } catch (Exception e) {
            Logger logger = Okio__JvmOkioKt.logger;
            Level level = Level.WARNING;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed to close timed out socket ");
            outline25.append(this.socket);
            logger.log(level, outline25.toString(), (Throwable) e);
        } catch (AssertionError e2) {
            if (SystemPropsKt.isAndroidGetsocknameError(e2)) {
                Logger logger2 = Okio__JvmOkioKt.logger;
                Level level2 = Level.WARNING;
                StringBuilder outline252 = GeneratedOutlineSupport.outline25("Failed to close timed out socket ");
                outline252.append(this.socket);
                logger2.log(level2, outline252.toString(), (Throwable) e2);
                return;
            }
            throw e2;
        }
    }
}
