package org.bouncycastle.crypto.engines;

import com.android.tools.r8.GeneratedOutlineSupport;
import kotlinx.coroutines.internal.SystemPropsKt;

public class ChaCha7539Engine extends Salsa20Engine {
    @Override // org.bouncycastle.crypto.engines.Salsa20Engine
    public void advanceCounter() {
        int[] iArr = this.engineState;
        int i = iArr[12] + 1;
        iArr[12] = i;
        if (i == 0) {
            throw new IllegalStateException("attempt to increase counter past 2^32.");
        }
    }

    @Override // org.bouncycastle.crypto.engines.Salsa20Engine
    public void generateKeyStream(byte[] bArr) {
        int[] iArr;
        ChaChaEngine.chachaCore(this.rounds, this.engineState, this.x);
        int i = 0;
        for (int i2 : this.x) {
            SystemPropsKt.intToLittleEndian(i2, bArr, i);
            i += 4;
        }
    }

    @Override // org.bouncycastle.crypto.engines.Salsa20Engine
    public String getAlgorithmName() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("ChaCha7539-");
        outline25.append(this.rounds);
        return outline25.toString();
    }

    @Override // org.bouncycastle.crypto.engines.Salsa20Engine
    public int getNonceSize() {
        return 12;
    }

    @Override // org.bouncycastle.crypto.engines.Salsa20Engine
    public void resetCounter() {
        this.engineState[12] = 0;
    }

    @Override // org.bouncycastle.crypto.engines.Salsa20Engine
    public void setKey(byte[] bArr, byte[] bArr2) {
        if (bArr != null) {
            if (bArr.length == 32) {
                packTauOrSigma(bArr.length, this.engineState, 0);
                SystemPropsKt.littleEndianToInt(bArr, 0, this.engineState, 4, 8);
            } else {
                throw new IllegalArgumentException(getAlgorithmName() + " requires 256 bit key");
            }
        }
        SystemPropsKt.littleEndianToInt(bArr2, 0, this.engineState, 13, 3);
    }
}
