package org.bouncycastle.crypto.engines;

import com.android.tools.r8.GeneratedOutlineSupport;
import org.bouncycastle.crypto.CipherParameters;
import org.bouncycastle.crypto.DataLengthException;
import org.bouncycastle.crypto.OutputLengthException;
import org.bouncycastle.crypto.StreamCipher;
import org.bouncycastle.crypto.params.KeyParameter;
import org.xbill.DNS.KEYRecord;

public class RC4Engine implements StreamCipher {
    public byte[] engineState = null;
    public byte[] workingKey = null;
    public int x = 0;
    public int y = 0;

    @Override // org.bouncycastle.crypto.StreamCipher
    public void init(boolean z, CipherParameters cipherParameters) {
        if (cipherParameters instanceof KeyParameter) {
            byte[] bArr = ((KeyParameter) cipherParameters).key;
            this.workingKey = bArr;
            this.workingKey = bArr;
            this.x = 0;
            this.y = 0;
            if (this.engineState == null) {
                this.engineState = new byte[256];
            }
            for (int i = 0; i < 256; i++) {
                this.engineState[i] = (byte) i;
            }
            int i2 = 0;
            int i3 = 0;
            for (int i4 = 0; i4 < 256; i4++) {
                byte[] bArr2 = this.engineState;
                i3 = ((bArr[i2] & 255) + bArr2[i4] + i3) & KEYRecord.PROTOCOL_ANY;
                byte b = bArr2[i4];
                bArr2[i4] = bArr2[i3];
                bArr2[i3] = b;
                i2 = (i2 + 1) % bArr.length;
            }
            return;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("invalid parameter passed to RC4 init - ");
        outline25.append(cipherParameters.getClass().getName());
        throw new IllegalArgumentException(outline25.toString());
    }

    @Override // org.bouncycastle.crypto.StreamCipher
    public int processBytes(byte[] bArr, int i, int i2, byte[] bArr2, int i3) {
        if (i + i2 > bArr.length) {
            throw new DataLengthException("input buffer too short");
        } else if (i3 + i2 <= bArr2.length) {
            for (int i4 = 0; i4 < i2; i4++) {
                int i5 = (this.x + 1) & KEYRecord.PROTOCOL_ANY;
                this.x = i5;
                byte[] bArr3 = this.engineState;
                int i6 = (bArr3[i5] + this.y) & KEYRecord.PROTOCOL_ANY;
                this.y = i6;
                byte b = bArr3[i5];
                bArr3[i5] = bArr3[i6];
                bArr3[i6] = b;
                bArr2[i4 + i3] = (byte) (bArr3[(bArr3[i5] + bArr3[i6]) & KEYRecord.PROTOCOL_ANY] ^ bArr[i4 + i]);
            }
            return i2;
        } else {
            throw new OutputLengthException("output buffer too short");
        }
    }
}
