package org.bouncycastle.crypto.modes;

import org.bouncycastle.crypto.BlockCipher;
import org.bouncycastle.crypto.CipherParameters;
import org.bouncycastle.crypto.StreamBlockCipher;
import org.bouncycastle.crypto.params.ParametersWithIV;

public class CFBBlockCipher extends StreamBlockCipher {
    public byte[] IV;
    public int blockSize;
    public int byteCount;
    public byte[] cfbOutV;
    public byte[] cfbV;
    public BlockCipher cipher = null;
    public boolean encrypting;
    public byte[] inBuf;

    public CFBBlockCipher(BlockCipher blockCipher, int i) {
        super(blockCipher);
        this.cipher = blockCipher;
        this.blockSize = i / 8;
        this.IV = new byte[blockCipher.getBlockSize()];
        this.cfbV = new byte[blockCipher.getBlockSize()];
        this.cfbOutV = new byte[blockCipher.getBlockSize()];
        this.inBuf = new byte[this.blockSize];
    }

    @Override // org.bouncycastle.crypto.StreamBlockCipher
    public byte calculateByte(byte b) {
        byte b2;
        if (this.encrypting) {
            if (this.byteCount == 0) {
                this.cipher.processBlock(this.cfbV, 0, this.cfbOutV, 0);
            }
            byte[] bArr = this.cfbOutV;
            int i = this.byteCount;
            b2 = (byte) (b ^ bArr[i]);
            byte[] bArr2 = this.inBuf;
            int i2 = i + 1;
            this.byteCount = i2;
            bArr2[i] = b2;
            int i3 = this.blockSize;
            if (i2 == i3) {
                this.byteCount = 0;
                byte[] bArr3 = this.cfbV;
                System.arraycopy(bArr3, i3, bArr3, 0, bArr3.length - i3);
                byte[] bArr4 = this.inBuf;
                byte[] bArr5 = this.cfbV;
                int length = bArr5.length;
                int i4 = this.blockSize;
                System.arraycopy(bArr4, 0, bArr5, length - i4, i4);
            }
        } else {
            if (this.byteCount == 0) {
                this.cipher.processBlock(this.cfbV, 0, this.cfbOutV, 0);
            }
            byte[] bArr6 = this.inBuf;
            int i5 = this.byteCount;
            bArr6[i5] = b;
            byte[] bArr7 = this.cfbOutV;
            int i6 = i5 + 1;
            this.byteCount = i6;
            b2 = (byte) (b ^ bArr7[i5]);
            int i7 = this.blockSize;
            if (i6 == i7) {
                this.byteCount = 0;
                byte[] bArr8 = this.cfbV;
                System.arraycopy(bArr8, i7, bArr8, 0, bArr8.length - i7);
                byte[] bArr9 = this.inBuf;
                byte[] bArr10 = this.cfbV;
                int length2 = bArr10.length;
                int i8 = this.blockSize;
                System.arraycopy(bArr9, 0, bArr10, length2 - i8, i8);
            }
        }
        return b2;
    }

    @Override // org.bouncycastle.crypto.BlockCipher
    public int getBlockSize() {
        return this.blockSize;
    }

    @Override // org.bouncycastle.crypto.StreamCipher, org.bouncycastle.crypto.BlockCipher
    public void init(boolean z, CipherParameters cipherParameters) {
        this.encrypting = z;
        if (cipherParameters instanceof ParametersWithIV) {
            ParametersWithIV parametersWithIV = (ParametersWithIV) cipherParameters;
            byte[] bArr = parametersWithIV.iv;
            int length = bArr.length;
            byte[] bArr2 = this.IV;
            if (length < bArr2.length) {
                System.arraycopy(bArr, 0, bArr2, bArr2.length - bArr.length, bArr.length);
                int i = 0;
                while (true) {
                    byte[] bArr3 = this.IV;
                    if (i >= bArr3.length - bArr.length) {
                        break;
                    }
                    bArr3[i] = 0;
                    i++;
                }
            } else {
                System.arraycopy(bArr, 0, bArr2, 0, bArr2.length);
            }
            reset();
            CipherParameters cipherParameters2 = parametersWithIV.parameters;
            if (cipherParameters2 != null) {
                this.cipher.init(true, cipherParameters2);
                return;
            }
            return;
        }
        reset();
        if (cipherParameters != null) {
            this.cipher.init(true, cipherParameters);
        }
    }

    @Override // org.bouncycastle.crypto.BlockCipher
    public int processBlock(byte[] bArr, int i, byte[] bArr2, int i2) {
        processBytes(bArr, i, this.blockSize, bArr2, i2);
        return this.blockSize;
    }

    @Override // org.bouncycastle.crypto.BlockCipher
    public void reset() {
        byte[] bArr = this.IV;
        System.arraycopy(bArr, 0, this.cfbV, 0, bArr.length);
        byte[] bArr2 = this.inBuf;
        for (int i = 0; i < bArr2.length; i++) {
            bArr2[i] = 0;
        }
        this.byteCount = 0;
        this.cipher.reset();
    }
}
