package org.xbill.DNS;

import java.net.InetAddress;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import kotlinx.coroutines.internal.SystemPropsKt;
import org.xbill.DNS.Tokenizer;

public class APLRecord extends Record {
    private static final long serialVersionUID = -1348173791712935864L;
    private List elements;

    public class Element {
        public final Object address;
        public final int family;
        public final boolean negative;
        public final int prefixLength;

        public Element(int i, boolean z, Object obj, int i2) {
            this.family = i;
            this.negative = z;
            this.address = obj;
            this.prefixLength = i2;
            if (!APLRecord.validatePrefixLength(i, i2)) {
                throw new IllegalArgumentException("invalid prefix length");
            }
        }

        public boolean equals(Object obj) {
            if (obj == null || !(obj instanceof Element)) {
                return false;
            }
            Element element = (Element) obj;
            if (this.family == element.family && this.negative == element.negative && this.prefixLength == element.prefixLength && this.address.equals(element.address)) {
                return true;
            }
            return false;
        }

        public int hashCode() {
            return this.address.hashCode() + this.prefixLength + (this.negative ? 1 : 0);
        }

        public String toString() {
            StringBuffer stringBuffer = new StringBuffer();
            if (this.negative) {
                stringBuffer.append("!");
            }
            stringBuffer.append(this.family);
            stringBuffer.append(":");
            int i = this.family;
            if (i == 1 || i == 2) {
                stringBuffer.append(((InetAddress) this.address).getHostAddress());
            } else {
                stringBuffer.append(SystemPropsKt.toString((byte[]) this.address));
            }
            stringBuffer.append("/");
            stringBuffer.append(this.prefixLength);
            return stringBuffer.toString();
        }
    }

    public APLRecord() {
    }

    public static boolean validatePrefixLength(int i, int i2) {
        if (i2 < 0 || i2 >= 256) {
            return false;
        }
        return (i != 1 || i2 <= 32) && (i != 2 || i2 <= 128);
    }

    public List getElements() {
        return this.elements;
    }

    @Override // org.xbill.DNS.Record
    public Record getObject() {
        return new APLRecord();
    }

    @Override // org.xbill.DNS.Record
    public void rdataFromString(Tokenizer tokenizer, Name name) {
        boolean z;
        this.elements = new ArrayList(1);
        while (true) {
            Tokenizer.Token token = tokenizer.get();
            if (!token.isString()) {
                tokenizer.unget();
                return;
            }
            String str = token.value;
            int i = 0;
            if (str.startsWith("!")) {
                z = true;
                i = 1;
            } else {
                z = false;
            }
            int indexOf = str.indexOf(58, i);
            if (indexOf >= 0) {
                int indexOf2 = str.indexOf(47, indexOf);
                if (indexOf2 >= 0) {
                    String substring = str.substring(i, indexOf);
                    String substring2 = str.substring(indexOf + 1, indexOf2);
                    String substring3 = str.substring(indexOf2 + 1);
                    try {
                        int parseInt = Integer.parseInt(substring);
                        if (parseInt == 1 || parseInt == 2) {
                            try {
                                int parseInt2 = Integer.parseInt(substring3);
                                if (validatePrefixLength(parseInt, parseInt2)) {
                                    byte[] byteArray = SystemPropsKt.toByteArray(substring2, parseInt);
                                    if (byteArray != null) {
                                        InetAddress byAddress = InetAddress.getByAddress(byteArray);
                                        this.elements.add(new Element(SystemPropsKt.familyOf(byAddress), z, byAddress, parseInt2));
                                    } else {
                                        StringBuffer stringBuffer = new StringBuffer();
                                        stringBuffer.append("invalid IP address ");
                                        stringBuffer.append(substring2);
                                        throw tokenizer.exception(stringBuffer.toString());
                                    }
                                } else {
                                    throw tokenizer.exception("invalid prefix length");
                                }
                            } catch (NumberFormatException unused) {
                                throw tokenizer.exception("invalid prefix length");
                            }
                        } else {
                            throw tokenizer.exception("unknown family");
                        }
                    } catch (NumberFormatException unused2) {
                        throw tokenizer.exception("invalid family");
                    }
                } else {
                    throw tokenizer.exception("invalid address prefix element");
                }
            } else {
                throw tokenizer.exception("invalid address prefix element");
            }
        }
    }

    @Override // org.xbill.DNS.Record
    public void rrFromWire(DNSInput dNSInput) {
        Element element;
        this.elements = new ArrayList(1);
        while (dNSInput.remaining() != 0) {
            int readU16 = dNSInput.readU16();
            int readU8 = dNSInput.readU8();
            int readU82 = dNSInput.readU8();
            boolean z = (readU82 & 128) != 0;
            byte[] readByteArray = dNSInput.readByteArray(readU82 & -129);
            if (validatePrefixLength(readU16, readU8)) {
                if (readU16 == 1 || readU16 == 2) {
                    int addressLength = SystemPropsKt.addressLength(readU16);
                    if (readByteArray.length <= addressLength) {
                        if (readByteArray.length != addressLength) {
                            byte[] bArr = new byte[addressLength];
                            System.arraycopy(readByteArray, 0, bArr, 0, readByteArray.length);
                            readByteArray = bArr;
                        }
                        InetAddress byAddress = InetAddress.getByAddress(readByteArray);
                        element = new Element(SystemPropsKt.familyOf(byAddress), z, byAddress, readU8);
                    } else {
                        throw new WireParseException("invalid address length");
                    }
                } else {
                    element = new Element(readU16, z, readByteArray, readU8);
                }
                this.elements.add(element);
            } else {
                throw new WireParseException("invalid prefix length");
            }
        }
    }

    @Override // org.xbill.DNS.Record
    public String rrToString() {
        StringBuffer stringBuffer = new StringBuffer();
        Iterator it = this.elements.iterator();
        while (it.hasNext()) {
            stringBuffer.append((Element) it.next());
            if (it.hasNext()) {
                stringBuffer.append(" ");
            }
        }
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        int i;
        byte[] bArr;
        for (Element element : this.elements) {
            int i2 = element.family;
            if (i2 == 1 || i2 == 2) {
                bArr = ((InetAddress) element.address).getAddress();
                int length = bArr.length;
                while (true) {
                    length--;
                    if (length >= 0) {
                        if (bArr[length] != 0) {
                            i = length + 1;
                            break;
                        }
                    } else {
                        i = 0;
                        break;
                    }
                }
            } else {
                bArr = (byte[]) element.address;
                i = bArr.length;
            }
            int i3 = element.negative ? i | 128 : i;
            dNSOutput.writeU16(element.family);
            dNSOutput.writeU8(element.prefixLength);
            dNSOutput.writeU8(i3);
            dNSOutput.writeByteArray(bArr, 0, i);
        }
    }

    public APLRecord(Name name, int i, long j, List list) {
        super(name, 42, i, j);
        this.elements = new ArrayList(list.size());
        for (Object obj : list) {
            if (obj instanceof Element) {
                Element element = (Element) obj;
                int i2 = element.family;
                if (i2 == 1 || i2 == 2) {
                    this.elements.add(element);
                } else {
                    throw new IllegalArgumentException("unknown family");
                }
            } else {
                throw new IllegalArgumentException("illegal element");
            }
        }
    }
}
