package org.xbill.DNS;

import java.net.InetAddress;
import java.net.UnknownHostException;
import kotlinx.coroutines.internal.SystemPropsKt;

public class ClientSubnetOption extends EDNSOption {
    public InetAddress address;
    public int family;
    public int scopeNetmask;
    public int sourceNetmask;

    public ClientSubnetOption() {
        super(8);
    }

    @Override // org.xbill.DNS.EDNSOption
    public void optionFromWire(DNSInput dNSInput) {
        int readU16 = dNSInput.readU16();
        this.family = readU16;
        if (readU16 == 1 || readU16 == 2) {
            int readU8 = dNSInput.readU8();
            this.sourceNetmask = readU8;
            if (readU8 <= SystemPropsKt.addressLength(this.family) * 8) {
                int readU82 = dNSInput.readU8();
                this.scopeNetmask = readU82;
                if (readU82 <= SystemPropsKt.addressLength(this.family) * 8) {
                    byte[] readByteArray = dNSInput.readByteArray();
                    if (readByteArray.length == (this.sourceNetmask + 7) / 8) {
                        byte[] bArr = new byte[SystemPropsKt.addressLength(this.family)];
                        System.arraycopy(readByteArray, 0, bArr, 0, readByteArray.length);
                        try {
                            InetAddress byAddress = InetAddress.getByAddress(bArr);
                            this.address = byAddress;
                            int i = this.sourceNetmask;
                            int addressLength = SystemPropsKt.addressLength(SystemPropsKt.familyOf(byAddress)) * 8;
                            if (i < 0 || i > addressLength) {
                                throw new IllegalArgumentException("invalid mask length");
                            }
                            if (i != addressLength) {
                                byte[] address2 = byAddress.getAddress();
                                int i2 = i / 8;
                                for (int i3 = i2 + 1; i3 < address2.length; i3++) {
                                    address2[i3] = 0;
                                }
                                int i4 = 0;
                                for (int i5 = 0; i5 < i % 8; i5++) {
                                    i4 |= 1 << (7 - i5);
                                }
                                address2[i2] = (byte) (address2[i2] & i4);
                                try {
                                    byAddress = InetAddress.getByAddress(address2);
                                } catch (UnknownHostException unused) {
                                    throw new IllegalArgumentException("invalid address");
                                }
                            }
                            if (!byAddress.equals(this.address)) {
                                throw new WireParseException("invalid padding");
                            }
                        } catch (UnknownHostException e) {
                            throw new WireParseException("invalid address", e);
                        }
                    } else {
                        throw new WireParseException("invalid address");
                    }
                } else {
                    throw new WireParseException("invalid scope netmask");
                }
            } else {
                throw new WireParseException("invalid source netmask");
            }
        } else {
            throw new WireParseException("unknown address family");
        }
    }

    @Override // org.xbill.DNS.EDNSOption
    public String optionToString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.address.getHostAddress());
        stringBuffer.append("/");
        stringBuffer.append(this.sourceNetmask);
        stringBuffer.append(", scope netmask ");
        stringBuffer.append(this.scopeNetmask);
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.EDNSOption
    public void optionToWire(DNSOutput dNSOutput) {
        dNSOutput.writeU16(this.family);
        dNSOutput.writeU8(this.sourceNetmask);
        dNSOutput.writeU8(this.scopeNetmask);
        dNSOutput.writeByteArray(this.address.getAddress(), 0, (this.sourceNetmask + 7) / 8);
    }
}
