package org.xbill.DNS;

import java.nio.ByteBuffer;

public class DNSInput {
    public ByteBuffer byteBuffer;
    public int saved_end = -1;
    public int saved_pos = -1;

    public DNSInput(byte[] bArr) {
        this.byteBuffer = ByteBuffer.wrap(bArr);
    }

    public int current() {
        return this.byteBuffer.position();
    }

    public byte[] readByteArray(int i) {
        require(i);
        byte[] bArr = new byte[i];
        this.byteBuffer.get(bArr, 0, i);
        return bArr;
    }

    public byte[] readCountedString() {
        return readByteArray(readU8());
    }

    public int readU16() {
        require(2);
        return this.byteBuffer.getShort() & 65535;
    }

    public long readU32() {
        require(4);
        return ((long) this.byteBuffer.getInt()) & 4294967295L;
    }

    public int readU8() {
        require(1);
        return this.byteBuffer.get() & 255;
    }

    public int remaining() {
        return this.byteBuffer.remaining();
    }

    public final void require(int i) {
        if (i > remaining()) {
            throw new WireParseException("end of input");
        }
    }

    public void setActive(int i) {
        if (i <= this.byteBuffer.capacity() - this.byteBuffer.position()) {
            ByteBuffer byteBuffer2 = this.byteBuffer;
            byteBuffer2.limit(byteBuffer2.position() + i);
            return;
        }
        throw new IllegalArgumentException("cannot set active region past end of input");
    }

    public byte[] readByteArray() {
        int remaining = remaining();
        byte[] bArr = new byte[remaining];
        this.byteBuffer.get(bArr, 0, remaining);
        return bArr;
    }

    public DNSInput(ByteBuffer byteBuffer2) {
        this.byteBuffer = byteBuffer2;
    }
}
