package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.handler.codec.compression.FastLz;
import java.util.Arrays;

public abstract class EDNSOption {
    public final int code;

    public abstract class Code {
        public static Mnemonic codes;

        static {
            Mnemonic mnemonic = new Mnemonic("EDNS Option Codes", 2);
            codes = mnemonic;
            mnemonic.max = FastLz.MAX_CHUNK_LENGTH;
            mnemonic.prefix = mnemonic.sanitize("CODE");
            Mnemonic mnemonic2 = codes;
            mnemonic2.numericok = true;
            mnemonic2.add(3, "NSID");
            codes.add(8, "CLIENT_SUBNET");
        }
    }

    public EDNSOption(int i) {
        this.code = Record.checkU16("code", i);
    }

    public boolean equals(Object obj) {
        if (obj == null || !(obj instanceof EDNSOption)) {
            return false;
        }
        EDNSOption eDNSOption = (EDNSOption) obj;
        if (this.code != eDNSOption.code) {
            return false;
        }
        return Arrays.equals(getData(), eDNSOption.getData());
    }

    public byte[] getData() {
        DNSOutput dNSOutput = new DNSOutput();
        optionToWire(dNSOutput);
        return dNSOutput.toByteArray();
    }

    public int hashCode() {
        byte[] data;
        int i = 0;
        for (byte b : getData()) {
            i += (i << 3) + (b & 255);
        }
        return i;
    }

    public abstract void optionFromWire(DNSInput dNSInput);

    public abstract String optionToString();

    public abstract void optionToWire(DNSOutput dNSOutput);

    public String toString() {
        StringBuffer outline24 = GeneratedOutlineSupport.outline24("{");
        outline24.append(Code.codes.getText(this.code));
        outline24.append(": ");
        outline24.append(optionToString());
        outline24.append("}");
        return outline24.toString();
    }
}
