package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.handler.codec.compression.FastLz;
import java.util.Random;

public class Header implements Cloneable {
    public static Random random = new Random();
    public int[] counts;
    public int flags;
    public int id;

    public Header(int i) {
        this.counts = new int[4];
        this.flags = 0;
        this.id = -1;
        if (i < 0 || i > 65535) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("DNS message ID ");
            stringBuffer.append(i);
            stringBuffer.append(" is out of range");
            throw new IllegalArgumentException(stringBuffer.toString());
        }
        this.id = i;
    }

    public static void checkFlag(int i) {
        if (!validFlag(i)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("invalid flag bit ");
            stringBuffer.append(i);
            throw new IllegalArgumentException(stringBuffer.toString());
        }
    }

    public static int setFlag(int i, int i2, boolean z) {
        checkFlag(i2);
        return z ? i | (1 << (15 - i2)) : i & (~(1 << (15 - i2)));
    }

    public static boolean validFlag(int i) {
        if (i >= 0 && i <= 15) {
            Flags.flags.check(i);
            if ((i < 1 || i > 4) && i < 12) {
                return true;
            }
        }
        return false;
    }

    @Override // java.lang.Object
    public Object clone() {
        Header header = new Header();
        header.id = this.id;
        header.flags = this.flags;
        int[] iArr = this.counts;
        System.arraycopy(iArr, 0, header.counts, 0, iArr.length);
        return header;
    }

    public boolean getFlag(int i) {
        checkFlag(i);
        return ((1 << (15 - i)) & this.flags) != 0;
    }

    public int getID() {
        int i;
        int i2 = this.id;
        if (i2 >= 0) {
            return i2;
        }
        synchronized (this) {
            if (this.id < 0) {
                this.id = random.nextInt(FastLz.MAX_CHUNK_LENGTH);
            }
            i = this.id;
        }
        return i;
    }

    public int getOpcode() {
        return (this.flags >> 11) & 15;
    }

    public void incCount(int i) {
        int[] iArr = this.counts;
        if (iArr[i] != 65535) {
            iArr[i] = iArr[i] + 1;
            return;
        }
        throw new IllegalStateException("DNS section count cannot be incremented");
    }

    public String toString() {
        return toStringWithRcode(this.flags & 15);
    }

    public String toStringWithRcode(int i) {
        StringBuffer outline24 = GeneratedOutlineSupport.outline24(";; ->>HEADER<<- ");
        StringBuffer outline242 = GeneratedOutlineSupport.outline24("opcode: ");
        outline242.append(Opcode.opcodes.getText(getOpcode()));
        outline24.append(outline242.toString());
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(", status: ");
        stringBuffer.append(Rcode.string(i));
        outline24.append(stringBuffer.toString());
        StringBuffer stringBuffer2 = new StringBuffer();
        stringBuffer2.append(", id: ");
        stringBuffer2.append(getID());
        outline24.append(stringBuffer2.toString());
        outline24.append("\n");
        StringBuffer stringBuffer3 = new StringBuffer();
        stringBuffer3.append(";; flags: ");
        StringBuffer stringBuffer4 = new StringBuffer();
        for (int i2 = 0; i2 < 16; i2++) {
            if (validFlag(i2) && getFlag(i2)) {
                stringBuffer4.append(Flags.flags.getText(i2));
                stringBuffer4.append(" ");
            }
        }
        stringBuffer3.append(stringBuffer4.toString());
        outline24.append(stringBuffer3.toString());
        outline24.append("; ");
        for (int i3 = 0; i3 < 4; i3++) {
            StringBuffer stringBuffer5 = new StringBuffer();
            stringBuffer5.append(Section.sections.getText(i3));
            stringBuffer5.append(": ");
            stringBuffer5.append(this.counts[i3]);
            stringBuffer5.append(" ");
            outline24.append(stringBuffer5.toString());
        }
        return outline24.toString();
    }

    public void toWire(DNSOutput dNSOutput) {
        dNSOutput.writeU16(getID());
        dNSOutput.writeU16(this.flags);
        int i = 0;
        while (true) {
            int[] iArr = this.counts;
            if (i < iArr.length) {
                dNSOutput.writeU16(iArr[i]);
                i++;
            } else {
                return;
            }
        }
    }

    public void setFlag(int i) {
        checkFlag(i);
        this.flags = setFlag(this.flags, i, true);
    }

    public Header() {
        this.counts = new int[4];
        this.flags = 0;
        this.id = -1;
    }
}
