package org.xbill.DNS;

import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import io.netty.handler.codec.compression.FastLz;
import java.io.IOException;
import java.security.GeneralSecurityException;
import java.security.PublicKey;
import kotlinx.coroutines.internal.SystemPropsKt;
import org.xbill.DNS.DNSSEC;

public abstract class KEYBase extends Record {
    private static final long serialVersionUID = 3469321722693285454L;
    public int alg;
    public int flags;
    public int footprint = -1;
    public byte[] key;
    public int proto;
    public PublicKey publicKey = null;

    public KEYBase() {
    }

    public int getAlgorithm() {
        return this.alg;
    }

    public int getFlags() {
        return this.flags;
    }

    public int getFootprint() {
        int i;
        int i2;
        int i3 = this.footprint;
        if (i3 >= 0) {
            return i3;
        }
        DNSOutput dNSOutput = new DNSOutput();
        int i4 = 0;
        rrToWire(dNSOutput, null, false);
        byte[] byteArray = dNSOutput.toByteArray();
        if (this.alg == 1) {
            i2 = byteArray[byteArray.length - 2] & 255;
            i = (byteArray[byteArray.length - 3] & 255) << 8;
        } else {
            i = 0;
            while (i4 < byteArray.length - 1) {
                i += ((byteArray[i4] & 255) << 8) + (byteArray[i4 + 1] & 255);
                i4 += 2;
            }
            if (i4 < byteArray.length) {
                i += (byteArray[i4] & 255) << 8;
            }
            i2 = (i >> 16) & FastLz.MAX_CHUNK_LENGTH;
        }
        int i5 = (i + i2) & FastLz.MAX_CHUNK_LENGTH;
        this.footprint = i5;
        return i5;
    }

    public byte[] getKey() {
        return this.key;
    }

    public int getProtocol() {
        return this.proto;
    }

    public PublicKey getPublicKey() {
        PublicKey publicKey2;
        PublicKey publicKey3 = this.publicKey;
        if (publicKey3 != null) {
            return publicKey3;
        }
        DNSSEC.ECKeyInfo eCKeyInfo = DNSSEC.GOST;
        int algorithm = getAlgorithm();
        switch (algorithm) {
            case 1:
            case 5:
            case 7:
            case 8:
            case 10:
                publicKey2 = DNSSEC.toRSAPublicKey(this);
                break;
            case 2:
            case 4:
            case 9:
            case 11:
            default:
                try {
                    throw new DNSSEC.UnsupportedAlgorithmException(algorithm);
                } catch (IOException unused) {
                    throw new DNSSEC.MalformedKeyException(this);
                } catch (GeneralSecurityException e) {
                    throw new DNSSEC.DNSSECException(e.toString());
                }
            case 3:
            case 6:
                publicKey2 = DNSSEC.toDSAPublicKey(this);
                break;
            case 12:
                publicKey2 = DNSSEC.toECGOSTPublicKey(this, DNSSEC.GOST);
                break;
            case 13:
                publicKey2 = DNSSEC.toECDSAPublicKey(this, DNSSEC.ECDSA_P256);
                break;
            case 14:
                publicKey2 = DNSSEC.toECDSAPublicKey(this, DNSSEC.ECDSA_P384);
                break;
        }
        this.publicKey = publicKey2;
        return publicKey2;
    }

    @Override // org.xbill.DNS.Record
    public void rrFromWire(DNSInput dNSInput) {
        this.flags = dNSInput.readU16();
        this.proto = dNSInput.readU8();
        this.alg = dNSInput.readU8();
        if (dNSInput.remaining() > 0) {
            this.key = dNSInput.readByteArray();
        }
    }

    @Override // org.xbill.DNS.Record
    public String rrToString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.flags);
        stringBuffer.append(" ");
        stringBuffer.append(this.proto);
        stringBuffer.append(" ");
        stringBuffer.append(this.alg);
        if (this.key != null) {
            if (Options.check("multiline")) {
                stringBuffer.append(" (\n");
                stringBuffer.append(SystemPropsKt.formatString(this.key, 64, "\t", true));
                stringBuffer.append(" ; key_tag = ");
                stringBuffer.append(getFootprint());
            } else {
                stringBuffer.append(" ");
                stringBuffer.append(SystemPropsKt.toString1(this.key));
            }
        }
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        dNSOutput.writeU16(this.flags);
        dNSOutput.writeU8(this.proto);
        dNSOutput.writeU8(this.alg);
        byte[] bArr = this.key;
        if (bArr != null) {
            dNSOutput.writeByteArray(bArr);
        }
    }

    public KEYBase(Name name, int i, int i2, long j, int i3, int i4, int i5, byte[] bArr) {
        super(name, i, i2, j);
        this.flags = Record.checkU16(VpnProfileDataSource.KEY_FLAGS, i3);
        this.proto = Record.checkU8("proto", i4);
        this.alg = Record.checkU8("alg", i5);
        this.key = bArr;
    }
}
