package org.xbill.DNS;

import io.netty.handler.codec.compression.FastLz;
import java.security.PublicKey;
import java.util.StringTokenizer;
import org.xbill.DNS.DNSSEC;

public class KEYRecord extends KEYBase {
    public static final int FLAG_NOAUTH = 32768;
    public static final int FLAG_NOCONF = 16384;
    public static final int FLAG_NOKEY = 49152;
    public static final int OWNER_HOST = 512;
    public static final int OWNER_USER = 0;
    public static final int OWNER_ZONE = 256;
    public static final int PROTOCOL_ANY = 255;
    public static final int PROTOCOL_DNSSEC = 3;
    public static final int PROTOCOL_EMAIL = 2;
    public static final int PROTOCOL_IPSEC = 4;
    public static final int PROTOCOL_TLS = 1;
    private static final long serialVersionUID = 6385613447571488906L;

    public abstract class Flags {
        public static Mnemonic flags;

        static {
            Mnemonic mnemonic = new Mnemonic("KEY flags", 2);
            flags = mnemonic;
            mnemonic.max = FastLz.MAX_CHUNK_LENGTH;
            mnemonic.numericok = false;
            mnemonic.add(16384, "NOCONF");
            flags.add(32768, "NOAUTH");
            flags.add(KEYRecord.FLAG_NOKEY, "NOKEY");
            flags.add(8192, "FLAG2");
            flags.add(4096, "EXTEND");
            flags.add(2048, "FLAG4");
            flags.add(1024, "FLAG5");
            flags.add(0, "USER");
            flags.add(256, "ZONE");
            flags.add(512, "HOST");
            flags.add(768, "NTYP3");
            flags.add(128, "FLAG8");
            flags.add(64, "FLAG9");
            flags.add(32, "FLAG10");
            flags.add(16, "FLAG11");
            flags.add(0, "SIG0");
            flags.add(1, "SIG1");
            flags.add(2, "SIG2");
            flags.add(3, "SIG3");
            flags.add(4, "SIG4");
            flags.add(5, "SIG5");
            flags.add(6, "SIG6");
            flags.add(7, "SIG7");
            flags.add(8, "SIG8");
            flags.add(9, "SIG9");
            flags.add(10, "SIG10");
            flags.add(11, "SIG11");
            flags.add(12, "SIG12");
            flags.add(13, "SIG13");
            flags.add(14, "SIG14");
            flags.add(15, "SIG15");
        }
    }

    public abstract class Protocol {
        public static Mnemonic protocols;

        static {
            Mnemonic mnemonic = new Mnemonic("KEY protocol", 2);
            protocols = mnemonic;
            mnemonic.max = KEYRecord.PROTOCOL_ANY;
            mnemonic.numericok = true;
            mnemonic.add(0, "NONE");
            protocols.add(1, "TLS");
            protocols.add(2, "EMAIL");
            protocols.add(3, "DNSSEC");
            protocols.add(4, "IPSEC");
            protocols.add(KEYRecord.PROTOCOL_ANY, "ANY");
        }
    }

    public KEYRecord() {
    }

    @Override // org.xbill.DNS.Record
    public Record getObject() {
        return new KEYRecord();
    }

    @Override // org.xbill.DNS.Record
    public void rdataFromString(Tokenizer tokenizer, Name name) {
        String identifier = tokenizer.getIdentifier();
        Mnemonic mnemonic = Flags.flags;
        int i = -1;
        try {
            int parseInt = Integer.parseInt(identifier);
            if (parseInt >= 0 && parseInt <= 65535) {
                i = parseInt;
            }
        } catch (NumberFormatException unused) {
            StringTokenizer stringTokenizer = new StringTokenizer(identifier, "|");
            int i2 = 0;
            while (true) {
                if (!stringTokenizer.hasMoreTokens()) {
                    i = i2;
                    break;
                }
                int value = Flags.flags.getValue(stringTokenizer.nextToken());
                if (value < 0) {
                    break;
                }
                i2 |= value;
            }
        }
        this.flags = i;
        if (i >= 0) {
            String identifier2 = tokenizer.getIdentifier();
            int value2 = Protocol.protocols.getValue(identifier2);
            this.proto = value2;
            if (value2 >= 0) {
                String identifier3 = tokenizer.getIdentifier();
                int value3 = DNSSEC.Algorithm.value(identifier3);
                this.alg = value3;
                if (value3 < 0) {
                    StringBuffer stringBuffer = new StringBuffer();
                    stringBuffer.append("Invalid algorithm: ");
                    stringBuffer.append(identifier3);
                    throw tokenizer.exception(stringBuffer.toString());
                } else if ((this.flags & FLAG_NOKEY) == 49152) {
                    this.key = null;
                } else {
                    this.key = tokenizer.getBase64();
                }
            } else {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("Invalid protocol: ");
                stringBuffer2.append(identifier2);
                throw tokenizer.exception(stringBuffer2.toString());
            }
        } else {
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("Invalid flags: ");
            stringBuffer3.append(identifier);
            throw tokenizer.exception(stringBuffer3.toString());
        }
    }

    public KEYRecord(Name name, int i, long j, int i2, int i3, int i4, byte[] bArr) {
        super(name, 25, i, j, i2, i3, i4, bArr);
    }

    public KEYRecord(Name name, int i, long j, int i2, int i3, int i4, PublicKey publicKey) {
        super(name, 25, i, j, i2, i3, i4, DNSSEC.fromPublicKey(publicKey, i4));
        this.publicKey = publicKey;
    }
}
