package org.xbill.DNS;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import org.xbill.DNS.Tokenizer;

public class LOCRecord extends Record {
    private static final long serialVersionUID = 9058224788126750409L;
    public static NumberFormat w2;
    public static NumberFormat w3;
    private long altitude;
    private long hPrecision;
    private long latitude;
    private long longitude;
    private long size;
    private long vPrecision;

    static {
        DecimalFormat decimalFormat = new DecimalFormat();
        w2 = decimalFormat;
        decimalFormat.setMinimumIntegerDigits(2);
        DecimalFormat decimalFormat2 = new DecimalFormat();
        w3 = decimalFormat2;
        decimalFormat2.setMinimumIntegerDigits(3);
    }

    public LOCRecord() {
    }

    public static long parseLOCformat(int i) {
        long j = (long) (i >> 4);
        int i2 = i & 15;
        if (j > 9 || i2 > 9) {
            throw new WireParseException("Invalid LOC Encoding");
        }
        while (true) {
            int i3 = i2 - 1;
            if (i2 <= 0) {
                return j;
            }
            j *= 10;
            i2 = i3;
        }
    }

    public double getAltitude() {
        return ((double) (this.altitude - 10000000)) / 100.0d;
    }

    public double getHPrecision() {
        return ((double) this.hPrecision) / 100.0d;
    }

    public double getLatitude() {
        return ((double) (this.latitude - 2147483648L)) / 3600000.0d;
    }

    public double getLongitude() {
        return ((double) (this.longitude - 2147483648L)) / 3600000.0d;
    }

    @Override // org.xbill.DNS.Record
    public Record getObject() {
        return new LOCRecord();
    }

    public double getSize() {
        return ((double) this.size) / 100.0d;
    }

    public double getVPrecision() {
        return ((double) this.vPrecision) / 100.0d;
    }

    public final long parseDouble(Tokenizer tokenizer, String str, boolean z, long j, long j2, long j3) {
        Tokenizer.Token token = tokenizer.get();
        int i = token.type;
        if (!(i == 1 || i == 0)) {
            String str2 = token.value;
            if (str2.length() > 1 && str2.charAt(str2.length() - 1) == 'm') {
                str2 = str2.substring(0, str2.length() - 1);
            }
            try {
                long parseFixedPoint = (long) (parseFixedPoint(str2) * 100.0d);
                if (parseFixedPoint >= j && parseFixedPoint <= j2) {
                    return parseFixedPoint;
                }
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Invalid LOC ");
                stringBuffer.append(str);
                throw tokenizer.exception(stringBuffer.toString());
            } catch (NumberFormatException unused) {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("Invalid LOC ");
                stringBuffer2.append(str);
                throw tokenizer.exception(stringBuffer2.toString());
            }
        } else if (!z) {
            tokenizer.unget();
            return j3;
        } else {
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append("Invalid LOC ");
            stringBuffer3.append(str);
            throw tokenizer.exception(stringBuffer3.toString());
        }
    }

    public final double parseFixedPoint(String str) {
        if (str.matches("^-?\\d+$")) {
            return (double) Integer.parseInt(str);
        }
        if (str.matches("^-?\\d+\\.\\d*$")) {
            String[] split = str.split("\\.");
            double parseInt = (double) Integer.parseInt(split[0]);
            double parseInt2 = (double) Integer.parseInt(split[1]);
            if (parseInt < 0.0d) {
                parseInt2 *= -1.0d;
            }
            return (parseInt2 / Math.pow(10.0d, (double) split[1].length())) + parseInt;
        }
        throw new NumberFormatException();
    }

    /* JADX WARNING: Removed duplicated region for block: B:36:0x0087  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00d9  */
    public final long parsePosition(Tokenizer tokenizer, String str) {
        double d;
        int i;
        boolean equals = str.equals("latitude");
        int uInt16 = tokenizer.getUInt16();
        if (uInt16 > 180 || (uInt16 > 90 && equals)) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Invalid LOC ");
            stringBuffer.append(str);
            stringBuffer.append(" degrees");
            throw tokenizer.exception(stringBuffer.toString());
        }
        String string = tokenizer.getString();
        double d2 = 0.0d;
        try {
            i = Integer.parseInt(string);
            if (i < 0 || i > 59) {
                StringBuffer stringBuffer2 = new StringBuffer();
                stringBuffer2.append("Invalid LOC ");
                stringBuffer2.append(str);
                stringBuffer2.append(" minutes");
                throw tokenizer.exception(stringBuffer2.toString());
            }
            try {
                string = tokenizer.getString();
            } catch (NumberFormatException unused) {
                d = d2;
                if (string.length() == 1) {
                }
            }
            try {
                d = parseFixedPoint(string);
                if (d < 0.0d || d >= 60.0d) {
                    StringBuffer stringBuffer3 = new StringBuffer();
                    stringBuffer3.append("Invalid LOC ");
                    stringBuffer3.append(str);
                    stringBuffer3.append(" seconds");
                    throw tokenizer.exception(stringBuffer3.toString());
                }
                try {
                    string = tokenizer.getString();
                } catch (NumberFormatException unused2) {
                    d2 = d;
                    d = d2;
                    if (string.length() == 1) {
                    }
                }
                if (string.length() == 1) {
                    long j = (long) ((d + ((double) (((((long) uInt16) * 60) + ((long) i)) * 60))) * 1000.0d);
                    char upperCase = Character.toUpperCase(string.charAt(0));
                    if ((equals && upperCase == 'S') || (!equals && upperCase == 'W')) {
                        j = -j;
                    } else if ((equals && upperCase != 'N') || (!equals && upperCase != 'E')) {
                        StringBuffer stringBuffer4 = new StringBuffer();
                        stringBuffer4.append("Invalid LOC ");
                        stringBuffer4.append(str);
                        throw tokenizer.exception(stringBuffer4.toString());
                    }
                    return j + 2147483648L;
                }
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append("Invalid LOC ");
                stringBuffer5.append(str);
                throw tokenizer.exception(stringBuffer5.toString());
            } catch (NumberFormatException unused3) {
                d = d2;
                if (string.length() == 1) {
                }
            }
        } catch (NumberFormatException unused4) {
            i = 0;
            d = d2;
            if (string.length() == 1) {
            }
        }
    }

    public final String positionToString(long j, char c, char c2) {
        StringBuffer stringBuffer = new StringBuffer();
        long j2 = j - 2147483648L;
        if (j2 < 0) {
            j2 = -j2;
            c = c2;
        }
        stringBuffer.append(j2 / 3600000);
        long j3 = j2 % 3600000;
        stringBuffer.append(" ");
        stringBuffer.append(j3 / 60000);
        stringBuffer.append(" ");
        renderFixedPoint(stringBuffer, w3, j3 % 60000, 1000);
        stringBuffer.append(" ");
        stringBuffer.append(c);
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rdataFromString(Tokenizer tokenizer, Name name) {
        this.latitude = parsePosition(tokenizer, "latitude");
        this.longitude = parsePosition(tokenizer, "longitude");
        this.altitude = parseDouble(tokenizer, "altitude", true, -10000000, 4284967295L, 0) + 10000000;
        this.size = parseDouble(tokenizer, "size", false, 0, 9000000000L, 100);
        this.hPrecision = parseDouble(tokenizer, "horizontal precision", false, 0, 9000000000L, 1000000);
        this.vPrecision = parseDouble(tokenizer, "vertical precision", false, 0, 9000000000L, 1000);
    }

    public final void renderFixedPoint(StringBuffer stringBuffer, NumberFormat numberFormat, long j, long j2) {
        stringBuffer.append(j / j2);
        long j3 = j % j2;
        if (j3 != 0) {
            stringBuffer.append(".");
            stringBuffer.append(numberFormat.format(j3));
        }
    }

    @Override // org.xbill.DNS.Record
    public void rrFromWire(DNSInput dNSInput) {
        if (dNSInput.readU8() == 0) {
            this.size = parseLOCformat(dNSInput.readU8());
            this.hPrecision = parseLOCformat(dNSInput.readU8());
            this.vPrecision = parseLOCformat(dNSInput.readU8());
            this.latitude = dNSInput.readU32();
            this.longitude = dNSInput.readU32();
            this.altitude = dNSInput.readU32();
            return;
        }
        throw new WireParseException("Invalid LOC version");
    }

    @Override // org.xbill.DNS.Record
    public String rrToString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(positionToString(this.latitude, 'N', 'S'));
        stringBuffer.append(" ");
        stringBuffer.append(positionToString(this.longitude, 'E', 'W'));
        stringBuffer.append(" ");
        renderFixedPoint(stringBuffer, w2, this.altitude - 10000000, 100);
        stringBuffer.append("m ");
        renderFixedPoint(stringBuffer, w2, this.size, 100);
        stringBuffer.append("m ");
        renderFixedPoint(stringBuffer, w2, this.hPrecision, 100);
        stringBuffer.append("m ");
        renderFixedPoint(stringBuffer, w2, this.vPrecision, 100);
        stringBuffer.append("m");
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        dNSOutput.writeU8(0);
        dNSOutput.writeU8(toLOCformat(this.size));
        dNSOutput.writeU8(toLOCformat(this.hPrecision));
        dNSOutput.writeU8(toLOCformat(this.vPrecision));
        dNSOutput.writeU32(this.latitude);
        dNSOutput.writeU32(this.longitude);
        dNSOutput.writeU32(this.altitude);
    }

    public final int toLOCformat(long j) {
        byte b = 0;
        while (j > 9) {
            b = (byte) (b + 1);
            j /= 10;
        }
        return (int) ((j << 4) + ((long) b));
    }

    public LOCRecord(Name name, int i, long j, double d, double d2, double d3, double d4, double d5, double d6) {
        super(name, 29, i, j);
        this.latitude = (long) ((d * 3600.0d * 1000.0d) + 2.147483648E9d);
        this.longitude = (long) ((3600.0d * d2 * 1000.0d) + 2.147483648E9d);
        this.altitude = (long) ((d3 + 100000.0d) * 100.0d);
        this.size = (long) (d4 * 100.0d);
        this.hPrecision = (long) (d5 * 100.0d);
        this.vPrecision = (long) (d6 * 100.0d);
    }
}
