package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

public class Message implements Cloneable {
    public static RRset[] emptyRRsetArray = new RRset[0];
    public static Record[] emptyRecordArray = new Record[0];
    public Header header;
    public List[] sections;
    public int size;
    public int tsigstart;

    public Message(int i) {
        Header header2 = new Header(i);
        this.sections = new List[4];
        this.header = header2;
    }

    public void addRecord(Record record, int i) {
        List[] listArr = this.sections;
        if (listArr[i] == null) {
            listArr[i] = new LinkedList();
        }
        this.header.incCount(i);
        this.sections[i].add(record);
    }

    @Override // java.lang.Object
    public Object clone() {
        Message message = new Message();
        int i = 0;
        while (true) {
            List[] listArr = this.sections;
            if (i < listArr.length) {
                if (listArr[i] != null) {
                    message.sections[i] = new LinkedList(this.sections[i]);
                }
                i++;
            } else {
                message.header = (Header) this.header.clone();
                message.size = this.size;
                return message;
            }
        }
    }

    public OPTRecord getOPT() {
        Record[] sectionArray = getSectionArray(3);
        for (int i = 0; i < sectionArray.length; i++) {
            if (sectionArray[i] instanceof OPTRecord) {
                return (OPTRecord) sectionArray[i];
            }
        }
        return null;
    }

    public Record getQuestion() {
        List list = this.sections[0];
        if (list == null || list.size() == 0) {
            return null;
        }
        return (Record) list.get(0);
    }

    public int getRcode() {
        int i = this.header.flags & 15;
        OPTRecord opt = getOPT();
        return opt != null ? i + (opt.getExtendedRcode() << 4) : i;
    }

    public Record[] getSectionArray(int i) {
        List[] listArr = this.sections;
        if (listArr[i] == null) {
            return emptyRecordArray;
        }
        List list = listArr[i];
        return (Record[]) list.toArray(new Record[list.size()]);
    }

    public String toString() {
        String str;
        StringBuffer stringBuffer = new StringBuffer();
        if (getOPT() != null) {
            StringBuffer stringBuffer2 = new StringBuffer();
            stringBuffer2.append(this.header.toStringWithRcode(getRcode()));
            stringBuffer2.append("\n");
            stringBuffer.append(stringBuffer2.toString());
        } else {
            StringBuffer stringBuffer3 = new StringBuffer();
            stringBuffer3.append(this.header);
            stringBuffer3.append("\n");
            stringBuffer.append(stringBuffer3.toString());
        }
        for (int i = 0; i < 4; i++) {
            if (this.header.getOpcode() != 5) {
                StringBuffer outline24 = GeneratedOutlineSupport.outline24(";; ");
                Section.sections.check(i);
                outline24.append(Section.longSections[i]);
                outline24.append(":\n");
                stringBuffer.append(outline24.toString());
            } else {
                StringBuffer outline242 = GeneratedOutlineSupport.outline24(";; ");
                Section.sections.check(i);
                outline242.append(Section.updateSections[i]);
                outline242.append(":\n");
                stringBuffer.append(outline242.toString());
            }
            StringBuffer stringBuffer4 = new StringBuffer();
            if (i > 3) {
                str = null;
            } else {
                StringBuffer stringBuffer5 = new StringBuffer();
                Record[] sectionArray = getSectionArray(i);
                for (Record record : sectionArray) {
                    if (i == 0) {
                        StringBuffer outline243 = GeneratedOutlineSupport.outline24(";;\t");
                        outline243.append(record.name);
                        stringBuffer5.append(outline243.toString());
                        StringBuffer stringBuffer6 = new StringBuffer();
                        stringBuffer6.append(", type = ");
                        stringBuffer6.append(Type.string(record.type));
                        stringBuffer5.append(stringBuffer6.toString());
                        StringBuffer stringBuffer7 = new StringBuffer();
                        stringBuffer7.append(", class = ");
                        stringBuffer7.append(DClass.string(record.dclass));
                        stringBuffer5.append(stringBuffer7.toString());
                    } else {
                        stringBuffer5.append(record);
                    }
                    stringBuffer5.append("\n");
                }
                str = stringBuffer5.toString();
            }
            stringBuffer4.append(str);
            stringBuffer4.append("\n");
            stringBuffer.append(stringBuffer4.toString());
        }
        StringBuffer outline244 = GeneratedOutlineSupport.outline24(";; Message size: ");
        outline244.append(this.size);
        outline244.append(" bytes");
        stringBuffer.append(outline244.toString());
        return stringBuffer.toString();
    }

    public byte[] toWire() {
        DNSOutput dNSOutput = new DNSOutput();
        this.header.toWire(dNSOutput);
        Compression compression = new Compression();
        for (int i = 0; i < 4; i++) {
            if (this.sections[i] != null) {
                for (int i2 = 0; i2 < this.sections[i].size(); i2++) {
                    ((Record) this.sections[i].get(i2)).toWire(dNSOutput, i, compression);
                }
            }
        }
        this.size = dNSOutput.pos;
        return dNSOutput.toByteArray();
    }

    public Message() {
        Header header2 = new Header();
        this.sections = new List[4];
        this.header = header2;
    }

    public Message(DNSInput dNSInput) {
        Header header2 = new Header(dNSInput.readU16());
        header2.flags = dNSInput.readU16();
        int i = 0;
        while (true) {
            int[] iArr = header2.counts;
            if (i >= iArr.length) {
                break;
            }
            iArr[i] = dNSInput.readU16();
            i++;
        }
        this.sections = new List[4];
        this.header = header2;
        boolean z = header2.getOpcode() == 5;
        boolean flag = this.header.getFlag(6);
        for (int i2 = 0; i2 < 4; i2++) {
            try {
                int i3 = this.header.counts[i2];
                if (i3 > 0) {
                    this.sections[i2] = new ArrayList(i3);
                }
                for (int i4 = 0; i4 < i3; i4++) {
                    int current = dNSInput.current();
                    Record fromWire = Record.fromWire(dNSInput, i2, z);
                    this.sections[i2].add(fromWire);
                    if (i2 == 3) {
                        if (fromWire.getType() == 250) {
                            this.tsigstart = current;
                        }
                        if (fromWire.getType() == 24) {
                            ((SIGRecord) fromWire).getTypeCovered();
                        }
                    }
                }
            } catch (WireParseException e) {
                if (!flag) {
                    throw e;
                }
            }
        }
        this.size = dNSInput.current();
    }
}
