package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.PrintStream;
import java.io.Serializable;
import java.nio.ByteBuffer;
import java.text.DecimalFormat;
import java.util.Objects;
import org.xbill.DNS.Compression;

public class Name implements Comparable, Serializable {
    public static final DecimalFormat byteFormat;
    public static final Name empty;
    public static final byte[] emptyLabel = {0};
    public static final byte[] lowercase = new byte[256];
    public static final Name root;
    private static final long serialVersionUID = -7257019940971525644L;
    public static final Name wild;
    public static final byte[] wildLabel = {1, 42};
    private int hashcode;
    private byte[] name;
    private long offsets;

    static {
        DecimalFormat decimalFormat = new DecimalFormat();
        byteFormat = decimalFormat;
        decimalFormat.setMinimumIntegerDigits(3);
        int i = 0;
        while (true) {
            byte[] bArr = lowercase;
            if (i >= bArr.length) {
                break;
            }
            if (i < 65 || i > 90) {
                bArr[i] = (byte) i;
            } else {
                bArr[i] = (byte) ((i - 65) + 97);
            }
            i++;
        }
        Name name2 = new Name();
        root = name2;
        byte[] bArr2 = emptyLabel;
        Objects.requireNonNull(name2);
        try {
            name2.append(bArr2, 0, 1);
        } catch (NameTooLongException unused) {
        }
        Name name3 = new Name();
        empty = name3;
        name3.name = new byte[0];
        Name name4 = new Name();
        wild = name4;
        byte[] bArr3 = wildLabel;
        Objects.requireNonNull(name4);
        try {
            name4.append(bArr3, 0, 1);
        } catch (NameTooLongException unused2) {
        }
    }

    public Name() {
    }

    public static Name concatenate(Name name2, Name name3) {
        if (name2.isAbsolute()) {
            return name2;
        }
        Name name4 = new Name();
        copy(name2, name4);
        name4.append(name3.name, name3.offset(0), name3.getlabels());
        return name4;
    }

    public static final void copy(Name name2, Name name3) {
        int i = 0;
        if (name2.offset(0) == 0) {
            name3.name = name2.name;
            name3.offsets = name2.offsets;
            return;
        }
        int offset = name2.offset(0);
        int length = name2.name.length - offset;
        int labels = name2.labels();
        byte[] bArr = new byte[length];
        name3.name = bArr;
        System.arraycopy(name2.name, offset, bArr, 0, length);
        while (i < labels && i < 7) {
            name3.setoffset(i, name2.offset(i) - offset);
            i++;
        }
        name3.setlabels(labels);
    }

    public static Name fromConstantString(String str) {
        try {
            return fromString(str, null);
        } catch (TextParseException unused) {
            StringBuffer stringBuffer = new StringBuffer();
            stringBuffer.append("Invalid name '");
            stringBuffer.append(str);
            stringBuffer.append("'");
            throw new IllegalArgumentException(stringBuffer.toString());
        }
    }

    public static Name fromString(String str, Name name2) {
        if (str.equals("@") && name2 != null) {
            return name2;
        }
        if (str.equals(".")) {
            return root;
        }
        return new Name(str, name2);
    }

    public static TextParseException parseException(String str, String str2) {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("'");
        stringBuffer.append(str);
        stringBuffer.append("': ");
        stringBuffer.append(str2);
        return new TextParseException(stringBuffer.toString());
    }

    public final void append(byte[] bArr, int i, int i2) {
        byte[] bArr2 = this.name;
        int length = bArr2 == null ? 0 : bArr2.length - offset(0);
        int i3 = i;
        int i4 = 0;
        for (int i5 = 0; i5 < i2; i5++) {
            byte b = bArr[i3];
            if (b <= 63) {
                int i6 = b + 1;
                i3 += i6;
                i4 += i6;
            } else {
                throw new IllegalStateException("invalid label");
            }
        }
        int i7 = length + i4;
        if (i7 <= 255) {
            int i8 = getlabels();
            int i9 = i8 + i2;
            if (i9 <= 128) {
                byte[] bArr3 = new byte[i7];
                if (length != 0) {
                    System.arraycopy(this.name, offset(0), bArr3, 0, length);
                }
                System.arraycopy(bArr, i, bArr3, length, i4);
                this.name = bArr3;
                for (int i10 = 0; i10 < i2; i10++) {
                    setoffset(i8 + i10, length);
                    length += bArr3[length] + 1;
                }
                setlabels(i9);
                return;
            }
            throw new IllegalStateException("too many labels");
        }
        throw new NameTooLongException();
    }

    public final void appendFromString(String str, byte[] bArr, int i, int i2) {
        try {
            append(bArr, i, i2);
        } catch (NameTooLongException unused) {
            throw parseException(str, "Name too long");
        }
    }

    public final String byteString(byte[] bArr, int i) {
        StringBuffer stringBuffer = new StringBuffer();
        int i2 = i + 1;
        byte b = bArr[i];
        for (int i3 = i2; i3 < i2 + b; i3++) {
            int i4 = bArr[i3] & 255;
            if (i4 <= 32 || i4 >= 127) {
                stringBuffer.append('\\');
                stringBuffer.append(byteFormat.format((long) i4));
            } else if (i4 == 34 || i4 == 40 || i4 == 41 || i4 == 46 || i4 == 59 || i4 == 92 || i4 == 64 || i4 == 36) {
                stringBuffer.append('\\');
                stringBuffer.append((char) i4);
            } else {
                stringBuffer.append((char) i4);
            }
        }
        return stringBuffer.toString();
    }

    public Name canonicalize() {
        byte[] bArr;
        boolean z;
        int i = 0;
        int i2 = 0;
        while (true) {
            bArr = this.name;
            if (i2 >= bArr.length) {
                z = true;
                break;
            } else if (lowercase[bArr[i2] & 255] != bArr[i2]) {
                z = false;
                break;
            } else {
                i2++;
            }
        }
        if (z) {
            return this;
        }
        Name name2 = new Name();
        try {
            name2.append(bArr, offset(0), getlabels());
        } catch (NameTooLongException unused) {
        }
        while (true) {
            byte[] bArr2 = name2.name;
            if (i >= bArr2.length) {
                return name2;
            }
            bArr2[i] = lowercase[bArr2[i] & 255];
            i++;
        }
    }

    @Override // java.lang.Comparable
    public int compareTo(Object obj) {
        Name name2 = (Name) obj;
        if (this == name2) {
            return 0;
        }
        int labels = labels();
        int labels2 = name2.labels();
        int i = labels > labels2 ? labels2 : labels;
        for (int i2 = 1; i2 <= i; i2++) {
            int offset = offset(labels - i2);
            int offset2 = name2.offset(labels2 - i2);
            byte b = this.name[offset];
            byte b2 = name2.name[offset2];
            int i3 = 0;
            while (i3 < b && i3 < b2) {
                byte[] bArr = lowercase;
                int i4 = bArr[this.name[(i3 + offset) + 1] & 255] - bArr[name2.name[(i3 + offset2) + 1] & 255];
                if (i4 != 0) {
                    return i4;
                }
                i3++;
            }
            if (b != b2) {
                return b - b2;
            }
        }
        return labels - labels2;
    }

    public final boolean equals(byte[] bArr, int i) {
        int labels = labels();
        int offset = offset(0);
        int i2 = 0;
        while (i2 < labels) {
            byte[] bArr2 = this.name;
            if (bArr2[offset] != bArr[i]) {
                return false;
            }
            int i3 = offset + 1;
            byte b = bArr2[offset];
            i++;
            if (b <= 63) {
                int i4 = 0;
                while (i4 < b) {
                    byte[] bArr3 = lowercase;
                    int i5 = i3 + 1;
                    int i6 = i + 1;
                    if (bArr3[this.name[i3] & 255] != bArr3[bArr[i] & 255]) {
                        return false;
                    }
                    i4++;
                    i = i6;
                    i3 = i5;
                }
                i2++;
                offset = i3;
            } else {
                throw new IllegalStateException("invalid label");
            }
        }
        return true;
    }

    public Name fromDNAME(DNAMERecord dNAMERecord) {
        Name name2 = dNAMERecord.getName();
        Name target = dNAMERecord.getTarget();
        if (!subdomain(name2)) {
            return null;
        }
        int labels = labels() - name2.labels();
        int length = length() - name2.length();
        int i = 0;
        int offset = offset(0);
        int labels2 = target.labels();
        short length2 = target.length();
        int i2 = length + length2;
        if (i2 <= 255) {
            Name name3 = new Name();
            int i3 = labels + labels2;
            name3.setlabels(i3);
            byte[] bArr = new byte[i2];
            name3.name = bArr;
            System.arraycopy(this.name, offset, bArr, 0, length);
            System.arraycopy(target.name, 0, name3.name, length, length2);
            int i4 = 0;
            while (i < 7 && i < i3) {
                name3.setoffset(i, i4);
                i4 += name3.name[i4] + 1;
                i++;
            }
            return name3;
        }
        throw new NameTooLongException();
    }

    public byte[] getLabel(int i) {
        int offset = offset(i);
        byte[] bArr = this.name;
        int i2 = (byte) (bArr[offset] + 1);
        byte[] bArr2 = new byte[i2];
        System.arraycopy(bArr, offset, bArr2, 0, i2);
        return bArr2;
    }

    public String getLabelString(int i) {
        return byteString(this.name, offset(i));
    }

    public final int getlabels() {
        return (int) (this.offsets & 255);
    }

    public int hashCode() {
        int i = this.hashcode;
        if (i != 0) {
            return i;
        }
        int i2 = 0;
        int offset = offset(0);
        while (true) {
            byte[] bArr = this.name;
            if (offset < bArr.length) {
                i2 += (i2 << 3) + lowercase[bArr[offset] & 255];
                offset++;
            } else {
                this.hashcode = i2;
                return i2;
            }
        }
    }

    public boolean isAbsolute() {
        int labels = labels();
        if (labels != 0 && this.name[offset(labels - 1)] == 0) {
            return true;
        }
        return false;
    }

    public boolean isWild() {
        if (labels() == 0) {
            return false;
        }
        byte[] bArr = this.name;
        if (bArr[0] == 1 && bArr[1] == 42) {
            return true;
        }
        return false;
    }

    public int labels() {
        return getlabels();
    }

    public short length() {
        if (getlabels() == 0) {
            return 0;
        }
        return (short) (this.name.length - offset(0));
    }

    public final int offset(int i) {
        if (i == 0 && getlabels() == 0) {
            return 0;
        }
        if (i < 0 || i >= getlabels()) {
            throw new IllegalArgumentException("label out of range");
        } else if (i < 7) {
            return ((int) (this.offsets >>> ((7 - i) * 8))) & KEYRecord.PROTOCOL_ANY;
        } else {
            int offset = offset(6);
            for (int i2 = 6; i2 < i; i2++) {
                offset += this.name[offset] + 1;
            }
            return offset;
        }
    }

    public Name relativize(Name name2) {
        if (name2 == null || !subdomain(name2)) {
            return this;
        }
        Name name3 = new Name();
        copy(this, name3);
        int length = length() - name2.length();
        name3.setlabels(name3.labels() - name2.labels());
        name3.name = new byte[length];
        System.arraycopy(this.name, offset(0), name3.name, 0, length);
        return name3;
    }

    public final void setlabels(int i) {
        long j = this.offsets & -256;
        this.offsets = j;
        this.offsets = j | ((long) i);
    }

    public final void setoffset(int i, int i2) {
        if (i < 7) {
            int i3 = (7 - i) * 8;
            long j = this.offsets & (~(255 << i3));
            this.offsets = j;
            this.offsets = (((long) i2) << i3) | j;
        }
    }

    public boolean subdomain(Name name2) {
        int labels = labels();
        int labels2 = name2.labels();
        if (labels2 > labels) {
            return false;
        }
        if (labels2 == labels) {
            return equals(name2);
        }
        return name2.equals(this.name, offset(labels - labels2));
    }

    public String toString(boolean z) {
        int labels = labels();
        if (labels == 0) {
            return "@";
        }
        int i = 0;
        if (labels == 1 && this.name[offset(0)] == 0) {
            return ".";
        }
        StringBuffer stringBuffer = new StringBuffer();
        int offset = offset(0);
        while (true) {
            if (i >= labels) {
                break;
            }
            byte b = this.name[offset];
            if (b > 63) {
                throw new IllegalStateException("invalid label");
            } else if (b != 0) {
                if (i > 0) {
                    stringBuffer.append('.');
                }
                stringBuffer.append(byteString(this.name, offset));
                offset += b + 1;
                i++;
            } else if (!z) {
                stringBuffer.append('.');
            }
        }
        return stringBuffer.toString();
    }

    public void toWire(DNSOutput dNSOutput, Compression compression) {
        Name name2;
        int i;
        if (isAbsolute()) {
            int labels = labels();
            for (int i2 = 0; i2 < labels - 1; i2++) {
                if (i2 == 0) {
                    name2 = this;
                } else {
                    name2 = new Name(this, i2);
                }
                int i3 = -1;
                if (compression != null) {
                    for (Compression.Entry entry = compression.table[(name2.hashCode() & Integer.MAX_VALUE) % 17]; entry != null; entry = entry.next) {
                        if (entry.name.equals(name2)) {
                            i3 = entry.pos;
                        }
                    }
                    if (compression.verbose) {
                        PrintStream printStream = System.err;
                        StringBuffer stringBuffer = new StringBuffer();
                        stringBuffer.append("Looking for ");
                        stringBuffer.append(name2);
                        stringBuffer.append(", found ");
                        stringBuffer.append(i3);
                        printStream.println(stringBuffer.toString());
                    }
                }
                if (i3 >= 0) {
                    dNSOutput.writeU16(49152 | i3);
                    return;
                }
                if (compression != null && (i = dNSOutput.pos) <= 16383) {
                    int hashCode = (Integer.MAX_VALUE & name2.hashCode()) % 17;
                    Compression.Entry entry2 = new Compression.Entry(null);
                    entry2.name = name2;
                    entry2.pos = i;
                    Compression.Entry[] entryArr = compression.table;
                    entry2.next = entryArr[hashCode];
                    entryArr[hashCode] = entry2;
                    if (compression.verbose) {
                        PrintStream printStream2 = System.err;
                        StringBuffer stringBuffer2 = new StringBuffer();
                        stringBuffer2.append("Adding ");
                        stringBuffer2.append(name2);
                        stringBuffer2.append(" at ");
                        stringBuffer2.append(i);
                        printStream2.println(stringBuffer2.toString());
                    }
                }
                int offset = offset(i2);
                byte[] bArr = this.name;
                dNSOutput.writeByteArray(bArr, offset, bArr[offset] + 1);
            }
            dNSOutput.writeU8(0);
            return;
        }
        throw new IllegalArgumentException("toWire() called on non-absolute name");
    }

    public void toWireCanonical(DNSOutput dNSOutput) {
        dNSOutput.writeByteArray(toWireCanonical());
    }

    public Name wild(int i) {
        if (i >= 1) {
            try {
                Name name2 = new Name();
                copy(wild, name2);
                name2.append(this.name, offset(i), getlabels() - i);
                return name2;
            } catch (NameTooLongException unused) {
                throw new IllegalStateException("Name.wild: concatenate failed");
            }
        } else {
            throw new IllegalArgumentException("must replace 1 or more labels");
        }
    }

    public Name(String str, Name name2) {
        int i;
        boolean z;
        int i2;
        if (str.equals("")) {
            throw parseException(str, "empty name");
        } else if (str.equals("@")) {
            if (name2 == null) {
                copy(empty, this);
            } else {
                copy(name2, this);
            }
        } else if (str.equals(".")) {
            copy(root, this);
        } else {
            byte[] bArr = new byte[64];
            int i3 = 0;
            boolean z2 = false;
            int i4 = -1;
            int i5 = 1;
            int i6 = 0;
            for (int i7 = 0; i7 < str.length(); i7++) {
                byte charAt = (byte) str.charAt(i7);
                if (z2) {
                    if (charAt >= 48 && charAt <= 57 && i3 < 3) {
                        i3++;
                        i6 = (i6 * 10) + (charAt - 48);
                        if (i6 > 255) {
                            throw parseException(str, "bad escape");
                        } else if (i3 < 3) {
                            continue;
                        } else {
                            charAt = (byte) i6;
                        }
                    } else if (i3 > 0 && i3 < 3) {
                        throw parseException(str, "bad escape");
                    }
                    if (i5 <= 63) {
                        i2 = i5 + 1;
                        bArr[i5] = charAt;
                        i4 = i5;
                        z2 = false;
                    } else {
                        throw parseException(str, "label too long");
                    }
                } else {
                    if (charAt == 92) {
                        i3 = 0;
                        z2 = true;
                        i6 = 0;
                    } else if (charAt != 46) {
                        i4 = i4 == -1 ? i7 : i4;
                        if (i5 <= 63) {
                            i2 = i5 + 1;
                            bArr[i5] = charAt;
                        } else {
                            throw parseException(str, "label too long");
                        }
                    } else if (i4 != -1) {
                        bArr[0] = (byte) (i5 - 1);
                        appendFromString(str, bArr, 0, 1);
                        i4 = -1;
                        i5 = 1;
                    } else {
                        throw parseException(str, "invalid empty label");
                    }
                }
                i5 = i2;
            }
            if (i3 > 0 && i3 < 3) {
                throw parseException(str, "bad escape");
            } else if (!z2) {
                if (i4 == -1) {
                    z = true;
                    i = 0;
                    appendFromString(str, emptyLabel, 0, 1);
                } else {
                    i = 0;
                    bArr[0] = (byte) (i5 - 1);
                    appendFromString(str, bArr, 0, 1);
                    z = false;
                }
                if (!(name2 == null || z)) {
                    appendFromString(str, name2.name, name2.offset(i), name2.getlabels());
                }
            } else {
                throw parseException(str, "bad escape");
            }
        }
    }

    public byte[] toWireCanonical() {
        int labels = labels();
        if (labels == 0) {
            return new byte[0];
        }
        byte[] bArr = new byte[(this.name.length - offset(0))];
        int offset = offset(0);
        int i = 0;
        for (int i2 = 0; i2 < labels; i2++) {
            byte[] bArr2 = this.name;
            byte b = bArr2[offset];
            if (b <= 63) {
                bArr[i] = bArr2[offset];
                i++;
                offset++;
                int i3 = 0;
                while (i3 < b) {
                    bArr[i] = lowercase[this.name[offset] & 255];
                    i3++;
                    i++;
                    offset++;
                }
            } else {
                throw new IllegalStateException("invalid label");
            }
        }
        return bArr;
    }

    public static Name fromString(String str) {
        return fromString(str, null);
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (obj == null || !(obj instanceof Name)) {
            return false;
        }
        Name name2 = (Name) obj;
        if (name2.hashcode == 0) {
            name2.hashCode();
        }
        if (this.hashcode == 0) {
            hashCode();
        }
        if (name2.hashcode == this.hashcode && name2.labels() == labels()) {
            return equals(name2.name, name2.offset(0));
        }
        return false;
    }

    public String toString() {
        return toString(false);
    }

    public byte[] toWire() {
        DNSOutput dNSOutput = new DNSOutput();
        toWire(dNSOutput, null);
        return dNSOutput.toByteArray();
    }

    public Name(String str) {
        this(str, (Name) null);
    }

    public Name(DNSInput dNSInput) {
        byte[] bArr = new byte[64];
        boolean z = false;
        boolean z2 = false;
        while (!z) {
            int readU8 = dNSInput.readU8();
            int i = readU8 & 192;
            if (i != 0) {
                if (i == 192) {
                    int readU82 = dNSInput.readU8() + ((readU8 & -193) << 8);
                    if (Options.check("verbosecompression")) {
                        PrintStream printStream = System.err;
                        StringBuffer outline24 = GeneratedOutlineSupport.outline24("currently ");
                        outline24.append(dNSInput.current());
                        outline24.append(", pointer to ");
                        outline24.append(readU82);
                        printStream.println(outline24.toString());
                    }
                    if (readU82 < dNSInput.current() - 2) {
                        if (!z2) {
                            dNSInput.saved_pos = dNSInput.byteBuffer.position();
                            dNSInput.saved_end = dNSInput.byteBuffer.limit();
                            z2 = true;
                        }
                        if (readU82 < dNSInput.byteBuffer.capacity()) {
                            dNSInput.byteBuffer.position(readU82);
                            ByteBuffer byteBuffer = dNSInput.byteBuffer;
                            byteBuffer.limit(byteBuffer.capacity());
                            if (Options.check("verbosecompression")) {
                                PrintStream printStream2 = System.err;
                                StringBuffer stringBuffer = new StringBuffer();
                                stringBuffer.append("current name '");
                                stringBuffer.append(this);
                                stringBuffer.append("', seeking to ");
                                stringBuffer.append(readU82);
                                printStream2.println(stringBuffer.toString());
                            }
                        } else {
                            throw new IllegalArgumentException("cannot jump past end of input");
                        }
                    } else {
                        throw new WireParseException("bad compression");
                    }
                } else {
                    throw new WireParseException("bad label type");
                }
            } else if (getlabels() >= 128) {
                throw new WireParseException("too many labels");
            } else if (readU8 == 0) {
                append(emptyLabel, 0, 1);
                z = true;
            } else {
                bArr[0] = (byte) readU8;
                dNSInput.require(readU8);
                dNSInput.byteBuffer.get(bArr, 1, readU8);
                append(bArr, 0, 1);
            }
        }
        if (z2) {
            int i2 = dNSInput.saved_pos;
            if (i2 >= 0) {
                dNSInput.byteBuffer.position(i2);
                dNSInput.byteBuffer.limit(dNSInput.saved_end);
                dNSInput.saved_pos = -1;
                dNSInput.saved_end = -1;
                return;
            }
            throw new IllegalStateException("no previous state");
        }
    }

    public void toWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        if (z) {
            toWireCanonical(dNSOutput);
        } else {
            toWire(dNSOutput, compression);
        }
    }

    public Name(byte[] bArr) {
        this(new DNSInput(bArr));
    }

    public Name(Name name2, int i) {
        int labels = name2.labels();
        if (i <= labels) {
            this.name = name2.name;
            int i2 = labels - i;
            setlabels(i2);
            int i3 = 0;
            while (i3 < 7 && i3 < i2) {
                setoffset(i3, name2.offset(i3 + i));
                i3++;
            }
            return;
        }
        throw new IllegalArgumentException("attempted to remove too many labels");
    }
}
