package org.xbill.DNS;

import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class OPTRecord extends Record {
    private static final long serialVersionUID = -6254521894809367938L;
    private List options;

    public OPTRecord() {
    }

    @Override // org.xbill.DNS.Record
    public boolean equals(Object obj) {
        return super.equals(obj) && this.ttl == ((OPTRecord) obj).ttl;
    }

    public int getExtendedRcode() {
        return (int) (this.ttl >>> 24);
    }

    public int getFlags() {
        return (int) (this.ttl & 65535);
    }

    @Override // org.xbill.DNS.Record
    public Record getObject() {
        return new OPTRecord();
    }

    public List getOptions() {
        List list = this.options;
        if (list == null) {
            return Collections.EMPTY_LIST;
        }
        return Collections.unmodifiableList(list);
    }

    public int getPayloadSize() {
        return this.dclass;
    }

    public int getVersion() {
        return (int) ((this.ttl >>> 16) & 255);
    }

    @Override // org.xbill.DNS.Record
    public void rdataFromString(Tokenizer tokenizer, Name name) {
        throw tokenizer.exception("no text format defined for OPT");
    }

    @Override // org.xbill.DNS.Record
    public void rrFromWire(DNSInput dNSInput) {
        EDNSOption eDNSOption;
        if (dNSInput.remaining() > 0) {
            this.options = new ArrayList();
        }
        while (dNSInput.remaining() > 0) {
            int readU16 = dNSInput.readU16();
            int readU162 = dNSInput.readU16();
            if (dNSInput.remaining() >= readU162) {
                int limit = dNSInput.byteBuffer.limit();
                dNSInput.setActive(readU162);
                if (readU16 == 3) {
                    eDNSOption = new NSIDOption();
                } else if (readU16 != 8) {
                    eDNSOption = new GenericEDNSOption(readU16);
                } else {
                    eDNSOption = new ClientSubnetOption();
                }
                eDNSOption.optionFromWire(dNSInput);
                if (limit <= dNSInput.byteBuffer.capacity()) {
                    ByteBuffer byteBuffer = dNSInput.byteBuffer;
                    byteBuffer.limit(byteBuffer.position());
                    this.options.add(eDNSOption);
                } else {
                    throw new IllegalArgumentException("cannot set active region past end of input");
                }
            } else {
                throw new WireParseException("truncated option");
            }
        }
    }

    @Override // org.xbill.DNS.Record
    public String rrToString() {
        StringBuffer stringBuffer = new StringBuffer();
        List list = this.options;
        if (list != null) {
            stringBuffer.append(list);
            stringBuffer.append(" ");
        }
        stringBuffer.append(" ; payload ");
        stringBuffer.append(getPayloadSize());
        stringBuffer.append(", xrcode ");
        stringBuffer.append(getExtendedRcode());
        stringBuffer.append(", version ");
        stringBuffer.append(getVersion());
        stringBuffer.append(", flags ");
        stringBuffer.append(getFlags());
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        List<EDNSOption> list = this.options;
        if (list != null) {
            for (EDNSOption eDNSOption : list) {
                dNSOutput.writeU16(eDNSOption.code);
                int i = dNSOutput.pos;
                dNSOutput.writeU16(0);
                eDNSOption.optionToWire(dNSOutput);
                dNSOutput.writeU16At((dNSOutput.pos - i) - 2, i);
            }
        }
    }

    public OPTRecord(int i, int i2, int i3, int i4, List list) {
        super(Name.root, 41, i, 0);
        Record.checkU16("payloadSize", i);
        Record.checkU8("xrcode", i2);
        Record.checkU8("version", i3);
        Record.checkU16(VpnProfileDataSource.KEY_FLAGS, i4);
        this.ttl = (((long) i2) << 24) + (((long) i3) << 16) + ((long) i4);
        if (list != null) {
            this.options = new ArrayList(list);
        }
    }

    public List getOptions(int i) {
        List<EDNSOption> list = this.options;
        if (list == null) {
            return Collections.EMPTY_LIST;
        }
        List list2 = Collections.EMPTY_LIST;
        for (EDNSOption eDNSOption : list) {
            if (eDNSOption.code == i) {
                if (list2 == Collections.EMPTY_LIST) {
                    list2 = new ArrayList();
                }
                list2.add(eDNSOption);
            }
        }
        return list2;
    }

    public OPTRecord(int i, int i2, int i3, int i4) {
        this(i, i2, i3, i4, null);
    }

    public OPTRecord(int i, int i2, int i3) {
        this(i, i2, i3, 0, null);
    }
}
