package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.Serializable;
import java.nio.ByteBuffer;
import java.text.DecimalFormat;
import java.util.Arrays;
import java.util.Objects;
import kotlinx.coroutines.internal.SystemPropsKt;
import org.xbill.DNS.Tokenizer;
import org.xbill.DNS.Type;

public abstract class Record implements Cloneable, Comparable, Serializable {
    public static final DecimalFormat byteFormat;
    private static final long serialVersionUID = 2694906050116005466L;
    public int dclass;
    public Name name;
    public long ttl;
    public int type;

    static {
        DecimalFormat decimalFormat = new DecimalFormat();
        byteFormat = decimalFormat;
        decimalFormat.setMinimumIntegerDigits(3);
    }

    public Record() {
    }

    public static byte[] byteArrayFromString(String str) {
        boolean z;
        byte[] bytes = str.getBytes();
        int i = 0;
        while (true) {
            if (i >= bytes.length) {
                z = false;
                break;
            } else if (bytes[i] == 92) {
                z = true;
                break;
            } else {
                i++;
            }
        }
        if (z) {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            int i2 = 0;
            boolean z2 = false;
            int i3 = 0;
            for (int i4 = 0; i4 < bytes.length; i4++) {
                byte b = bytes[i4];
                if (z2) {
                    if (b >= 48 && b <= 57 && i2 < 3) {
                        i2++;
                        i3 = (i3 * 10) + (b - 48);
                        if (i3 > 255) {
                            throw new TextParseException("bad escape");
                        } else if (i2 >= 3) {
                            b = (byte) i3;
                        }
                    } else if (i2 > 0 && i2 < 3) {
                        throw new TextParseException("bad escape");
                    }
                    byteArrayOutputStream.write(b);
                    z2 = false;
                } else if (bytes[i4] == 92) {
                    i2 = 0;
                    z2 = true;
                    i3 = 0;
                } else {
                    byteArrayOutputStream.write(bytes[i4]);
                }
            }
            if (i2 > 0 && i2 < 3) {
                throw new TextParseException("bad escape");
            } else if (byteArrayOutputStream.toByteArray().length <= 255) {
                return byteArrayOutputStream.toByteArray();
            } else {
                throw new TextParseException("text string too long");
            }
        } else if (bytes.length <= 255) {
            return bytes;
        } else {
            throw new TextParseException("text string too long");
        }
    }

    public static String byteArrayToString(byte[] bArr, boolean z) {
        StringBuffer stringBuffer = new StringBuffer();
        if (z) {
            stringBuffer.append(StringUtil.DOUBLE_QUOTE);
        }
        for (byte b : bArr) {
            int i = b & 255;
            if (i < 32 || i >= 127) {
                stringBuffer.append('\\');
                stringBuffer.append(byteFormat.format((long) i));
            } else if (i == 34 || i == 92) {
                stringBuffer.append('\\');
                stringBuffer.append((char) i);
            } else {
                stringBuffer.append((char) i);
            }
        }
        if (z) {
            stringBuffer.append(StringUtil.DOUBLE_QUOTE);
        }
        return stringBuffer.toString();
    }

    public static byte[] checkByteArrayLength(String str, byte[] bArr, int i) {
        if (bArr.length <= 65535) {
            byte[] bArr2 = new byte[bArr.length];
            System.arraycopy(bArr, 0, bArr2, 0, bArr.length);
            return bArr2;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("\"");
        stringBuffer.append(str);
        stringBuffer.append("\" array must have no more than ");
        stringBuffer.append(i);
        stringBuffer.append(" elements");
        throw new IllegalArgumentException(stringBuffer.toString());
    }

    public static Name checkName(String str, Name name2) {
        if (name2.isAbsolute()) {
            return name2;
        }
        throw new RelativeNameException(name2);
    }

    public static int checkU16(String str, int i) {
        if (i >= 0 && i <= 65535) {
            return i;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("\"");
        stringBuffer.append(str);
        stringBuffer.append("\" ");
        stringBuffer.append(i);
        stringBuffer.append(" must be an unsigned 16 bit value");
        throw new IllegalArgumentException(stringBuffer.toString());
    }

    public static long checkU32(String str, long j) {
        if (j >= 0 && j <= 4294967295L) {
            return j;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("\"");
        stringBuffer.append(str);
        stringBuffer.append("\" ");
        stringBuffer.append(j);
        stringBuffer.append(" must be an unsigned 32 bit value");
        throw new IllegalArgumentException(stringBuffer.toString());
    }

    public static int checkU8(String str, int i) {
        if (i >= 0 && i <= 255) {
            return i;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("\"");
        stringBuffer.append(str);
        stringBuffer.append("\" ");
        stringBuffer.append(i);
        stringBuffer.append(" must be an unsigned 8 bit value");
        throw new IllegalArgumentException(stringBuffer.toString());
    }

    public static Record fromString(Name name2, int i, int i2, long j, Tokenizer tokenizer, Name name3) {
        if (name2.isAbsolute()) {
            Type.check(i);
            DClass.check(i2);
            SystemPropsKt.check(j);
            Tokenizer.Token token = tokenizer.get();
            if (token.type != 3 || !token.value.equals("\\#")) {
                tokenizer.unget();
                Record emptyRecord = getEmptyRecord(name2, i, i2, j, true);
                emptyRecord.rdataFromString(tokenizer, name3);
                int i3 = tokenizer.get().type;
                if (i3 == 1 || i3 == 0) {
                    return emptyRecord;
                }
                throw tokenizer.exception("unexpected tokens at end of record");
            }
            int uInt16 = tokenizer.getUInt16();
            byte[] hex = tokenizer.getHex();
            if (hex == null) {
                hex = new byte[0];
            }
            if (uInt16 == hex.length) {
                return newRecord(name2, i, i2, j, uInt16, new DNSInput(hex));
            }
            throw tokenizer.exception("invalid unknown RR encoding: length mismatch");
        }
        throw new RelativeNameException(name2);
    }

    public static Record fromWire(DNSInput dNSInput, int i, boolean z) {
        Name name2 = new Name(dNSInput);
        int readU16 = dNSInput.readU16();
        int readU162 = dNSInput.readU16();
        if (i == 0) {
            return newRecord(name2, readU16, readU162);
        }
        long readU32 = dNSInput.readU32();
        int readU163 = dNSInput.readU16();
        if (readU163 == 0 && z && (i == 1 || i == 2)) {
            return newRecord(name2, readU16, readU162, readU32);
        }
        return newRecord(name2, readU16, readU162, readU32, readU163, dNSInput);
    }

    public static final Record getEmptyRecord(Name name2, int i, int i2, long j, boolean z) {
        Record record;
        if (z) {
            Type.TypeMnemonic typeMnemonic = Type.types;
            Objects.requireNonNull(typeMnemonic);
            Type.check(i);
            Record record2 = (Record) typeMnemonic.objects.get(Mnemonic.toInteger(i));
            if (record2 != null) {
                record = record2.getObject();
            } else {
                record = new UNKRecord();
            }
        } else {
            record = new EmptyRecord();
        }
        record.name = name2;
        record.type = i;
        record.dclass = i2;
        record.ttl = j;
        return record;
    }

    public static Record newRecord(Name name2, int i, int i2, long j, int i3, DNSInput dNSInput) {
        Record emptyRecord = getEmptyRecord(name2, i, i2, j, dNSInput != null);
        if (dNSInput != null) {
            if (dNSInput.remaining() >= i3) {
                dNSInput.setActive(i3);
                emptyRecord.rrFromWire(dNSInput);
                if (dNSInput.remaining() <= 0) {
                    ByteBuffer byteBuffer = dNSInput.byteBuffer;
                    byteBuffer.limit(byteBuffer.capacity());
                } else {
                    throw new WireParseException("invalid record length");
                }
            } else {
                throw new WireParseException("truncated record");
            }
        }
        return emptyRecord;
    }

    public static String unknownToString(byte[] bArr) {
        StringBuffer outline24 = GeneratedOutlineSupport.outline24("\\# ");
        outline24.append(bArr.length);
        outline24.append(" ");
        outline24.append(SystemPropsKt.toString(bArr));
        return outline24.toString();
    }

    public Record cloneRecord() {
        try {
            return (Record) clone();
        } catch (CloneNotSupportedException unused) {
            throw new IllegalStateException();
        }
    }

    @Override // java.lang.Comparable
    public int compareTo(Object obj) {
        Record record = (Record) obj;
        int i = 0;
        if (this == record) {
            return 0;
        }
        int compareTo = this.name.compareTo(record.name);
        if (compareTo != 0) {
            return compareTo;
        }
        int i2 = this.dclass - record.dclass;
        if (i2 != 0) {
            return i2;
        }
        int i3 = this.type - record.type;
        if (i3 != 0) {
            return i3;
        }
        byte[] rdataToWireCanonical = rdataToWireCanonical();
        byte[] rdataToWireCanonical2 = record.rdataToWireCanonical();
        while (i < rdataToWireCanonical.length && i < rdataToWireCanonical2.length) {
            int i4 = (rdataToWireCanonical[i] & 255) - (rdataToWireCanonical2[i] & 255);
            if (i4 != 0) {
                return i4;
            }
            i++;
        }
        return rdataToWireCanonical.length - rdataToWireCanonical2.length;
    }

    public boolean equals(Object obj) {
        if (obj != null && (obj instanceof Record)) {
            Record record = (Record) obj;
            if (this.type == record.type && this.dclass == record.dclass && this.name.equals(record.name)) {
                return Arrays.equals(rdataToWireCanonical(), record.rdataToWireCanonical());
            }
        }
        return false;
    }

    public Name getAdditionalName() {
        return null;
    }

    public int getDClass() {
        return this.dclass;
    }

    public Name getName() {
        return this.name;
    }

    public abstract Record getObject();

    public int getRRsetType() {
        return this.type;
    }

    public long getTTL() {
        return this.ttl;
    }

    public int getType() {
        return this.type;
    }

    public int hashCode() {
        byte[] wireCanonical;
        int i = 0;
        for (byte b : toWireCanonical(true)) {
            i += (i << 3) + (b & 255);
        }
        return i;
    }

    public abstract void rdataFromString(Tokenizer tokenizer, Name name2);

    public String rdataToString() {
        return rrToString();
    }

    public byte[] rdataToWireCanonical() {
        DNSOutput dNSOutput = new DNSOutput();
        rrToWire(dNSOutput, null, true);
        return dNSOutput.toByteArray();
    }

    public abstract void rrFromWire(DNSInput dNSInput);

    public abstract String rrToString();

    public abstract void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z);

    public boolean sameRRset(Record record) {
        return getRRsetType() == record.getRRsetType() && this.dclass == record.dclass && this.name.equals(record.name);
    }

    public void setTTL(long j) {
        this.ttl = j;
    }

    public String toString() {
        long j;
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.name);
        if (stringBuffer.length() < 8) {
            stringBuffer.append("\t");
        }
        if (stringBuffer.length() < 16) {
            stringBuffer.append("\t");
        }
        stringBuffer.append("\t");
        if (Options.check("BINDTTL")) {
            long j2 = this.ttl;
            SystemPropsKt.check(j2);
            StringBuffer stringBuffer2 = new StringBuffer();
            long j3 = j2 % 60;
            long j4 = j2 / 60;
            long j5 = j4 % 60;
            long j6 = j4 / 60;
            long j7 = j6 % 24;
            long j8 = j6 / 24;
            long j9 = j8 % 7;
            long j10 = j8 / 7;
            int i = (j10 > 0 ? 1 : (j10 == 0 ? 0 : -1));
            if (i > 0) {
                StringBuffer stringBuffer3 = new StringBuffer();
                stringBuffer3.append(j10);
                stringBuffer3.append("W");
                stringBuffer2.append(stringBuffer3.toString());
                j = 0;
            } else {
                j = 0;
            }
            int i2 = (j9 > j ? 1 : (j9 == j ? 0 : -1));
            if (i2 > 0) {
                StringBuffer stringBuffer4 = new StringBuffer();
                stringBuffer4.append(j9);
                stringBuffer4.append("D");
                stringBuffer2.append(stringBuffer4.toString());
            }
            int i3 = (j7 > j ? 1 : (j7 == j ? 0 : -1));
            if (i3 > 0) {
                StringBuffer stringBuffer5 = new StringBuffer();
                stringBuffer5.append(j7);
                stringBuffer5.append("H");
                stringBuffer2.append(stringBuffer5.toString());
            }
            int i4 = (j5 > j ? 1 : (j5 == j ? 0 : -1));
            if (i4 > 0) {
                StringBuffer stringBuffer6 = new StringBuffer();
                stringBuffer6.append(j5);
                stringBuffer6.append("M");
                stringBuffer2.append(stringBuffer6.toString());
            }
            if (j3 > j || (i == 0 && i2 == 0 && i3 == 0 && i4 == 0)) {
                StringBuffer stringBuffer7 = new StringBuffer();
                stringBuffer7.append(j3);
                stringBuffer7.append("S");
                stringBuffer2.append(stringBuffer7.toString());
            }
            stringBuffer.append(stringBuffer2.toString());
        } else {
            stringBuffer.append(this.ttl);
        }
        stringBuffer.append("\t");
        if (this.dclass != 1 || !Options.check("noPrintIN")) {
            stringBuffer.append(DClass.string(this.dclass));
            stringBuffer.append("\t");
        }
        stringBuffer.append(Type.string(this.type));
        String rrToString = rrToString();
        if (!rrToString.equals("")) {
            stringBuffer.append("\t");
            stringBuffer.append(rrToString);
        }
        return stringBuffer.toString();
    }

    public void toWire(DNSOutput dNSOutput, int i, Compression compression) {
        this.name.toWire(dNSOutput, compression);
        dNSOutput.writeU16(this.type);
        dNSOutput.writeU16(this.dclass);
        if (i != 0) {
            dNSOutput.writeU32(this.ttl);
            int i2 = dNSOutput.pos;
            dNSOutput.writeU16(0);
            rrToWire(dNSOutput, compression, false);
            dNSOutput.writeU16At((dNSOutput.pos - i2) - 2, i2);
        }
    }

    public final byte[] toWireCanonical(boolean z) {
        DNSOutput dNSOutput = new DNSOutput();
        this.name.toWireCanonical(dNSOutput);
        dNSOutput.writeU16(this.type);
        dNSOutput.writeU16(this.dclass);
        if (z) {
            dNSOutput.writeU32(0);
        } else {
            dNSOutput.writeU32(this.ttl);
        }
        int i = dNSOutput.pos;
        dNSOutput.writeU16(0);
        rrToWire(dNSOutput, null, true);
        dNSOutput.writeU16At((dNSOutput.pos - i) - 2, i);
        return dNSOutput.toByteArray();
    }

    public Record withDClass(int i, long j) {
        Record cloneRecord = cloneRecord();
        cloneRecord.dclass = i;
        cloneRecord.ttl = j;
        return cloneRecord;
    }

    public Record withName(Name name2) {
        if (name2.isAbsolute()) {
            Record cloneRecord = cloneRecord();
            cloneRecord.name = name2;
            return cloneRecord;
        }
        throw new RelativeNameException(name2);
    }

    public Record(Name name2, int i, int i2, long j) {
        if (name2.isAbsolute()) {
            Type.check(i);
            DClass.check(i2);
            SystemPropsKt.check(j);
            this.name = name2;
            this.type = i;
            this.dclass = i2;
            this.ttl = j;
            return;
        }
        throw new RelativeNameException(name2);
    }

    public static Record fromWire(DNSInput dNSInput, int i) {
        return fromWire(dNSInput, i, false);
    }

    public static Record newRecord(Name name2, int i, int i2, long j, int i3, byte[] bArr) {
        if (name2.isAbsolute()) {
            Type.check(i);
            DClass.check(i2);
            SystemPropsKt.check(j);
            try {
                return newRecord(name2, i, i2, j, i3, bArr != null ? new DNSInput(bArr) : null);
            } catch (IOException unused) {
                return null;
            }
        } else {
            throw new RelativeNameException(name2);
        }
    }

    public static Record fromWire(byte[] bArr, int i) {
        return fromWire(new DNSInput(bArr), i, false);
    }

    public byte[] toWire(int i) {
        DNSOutput dNSOutput = new DNSOutput();
        toWire(dNSOutput, i, null);
        return dNSOutput.toByteArray();
    }

    public byte[] toWireCanonical() {
        return toWireCanonical(false);
    }

    public static Record newRecord(Name name2, int i, int i2, long j, byte[] bArr) {
        return newRecord(name2, i, i2, j, bArr.length, bArr);
    }

    public static Record newRecord(Name name2, int i, int i2, long j) {
        if (name2.isAbsolute()) {
            Type.check(i);
            DClass.check(i2);
            SystemPropsKt.check(j);
            return getEmptyRecord(name2, i, i2, j, false);
        }
        throw new RelativeNameException(name2);
    }

    public static Record fromString(Name name2, int i, int i2, long j, String str, Name name3) {
        return fromString(name2, i, i2, j, new Tokenizer(str), name3);
    }

    public static Record newRecord(Name name2, int i, int i2) {
        return newRecord(name2, i, i2, 0);
    }
}
