package org.xbill.DNS;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.handler.codec.compression.FastLz;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Arrays;
import kotlinx.coroutines.internal.SystemPropsKt;
import org.xbill.DNS.Tokenizer;

public class WKSRecord extends Record {
    private static final long serialVersionUID = -9104259763909119805L;
    private byte[] address;
    private int protocol;
    private int[] services;

    public abstract class Protocol {
        public static Mnemonic protocols;

        static {
            Mnemonic mnemonic = new Mnemonic("IP protocol", 3);
            protocols = mnemonic;
            mnemonic.max = KEYRecord.PROTOCOL_ANY;
            mnemonic.numericok = true;
            mnemonic.add(1, "icmp");
            protocols.add(2, "igmp");
            protocols.add(3, "ggp");
            protocols.add(5, "st");
            protocols.add(6, "tcp");
            protocols.add(7, "ucl");
            protocols.add(8, "egp");
            protocols.add(9, "igp");
            protocols.add(10, "bbn-rcc-mon");
            protocols.add(11, "nvp-ii");
            protocols.add(12, "pup");
            protocols.add(13, "argus");
            protocols.add(14, "emcon");
            protocols.add(15, "xnet");
            protocols.add(16, "chaos");
            protocols.add(17, "udp");
            protocols.add(18, "mux");
            protocols.add(19, "dcn-meas");
            protocols.add(20, "hmp");
            protocols.add(21, "prm");
            protocols.add(22, "xns-idp");
            protocols.add(23, "trunk-1");
            protocols.add(24, "trunk-2");
            protocols.add(25, "leaf-1");
            protocols.add(26, "leaf-2");
            protocols.add(27, "rdp");
            protocols.add(28, "irtp");
            protocols.add(29, "iso-tp4");
            protocols.add(30, "netblt");
            protocols.add(31, "mfe-nsp");
            protocols.add(32, "merit-inp");
            protocols.add(33, "sep");
            protocols.add(62, "cftp");
            protocols.add(64, "sat-expak");
            protocols.add(65, "mit-subnet");
            protocols.add(66, "rvd");
            protocols.add(67, "ippc");
            protocols.add(69, "sat-mon");
            protocols.add(71, "ipcv");
            protocols.add(76, "br-sat-mon");
            protocols.add(78, "wb-mon");
            protocols.add(79, "wb-expak");
        }
    }

    public abstract class Service {
        public static Mnemonic services;

        static {
            Mnemonic mnemonic = new Mnemonic("TCP/UDP service", 3);
            services = mnemonic;
            mnemonic.max = FastLz.MAX_CHUNK_LENGTH;
            mnemonic.numericok = true;
            mnemonic.add(5, "rje");
            services.add(7, "echo");
            services.add(9, "discard");
            services.add(11, "users");
            services.add(13, "daytime");
            services.add(17, "quote");
            services.add(19, "chargen");
            services.add(20, "ftp-data");
            services.add(21, "ftp");
            services.add(23, "telnet");
            services.add(25, "smtp");
            services.add(27, "nsw-fe");
            services.add(29, "msg-icp");
            services.add(31, "msg-auth");
            services.add(33, "dsp");
            services.add(37, "time");
            services.add(39, "rlp");
            services.add(41, "graphics");
            services.add(42, "nameserver");
            services.add(43, "nicname");
            services.add(44, "mpm-flags");
            services.add(45, "mpm");
            services.add(46, "mpm-snd");
            services.add(47, "ni-ftp");
            services.add(49, "login");
            services.add(51, "la-maint");
            services.add(53, "domain");
            services.add(55, "isi-gl");
            services.add(61, "ni-mail");
            services.add(63, "via-ftp");
            services.add(65, "tacacs-ds");
            services.add(67, "bootps");
            services.add(68, "bootpc");
            services.add(69, "tftp");
            services.add(71, "netrjs-1");
            services.add(72, "netrjs-2");
            services.add(73, "netrjs-3");
            services.add(74, "netrjs-4");
            services.add(79, "finger");
            services.add(81, "hosts2-ns");
            services.add(89, "su-mit-tg");
            services.add(91, "mit-dov");
            services.add(93, "dcp");
            services.add(95, "supdup");
            services.add(97, "swift-rvf");
            services.add(98, "tacnews");
            services.add(99, "metagram");
            services.add(101, "hostname");
            services.add(102, "iso-tsap");
            services.add(103, "x400");
            services.add(104, "x400-snd");
            services.add(105, "csnet-ns");
            services.add(107, "rtelnet");
            services.add(109, "pop-2");
            services.add(111, "sunrpc");
            services.add(113, "auth");
            services.add(115, "sftp");
            services.add(117, "uucp-path");
            services.add(119, "nntp");
            services.add(121, "erpc");
            services.add(123, "ntp");
            services.add(125, "locus-map");
            services.add(127, "locus-con");
            services.add(129, "pwdgen");
            services.add(130, "cisco-fna");
            services.add(131, "cisco-tna");
            services.add(132, "cisco-sys");
            services.add(133, "statsrv");
            services.add(134, "ingres-net");
            services.add(135, "loc-srv");
            services.add(136, "profile");
            services.add(137, "netbios-ns");
            services.add(138, "netbios-dgm");
            services.add(139, "netbios-ssn");
            services.add(140, "emfis-data");
            services.add(141, "emfis-cntl");
            services.add(142, "bl-idm");
            services.add(243, "sur-meas");
            services.add(245, "link");
        }
    }

    public WKSRecord() {
    }

    public InetAddress getAddress() {
        try {
            return InetAddress.getByAddress(this.address);
        } catch (UnknownHostException unused) {
            return null;
        }
    }

    @Override // org.xbill.DNS.Record
    public Record getObject() {
        return new WKSRecord();
    }

    public int getProtocol() {
        return this.protocol;
    }

    public int[] getServices() {
        return this.services;
    }

    @Override // org.xbill.DNS.Record
    public void rdataFromString(Tokenizer tokenizer, Name name) {
        byte[] byteArray = SystemPropsKt.toByteArray(tokenizer.getString(), 1);
        this.address = byteArray;
        if (byteArray != null) {
            String string = tokenizer.getString();
            int value = Protocol.protocols.getValue(string);
            this.protocol = value;
            if (value >= 0) {
                ArrayList arrayList = new ArrayList();
                while (true) {
                    Tokenizer.Token token = tokenizer.get();
                    if (!token.isString()) {
                        tokenizer.unget();
                        this.services = new int[arrayList.size()];
                        for (int i = 0; i < arrayList.size(); i++) {
                            this.services[i] = ((Integer) arrayList.get(i)).intValue();
                        }
                        return;
                    }
                    int value2 = Service.services.getValue(token.value);
                    if (value2 >= 0) {
                        arrayList.add(new Integer(value2));
                    } else {
                        StringBuffer outline24 = GeneratedOutlineSupport.outline24("Invalid TCP/UDP service: ");
                        outline24.append(token.value);
                        throw tokenizer.exception(outline24.toString());
                    }
                }
            } else {
                StringBuffer stringBuffer = new StringBuffer();
                stringBuffer.append("Invalid IP protocol: ");
                stringBuffer.append(string);
                throw tokenizer.exception(stringBuffer.toString());
            }
        } else {
            throw tokenizer.exception("invalid address");
        }
    }

    @Override // org.xbill.DNS.Record
    public void rrFromWire(DNSInput dNSInput) {
        this.address = dNSInput.readByteArray(4);
        this.protocol = dNSInput.readU8();
        byte[] readByteArray = dNSInput.readByteArray();
        ArrayList arrayList = new ArrayList();
        for (int i = 0; i < readByteArray.length; i++) {
            for (int i2 = 0; i2 < 8; i2++) {
                if ((readByteArray[i] & 255 & (1 << (7 - i2))) != 0) {
                    arrayList.add(new Integer((i * 8) + i2));
                }
            }
        }
        this.services = new int[arrayList.size()];
        for (int i3 = 0; i3 < arrayList.size(); i3++) {
            this.services[i3] = ((Integer) arrayList.get(i3)).intValue();
        }
    }

    @Override // org.xbill.DNS.Record
    public String rrToString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(SystemPropsKt.toDottedQuad(this.address));
        stringBuffer.append(" ");
        stringBuffer.append(this.protocol);
        for (int i = 0; i < this.services.length; i++) {
            StringBuffer outline24 = GeneratedOutlineSupport.outline24(" ");
            outline24.append(this.services[i]);
            stringBuffer.append(outline24.toString());
        }
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        dNSOutput.writeByteArray(this.address);
        dNSOutput.writeU8(this.protocol);
        int[] iArr = this.services;
        byte[] bArr = new byte[((iArr[iArr.length - 1] / 8) + 1)];
        int i = 0;
        while (true) {
            int[] iArr2 = this.services;
            if (i < iArr2.length) {
                int i2 = iArr2[i];
                int i3 = i2 / 8;
                bArr[i3] = (byte) ((1 << (7 - (i2 % 8))) | bArr[i3]);
                i++;
            } else {
                dNSOutput.writeByteArray(bArr);
                return;
            }
        }
    }

    public WKSRecord(Name name, int i, long j, InetAddress inetAddress, int i2, int[] iArr) {
        super(name, 11, i, j);
        if (SystemPropsKt.familyOf(inetAddress) == 1) {
            this.address = inetAddress.getAddress();
            this.protocol = Record.checkU8("protocol", i2);
            for (int i3 : iArr) {
                Record.checkU16("service", i3);
            }
            int[] iArr2 = new int[iArr.length];
            this.services = iArr2;
            System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
            Arrays.sort(this.services);
            return;
        }
        throw new IllegalArgumentException("invalid IPv4 address");
    }
}
