package androidx.constraintlayout.motion.widget;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.DashPathEffect;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.os.Bundle;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.util.SparseBooleanArray;
import android.util.SparseIntArray;
import android.view.Display;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.AnimationUtils;
import android.view.animation.Interpolator;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.constraintlayout.core.motion.utils.CurveFit;
import androidx.constraintlayout.core.motion.utils.Easing;
import androidx.constraintlayout.core.motion.utils.KeyCache;
import androidx.constraintlayout.core.motion.utils.SpringStopEngine;
import androidx.constraintlayout.core.widgets.Barrier;
import androidx.constraintlayout.core.widgets.ConstraintWidget;
import androidx.constraintlayout.core.widgets.ConstraintWidgetContainer;
import androidx.constraintlayout.core.widgets.Flow;
import androidx.constraintlayout.core.widgets.Guideline;
import androidx.constraintlayout.core.widgets.Helper;
import androidx.constraintlayout.core.widgets.HelperWidget;
import androidx.constraintlayout.core.widgets.Placeholder;
import androidx.constraintlayout.core.widgets.VirtualLayout;
import androidx.constraintlayout.core.widgets.WidgetContainer;
import androidx.constraintlayout.helper.widget.MotionEffect;
import androidx.constraintlayout.motion.utils.StopLogic;
import androidx.constraintlayout.motion.utils.ViewOscillator;
import androidx.constraintlayout.motion.utils.ViewSpline;
import androidx.constraintlayout.motion.widget.MotionScene;
import androidx.constraintlayout.motion.widget.ViewTransition;
import androidx.constraintlayout.widget.ConstraintHelper;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.constraintlayout.widget.ConstraintLayoutStates;
import androidx.constraintlayout.widget.ConstraintSet;
import androidx.constraintlayout.widget.Constraints;
import androidx.constraintlayout.widget.R$styleable;
import androidx.constraintlayout.widget.StateSet;
import androidx.core.view.NestedScrollingParent3;
import androidx.core.widget.NestedScrollView;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Objects;
import java.util.concurrent.CopyOnWriteArrayList;

public class MotionLayout extends ConstraintLayout implements NestedScrollingParent3 {
    public static boolean IS_IN_EDIT_MODE;
    public float lastPos;
    public float lastY;
    public long mAnimationStartTime = 0;
    public int mBeginState = -1;
    public RectF mBoundsCheck = new RectF();
    public int mCurrentState = -1;
    public int mDebugPath = 0;
    public DecelerateInterpolator mDecelerateLogic = new DecelerateInterpolator();
    public ArrayList<MotionHelper> mDecoratorsHelpers = null;
    public boolean mDelayedApply = false;
    public DesignTool mDesignTool;
    public DevModeDraw mDevModeDraw;
    public int mEndState = -1;
    public int mEndWrapHeight;
    public int mEndWrapWidth;
    public HashMap<View, MotionController> mFrameArrayList = new HashMap<>();
    public int mFrames = 0;
    public int mHeightMeasureMode;
    public boolean mInLayout = false;
    public boolean mInTransition = false;
    public boolean mInteractionEnabled = true;
    public Interpolator mInterpolator;
    public Matrix mInverseMatrix = null;
    public boolean mKeepAnimating = false;
    public KeyCache mKeyCache = new KeyCache();
    public long mLastDrawTime = -1;
    public float mLastFps = 0.0f;
    public int mLastHeightMeasureSpec = 0;
    public int mLastLayoutHeight;
    public int mLastLayoutWidth;
    public float mLastVelocity = 0.0f;
    public int mLastWidthMeasureSpec = 0;
    public float mListenerPosition = 0.0f;
    public int mListenerState = 0;
    public boolean mMeasureDuringTransition = false;
    public Model mModel = new Model();
    public boolean mNeedsFireTransitionCompleted = false;
    public Runnable mOnComplete = null;
    public ArrayList<MotionHelper> mOnHideHelpers = null;
    public ArrayList<MotionHelper> mOnShowHelpers = null;
    public float mPostInterpolationPosition;
    public HashMap<View, ?> mPreRotate = new HashMap<>();
    public Interpolator mProgressInterpolator = null;
    public View mRegionView = null;
    public MotionScene mScene;
    public float mScrollTargetDT;
    public float mScrollTargetDX;
    public float mScrollTargetDY;
    public long mScrollTargetTime;
    public int mStartWrapHeight;
    public int mStartWrapWidth;
    public StateCache mStateCache;
    public StopLogic mStopLogic = new StopLogic();
    public Rect mTempRect = new Rect();
    public boolean mTemporalInterpolator = false;
    public ArrayList<Integer> mTransitionCompleted = new ArrayList<>();
    public float mTransitionDuration = 1.0f;
    public float mTransitionGoalPosition = 0.0f;
    public boolean mTransitionInstantly;
    public float mTransitionLastPosition = 0.0f;
    public long mTransitionLastTime;
    public TransitionListener mTransitionListener;
    public CopyOnWriteArrayList<TransitionListener> mTransitionListeners = null;
    public float mTransitionPosition = 0.0f;
    public TransitionState mTransitionState = TransitionState.UNDEFINED;
    public boolean mUndergoingMotion = false;
    public int mWidthMeasureMode;

    public class DecelerateInterpolator extends MotionInterpolator {
        public float currentP = 0.0f;
        public float initalV = 0.0f;
        public float maxA;

        public DecelerateInterpolator() {
        }

        public float getInterpolation(float f) {
            float f2 = this.initalV;
            if (f2 > 0.0f) {
                float f3 = this.maxA;
                if (f2 / f3 < f) {
                    f = f2 / f3;
                }
                MotionLayout.this.mLastVelocity = f2 - (f3 * f);
                return ((f2 * f) - (((f3 * f) * f) / 2.0f)) + this.currentP;
            }
            float f4 = this.maxA;
            if ((-f2) / f4 < f) {
                f = (-f2) / f4;
            }
            MotionLayout.this.mLastVelocity = (f4 * f) + f2;
            return (((f4 * f) * f) / 2.0f) + (f2 * f) + this.currentP;
        }

        @Override // androidx.constraintlayout.motion.widget.MotionInterpolator
        public float getVelocity() {
            return MotionLayout.this.mLastVelocity;
        }
    }

    public class DevModeDraw {
        public Rect mBounds = new Rect();
        public DashPathEffect mDashPathEffect;
        public Paint mFillPaint;
        public int mKeyFrameCount;
        public float[] mKeyFramePoints;
        public Paint mPaint;
        public Paint mPaintGraph;
        public Paint mPaintKeyframes;
        public Path mPath;
        public int[] mPathMode;
        public float[] mPoints;
        public float[] mRectangle;
        public int mShadowTranslate = 1;
        public Paint mTextPaint;

        public DevModeDraw() {
            Paint paint = new Paint();
            this.mPaint = paint;
            paint.setAntiAlias(true);
            this.mPaint.setColor(-21965);
            this.mPaint.setStrokeWidth(2.0f);
            this.mPaint.setStyle(Paint.Style.STROKE);
            Paint paint2 = new Paint();
            this.mPaintKeyframes = paint2;
            paint2.setAntiAlias(true);
            this.mPaintKeyframes.setColor(-2067046);
            this.mPaintKeyframes.setStrokeWidth(2.0f);
            this.mPaintKeyframes.setStyle(Paint.Style.STROKE);
            Paint paint3 = new Paint();
            this.mPaintGraph = paint3;
            paint3.setAntiAlias(true);
            this.mPaintGraph.setColor(-13391360);
            this.mPaintGraph.setStrokeWidth(2.0f);
            this.mPaintGraph.setStyle(Paint.Style.STROKE);
            Paint paint4 = new Paint();
            this.mTextPaint = paint4;
            paint4.setAntiAlias(true);
            this.mTextPaint.setColor(-13391360);
            this.mTextPaint.setTextSize(MotionLayout.this.getContext().getResources().getDisplayMetrics().density * 12.0f);
            this.mRectangle = new float[8];
            Paint paint5 = new Paint();
            this.mFillPaint = paint5;
            paint5.setAntiAlias(true);
            DashPathEffect dashPathEffect = new DashPathEffect(new float[]{4.0f, 8.0f}, 0.0f);
            this.mDashPathEffect = dashPathEffect;
            this.mPaintGraph.setPathEffect(dashPathEffect);
            this.mKeyFramePoints = new float[100];
            this.mPathMode = new int[50];
        }

        public void drawAll(Canvas canvas, int i, int i2, MotionController motionController) {
            int i3;
            int i4;
            int i5;
            float f;
            float f2;
            if (i == 4) {
                boolean z = false;
                boolean z2 = false;
                for (int i6 = 0; i6 < this.mKeyFrameCount; i6++) {
                    int[] iArr = this.mPathMode;
                    if (iArr[i6] == 1) {
                        z = true;
                    }
                    if (iArr[i6] == 0) {
                        z2 = true;
                    }
                }
                if (z) {
                    drawPathRelative(canvas);
                }
                if (z2) {
                    drawPathCartesian(canvas);
                }
            }
            if (i == 2) {
                drawPathRelative(canvas);
            }
            if (i == 3) {
                drawPathCartesian(canvas);
            }
            canvas.drawLines(this.mPoints, this.mPaint);
            View view = motionController.mView;
            if (view != null) {
                i4 = view.getWidth();
                i3 = motionController.mView.getHeight();
            } else {
                i4 = 0;
                i3 = 0;
            }
            int i7 = 1;
            while (i7 < i2 - 1) {
                if (i == 4 && this.mPathMode[i7 - 1] == 0) {
                    i5 = i7;
                } else {
                    float[] fArr = this.mKeyFramePoints;
                    int i8 = i7 * 2;
                    float f3 = fArr[i8];
                    float f4 = fArr[i8 + 1];
                    this.mPath.reset();
                    this.mPath.moveTo(f3, f4 + 10.0f);
                    this.mPath.lineTo(f3 + 10.0f, f4);
                    this.mPath.lineTo(f3, f4 - 10.0f);
                    this.mPath.lineTo(f3 - 10.0f, f4);
                    this.mPath.close();
                    int i9 = i7 - 1;
                    motionController.mMotionPaths.get(i9);
                    if (i == 4) {
                        int[] iArr2 = this.mPathMode;
                        if (iArr2[i9] == 1) {
                            drawPathRelativeTicks(canvas, f3 - 0.0f, f4 - 0.0f);
                        } else if (iArr2[i9] == 0) {
                            drawPathCartesianTicks(canvas, f3 - 0.0f, f4 - 0.0f);
                        } else if (iArr2[i9] == 2) {
                            f = f4;
                            f2 = f3;
                            i5 = i7;
                            drawPathScreenTicks(canvas, f3 - 0.0f, f4 - 0.0f, i4, i3);
                            canvas.drawPath(this.mPath, this.mFillPaint);
                        }
                        f = f4;
                        f2 = f3;
                        i5 = i7;
                        canvas.drawPath(this.mPath, this.mFillPaint);
                    } else {
                        f = f4;
                        f2 = f3;
                        i5 = i7;
                    }
                    if (i == 2) {
                        drawPathRelativeTicks(canvas, f2 - 0.0f, f - 0.0f);
                    }
                    if (i == 3) {
                        drawPathCartesianTicks(canvas, f2 - 0.0f, f - 0.0f);
                    }
                    if (i == 6) {
                        drawPathScreenTicks(canvas, f2 - 0.0f, f - 0.0f, i4, i3);
                    }
                    canvas.drawPath(this.mPath, this.mFillPaint);
                }
                i7 = i5 + 1;
            }
            float[] fArr2 = this.mPoints;
            if (fArr2.length > 1) {
                canvas.drawCircle(fArr2[0], fArr2[1], 8.0f, this.mPaintKeyframes);
                float[] fArr3 = this.mPoints;
                canvas.drawCircle(fArr3[fArr3.length - 2], fArr3[fArr3.length - 1], 8.0f, this.mPaintKeyframes);
            }
        }

        public final void drawPathCartesian(Canvas canvas) {
            float[] fArr = this.mPoints;
            float f = fArr[0];
            float f2 = fArr[1];
            float f3 = fArr[fArr.length - 2];
            float f4 = fArr[fArr.length - 1];
            canvas.drawLine(Math.min(f, f3), Math.max(f2, f4), Math.max(f, f3), Math.max(f2, f4), this.mPaintGraph);
            canvas.drawLine(Math.min(f, f3), Math.min(f2, f4), Math.min(f, f3), Math.max(f2, f4), this.mPaintGraph);
        }

        public final void drawPathCartesianTicks(Canvas canvas, float f, float f2) {
            float[] fArr = this.mPoints;
            float f3 = fArr[0];
            float f4 = fArr[1];
            float f5 = fArr[fArr.length - 2];
            float f6 = fArr[fArr.length - 1];
            float min = Math.min(f3, f5);
            float max = Math.max(f4, f6);
            float min2 = f - Math.min(f3, f5);
            float max2 = Math.max(f4, f6) - f2;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("");
            outline25.append(((float) ((int) (((double) ((min2 * 100.0f) / Math.abs(f5 - f3))) + 0.5d))) / 100.0f);
            String sb = outline25.toString();
            getTextBounds(sb, this.mTextPaint);
            canvas.drawText(sb, ((min2 / 2.0f) - ((float) (this.mBounds.width() / 2))) + min, f2 - 20.0f, this.mTextPaint);
            canvas.drawLine(f, f2, Math.min(f3, f5), f2, this.mPaintGraph);
            StringBuilder outline252 = GeneratedOutlineSupport.outline25("");
            outline252.append(((float) ((int) (((double) ((max2 * 100.0f) / Math.abs(f6 - f4))) + 0.5d))) / 100.0f);
            String sb2 = outline252.toString();
            getTextBounds(sb2, this.mTextPaint);
            canvas.drawText(sb2, f + 5.0f, max - ((max2 / 2.0f) - ((float) (this.mBounds.height() / 2))), this.mTextPaint);
            canvas.drawLine(f, f2, f, Math.max(f4, f6), this.mPaintGraph);
        }

        public final void drawPathRelative(Canvas canvas) {
            float[] fArr = this.mPoints;
            canvas.drawLine(fArr[0], fArr[1], fArr[fArr.length - 2], fArr[fArr.length - 1], this.mPaintGraph);
        }

        public final void drawPathRelativeTicks(Canvas canvas, float f, float f2) {
            float[] fArr = this.mPoints;
            float f3 = fArr[0];
            float f4 = fArr[1];
            float f5 = fArr[fArr.length - 2];
            float f6 = fArr[fArr.length - 1];
            float hypot = (float) Math.hypot((double) (f3 - f5), (double) (f4 - f6));
            float f7 = f5 - f3;
            float f8 = f6 - f4;
            float f9 = (((f2 - f4) * f8) + ((f - f3) * f7)) / (hypot * hypot);
            float f10 = f3 + (f7 * f9);
            float f11 = f4 + (f9 * f8);
            Path path = new Path();
            path.moveTo(f, f2);
            path.lineTo(f10, f11);
            float hypot2 = (float) Math.hypot((double) (f10 - f), (double) (f11 - f2));
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("");
            outline25.append(((float) ((int) ((hypot2 * 100.0f) / hypot))) / 100.0f);
            String sb = outline25.toString();
            getTextBounds(sb, this.mTextPaint);
            canvas.drawTextOnPath(sb, path, (hypot2 / 2.0f) - ((float) (this.mBounds.width() / 2)), -20.0f, this.mTextPaint);
            canvas.drawLine(f, f2, f10, f11, this.mPaintGraph);
        }

        public final void drawPathScreenTicks(Canvas canvas, float f, float f2, int i, int i2) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("");
            outline25.append(((float) ((int) (((double) (((f - ((float) (i / 2))) * 100.0f) / ((float) (MotionLayout.this.getWidth() - i)))) + 0.5d))) / 100.0f);
            String sb = outline25.toString();
            getTextBounds(sb, this.mTextPaint);
            canvas.drawText(sb, ((f / 2.0f) - ((float) (this.mBounds.width() / 2))) + 0.0f, f2 - 20.0f, this.mTextPaint);
            canvas.drawLine(f, f2, Math.min(0.0f, 1.0f), f2, this.mPaintGraph);
            StringBuilder outline252 = GeneratedOutlineSupport.outline25("");
            outline252.append(((float) ((int) (((double) (((f2 - ((float) (i2 / 2))) * 100.0f) / ((float) (MotionLayout.this.getHeight() - i2)))) + 0.5d))) / 100.0f);
            String sb2 = outline252.toString();
            getTextBounds(sb2, this.mTextPaint);
            canvas.drawText(sb2, f + 5.0f, 0.0f - ((f2 / 2.0f) - ((float) (this.mBounds.height() / 2))), this.mTextPaint);
            canvas.drawLine(f, f2, f, Math.max(0.0f, 1.0f), this.mPaintGraph);
        }

        public void getTextBounds(String str, Paint paint) {
            paint.getTextBounds(str, 0, str.length(), this.mBounds);
        }
    }

    public class Model {
        public ConstraintSet mEnd = null;
        public int mEndId;
        public ConstraintWidgetContainer mLayoutEnd = new ConstraintWidgetContainer();
        public ConstraintWidgetContainer mLayoutStart = new ConstraintWidgetContainer();
        public ConstraintSet mStart = null;
        public int mStartId;

        public Model() {
        }

        public void build() {
            int[] iArr;
            SparseArray sparseArray;
            int i;
            String str;
            String str2;
            String str3;
            int i2;
            ConstraintSet constraintSet;
            Rect rect;
            Interpolator interpolator;
            int childCount = MotionLayout.this.getChildCount();
            MotionLayout.this.mFrameArrayList.clear();
            SparseArray sparseArray2 = new SparseArray();
            int[] iArr2 = new int[childCount];
            for (int i3 = 0; i3 < childCount; i3++) {
                View childAt = MotionLayout.this.getChildAt(i3);
                MotionController motionController = new MotionController(childAt);
                int id = childAt.getId();
                iArr2[i3] = id;
                sparseArray2.put(id, motionController);
                MotionLayout.this.mFrameArrayList.put(childAt, motionController);
            }
            int i4 = 0;
            while (i4 < childCount) {
                View childAt2 = MotionLayout.this.getChildAt(i4);
                MotionController motionController2 = MotionLayout.this.mFrameArrayList.get(childAt2);
                if (motionController2 == null) {
                    i = childCount;
                    sparseArray = sparseArray2;
                    iArr = iArr2;
                } else {
                    Interpolator interpolator2 = null;
                    if (this.mStart != null) {
                        ConstraintWidget widget = getWidget(this.mLayoutStart, childAt2);
                        if (widget != null) {
                            Rect access$2000 = MotionLayout.access$2000(MotionLayout.this, widget);
                            ConstraintSet constraintSet2 = this.mStart;
                            int width = MotionLayout.this.getWidth();
                            int height = MotionLayout.this.getHeight();
                            int i5 = constraintSet2.mRotate;
                            if (i5 != 0) {
                                i2 = i5;
                                constraintSet = constraintSet2;
                                sparseArray = sparseArray2;
                                rect = access$2000;
                                str = "MotionLayout";
                                iArr = iArr2;
                                str2 = "no widget for  ";
                                i = childCount;
                                str3 = " (";
                                motionController2.rotate(access$2000, motionController2.mTempRect, i2, width, height);
                            } else {
                                i = childCount;
                                sparseArray = sparseArray2;
                                iArr = iArr2;
                                i2 = i5;
                                constraintSet = constraintSet2;
                                rect = access$2000;
                                str = "MotionLayout";
                                str2 = "no widget for  ";
                                str3 = " (";
                            }
                            MotionPaths motionPaths = motionController2.mStartMotionPath;
                            motionPaths.time = 0.0f;
                            motionPaths.position = 0.0f;
                            motionController2.readView(motionPaths);
                            motionController2.mStartMotionPath.setBounds((float) rect.left, (float) rect.top, (float) rect.width(), (float) rect.height());
                            ConstraintSet.Constraint constraint = constraintSet.get(motionController2.mId);
                            motionController2.mStartMotionPath.applyParameters(constraint);
                            motionController2.mMotionStagger = constraint.motion.mMotionStagger;
                            motionController2.mStartPoint.setState(rect, constraintSet, i2, motionController2.mId);
                            motionController2.mTransformPivotTarget = constraint.transform.transformPivotTarget;
                            ConstraintSet.Motion motion = constraint.motion;
                            motionController2.mQuantizeMotionSteps = motion.mQuantizeMotionSteps;
                            motionController2.mQuantizeMotionPhase = motion.mQuantizeMotionPhase;
                            Context context = motionController2.mView.getContext();
                            ConstraintSet.Motion motion2 = constraint.motion;
                            int i6 = motion2.mQuantizeInterpolatorType;
                            String str4 = motion2.mQuantizeInterpolatorString;
                            int i7 = motion2.mQuantizeInterpolatorID;
                            if (i6 == -2) {
                                interpolator2 = AnimationUtils.loadInterpolator(context, i7);
                            } else if (i6 == -1) {
                                interpolator = 
                                /*  JADX ERROR: Method code generation error
                                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x013b: CONSTRUCTOR  (r6v14 'interpolator' android.view.animation.Interpolator) = 
                                      (wrap: androidx.constraintlayout.core.motion.utils.Easing : 0x0135: INVOKE  (r2v30 androidx.constraintlayout.core.motion.utils.Easing) = (r10v12 'str4' java.lang.String) type: STATIC call: androidx.constraintlayout.core.motion.utils.Easing.getInterpolator(java.lang.String):androidx.constraintlayout.core.motion.utils.Easing)
                                     call: androidx.constraintlayout.motion.widget.MotionController.1.<init>(androidx.constraintlayout.core.motion.utils.Easing):void type: CONSTRUCTOR in method: androidx.constraintlayout.motion.widget.MotionLayout.Model.build():void, file: classes.dex
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                    	at jadx.core.codegen.RegionGen.connectElseIf(RegionGen.java:176)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:153)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:157)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                    	at jadx.core.codegen.RegionGen.makeLoop(RegionGen.java:239)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:67)
                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.constraintlayout.motion.widget.MotionController, state: GENERATED_AND_UNLOADED
                                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                                    	... 41 more
                                    */
                                /*
                                // Method dump skipped, instructions count: 612
                                */
                                throw new UnsupportedOperationException("Method not decompiled: androidx.constraintlayout.motion.widget.MotionLayout.Model.build():void");
                            }

                            public final void computeStartEndSize(int i, int i2) {
                                int optimizationLevel = MotionLayout.this.getOptimizationLevel();
                                MotionLayout motionLayout = MotionLayout.this;
                                if (motionLayout.mCurrentState == motionLayout.getStartState()) {
                                    MotionLayout motionLayout2 = MotionLayout.this;
                                    ConstraintWidgetContainer constraintWidgetContainer = this.mLayoutEnd;
                                    ConstraintSet constraintSet = this.mEnd;
                                    motionLayout2.resolveSystem(constraintWidgetContainer, optimizationLevel, (constraintSet == null || constraintSet.mRotate == 0) ? i : i2, (constraintSet == null || constraintSet.mRotate == 0) ? i2 : i);
                                    ConstraintSet constraintSet2 = this.mStart;
                                    if (constraintSet2 != null) {
                                        MotionLayout motionLayout3 = MotionLayout.this;
                                        ConstraintWidgetContainer constraintWidgetContainer2 = this.mLayoutStart;
                                        int i3 = constraintSet2.mRotate;
                                        int i4 = i3 == 0 ? i : i2;
                                        if (i3 == 0) {
                                            i = i2;
                                        }
                                        motionLayout3.resolveSystem(constraintWidgetContainer2, optimizationLevel, i4, i);
                                        return;
                                    }
                                    return;
                                }
                                ConstraintSet constraintSet3 = this.mStart;
                                if (constraintSet3 != null) {
                                    MotionLayout motionLayout4 = MotionLayout.this;
                                    ConstraintWidgetContainer constraintWidgetContainer3 = this.mLayoutStart;
                                    int i5 = constraintSet3.mRotate;
                                    motionLayout4.resolveSystem(constraintWidgetContainer3, optimizationLevel, i5 == 0 ? i : i2, i5 == 0 ? i2 : i);
                                }
                                MotionLayout motionLayout5 = MotionLayout.this;
                                ConstraintWidgetContainer constraintWidgetContainer4 = this.mLayoutEnd;
                                ConstraintSet constraintSet4 = this.mEnd;
                                int i6 = (constraintSet4 == null || constraintSet4.mRotate == 0) ? i : i2;
                                if (constraintSet4 == null || constraintSet4.mRotate == 0) {
                                    i = i2;
                                }
                                motionLayout5.resolveSystem(constraintWidgetContainer4, optimizationLevel, i6, i);
                            }

                            public void copy(ConstraintWidgetContainer constraintWidgetContainer, ConstraintWidgetContainer constraintWidgetContainer2) {
                                ConstraintWidget constraintWidget;
                                ArrayList<ConstraintWidget> arrayList = constraintWidgetContainer.mChildren;
                                HashMap<ConstraintWidget, ConstraintWidget> hashMap = new HashMap<>();
                                hashMap.put(constraintWidgetContainer, constraintWidgetContainer2);
                                constraintWidgetContainer2.mChildren.clear();
                                constraintWidgetContainer2.copy(constraintWidgetContainer, hashMap);
                                Iterator<ConstraintWidget> it = arrayList.iterator();
                                while (it.hasNext()) {
                                    ConstraintWidget next = it.next();
                                    if (next instanceof Barrier) {
                                        constraintWidget = new Barrier();
                                    } else if (next instanceof Guideline) {
                                        constraintWidget = new Guideline();
                                    } else if (next instanceof Flow) {
                                        constraintWidget = new Flow();
                                    } else if (next instanceof Placeholder) {
                                        constraintWidget = new Placeholder();
                                    } else if (next instanceof Helper) {
                                        constraintWidget = new HelperWidget();
                                    } else {
                                        constraintWidget = new ConstraintWidget();
                                    }
                                    constraintWidgetContainer2.mChildren.add(constraintWidget);
                                    ConstraintWidget constraintWidget2 = constraintWidget.mParent;
                                    if (constraintWidget2 != null) {
                                        ((WidgetContainer) constraintWidget2).mChildren.remove(constraintWidget);
                                        constraintWidget.reset();
                                    }
                                    constraintWidget.mParent = constraintWidgetContainer2;
                                    hashMap.put(next, constraintWidget);
                                }
                                Iterator<ConstraintWidget> it2 = arrayList.iterator();
                                while (it2.hasNext()) {
                                    ConstraintWidget next2 = it2.next();
                                    hashMap.get(next2).copy(next2, hashMap);
                                }
                            }

                            public ConstraintWidget getWidget(ConstraintWidgetContainer constraintWidgetContainer, View view) {
                                if (constraintWidgetContainer.mCompanionWidget == view) {
                                    return constraintWidgetContainer;
                                }
                                ArrayList<ConstraintWidget> arrayList = constraintWidgetContainer.mChildren;
                                int size = arrayList.size();
                                for (int i = 0; i < size; i++) {
                                    ConstraintWidget constraintWidget = arrayList.get(i);
                                    if (constraintWidget.mCompanionWidget == view) {
                                        return constraintWidget;
                                    }
                                }
                                return null;
                            }

                            public void initFrom(ConstraintSet constraintSet, ConstraintSet constraintSet2) {
                                this.mStart = constraintSet;
                                this.mEnd = constraintSet2;
                                this.mLayoutStart = new ConstraintWidgetContainer();
                                this.mLayoutEnd = new ConstraintWidgetContainer();
                                ConstraintWidgetContainer constraintWidgetContainer = this.mLayoutStart;
                                MotionLayout motionLayout = MotionLayout.this;
                                boolean z = MotionLayout.IS_IN_EDIT_MODE;
                                constraintWidgetContainer.setMeasurer(motionLayout.mLayoutWidget.mMeasurer);
                                this.mLayoutEnd.setMeasurer(MotionLayout.this.mLayoutWidget.mMeasurer);
                                this.mLayoutStart.mChildren.clear();
                                this.mLayoutEnd.mChildren.clear();
                                copy(MotionLayout.this.mLayoutWidget, this.mLayoutStart);
                                copy(MotionLayout.this.mLayoutWidget, this.mLayoutEnd);
                                if (((double) MotionLayout.this.mTransitionLastPosition) > 0.5d) {
                                    if (constraintSet != null) {
                                        setupConstraintWidget(this.mLayoutStart, constraintSet);
                                    }
                                    setupConstraintWidget(this.mLayoutEnd, constraintSet2);
                                } else {
                                    setupConstraintWidget(this.mLayoutEnd, constraintSet2);
                                    if (constraintSet != null) {
                                        setupConstraintWidget(this.mLayoutStart, constraintSet);
                                    }
                                }
                                this.mLayoutStart.mIsRtl = MotionLayout.this.isRtl();
                                ConstraintWidgetContainer constraintWidgetContainer2 = this.mLayoutStart;
                                constraintWidgetContainer2.mBasicMeasureSolver.updateHierarchy(constraintWidgetContainer2);
                                this.mLayoutEnd.mIsRtl = MotionLayout.this.isRtl();
                                ConstraintWidgetContainer constraintWidgetContainer3 = this.mLayoutEnd;
                                constraintWidgetContainer3.mBasicMeasureSolver.updateHierarchy(constraintWidgetContainer3);
                                ViewGroup.LayoutParams layoutParams = MotionLayout.this.getLayoutParams();
                                if (layoutParams != null) {
                                    if (layoutParams.width == -2) {
                                        ConstraintWidgetContainer constraintWidgetContainer4 = this.mLayoutStart;
                                        ConstraintWidget.DimensionBehaviour dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                        constraintWidgetContainer4.setHorizontalDimensionBehaviour(dimensionBehaviour);
                                        this.mLayoutEnd.setHorizontalDimensionBehaviour(dimensionBehaviour);
                                    }
                                    if (layoutParams.height == -2) {
                                        ConstraintWidgetContainer constraintWidgetContainer5 = this.mLayoutStart;
                                        ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                                        constraintWidgetContainer5.setVerticalDimensionBehaviour(dimensionBehaviour2);
                                        this.mLayoutEnd.setVerticalDimensionBehaviour(dimensionBehaviour2);
                                    }
                                }
                            }

                            public void reEvaluateState() {
                                MotionLayout motionLayout = MotionLayout.this;
                                int i = motionLayout.mLastWidthMeasureSpec;
                                int i2 = motionLayout.mLastHeightMeasureSpec;
                                int mode = View.MeasureSpec.getMode(i);
                                int mode2 = View.MeasureSpec.getMode(i2);
                                MotionLayout motionLayout2 = MotionLayout.this;
                                motionLayout2.mWidthMeasureMode = mode;
                                motionLayout2.mHeightMeasureMode = mode2;
                                motionLayout2.getOptimizationLevel();
                                computeStartEndSize(i, i2);
                                int i3 = 0;
                                boolean z = true;
                                if (((MotionLayout.this.getParent() instanceof MotionLayout) && mode == 1073741824 && mode2 == 1073741824) ? false : true) {
                                    computeStartEndSize(i, i2);
                                    MotionLayout.this.mStartWrapWidth = this.mLayoutStart.getWidth();
                                    MotionLayout.this.mStartWrapHeight = this.mLayoutStart.getHeight();
                                    MotionLayout.this.mEndWrapWidth = this.mLayoutEnd.getWidth();
                                    MotionLayout.this.mEndWrapHeight = this.mLayoutEnd.getHeight();
                                    MotionLayout motionLayout3 = MotionLayout.this;
                                    motionLayout3.mMeasureDuringTransition = (motionLayout3.mStartWrapWidth == motionLayout3.mEndWrapWidth && motionLayout3.mStartWrapHeight == motionLayout3.mEndWrapHeight) ? false : true;
                                }
                                MotionLayout motionLayout4 = MotionLayout.this;
                                int i4 = motionLayout4.mStartWrapWidth;
                                int i5 = motionLayout4.mStartWrapHeight;
                                int i6 = motionLayout4.mWidthMeasureMode;
                                if (i6 == Integer.MIN_VALUE || i6 == 0) {
                                    i4 = (int) ((motionLayout4.mPostInterpolationPosition * ((float) (motionLayout4.mEndWrapWidth - i4))) + ((float) i4));
                                }
                                int i7 = motionLayout4.mHeightMeasureMode;
                                if (i7 == Integer.MIN_VALUE || i7 == 0) {
                                    i5 = (int) ((motionLayout4.mPostInterpolationPosition * ((float) (motionLayout4.mEndWrapHeight - i5))) + ((float) i5));
                                }
                                ConstraintWidgetContainer constraintWidgetContainer = this.mLayoutStart;
                                motionLayout4.resolveMeasuredDimension(i, i2, i4, i5, constraintWidgetContainer.mWidthMeasuredTooSmall || this.mLayoutEnd.mWidthMeasuredTooSmall, constraintWidgetContainer.mHeightMeasuredTooSmall || this.mLayoutEnd.mHeightMeasuredTooSmall);
                                MotionLayout motionLayout5 = MotionLayout.this;
                                int childCount = motionLayout5.getChildCount();
                                motionLayout5.mModel.build();
                                motionLayout5.mInTransition = true;
                                SparseArray sparseArray = new SparseArray();
                                for (int i8 = 0; i8 < childCount; i8++) {
                                    View childAt = motionLayout5.getChildAt(i8);
                                    sparseArray.put(childAt.getId(), motionLayout5.mFrameArrayList.get(childAt));
                                }
                                int width = motionLayout5.getWidth();
                                int height = motionLayout5.getHeight();
                                MotionScene.Transition transition = motionLayout5.mScene.mCurrentTransition;
                                int i9 = transition != null ? transition.mPathMotionArc : -1;
                                if (i9 != -1) {
                                    for (int i10 = 0; i10 < childCount; i10++) {
                                        MotionController motionController = motionLayout5.mFrameArrayList.get(motionLayout5.getChildAt(i10));
                                        if (motionController != null) {
                                            motionController.mPathMotionArc = i9;
                                        }
                                    }
                                }
                                SparseBooleanArray sparseBooleanArray = new SparseBooleanArray();
                                int[] iArr = new int[motionLayout5.mFrameArrayList.size()];
                                int i11 = 0;
                                for (int i12 = 0; i12 < childCount; i12++) {
                                    MotionController motionController2 = motionLayout5.mFrameArrayList.get(motionLayout5.getChildAt(i12));
                                    int i13 = motionController2.mStartMotionPath.mAnimateRelativeTo;
                                    if (i13 != -1) {
                                        sparseBooleanArray.put(i13, true);
                                        iArr[i11] = motionController2.mStartMotionPath.mAnimateRelativeTo;
                                        i11++;
                                    }
                                }
                                if (motionLayout5.mDecoratorsHelpers != null) {
                                    for (int i14 = 0; i14 < i11; i14++) {
                                        MotionController motionController3 = motionLayout5.mFrameArrayList.get(motionLayout5.findViewById(iArr[i14]));
                                        if (motionController3 != null) {
                                            motionLayout5.mScene.getKeyFrames(motionController3);
                                        }
                                    }
                                    Iterator<MotionHelper> it = motionLayout5.mDecoratorsHelpers.iterator();
                                    while (it.hasNext()) {
                                        it.next().onPreSetup(motionLayout5, motionLayout5.mFrameArrayList);
                                    }
                                    for (int i15 = 0; i15 < i11; i15++) {
                                        MotionController motionController4 = motionLayout5.mFrameArrayList.get(motionLayout5.findViewById(iArr[i15]));
                                        if (motionController4 != null) {
                                            motionController4.setup(width, height, motionLayout5.getNanoTime());
                                        }
                                    }
                                } else {
                                    for (int i16 = 0; i16 < i11; i16++) {
                                        MotionController motionController5 = motionLayout5.mFrameArrayList.get(motionLayout5.findViewById(iArr[i16]));
                                        if (motionController5 != null) {
                                            motionLayout5.mScene.getKeyFrames(motionController5);
                                            motionController5.setup(width, height, motionLayout5.getNanoTime());
                                        }
                                    }
                                }
                                for (int i17 = 0; i17 < childCount; i17++) {
                                    View childAt2 = motionLayout5.getChildAt(i17);
                                    MotionController motionController6 = motionLayout5.mFrameArrayList.get(childAt2);
                                    if (!sparseBooleanArray.get(childAt2.getId()) && motionController6 != null) {
                                        motionLayout5.mScene.getKeyFrames(motionController6);
                                        motionController6.setup(width, height, motionLayout5.getNanoTime());
                                    }
                                }
                                MotionScene.Transition transition2 = motionLayout5.mScene.mCurrentTransition;
                                float f = transition2 != null ? transition2.mStagger : 0.0f;
                                if (f != 0.0f) {
                                    boolean z2 = ((double) f) < 0.0d;
                                    float abs = Math.abs(f);
                                    float f2 = -3.4028235E38f;
                                    float f3 = Float.MAX_VALUE;
                                    int i18 = 0;
                                    float f4 = Float.MAX_VALUE;
                                    float f5 = -3.4028235E38f;
                                    while (true) {
                                        if (i18 >= childCount) {
                                            z = false;
                                            break;
                                        }
                                        MotionController motionController7 = motionLayout5.mFrameArrayList.get(motionLayout5.getChildAt(i18));
                                        if (!Float.isNaN(motionController7.mMotionStagger)) {
                                            break;
                                        }
                                        MotionPaths motionPaths = motionController7.mEndMotionPath;
                                        float f6 = motionPaths.x;
                                        float f7 = motionPaths.y;
                                        float f8 = z2 ? f7 - f6 : f7 + f6;
                                        f4 = Math.min(f4, f8);
                                        f5 = Math.max(f5, f8);
                                        i18++;
                                    }
                                    if (z) {
                                        for (int i19 = 0; i19 < childCount; i19++) {
                                            MotionController motionController8 = motionLayout5.mFrameArrayList.get(motionLayout5.getChildAt(i19));
                                            if (!Float.isNaN(motionController8.mMotionStagger)) {
                                                f3 = Math.min(f3, motionController8.mMotionStagger);
                                                f2 = Math.max(f2, motionController8.mMotionStagger);
                                            }
                                        }
                                        while (i3 < childCount) {
                                            MotionController motionController9 = motionLayout5.mFrameArrayList.get(motionLayout5.getChildAt(i3));
                                            if (!Float.isNaN(motionController9.mMotionStagger)) {
                                                motionController9.mStaggerScale = 1.0f / (1.0f - abs);
                                                if (z2) {
                                                    motionController9.mStaggerOffset = abs - (((f2 - motionController9.mMotionStagger) / (f2 - f3)) * abs);
                                                } else {
                                                    motionController9.mStaggerOffset = abs - (((motionController9.mMotionStagger - f3) * abs) / (f2 - f3));
                                                }
                                            }
                                            i3++;
                                        }
                                        return;
                                    }
                                    while (i3 < childCount) {
                                        MotionController motionController10 = motionLayout5.mFrameArrayList.get(motionLayout5.getChildAt(i3));
                                        MotionPaths motionPaths2 = motionController10.mEndMotionPath;
                                        float f9 = motionPaths2.x;
                                        float f10 = motionPaths2.y;
                                        float f11 = z2 ? f10 - f9 : f10 + f9;
                                        motionController10.mStaggerScale = 1.0f / (1.0f - abs);
                                        motionController10.mStaggerOffset = abs - (((f11 - f4) * abs) / (f5 - f4));
                                        i3++;
                                    }
                                }
                            }

                            public final void setupConstraintWidget(ConstraintWidgetContainer constraintWidgetContainer, ConstraintSet constraintSet) {
                                ConstraintSet.Constraint constraint;
                                ConstraintSet.Constraint constraint2;
                                SparseArray<ConstraintWidget> sparseArray = new SparseArray<>();
                                Constraints.LayoutParams layoutParams = new Constraints.LayoutParams(-2, -2);
                                sparseArray.clear();
                                sparseArray.put(0, constraintWidgetContainer);
                                sparseArray.put(MotionLayout.this.getId(), constraintWidgetContainer);
                                if (!(constraintSet == null || constraintSet.mRotate == 0)) {
                                    MotionLayout motionLayout = MotionLayout.this;
                                    ConstraintWidgetContainer constraintWidgetContainer2 = this.mLayoutEnd;
                                    int optimizationLevel = motionLayout.getOptimizationLevel();
                                    int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(MotionLayout.this.getHeight(), 1073741824);
                                    int makeMeasureSpec2 = View.MeasureSpec.makeMeasureSpec(MotionLayout.this.getWidth(), 1073741824);
                                    boolean z = MotionLayout.IS_IN_EDIT_MODE;
                                    motionLayout.resolveSystem(constraintWidgetContainer2, optimizationLevel, makeMeasureSpec, makeMeasureSpec2);
                                }
                                Iterator<ConstraintWidget> it = constraintWidgetContainer.mChildren.iterator();
                                while (it.hasNext()) {
                                    ConstraintWidget next = it.next();
                                    sparseArray.put(((View) next.mCompanionWidget).getId(), next);
                                }
                                Iterator<ConstraintWidget> it2 = constraintWidgetContainer.mChildren.iterator();
                                while (it2.hasNext()) {
                                    ConstraintWidget next2 = it2.next();
                                    View view = (View) next2.mCompanionWidget;
                                    int id = view.getId();
                                    if (constraintSet.mConstraints.containsKey(Integer.valueOf(id)) && (constraint2 = constraintSet.mConstraints.get(Integer.valueOf(id))) != null) {
                                        constraint2.applyTo(layoutParams);
                                    }
                                    next2.setWidth(constraintSet.get(view.getId()).layout.mWidth);
                                    next2.setHeight(constraintSet.get(view.getId()).layout.mHeight);
                                    if (view instanceof ConstraintHelper) {
                                        ConstraintHelper constraintHelper = (ConstraintHelper) view;
                                        int id2 = constraintHelper.getId();
                                        if (constraintSet.mConstraints.containsKey(Integer.valueOf(id2)) && (constraint = constraintSet.mConstraints.get(Integer.valueOf(id2))) != null && (next2 instanceof HelperWidget)) {
                                            constraintHelper.loadParameters(constraint, (HelperWidget) next2, layoutParams, sparseArray);
                                        }
                                        if (view instanceof androidx.constraintlayout.widget.Barrier) {
                                            ((androidx.constraintlayout.widget.Barrier) view).validateParams();
                                        }
                                    }
                                    layoutParams.resolveLayoutDirection(MotionLayout.this.getLayoutDirection());
                                    MotionLayout motionLayout2 = MotionLayout.this;
                                    boolean z2 = MotionLayout.IS_IN_EDIT_MODE;
                                    motionLayout2.applyConstraintsFromLayoutParams(false, view, next2, layoutParams, sparseArray);
                                    if (constraintSet.get(view.getId()).propertySet.mVisibilityMode == 1) {
                                        next2.mVisibility = view.getVisibility();
                                    } else {
                                        next2.mVisibility = constraintSet.get(view.getId()).propertySet.visibility;
                                    }
                                }
                                Iterator<ConstraintWidget> it3 = constraintWidgetContainer.mChildren.iterator();
                                while (it3.hasNext()) {
                                    ConstraintWidget next3 = it3.next();
                                    if (next3 instanceof VirtualLayout) {
                                        Helper helper = (Helper) next3;
                                        ((ConstraintHelper) next3.mCompanionWidget).updatePreLayout(constraintWidgetContainer, helper, sparseArray);
                                        ((VirtualLayout) helper).captureWidgets();
                                    }
                                }
                            }
                        }

                        public interface MotionTracker {
                        }

                        public static class MyTracker implements MotionTracker {
                            public static MyTracker me = new MyTracker();
                            public VelocityTracker tracker;

                            public void computeCurrentVelocity(int i) {
                                VelocityTracker velocityTracker = this.tracker;
                                if (velocityTracker != null) {
                                    velocityTracker.computeCurrentVelocity(i);
                                }
                            }

                            public float getXVelocity() {
                                VelocityTracker velocityTracker = this.tracker;
                                if (velocityTracker != null) {
                                    return velocityTracker.getXVelocity();
                                }
                                return 0.0f;
                            }

                            public float getYVelocity() {
                                VelocityTracker velocityTracker = this.tracker;
                                if (velocityTracker != null) {
                                    return velocityTracker.getYVelocity();
                                }
                                return 0.0f;
                            }
                        }

                        public class StateCache {
                            public int endState = -1;
                            public float mProgress = Float.NaN;
                            public float mVelocity = Float.NaN;
                            public int startState = -1;

                            public StateCache() {
                            }

                            public void apply() {
                                int i = this.startState;
                                if (!(i == -1 && this.endState == -1)) {
                                    if (i == -1) {
                                        MotionLayout.this.transitionToState(this.endState);
                                    } else {
                                        int i2 = this.endState;
                                        if (i2 == -1) {
                                            MotionLayout.this.setState(i, -1, -1);
                                        } else {
                                            MotionLayout.this.setTransition(i, i2);
                                        }
                                    }
                                    MotionLayout.this.setState(TransitionState.SETUP);
                                }
                                if (!Float.isNaN(this.mVelocity)) {
                                    MotionLayout motionLayout = MotionLayout.this;
                                    float f = this.mProgress;
                                    float f2 = this.mVelocity;
                                    if (!motionLayout.isAttachedToWindow()) {
                                        if (motionLayout.mStateCache == null) {
                                            motionLayout.mStateCache = new StateCache();
                                        }
                                        StateCache stateCache = motionLayout.mStateCache;
                                        stateCache.mProgress = f;
                                        stateCache.mVelocity = f2;
                                    } else {
                                        motionLayout.setProgress(f);
                                        motionLayout.setState(TransitionState.MOVING);
                                        motionLayout.mLastVelocity = f2;
                                        motionLayout.animateTo(1.0f);
                                    }
                                    this.mProgress = Float.NaN;
                                    this.mVelocity = Float.NaN;
                                    this.startState = -1;
                                    this.endState = -1;
                                } else if (!Float.isNaN(this.mProgress)) {
                                    MotionLayout.this.setProgress(this.mProgress);
                                }
                            }
                        }

                        public interface TransitionListener {
                            void onTransitionChange(MotionLayout motionLayout, int i, int i2, float f);

                            void onTransitionCompleted(MotionLayout motionLayout, int i);
                        }

                        public enum TransitionState {
                            UNDEFINED,
                            SETUP,
                            MOVING,
                            FINISHED
                        }

                        public MotionLayout(Context context) {
                            super(context);
                            init(null);
                        }

                        public static Rect access$2000(MotionLayout motionLayout, ConstraintWidget constraintWidget) {
                            motionLayout.mTempRect.top = constraintWidget.getY();
                            motionLayout.mTempRect.left = constraintWidget.getX();
                            Rect rect = motionLayout.mTempRect;
                            int width = constraintWidget.getWidth();
                            Rect rect2 = motionLayout.mTempRect;
                            rect.right = width + rect2.left;
                            int height = constraintWidget.getHeight();
                            Rect rect3 = motionLayout.mTempRect;
                            rect2.bottom = height + rect3.top;
                            return rect3;
                        }

                        public void animateTo(float f) {
                            MotionScene motionScene = this.mScene;
                            if (motionScene != null) {
                                float f2 = this.mTransitionLastPosition;
                                float f3 = this.mTransitionPosition;
                                if (f2 != f3 && this.mTransitionInstantly) {
                                    this.mTransitionLastPosition = f3;
                                }
                                float f4 = this.mTransitionLastPosition;
                                if (f4 != f) {
                                    this.mTemporalInterpolator = false;
                                    this.mTransitionGoalPosition = f;
                                    this.mTransitionDuration = ((float) motionScene.getDuration()) / 1000.0f;
                                    setProgress(this.mTransitionGoalPosition);
                                    this.mInterpolator = null;
                                    this.mProgressInterpolator = this.mScene.getInterpolator();
                                    this.mTransitionInstantly = false;
                                    this.mAnimationStartTime = getNanoTime();
                                    this.mInTransition = true;
                                    this.mTransitionPosition = f4;
                                    this.mTransitionLastPosition = f4;
                                    invalidate();
                                }
                            }
                        }

                        /* JADX WARNING: Removed duplicated region for block: B:116:0x0314  */
                        /* JADX WARNING: Removed duplicated region for block: B:127:0x0340  */
                        /* JADX WARNING: Removed duplicated region for block: B:131:0x035a  */
                        /* JADX WARNING: Removed duplicated region for block: B:134:0x036a  */
                        /* JADX WARNING: Removed duplicated region for block: B:137:0x0375  */
                        /* JADX WARNING: Removed duplicated region for block: B:140:0x0394  */
                        /* JADX WARNING: Removed duplicated region for block: B:141:0x039e  */
                        /* JADX WARNING: Removed duplicated region for block: B:144:0x03ab  */
                        /* JADX WARNING: Removed duplicated region for block: B:145:0x03b7  */
                        /* JADX WARNING: Removed duplicated region for block: B:181:0x0525  */
                        /* JADX WARNING: Removed duplicated region for block: B:213:? A[ORIG_RETURN, RETURN, SYNTHETIC] */
                        @Override // androidx.constraintlayout.widget.ConstraintLayout
                        public void dispatchDraw(Canvas canvas) {
                            ArrayList<MotionHelper> arrayList;
                            Iterator<MotionController> it;
                            int i;
                            int i2;
                            int i3;
                            int i4;
                            int i5;
                            Easing easing;
                            Iterator<MotionPaths> it2;
                            double d;
                            CurveFit curveFit;
                            ViewOscillator viewOscillator;
                            String str;
                            ViewTransitionController viewTransitionController;
                            ArrayList<ViewTransition.Animate> arrayList2;
                            MotionLayout motionLayout = this;
                            ArrayList<MotionHelper> arrayList3 = motionLayout.mDecoratorsHelpers;
                            if (arrayList3 != null) {
                                Iterator<MotionHelper> it3 = arrayList3.iterator();
                                while (it3.hasNext()) {
                                    it3.next().onPreDraw();
                                }
                            }
                            char c = 0;
                            motionLayout.evaluate(false);
                            MotionScene motionScene = motionLayout.mScene;
                            if (!(motionScene == null || (viewTransitionController = motionScene.mViewTransitionController) == null || (arrayList2 = viewTransitionController.animations) == null)) {
                                Iterator<ViewTransition.Animate> it4 = arrayList2.iterator();
                                while (it4.hasNext()) {
                                    it4.next().mutate();
                                }
                                viewTransitionController.animations.removeAll(viewTransitionController.removeList);
                                viewTransitionController.removeList.clear();
                                if (viewTransitionController.animations.isEmpty()) {
                                    viewTransitionController.animations = null;
                                }
                            }
                            super.dispatchDraw(canvas);
                            if (motionLayout.mScene != null) {
                                if ((motionLayout.mDebugPath & 1) == 1 && !isInEditMode()) {
                                    motionLayout.mFrames++;
                                    long nanoTime = getNanoTime();
                                    long j = motionLayout.mLastDrawTime;
                                    if (j != -1) {
                                        long j2 = nanoTime - j;
                                        if (j2 > 200000000) {
                                            motionLayout.mLastFps = ((float) ((int) ((((float) motionLayout.mFrames) / (((float) j2) * 1.0E-9f)) * 100.0f))) / 100.0f;
                                            motionLayout.mFrames = 0;
                                            motionLayout.mLastDrawTime = nanoTime;
                                        }
                                    } else {
                                        motionLayout.mLastDrawTime = nanoTime;
                                    }
                                    Paint paint = new Paint();
                                    paint.setTextSize(42.0f);
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25(motionLayout.mLastFps + " fps " + AppCompatDelegateImpl.Api17Impl.getState(motionLayout, motionLayout.mBeginState) + " -> ");
                                    outline25.append(AppCompatDelegateImpl.Api17Impl.getState(motionLayout, motionLayout.mEndState));
                                    outline25.append(" (progress: ");
                                    outline25.append(((float) ((int) (getProgress() * 1000.0f))) / 10.0f);
                                    outline25.append(" ) state=");
                                    int i6 = motionLayout.mCurrentState;
                                    if (i6 == -1) {
                                        str = "undefined";
                                    } else {
                                        str = AppCompatDelegateImpl.Api17Impl.getState(motionLayout, i6);
                                    }
                                    outline25.append(str);
                                    String sb = outline25.toString();
                                    paint.setColor(-16777216);
                                    canvas.drawText(sb, 11.0f, (float) (getHeight() - 29), paint);
                                    paint.setColor(-7864184);
                                    canvas.drawText(sb, 10.0f, (float) (getHeight() - 30), paint);
                                }
                                if (motionLayout.mDebugPath > 1) {
                                    if (motionLayout.mDevModeDraw == null) {
                                        motionLayout.mDevModeDraw = new DevModeDraw();
                                    }
                                    DevModeDraw devModeDraw = motionLayout.mDevModeDraw;
                                    HashMap<View, MotionController> hashMap = motionLayout.mFrameArrayList;
                                    int duration = motionLayout.mScene.getDuration();
                                    int i7 = motionLayout.mDebugPath;
                                    Objects.requireNonNull(devModeDraw);
                                    if (hashMap != null) {
                                        if (hashMap.size() != 0) {
                                            canvas.save();
                                            if (!MotionLayout.this.isInEditMode() && (i7 & 1) == 2) {
                                                String str2 = MotionLayout.this.getContext().getResources().getResourceName(MotionLayout.this.mEndState) + ":" + MotionLayout.this.getProgress();
                                                canvas.drawText(str2, 10.0f, (float) (MotionLayout.this.getHeight() - 30), devModeDraw.mTextPaint);
                                                canvas.drawText(str2, 11.0f, (float) (MotionLayout.this.getHeight() - 29), devModeDraw.mPaint);
                                            }
                                            Iterator<MotionController> it5 = hashMap.values().iterator();
                                            Canvas canvas2 = canvas;
                                            while (it5.hasNext()) {
                                                MotionController next = it5.next();
                                                int i8 = next.mStartMotionPath.mDrawPath;
                                                Iterator<MotionPaths> it6 = next.mMotionPaths.iterator();
                                                while (it6.hasNext()) {
                                                    i8 = Math.max(i8, it6.next().mDrawPath);
                                                }
                                                int max = Math.max(i8, next.mEndMotionPath.mDrawPath);
                                                if (i7 > 0 && max == 0) {
                                                    max = 1;
                                                }
                                                if (max != 0) {
                                                    float[] fArr = devModeDraw.mKeyFramePoints;
                                                    int[] iArr = devModeDraw.mPathMode;
                                                    if (fArr != null) {
                                                        double[] timePoints = next.mSpline[c].getTimePoints();
                                                        if (iArr != null) {
                                                            Iterator<MotionPaths> it7 = next.mMotionPaths.iterator();
                                                            int i9 = 0;
                                                            while (it7.hasNext()) {
                                                                iArr[i9] = it7.next().mMode;
                                                                i9++;
                                                            }
                                                        }
                                                        int i10 = 0;
                                                        int i11 = 0;
                                                        while (i10 < timePoints.length) {
                                                            next.mSpline[c].getPos(timePoints[i10], next.mInterpolateData);
                                                            next.mStartMotionPath.getCenter(timePoints[i10], next.mInterpolateVariables, next.mInterpolateData, fArr, i11);
                                                            i11 += 2;
                                                            i10++;
                                                            timePoints = timePoints;
                                                            it5 = it5;
                                                            c = 0;
                                                        }
                                                        it = it5;
                                                        i = i11 / 2;
                                                    } else {
                                                        it = it5;
                                                        i = 0;
                                                    }
                                                    devModeDraw.mKeyFrameCount = i;
                                                    if (max >= 1) {
                                                        int i12 = duration / 16;
                                                        float[] fArr2 = devModeDraw.mPoints;
                                                        if (fArr2 == null || fArr2.length != i12 * 2) {
                                                            devModeDraw.mPoints = new float[(i12 * 2)];
                                                            devModeDraw.mPath = new Path();
                                                        }
                                                        float f = (float) devModeDraw.mShadowTranslate;
                                                        canvas2.translate(f, f);
                                                        devModeDraw.mPaint.setColor(1996488704);
                                                        devModeDraw.mFillPaint.setColor(1996488704);
                                                        devModeDraw.mPaintKeyframes.setColor(1996488704);
                                                        devModeDraw.mPaintGraph.setColor(1996488704);
                                                        float[] fArr3 = devModeDraw.mPoints;
                                                        float f2 = 1.0f;
                                                        float f3 = 1.0f / ((float) (i12 - 1));
                                                        HashMap<String, ViewSpline> hashMap2 = next.mAttributesMap;
                                                        ViewSpline viewSpline = hashMap2 == null ? null : hashMap2.get("translationX");
                                                        HashMap<String, ViewSpline> hashMap3 = next.mAttributesMap;
                                                        ViewSpline viewSpline2 = hashMap3 == null ? null : hashMap3.get("translationY");
                                                        HashMap<String, ViewOscillator> hashMap4 = next.mCycleMap;
                                                        ViewOscillator viewOscillator2 = hashMap4 == null ? null : hashMap4.get("translationX");
                                                        HashMap<String, ViewOscillator> hashMap5 = next.mCycleMap;
                                                        ViewOscillator viewOscillator3 = hashMap5 == null ? null : hashMap5.get("translationY");
                                                        int i13 = 0;
                                                        while (i13 < i12) {
                                                            float f4 = ((float) i13) * f3;
                                                            float f5 = next.mStaggerScale;
                                                            if (f5 != f2) {
                                                                float f6 = next.mStaggerOffset;
                                                                if (f4 < f6) {
                                                                    f4 = 0.0f;
                                                                }
                                                                if (f4 > f6) {
                                                                    i5 = duration;
                                                                    i4 = i7;
                                                                    if (((double) f4) < 1.0d) {
                                                                        f4 = Math.min((f4 - f6) * f5, 1.0f);
                                                                    }
                                                                    double d2 = (double) f4;
                                                                    easing = next.mStartMotionPath.mKeyFrameEasing;
                                                                    it2 = next.mMotionPaths.iterator();
                                                                    float f7 = Float.NaN;
                                                                    float f8 = 0.0f;
                                                                    while (it2.hasNext()) {
                                                                        MotionPaths next2 = it2.next();
                                                                        Easing easing2 = next2.mKeyFrameEasing;
                                                                        if (easing2 != null) {
                                                                            float f9 = next2.time;
                                                                            if (f9 < f4) {
                                                                                f8 = f9;
                                                                                easing = easing2;
                                                                            } else if (Float.isNaN(f7)) {
                                                                                f7 = next2.time;
                                                                            }
                                                                        }
                                                                        d2 = d2;
                                                                    }
                                                                    if (easing == null) {
                                                                        if (Float.isNaN(f7)) {
                                                                            f7 = 1.0f;
                                                                        }
                                                                        float f10 = f7 - f8;
                                                                        d = (double) ((((float) easing.get((double) ((f4 - f8) / f10))) * f10) + f8);
                                                                    } else {
                                                                        d = d2;
                                                                    }
                                                                    next.mSpline[0].getPos(d, next.mInterpolateData);
                                                                    curveFit = next.mArcSpline;
                                                                    if (curveFit == null) {
                                                                        double[] dArr = next.mInterpolateData;
                                                                        viewOscillator = viewOscillator2;
                                                                        if (dArr.length > 0) {
                                                                            curveFit.getPos(d, dArr);
                                                                        }
                                                                    } else {
                                                                        viewOscillator = viewOscillator2;
                                                                    }
                                                                    int i14 = i13 * 2;
                                                                    next.mStartMotionPath.getCenter(d, next.mInterpolateVariables, next.mInterpolateData, fArr3, i14);
                                                                    if (viewOscillator == null) {
                                                                        fArr3[i14] = viewOscillator.get(f4) + fArr3[i14];
                                                                    } else if (viewSpline != null) {
                                                                        fArr3[i14] = viewSpline.get(f4) + fArr3[i14];
                                                                    }
                                                                    if (viewOscillator3 == null) {
                                                                        int i15 = i14 + 1;
                                                                        fArr3[i15] = viewOscillator3.get(f4) + fArr3[i15];
                                                                    } else if (viewSpline2 != null) {
                                                                        int i16 = i14 + 1;
                                                                        fArr3[i16] = viewSpline2.get(f4) + fArr3[i16];
                                                                    }
                                                                    i13++;
                                                                    f2 = 1.0f;
                                                                    viewOscillator2 = viewOscillator;
                                                                    viewSpline2 = viewSpline2;
                                                                    viewOscillator3 = viewOscillator3;
                                                                    viewSpline = viewSpline;
                                                                    i12 = i12;
                                                                    f3 = f3;
                                                                    duration = i5;
                                                                    i7 = i4;
                                                                }
                                                            }
                                                            i5 = duration;
                                                            i4 = i7;
                                                            double d22 = (double) f4;
                                                            easing = next.mStartMotionPath.mKeyFrameEasing;
                                                            it2 = next.mMotionPaths.iterator();
                                                            float f72 = Float.NaN;
                                                            float f82 = 0.0f;
                                                            while (it2.hasNext()) {
                                                            }
                                                            if (easing == null) {
                                                            }
                                                            next.mSpline[0].getPos(d, next.mInterpolateData);
                                                            curveFit = next.mArcSpline;
                                                            if (curveFit == null) {
                                                            }
                                                            int i142 = i13 * 2;
                                                            next.mStartMotionPath.getCenter(d, next.mInterpolateVariables, next.mInterpolateData, fArr3, i142);
                                                            if (viewOscillator == null) {
                                                            }
                                                            if (viewOscillator3 == null) {
                                                            }
                                                            i13++;
                                                            f2 = 1.0f;
                                                            viewOscillator2 = viewOscillator;
                                                            viewSpline2 = viewSpline2;
                                                            viewOscillator3 = viewOscillator3;
                                                            viewSpline = viewSpline;
                                                            i12 = i12;
                                                            f3 = f3;
                                                            duration = i5;
                                                            i7 = i4;
                                                        }
                                                        i3 = duration;
                                                        i2 = i7;
                                                        devModeDraw.drawAll(canvas, max, devModeDraw.mKeyFrameCount, next);
                                                        devModeDraw.mPaint.setColor(-21965);
                                                        devModeDraw.mPaintKeyframes.setColor(-2067046);
                                                        devModeDraw.mFillPaint.setColor(-2067046);
                                                        devModeDraw.mPaintGraph.setColor(-13391360);
                                                        float f11 = (float) (-devModeDraw.mShadowTranslate);
                                                        canvas.translate(f11, f11);
                                                        devModeDraw.drawAll(canvas, max, devModeDraw.mKeyFrameCount, next);
                                                        if (max == 5) {
                                                            devModeDraw.mPath.reset();
                                                            for (int i17 = 0; i17 <= 50; i17++) {
                                                                float[] fArr4 = devModeDraw.mRectangle;
                                                                next.mSpline[0].getPos((double) next.getAdjustedPosition(((float) i17) / ((float) 50), null), next.mInterpolateData);
                                                                MotionPaths motionPaths = next.mStartMotionPath;
                                                                int[] iArr2 = next.mInterpolateVariables;
                                                                double[] dArr2 = next.mInterpolateData;
                                                                float f12 = motionPaths.x;
                                                                float f13 = motionPaths.y;
                                                                float f14 = motionPaths.width;
                                                                float f15 = motionPaths.height;
                                                                for (int i18 = 0; i18 < iArr2.length; i18++) {
                                                                    float f16 = (float) dArr2[i18];
                                                                    int i19 = iArr2[i18];
                                                                    if (i19 == 1) {
                                                                        f12 = f16;
                                                                    } else if (i19 == 2) {
                                                                        f13 = f16;
                                                                    } else if (i19 == 3) {
                                                                        f14 = f16;
                                                                    } else if (i19 == 4) {
                                                                        f15 = f16;
                                                                    }
                                                                }
                                                                if (motionPaths.mRelativeToController != null) {
                                                                    double d3 = (double) 0.0f;
                                                                    double d4 = (double) f12;
                                                                    double d5 = (double) f13;
                                                                    f12 = (float) (((Math.sin(d5) * d4) + d3) - ((double) (f14 / 2.0f)));
                                                                    f13 = (float) ((d3 - (Math.cos(d5) * d4)) - ((double) (f15 / 2.0f)));
                                                                }
                                                                float f17 = f14 + f12;
                                                                float f18 = f15 + f13;
                                                                Float.isNaN(Float.NaN);
                                                                Float.isNaN(Float.NaN);
                                                                float f19 = f12 + 0.0f;
                                                                float f20 = f13 + 0.0f;
                                                                float f21 = f17 + 0.0f;
                                                                float f22 = f18 + 0.0f;
                                                                fArr4[0] = f19;
                                                                fArr4[1] = f20;
                                                                fArr4[2] = f21;
                                                                fArr4[3] = f20;
                                                                fArr4[4] = f21;
                                                                fArr4[5] = f22;
                                                                fArr4[6] = f19;
                                                                fArr4[7] = f22;
                                                                Path path = devModeDraw.mPath;
                                                                float[] fArr5 = devModeDraw.mRectangle;
                                                                path.moveTo(fArr5[0], fArr5[1]);
                                                                Path path2 = devModeDraw.mPath;
                                                                float[] fArr6 = devModeDraw.mRectangle;
                                                                path2.lineTo(fArr6[2], fArr6[3]);
                                                                Path path3 = devModeDraw.mPath;
                                                                float[] fArr7 = devModeDraw.mRectangle;
                                                                path3.lineTo(fArr7[4], fArr7[5]);
                                                                Path path4 = devModeDraw.mPath;
                                                                float[] fArr8 = devModeDraw.mRectangle;
                                                                path4.lineTo(fArr8[6], fArr8[7]);
                                                                devModeDraw.mPath.close();
                                                            }
                                                            devModeDraw.mPaint.setColor(1140850688);
                                                            canvas.translate(2.0f, 2.0f);
                                                            canvas.drawPath(devModeDraw.mPath, devModeDraw.mPaint);
                                                            canvas.translate(-2.0f, -2.0f);
                                                            devModeDraw.mPaint.setColor(-65536);
                                                            canvas.drawPath(devModeDraw.mPath, devModeDraw.mPaint);
                                                        }
                                                        canvas2 = canvas;
                                                    } else {
                                                        i3 = duration;
                                                        i2 = i7;
                                                    }
                                                    c = 0;
                                                    it5 = it;
                                                    duration = i3;
                                                    i7 = i2;
                                                }
                                            }
                                            canvas.restore();
                                        }
                                        arrayList = motionLayout.mDecoratorsHelpers;
                                        if (arrayList == null) {
                                            Iterator<MotionHelper> it8 = arrayList.iterator();
                                            while (it8.hasNext()) {
                                                it8.next().onPostDraw();
                                            }
                                            return;
                                        }
                                        return;
                                    }
                                }
                                motionLayout = this;
                                arrayList = motionLayout.mDecoratorsHelpers;
                                if (arrayList == null) {
                                }
                            }
                        }

                        public void endTrigger(boolean z) {
                            int childCount = getChildCount();
                            for (int i = 0; i < childCount; i++) {
                                MotionController motionController = this.mFrameArrayList.get(getChildAt(i));
                                if (motionController != null) {
                                    "button".equals(AppCompatDelegateImpl.Api17Impl.getName(motionController.mView));
                                }
                            }
                        }

                        /* JADX WARNING: Removed duplicated region for block: B:115:0x01c4  */
                        /* JADX WARNING: Removed duplicated region for block: B:130:0x020d  */
                        /* JADX WARNING: Removed duplicated region for block: B:70:0x0117  */
                        /* JADX WARNING: Removed duplicated region for block: B:72:0x011e A[ADDED_TO_REGION] */
                        /* JADX WARNING: Removed duplicated region for block: B:87:0x0155  */
                        /* JADX WARNING: Removed duplicated region for block: B:88:0x0157  */
                        /* JADX WARNING: Removed duplicated region for block: B:91:0x015f  */
                        /* JADX WARNING: Removed duplicated region for block: B:94:0x0176  */
                        /* JADX WARNING: Removed duplicated region for block: B:99:0x019e  */
                        public void evaluate(boolean z) {
                            boolean z2;
                            char c;
                            int childCount;
                            Interpolator interpolator;
                            int i;
                            int i2;
                            int i3;
                            if (this.mTransitionLastTime == -1) {
                                this.mTransitionLastTime = getNanoTime();
                            }
                            float f = this.mTransitionLastPosition;
                            if (f > 0.0f && f < 1.0f) {
                                this.mCurrentState = -1;
                            }
                            boolean z3 = true;
                            boolean z4 = false;
                            if (this.mKeepAnimating || (this.mInTransition && (z || this.mTransitionGoalPosition != f))) {
                                float signum = Math.signum(this.mTransitionGoalPosition - f);
                                long nanoTime = getNanoTime();
                                Interpolator interpolator2 = this.mInterpolator;
                                float f2 = !(interpolator2 instanceof MotionInterpolator) ? ((((float) (nanoTime - this.mTransitionLastTime)) * signum) * 1.0E-9f) / this.mTransitionDuration : 0.0f;
                                float f3 = this.mTransitionLastPosition + f2;
                                if (this.mTransitionInstantly) {
                                    f3 = this.mTransitionGoalPosition;
                                }
                                int i4 = (signum > 0.0f ? 1 : (signum == 0.0f ? 0 : -1));
                                if ((i4 <= 0 || f3 < this.mTransitionGoalPosition) && (signum > 0.0f || f3 > this.mTransitionGoalPosition)) {
                                    z2 = false;
                                } else {
                                    f3 = this.mTransitionGoalPosition;
                                    this.mInTransition = false;
                                    z2 = true;
                                }
                                this.mTransitionLastPosition = f3;
                                this.mTransitionPosition = f3;
                                this.mTransitionLastTime = nanoTime;
                                if (interpolator2 == null || z2) {
                                    this.mLastVelocity = f2;
                                } else if (this.mTemporalInterpolator) {
                                    float interpolation = interpolator2.getInterpolation(((float) (nanoTime - this.mAnimationStartTime)) * 1.0E-9f);
                                    Interpolator interpolator3 = this.mInterpolator;
                                    StopLogic stopLogic = this.mStopLogic;
                                    c = interpolator3 == stopLogic ? stopLogic.mEngine.isStopped() ? (char) 2 : 1 : 0;
                                    this.mTransitionLastPosition = interpolation;
                                    this.mTransitionLastTime = nanoTime;
                                    Interpolator interpolator4 = this.mInterpolator;
                                    if (interpolator4 instanceof MotionInterpolator) {
                                        float velocity = ((MotionInterpolator) interpolator4).getVelocity();
                                        this.mLastVelocity = velocity;
                                        if (Math.abs(velocity) * this.mTransitionDuration <= 1.0E-5f && c == 2) {
                                            this.mInTransition = false;
                                        }
                                        if (velocity > 0.0f && interpolation >= 1.0f) {
                                            this.mTransitionLastPosition = 1.0f;
                                            this.mInTransition = false;
                                            interpolation = 1.0f;
                                        }
                                        if (velocity < 0.0f && interpolation <= 0.0f) {
                                            this.mTransitionLastPosition = 0.0f;
                                            this.mInTransition = false;
                                            f3 = 0.0f;
                                            if (Math.abs(this.mLastVelocity) > 1.0E-5f) {
                                                setState(TransitionState.MOVING);
                                            }
                                            if (c != 1) {
                                                if ((i4 > 0 && f3 >= this.mTransitionGoalPosition) || (signum <= 0.0f && f3 <= this.mTransitionGoalPosition)) {
                                                    f3 = this.mTransitionGoalPosition;
                                                    this.mInTransition = false;
                                                }
                                                if (f3 >= 1.0f || f3 <= 0.0f) {
                                                    this.mInTransition = false;
                                                    setState(TransitionState.FINISHED);
                                                }
                                            }
                                            childCount = getChildCount();
                                            this.mKeepAnimating = false;
                                            long nanoTime2 = getNanoTime();
                                            this.mPostInterpolationPosition = f3;
                                            Interpolator interpolator5 = this.mProgressInterpolator;
                                            float interpolation2 = interpolator5 == null ? f3 : interpolator5.getInterpolation(f3);
                                            interpolator = this.mProgressInterpolator;
                                            if (interpolator != null) {
                                                float interpolation3 = interpolator.getInterpolation((signum / this.mTransitionDuration) + f3);
                                                this.mLastVelocity = interpolation3;
                                                this.mLastVelocity = interpolation3 - this.mProgressInterpolator.getInterpolation(f3);
                                            }
                                            for (i = 0; i < childCount; i++) {
                                                View childAt = getChildAt(i);
                                                MotionController motionController = this.mFrameArrayList.get(childAt);
                                                if (motionController != null) {
                                                    this.mKeepAnimating = motionController.interpolate(childAt, interpolation2, nanoTime2, this.mKeyCache) | this.mKeepAnimating;
                                                }
                                            }
                                            boolean z5 = (i4 <= 0 && f3 >= this.mTransitionGoalPosition) || (signum <= 0.0f && f3 <= this.mTransitionGoalPosition);
                                            if (!this.mKeepAnimating && !this.mInTransition && z5) {
                                                setState(TransitionState.FINISHED);
                                            }
                                            if (this.mMeasureDuringTransition) {
                                                requestLayout();
                                            }
                                            this.mKeepAnimating = (!z5) | this.mKeepAnimating;
                                            if (!(f3 > 0.0f || (i3 = this.mBeginState) == -1 || this.mCurrentState == i3)) {
                                                this.mCurrentState = i3;
                                                this.mScene.getConstraintSet(i3).applyCustomAttributes(this);
                                                setState(TransitionState.FINISHED);
                                                z4 = true;
                                            }
                                            if (((double) f3) >= 1.0d && this.mCurrentState != (i2 = this.mEndState)) {
                                                this.mCurrentState = i2;
                                                this.mScene.getConstraintSet(i2).applyCustomAttributes(this);
                                                setState(TransitionState.FINISHED);
                                                z4 = true;
                                            }
                                            if (!this.mKeepAnimating || this.mInTransition) {
                                                invalidate();
                                            } else if ((i4 > 0 && f3 == 1.0f) || (signum < 0.0f && f3 == 0.0f)) {
                                                setState(TransitionState.FINISHED);
                                            }
                                            if (!this.mKeepAnimating && !this.mInTransition && ((i4 > 0 && f3 == 1.0f) || (signum < 0.0f && f3 == 0.0f))) {
                                                onNewStateAttachHandlers();
                                            }
                                        }
                                    }
                                    f3 = interpolation;
                                    if (Math.abs(this.mLastVelocity) > 1.0E-5f) {
                                    }
                                    if (c != 1) {
                                    }
                                    childCount = getChildCount();
                                    this.mKeepAnimating = false;
                                    long nanoTime22 = getNanoTime();
                                    this.mPostInterpolationPosition = f3;
                                    Interpolator interpolator52 = this.mProgressInterpolator;
                                    if (interpolator52 == null) {
                                    }
                                    interpolator = this.mProgressInterpolator;
                                    if (interpolator != null) {
                                    }
                                    while (i < childCount) {
                                    }
                                    if (i4 <= 0) {
                                    }
                                    setState(TransitionState.FINISHED);
                                    if (this.mMeasureDuringTransition) {
                                    }
                                    this.mKeepAnimating = (!z5) | this.mKeepAnimating;
                                    this.mCurrentState = i3;
                                    this.mScene.getConstraintSet(i3).applyCustomAttributes(this);
                                    setState(TransitionState.FINISHED);
                                    z4 = true;
                                    this.mCurrentState = i2;
                                    this.mScene.getConstraintSet(i2).applyCustomAttributes(this);
                                    setState(TransitionState.FINISHED);
                                    z4 = true;
                                    if (!this.mKeepAnimating) {
                                    }
                                    invalidate();
                                    onNewStateAttachHandlers();
                                } else {
                                    float interpolation4 = interpolator2.getInterpolation(f3);
                                    Interpolator interpolator6 = this.mInterpolator;
                                    if (interpolator6 instanceof MotionInterpolator) {
                                        this.mLastVelocity = ((MotionInterpolator) interpolator6).getVelocity();
                                    } else {
                                        this.mLastVelocity = ((interpolator6.getInterpolation(f3 + f2) - interpolation4) * signum) / f2;
                                    }
                                    f3 = interpolation4;
                                }
                                c = 0;
                                if (Math.abs(this.mLastVelocity) > 1.0E-5f) {
                                }
                                if (c != 1) {
                                }
                                childCount = getChildCount();
                                this.mKeepAnimating = false;
                                long nanoTime222 = getNanoTime();
                                this.mPostInterpolationPosition = f3;
                                Interpolator interpolator522 = this.mProgressInterpolator;
                                if (interpolator522 == null) {
                                }
                                interpolator = this.mProgressInterpolator;
                                if (interpolator != null) {
                                }
                                while (i < childCount) {
                                }
                                if (i4 <= 0) {
                                }
                                setState(TransitionState.FINISHED);
                                if (this.mMeasureDuringTransition) {
                                }
                                this.mKeepAnimating = (!z5) | this.mKeepAnimating;
                                this.mCurrentState = i3;
                                this.mScene.getConstraintSet(i3).applyCustomAttributes(this);
                                setState(TransitionState.FINISHED);
                                z4 = true;
                                this.mCurrentState = i2;
                                this.mScene.getConstraintSet(i2).applyCustomAttributes(this);
                                setState(TransitionState.FINISHED);
                                z4 = true;
                                if (!this.mKeepAnimating) {
                                }
                                invalidate();
                                onNewStateAttachHandlers();
                            }
                            float f4 = this.mTransitionLastPosition;
                            if (f4 >= 1.0f) {
                                int i5 = this.mCurrentState;
                                int i6 = this.mEndState;
                                if (i5 == i6) {
                                    z3 = z4;
                                }
                                this.mCurrentState = i6;
                            } else {
                                if (f4 <= 0.0f) {
                                    int i7 = this.mCurrentState;
                                    int i8 = this.mBeginState;
                                    if (i7 == i8) {
                                        z3 = z4;
                                    }
                                    this.mCurrentState = i8;
                                }
                                this.mNeedsFireTransitionCompleted |= z4;
                                if (z4 && !this.mInLayout) {
                                    requestLayout();
                                }
                                this.mTransitionPosition = this.mTransitionLastPosition;
                            }
                            z4 = z3;
                            this.mNeedsFireTransitionCompleted |= z4;
                            requestLayout();
                            this.mTransitionPosition = this.mTransitionLastPosition;
                        }

                        public final void fireTransitionChange() {
                            CopyOnWriteArrayList<TransitionListener> copyOnWriteArrayList;
                            if ((this.mTransitionListener != null || ((copyOnWriteArrayList = this.mTransitionListeners) != null && !copyOnWriteArrayList.isEmpty())) && this.mListenerPosition != this.mTransitionPosition) {
                                if (this.mListenerState != -1) {
                                    TransitionListener transitionListener = this.mTransitionListener;
                                    if (transitionListener != null) {
                                        MotionHelper motionHelper = (MotionHelper) transitionListener;
                                    }
                                    CopyOnWriteArrayList<TransitionListener> copyOnWriteArrayList2 = this.mTransitionListeners;
                                    if (copyOnWriteArrayList2 != null) {
                                        Iterator<TransitionListener> it = copyOnWriteArrayList2.iterator();
                                        while (it.hasNext()) {
                                            Objects.requireNonNull((MotionHelper) it.next());
                                        }
                                    }
                                }
                                this.mListenerState = -1;
                                float f = this.mTransitionPosition;
                                this.mListenerPosition = f;
                                TransitionListener transitionListener2 = this.mTransitionListener;
                                if (transitionListener2 != null) {
                                    transitionListener2.onTransitionChange(this, this.mBeginState, this.mEndState, f);
                                }
                                CopyOnWriteArrayList<TransitionListener> copyOnWriteArrayList3 = this.mTransitionListeners;
                                if (copyOnWriteArrayList3 != null) {
                                    Iterator<TransitionListener> it2 = copyOnWriteArrayList3.iterator();
                                    while (it2.hasNext()) {
                                        it2.next().onTransitionChange(this, this.mBeginState, this.mEndState, this.mTransitionPosition);
                                    }
                                }
                            }
                        }

                        public void fireTransitionCompleted() {
                            int i;
                            CopyOnWriteArrayList<TransitionListener> copyOnWriteArrayList;
                            if ((this.mTransitionListener != null || ((copyOnWriteArrayList = this.mTransitionListeners) != null && !copyOnWriteArrayList.isEmpty())) && this.mListenerState == -1) {
                                this.mListenerState = this.mCurrentState;
                                if (!this.mTransitionCompleted.isEmpty()) {
                                    ArrayList<Integer> arrayList = this.mTransitionCompleted;
                                    i = arrayList.get(arrayList.size() - 1).intValue();
                                } else {
                                    i = -1;
                                }
                                int i2 = this.mCurrentState;
                                if (!(i == i2 || i2 == -1)) {
                                    this.mTransitionCompleted.add(Integer.valueOf(i2));
                                }
                            }
                            processTransitionCompleted();
                            Runnable runnable = this.mOnComplete;
                            if (runnable != null) {
                                runnable.run();
                            }
                        }

                        public void getAnchorDpDt(int i, float f, float f2, float f3, float[] fArr) {
                            String str;
                            HashMap<View, MotionController> hashMap = this.mFrameArrayList;
                            View view = this.mChildrenByIds.get(i);
                            MotionController motionController = hashMap.get(view);
                            if (motionController != null) {
                                motionController.getDpDt(f, f2, f3, fArr);
                                float y = view.getY();
                                this.lastPos = f;
                                this.lastY = y;
                                return;
                            }
                            if (view == null) {
                                str = GeneratedOutlineSupport.outline11("", i);
                            } else {
                                str = view.getContext().getResources().getResourceName(i);
                            }
                            GeneratedOutlineSupport.outline32("WARNING could not find view id ", str, "MotionLayout");
                        }

                        public ConstraintSet getConstraintSet(int i) {
                            MotionScene motionScene = this.mScene;
                            if (motionScene == null) {
                                return null;
                            }
                            return motionScene.getConstraintSet(i);
                        }

                        public int[] getConstraintSetIds() {
                            MotionScene motionScene = this.mScene;
                            if (motionScene == null) {
                                return null;
                            }
                            int size = motionScene.mConstraintSetMap.size();
                            int[] iArr = new int[size];
                            for (int i = 0; i < size; i++) {
                                iArr[i] = motionScene.mConstraintSetMap.keyAt(i);
                            }
                            return iArr;
                        }

                        public int getCurrentState() {
                            return this.mCurrentState;
                        }

                        public ArrayList<MotionScene.Transition> getDefinedTransitions() {
                            MotionScene motionScene = this.mScene;
                            if (motionScene == null) {
                                return null;
                            }
                            return motionScene.mTransitionList;
                        }

                        public DesignTool getDesignTool() {
                            if (this.mDesignTool == null) {
                                this.mDesignTool = new DesignTool(this);
                            }
                            return this.mDesignTool;
                        }

                        public int getEndState() {
                            return this.mEndState;
                        }

                        public long getNanoTime() {
                            return System.nanoTime();
                        }

                        public float getProgress() {
                            return this.mTransitionLastPosition;
                        }

                        public MotionScene getScene() {
                            return this.mScene;
                        }

                        public int getStartState() {
                            return this.mBeginState;
                        }

                        public float getTargetPosition() {
                            return this.mTransitionGoalPosition;
                        }

                        public MotionScene.Transition getTransition(int i) {
                            Iterator<MotionScene.Transition> it = this.mScene.mTransitionList.iterator();
                            while (it.hasNext()) {
                                MotionScene.Transition next = it.next();
                                if (next.mId == i) {
                                    return next;
                                }
                            }
                            return null;
                        }

                        public Bundle getTransitionState() {
                            if (this.mStateCache == null) {
                                this.mStateCache = new StateCache();
                            }
                            StateCache stateCache = this.mStateCache;
                            MotionLayout motionLayout = MotionLayout.this;
                            stateCache.endState = motionLayout.mEndState;
                            stateCache.startState = motionLayout.mBeginState;
                            stateCache.mVelocity = motionLayout.getVelocity();
                            stateCache.mProgress = MotionLayout.this.getProgress();
                            StateCache stateCache2 = this.mStateCache;
                            Objects.requireNonNull(stateCache2);
                            Bundle bundle = new Bundle();
                            bundle.putFloat("motion.progress", stateCache2.mProgress);
                            bundle.putFloat("motion.velocity", stateCache2.mVelocity);
                            bundle.putInt("motion.StartState", stateCache2.startState);
                            bundle.putInt("motion.EndState", stateCache2.endState);
                            return bundle;
                        }

                        public long getTransitionTimeMs() {
                            MotionScene motionScene = this.mScene;
                            if (motionScene != null) {
                                this.mTransitionDuration = ((float) motionScene.getDuration()) / 1000.0f;
                            }
                            return (long) (this.mTransitionDuration * 1000.0f);
                        }

                        public float getVelocity() {
                            return this.mLastVelocity;
                        }

                        /* JADX WARNING: Removed duplicated region for block: B:10:0x0039  */
                        public final boolean handlesTouchEvent(float f, float f2, View view, MotionEvent motionEvent) {
                            boolean z;
                            boolean z2;
                            if (view instanceof ViewGroup) {
                                ViewGroup viewGroup = (ViewGroup) view;
                                int childCount = viewGroup.getChildCount() - 1;
                                while (true) {
                                    if (childCount < 0) {
                                        break;
                                    }
                                    View childAt = viewGroup.getChildAt(childCount);
                                    if (handlesTouchEvent((((float) childAt.getLeft()) + f) - ((float) view.getScrollX()), (((float) childAt.getTop()) + f2) - ((float) view.getScrollY()), childAt, motionEvent)) {
                                        z = true;
                                        break;
                                    }
                                    childCount--;
                                }
                                if (!z) {
                                    this.mBoundsCheck.set(f, f2, (((float) view.getRight()) + f) - ((float) view.getLeft()), (((float) view.getBottom()) + f2) - ((float) view.getTop()));
                                    if (motionEvent.getAction() != 0 || this.mBoundsCheck.contains(motionEvent.getX(), motionEvent.getY())) {
                                        float f3 = -f;
                                        float f4 = -f2;
                                        Matrix matrix = view.getMatrix();
                                        if (matrix.isIdentity()) {
                                            motionEvent.offsetLocation(f3, f4);
                                            z2 = view.onTouchEvent(motionEvent);
                                            motionEvent.offsetLocation(-f3, -f4);
                                        } else {
                                            MotionEvent obtain = MotionEvent.obtain(motionEvent);
                                            obtain.offsetLocation(f3, f4);
                                            if (this.mInverseMatrix == null) {
                                                this.mInverseMatrix = new Matrix();
                                            }
                                            matrix.invert(this.mInverseMatrix);
                                            obtain.transform(this.mInverseMatrix);
                                            z2 = view.onTouchEvent(obtain);
                                            obtain.recycle();
                                        }
                                        if (z2) {
                                            return true;
                                        }
                                    }
                                }
                                return z;
                            }
                            z = false;
                            if (!z) {
                            }
                            return z;
                        }

                        public final void init(AttributeSet attributeSet) {
                            MotionScene motionScene;
                            IS_IN_EDIT_MODE = isInEditMode();
                            if (attributeSet != null) {
                                TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R$styleable.MotionLayout);
                                int indexCount = obtainStyledAttributes.getIndexCount();
                                boolean z = true;
                                for (int i = 0; i < indexCount; i++) {
                                    int index = obtainStyledAttributes.getIndex(i);
                                    if (index == R$styleable.MotionLayout_layoutDescription) {
                                        this.mScene = new MotionScene(getContext(), this, obtainStyledAttributes.getResourceId(index, -1));
                                    } else if (index == R$styleable.MotionLayout_currentState) {
                                        this.mCurrentState = obtainStyledAttributes.getResourceId(index, -1);
                                    } else if (index == R$styleable.MotionLayout_motionProgress) {
                                        this.mTransitionGoalPosition = obtainStyledAttributes.getFloat(index, 0.0f);
                                        this.mInTransition = true;
                                    } else if (index == R$styleable.MotionLayout_applyMotionScene) {
                                        z = obtainStyledAttributes.getBoolean(index, z);
                                    } else if (index == R$styleable.MotionLayout_showPaths) {
                                        if (this.mDebugPath == 0) {
                                            this.mDebugPath = obtainStyledAttributes.getBoolean(index, false) ? 2 : 0;
                                        }
                                    } else if (index == R$styleable.MotionLayout_motionDebug) {
                                        this.mDebugPath = obtainStyledAttributes.getInt(index, 0);
                                    }
                                }
                                obtainStyledAttributes.recycle();
                                if (this.mScene == null) {
                                    Log.e("MotionLayout", "WARNING NO app:layoutDescription tag");
                                }
                                if (!z) {
                                    this.mScene = null;
                                }
                            }
                            if (this.mDebugPath != 0) {
                                MotionScene motionScene2 = this.mScene;
                                if (motionScene2 == null) {
                                    Log.e("MotionLayout", "CHECK: motion scene not set! set \"app:layoutDescription=\"@xml/file\"");
                                } else {
                                    int startId = motionScene2.getStartId();
                                    MotionScene motionScene3 = this.mScene;
                                    ConstraintSet constraintSet = motionScene3.getConstraintSet(motionScene3.getStartId());
                                    String name = AppCompatDelegateImpl.Api17Impl.getName(getContext(), startId);
                                    int childCount = getChildCount();
                                    for (int i2 = 0; i2 < childCount; i2++) {
                                        View childAt = getChildAt(i2);
                                        int id = childAt.getId();
                                        if (id == -1) {
                                            StringBuilder outline29 = GeneratedOutlineSupport.outline29("CHECK: ", name, " ALL VIEWS SHOULD HAVE ID's ");
                                            outline29.append(childAt.getClass().getName());
                                            outline29.append(" does not!");
                                            Log.w("MotionLayout", outline29.toString());
                                        }
                                        if (constraintSet.getConstraint(id) == null) {
                                            StringBuilder outline292 = GeneratedOutlineSupport.outline29("CHECK: ", name, " NO CONSTRAINTS for ");
                                            outline292.append(AppCompatDelegateImpl.Api17Impl.getName(childAt));
                                            Log.w("MotionLayout", outline292.toString());
                                        }
                                    }
                                    Integer[] numArr = (Integer[]) constraintSet.mConstraints.keySet().toArray(new Integer[0]);
                                    int length = numArr.length;
                                    int[] iArr = new int[length];
                                    for (int i3 = 0; i3 < length; i3++) {
                                        iArr[i3] = numArr[i3].intValue();
                                    }
                                    for (int i4 = 0; i4 < length; i4++) {
                                        int i5 = iArr[i4];
                                        String name2 = AppCompatDelegateImpl.Api17Impl.getName(getContext(), i5);
                                        if (findViewById(iArr[i4]) == null) {
                                            Log.w("MotionLayout", "CHECK: " + name + " NO View matches id " + name2);
                                        }
                                        if (constraintSet.get(i5).layout.mHeight == -1) {
                                            Log.w("MotionLayout", "CHECK: " + name + "(" + name2 + ") no LAYOUT_HEIGHT");
                                        }
                                        if (constraintSet.get(i5).layout.mWidth == -1) {
                                            Log.w("MotionLayout", "CHECK: " + name + "(" + name2 + ") no LAYOUT_HEIGHT");
                                        }
                                    }
                                    SparseIntArray sparseIntArray = new SparseIntArray();
                                    SparseIntArray sparseIntArray2 = new SparseIntArray();
                                    Iterator<MotionScene.Transition> it = this.mScene.mTransitionList.iterator();
                                    while (it.hasNext()) {
                                        MotionScene.Transition next = it.next();
                                        if (next == this.mScene.mCurrentTransition) {
                                            Log.v("MotionLayout", "CHECK: CURRENT");
                                        }
                                        if (next.mConstraintSetStart == next.mConstraintSetEnd) {
                                            Log.e("MotionLayout", "CHECK: start and end constraint set should not be the same!");
                                        }
                                        int i6 = next.mConstraintSetStart;
                                        int i7 = next.mConstraintSetEnd;
                                        String name3 = AppCompatDelegateImpl.Api17Impl.getName(getContext(), i6);
                                        String name4 = AppCompatDelegateImpl.Api17Impl.getName(getContext(), i7);
                                        if (sparseIntArray.get(i6) == i7) {
                                            Log.e("MotionLayout", "CHECK: two transitions with the same start and end " + name3 + "->" + name4);
                                        }
                                        if (sparseIntArray2.get(i7) == i6) {
                                            Log.e("MotionLayout", "CHECK: you can't have reverse transitions" + name3 + "->" + name4);
                                        }
                                        sparseIntArray.put(i6, i7);
                                        sparseIntArray2.put(i7, i6);
                                        if (this.mScene.getConstraintSet(i6) == null) {
                                            Log.e("MotionLayout", " no such constraintSetStart " + name3);
                                        }
                                        if (this.mScene.getConstraintSet(i7) == null) {
                                            Log.e("MotionLayout", " no such constraintSetEnd " + name3);
                                        }
                                    }
                                }
                            }
                            if (this.mCurrentState == -1 && (motionScene = this.mScene) != null) {
                                this.mCurrentState = motionScene.getStartId();
                                this.mBeginState = this.mScene.getStartId();
                                this.mEndState = this.mScene.getEndId();
                            }
                        }

                        public boolean isAttachedToWindow() {
                            return super.isAttachedToWindow();
                        }

                        public void onAttachedToWindow() {
                            MotionScene.Transition transition;
                            int i;
                            boolean z;
                            super.onAttachedToWindow();
                            Display display = getDisplay();
                            if (display != null) {
                                display.getRotation();
                            }
                            MotionScene motionScene = this.mScene;
                            if (!(motionScene == null || (i = this.mCurrentState) == -1)) {
                                ConstraintSet constraintSet = motionScene.getConstraintSet(i);
                                MotionScene motionScene2 = this.mScene;
                                int i2 = 0;
                                while (true) {
                                    if (i2 >= motionScene2.mConstraintSetMap.size()) {
                                        break;
                                    }
                                    int keyAt = motionScene2.mConstraintSetMap.keyAt(i2);
                                    int i3 = motionScene2.mDeriveMap.get(keyAt);
                                    int size = motionScene2.mDeriveMap.size();
                                    while (true) {
                                        if (i3 <= 0) {
                                            z = false;
                                            break;
                                        } else if (i3 == keyAt) {
                                            break;
                                        } else {
                                            int i4 = size - 1;
                                            if (size < 0) {
                                                break;
                                            }
                                            i3 = motionScene2.mDeriveMap.get(i3);
                                            size = i4;
                                        }
                                    }
                                    z = true;
                                    if (z) {
                                        Log.e("MotionScene", "Cannot be derived from yourself");
                                        break;
                                    } else {
                                        motionScene2.readConstraintChain(keyAt, this);
                                        i2++;
                                    }
                                }
                                ArrayList<MotionHelper> arrayList = this.mDecoratorsHelpers;
                                if (arrayList != null) {
                                    Iterator<MotionHelper> it = arrayList.iterator();
                                    while (it.hasNext()) {
                                        it.next().onFinishedMotionScene();
                                    }
                                }
                                if (constraintSet != null) {
                                    constraintSet.applyToInternal(this, true);
                                    setConstraintSet(null);
                                    requestLayout();
                                }
                                this.mBeginState = this.mCurrentState;
                            }
                            onNewStateAttachHandlers();
                            StateCache stateCache = this.mStateCache;
                            if (stateCache == null) {
                                MotionScene motionScene3 = this.mScene;
                                if (motionScene3 != null && (transition = motionScene3.mCurrentTransition) != null && transition.mAutoTransition == 4) {
                                    transitionToEnd();
                                    setState(TransitionState.SETUP);
                                    setState(TransitionState.MOVING);
                                }
                            } else if (this.mDelayedApply) {
                                post(new Runnable() {
                                    /* class androidx.constraintlayout.motion.widget.MotionLayout.AnonymousClass4 */

                                    public void run() {
                                        MotionLayout.this.mStateCache.apply();
                                    }
                                });
                            } else {
                                stateCache.apply();
                            }
                        }

                        /* JADX DEBUG: Failed to insert an additional move for type inference into block B:182:0x00ee */
                        /* JADX DEBUG: Failed to insert an additional move for type inference into block B:183:0x00ee */
                        /* JADX WARN: Multi-variable type inference failed */
                        /* JADX WARN: Type inference failed for: r13v0 */
                        /* JADX WARN: Type inference failed for: r13v1 */
                        /* JADX WARN: Type inference failed for: r13v2 */
                        /* JADX WARN: Type inference failed for: r13v3, types: [boolean, int] */
                        /* JADX WARN: Type inference failed for: r13v4 */
                        /* JADX WARN: Type inference failed for: r13v5 */
                        public boolean onInterceptTouchEvent(MotionEvent motionEvent) {
                            TouchResponse touchResponse;
                            int i;
                            RectF touchRegion;
                            int currentState;
                            ViewTransitionController viewTransitionController;
                            float f;
                            int i2;
                            Rect rect;
                            ConstraintSet constraintSet;
                            ViewTransition viewTransition;
                            Interpolator interpolator;
                            MotionScene motionScene = this.mScene;
                            char c = 0;
                            if (motionScene == null || !this.mInteractionEnabled) {
                                return false;
                            }
                            ViewTransitionController viewTransitionController2 = motionScene.mViewTransitionController;
                            int i3 = 1;
                            if (!(viewTransitionController2 == null || (currentState = viewTransitionController2.mMotionLayout.getCurrentState()) == -1)) {
                                if (viewTransitionController2.mRelatedViews == null) {
                                    viewTransitionController2.mRelatedViews = new HashSet<>();
                                    Iterator<ViewTransition> it = viewTransitionController2.viewTransitions.iterator();
                                    while (it.hasNext()) {
                                        ViewTransition next = it.next();
                                        int childCount = viewTransitionController2.mMotionLayout.getChildCount();
                                        for (int i4 = 0; i4 < childCount; i4++) {
                                            View childAt = viewTransitionController2.mMotionLayout.getChildAt(i4);
                                            if (next.matchesView(childAt)) {
                                                childAt.getId();
                                                viewTransitionController2.mRelatedViews.add(childAt);
                                            }
                                        }
                                    }
                                }
                                float x = motionEvent.getX();
                                float y = motionEvent.getY();
                                Rect rect2 = new Rect();
                                int action = motionEvent.getAction();
                                ArrayList<ViewTransition.Animate> arrayList = viewTransitionController2.animations;
                                int i5 = 2;
                                if (arrayList != null && !arrayList.isEmpty()) {
                                    Iterator<ViewTransition.Animate> it2 = viewTransitionController2.animations.iterator();
                                    while (it2.hasNext()) {
                                        ViewTransition.Animate next2 = it2.next();
                                        Objects.requireNonNull(next2);
                                        if (action != 1) {
                                            if (action == 2) {
                                                next2.mMC.mView.getHitRect(next2.mTempRec);
                                                if (!next2.mTempRec.contains((int) x, (int) y) && !next2.reverse) {
                                                    next2.reverse(true);
                                                }
                                            }
                                        } else if (!next2.reverse) {
                                            next2.reverse(true);
                                        }
                                    }
                                }
                                if (action == 0 || action == 1) {
                                    ConstraintSet constraintSet2 = viewTransitionController2.mMotionLayout.getConstraintSet(currentState);
                                    Iterator<ViewTransition> it3 = viewTransitionController2.viewTransitions.iterator();
                                    while (it3.hasNext()) {
                                        ViewTransition next3 = it3.next();
                                        int i6 = next3.mOnStateTransition;
                                        if (i6 != i3 ? !(i6 != i5 ? !(i6 == 3 && action == 0) : action != i3) : action == 0) {
                                            Iterator<View> it4 = viewTransitionController2.mRelatedViews.iterator();
                                            while (it4.hasNext()) {
                                                View next4 = it4.next();
                                                if (next3.matchesView(next4)) {
                                                    next4.getHitRect(rect2);
                                                    if (rect2.contains((int) x, (int) y)) {
                                                        MotionLayout motionLayout = viewTransitionController2.mMotionLayout;
                                                        View[] viewArr = new View[i3];
                                                        viewArr[c] = next4;
                                                        if (!next3.mDisabled) {
                                                            int i7 = next3.mViewTransitionMode;
                                                            if (i7 == i5) {
                                                                View view = viewArr[c];
                                                                MotionController motionController = new MotionController(view);
                                                                MotionPaths motionPaths = motionController.mStartMotionPath;
                                                                motionPaths.time = 0.0f;
                                                                motionPaths.position = 0.0f;
                                                                motionController.mNoMovement = i3;
                                                                motionPaths.setBounds(view.getX(), view.getY(), (float) view.getWidth(), (float) view.getHeight());
                                                                motionController.mEndMotionPath.setBounds(view.getX(), view.getY(), (float) view.getWidth(), (float) view.getHeight());
                                                                motionController.mStartPoint.setState(view);
                                                                motionController.mEndPoint.setState(view);
                                                                next3.mKeyFrames.addAllFrames(motionController);
                                                                motionController.setup(motionLayout.getWidth(), motionLayout.getHeight(), System.nanoTime());
                                                                int i8 = next3.mDuration;
                                                                int i9 = next3.mUpDuration;
                                                                int i10 = next3.mOnStateTransition;
                                                                Context context = motionLayout.getContext();
                                                                int i11 = next3.mDefaultInterpolator;
                                                                if (i11 == -2) {
                                                                    interpolator = AnimationUtils.loadInterpolator(context, next3.mDefaultInterpolatorID);
                                                                } else if (i11 == -1) {
                                                                    interpolator = 
                                                                    /*  JADX ERROR: Method code generation error
                                                                        jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x01d1: CONSTRUCTOR  (r3v25 'interpolator' android.view.animation.Interpolator) = 
                                                                          (r7v2 'next3' androidx.constraintlayout.motion.widget.ViewTransition)
                                                                          (wrap: androidx.constraintlayout.core.motion.utils.Easing : 0x01c8: INVOKE  (r3v24 androidx.constraintlayout.core.motion.utils.Easing) = 
                                                                          (wrap: java.lang.String : 0x01c6: IGET  (r3v23 java.lang.String) = (r7v2 'next3' androidx.constraintlayout.motion.widget.ViewTransition) androidx.constraintlayout.motion.widget.ViewTransition.mDefaultInterpolatorString java.lang.String)
                                                                         type: STATIC call: androidx.constraintlayout.core.motion.utils.Easing.getInterpolator(java.lang.String):androidx.constraintlayout.core.motion.utils.Easing)
                                                                         call: androidx.constraintlayout.motion.widget.ViewTransition.1.<init>(androidx.constraintlayout.motion.widget.ViewTransition, androidx.constraintlayout.core.motion.utils.Easing):void type: CONSTRUCTOR in method: androidx.constraintlayout.motion.widget.MotionLayout.onInterceptTouchEvent(android.view.MotionEvent):boolean, file: classes.dex
                                                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.connectElseIf(RegionGen.java:176)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:153)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeLoop(RegionGen.java:239)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:67)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeLoop(RegionGen.java:239)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:67)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                        	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                        	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                        	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                                                                        	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                                                                        	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                                                                        	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                                                                        	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                                                                        	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                                                                        	at java.util.ArrayList.forEach(ArrayList.java:1259)
                                                                        	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                                                                        	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                                                                        Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.constraintlayout.motion.widget.ViewTransition, state: GENERATED_AND_UNLOADED
                                                                        	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                                                                        	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                                                                        	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                                                                        	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                                                                        	... 70 more
                                                                        */
                                                                    /*
                                                                    // Method dump skipped, instructions count: 999
                                                                    */
                                                                    throw new UnsupportedOperationException("Method not decompiled: androidx.constraintlayout.motion.widget.MotionLayout.onInterceptTouchEvent(android.view.MotionEvent):boolean");
                                                                }

                                                                @Override // androidx.constraintlayout.widget.ConstraintLayout
                                                                public void onLayout(boolean z, int i, int i2, int i3, int i4) {
                                                                    this.mInLayout = true;
                                                                    try {
                                                                        if (this.mScene == null) {
                                                                            super.onLayout(z, i, i2, i3, i4);
                                                                            return;
                                                                        }
                                                                        int i5 = i3 - i;
                                                                        int i6 = i4 - i2;
                                                                        if (!(this.mLastLayoutWidth == i5 && this.mLastLayoutHeight == i6)) {
                                                                            rebuildScene();
                                                                            evaluate(true);
                                                                        }
                                                                        this.mLastLayoutWidth = i5;
                                                                        this.mLastLayoutHeight = i6;
                                                                        this.mInLayout = false;
                                                                    } finally {
                                                                        this.mInLayout = false;
                                                                    }
                                                                }

                                                                /* JADX WARNING: Code restructure failed: missing block: B:24:0x004e, code lost:
                                                                    if (((r6 == r8.mStartId && r7 == r8.mEndId) ? false : true) != false) goto L_0x0050;
                                                                 */
                                                                /* JADX WARNING: Removed duplicated region for block: B:45:0x00ea  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:46:0x00f7  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:49:0x00ff  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:64:0x0121  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:65:0x012c  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:76:0x0153  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:78:0x0159  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:84:0x0178  */
                                                                /* JADX WARNING: Removed duplicated region for block: B:90:? A[RETURN, SYNTHETIC] */
                                                                @Override // androidx.constraintlayout.widget.ConstraintLayout
                                                                public void onMeasure(int i, int i2) {
                                                                    boolean z;
                                                                    float f;
                                                                    int i3;
                                                                    int childCount;
                                                                    Interpolator interpolator;
                                                                    if (this.mScene == null) {
                                                                        super.onMeasure(i, i2);
                                                                        return;
                                                                    }
                                                                    boolean z2 = true;
                                                                    boolean z3 = (this.mLastWidthMeasureSpec == i && this.mLastHeightMeasureSpec == i2) ? false : true;
                                                                    if (this.mNeedsFireTransitionCompleted) {
                                                                        this.mNeedsFireTransitionCompleted = false;
                                                                        onNewStateAttachHandlers();
                                                                        processTransitionCompleted();
                                                                        z3 = true;
                                                                    }
                                                                    if (this.mDirtyHierarchy) {
                                                                        z3 = true;
                                                                    }
                                                                    this.mLastWidthMeasureSpec = i;
                                                                    this.mLastHeightMeasureSpec = i2;
                                                                    int startId = this.mScene.getStartId();
                                                                    int endId = this.mScene.getEndId();
                                                                    if (!z3) {
                                                                        Model model = this.mModel;
                                                                    }
                                                                    if (this.mBeginState != -1) {
                                                                        super.onMeasure(i, i2);
                                                                        this.mModel.initFrom(this.mScene.getConstraintSet(startId), this.mScene.getConstraintSet(endId));
                                                                        this.mModel.reEvaluateState();
                                                                        Model model2 = this.mModel;
                                                                        model2.mStartId = startId;
                                                                        model2.mEndId = endId;
                                                                        z = false;
                                                                        if (this.mMeasureDuringTransition || z) {
                                                                            int paddingBottom = getPaddingBottom() + getPaddingTop();
                                                                            int width = this.mLayoutWidget.getWidth() + getPaddingRight() + getPaddingLeft();
                                                                            int height = this.mLayoutWidget.getHeight() + paddingBottom;
                                                                            int i4 = this.mWidthMeasureMode;
                                                                            if (i4 == Integer.MIN_VALUE || i4 == 0) {
                                                                                int i5 = this.mStartWrapWidth;
                                                                                width = (int) ((this.mPostInterpolationPosition * ((float) (this.mEndWrapWidth - i5))) + ((float) i5));
                                                                                requestLayout();
                                                                            }
                                                                            int i6 = this.mHeightMeasureMode;
                                                                            if (i6 == Integer.MIN_VALUE || i6 == 0) {
                                                                                int i7 = this.mStartWrapHeight;
                                                                                height = (int) ((this.mPostInterpolationPosition * ((float) (this.mEndWrapHeight - i7))) + ((float) i7));
                                                                                requestLayout();
                                                                            }
                                                                            setMeasuredDimension(width, height);
                                                                        }
                                                                        float signum = Math.signum(this.mTransitionGoalPosition - this.mTransitionLastPosition);
                                                                        long nanoTime = getNanoTime();
                                                                        Interpolator interpolator2 = this.mInterpolator;
                                                                        f = this.mTransitionLastPosition + (interpolator2 instanceof StopLogic ? ((((float) (nanoTime - this.mTransitionLastTime)) * signum) * 1.0E-9f) / this.mTransitionDuration : 0.0f);
                                                                        if (this.mTransitionInstantly) {
                                                                            f = this.mTransitionGoalPosition;
                                                                        }
                                                                        i3 = (signum > 0.0f ? 1 : (signum == 0.0f ? 0 : -1));
                                                                        if ((i3 > 0 || f < this.mTransitionGoalPosition) && (signum > 0.0f || f > this.mTransitionGoalPosition)) {
                                                                            z2 = false;
                                                                        } else {
                                                                            f = this.mTransitionGoalPosition;
                                                                        }
                                                                        if (interpolator2 != null && !z2) {
                                                                            if (!this.mTemporalInterpolator) {
                                                                                f = interpolator2.getInterpolation(((float) (nanoTime - this.mAnimationStartTime)) * 1.0E-9f);
                                                                            } else {
                                                                                f = interpolator2.getInterpolation(f);
                                                                            }
                                                                        }
                                                                        if ((i3 > 0 && f >= this.mTransitionGoalPosition) || (signum <= 0.0f && f <= this.mTransitionGoalPosition)) {
                                                                            f = this.mTransitionGoalPosition;
                                                                        }
                                                                        this.mPostInterpolationPosition = f;
                                                                        childCount = getChildCount();
                                                                        long nanoTime2 = getNanoTime();
                                                                        interpolator = this.mProgressInterpolator;
                                                                        if (interpolator != null) {
                                                                            f = interpolator.getInterpolation(f);
                                                                        }
                                                                        for (int i8 = 0; i8 < childCount; i8++) {
                                                                            View childAt = getChildAt(i8);
                                                                            MotionController motionController = this.mFrameArrayList.get(childAt);
                                                                            if (motionController != null) {
                                                                                motionController.interpolate(childAt, f, nanoTime2, this.mKeyCache);
                                                                            }
                                                                        }
                                                                        if (!this.mMeasureDuringTransition) {
                                                                            requestLayout();
                                                                            return;
                                                                        }
                                                                        return;
                                                                    }
                                                                    if (z3) {
                                                                        super.onMeasure(i, i2);
                                                                    }
                                                                    z = true;
                                                                    int paddingBottom2 = getPaddingBottom() + getPaddingTop();
                                                                    int width2 = this.mLayoutWidget.getWidth() + getPaddingRight() + getPaddingLeft();
                                                                    int height2 = this.mLayoutWidget.getHeight() + paddingBottom2;
                                                                    int i42 = this.mWidthMeasureMode;
                                                                    int i52 = this.mStartWrapWidth;
                                                                    width2 = (int) ((this.mPostInterpolationPosition * ((float) (this.mEndWrapWidth - i52))) + ((float) i52));
                                                                    requestLayout();
                                                                    int i62 = this.mHeightMeasureMode;
                                                                    int i72 = this.mStartWrapHeight;
                                                                    height2 = (int) ((this.mPostInterpolationPosition * ((float) (this.mEndWrapHeight - i72))) + ((float) i72));
                                                                    requestLayout();
                                                                    setMeasuredDimension(width2, height2);
                                                                    float signum2 = Math.signum(this.mTransitionGoalPosition - this.mTransitionLastPosition);
                                                                    long nanoTime3 = getNanoTime();
                                                                    Interpolator interpolator22 = this.mInterpolator;
                                                                    f = this.mTransitionLastPosition + (interpolator22 instanceof StopLogic ? ((((float) (nanoTime3 - this.mTransitionLastTime)) * signum2) * 1.0E-9f) / this.mTransitionDuration : 0.0f);
                                                                    if (this.mTransitionInstantly) {
                                                                    }
                                                                    i3 = (signum2 > 0.0f ? 1 : (signum2 == 0.0f ? 0 : -1));
                                                                    if (i3 > 0) {
                                                                    }
                                                                    z2 = false;
                                                                    if (!this.mTemporalInterpolator) {
                                                                    }
                                                                    f = this.mTransitionGoalPosition;
                                                                    this.mPostInterpolationPosition = f;
                                                                    childCount = getChildCount();
                                                                    long nanoTime22 = getNanoTime();
                                                                    interpolator = this.mProgressInterpolator;
                                                                    if (interpolator != null) {
                                                                    }
                                                                    while (i8 < childCount) {
                                                                    }
                                                                    if (!this.mMeasureDuringTransition) {
                                                                    }
                                                                }

                                                                public boolean onNestedFling(View view, float f, float f2, boolean z) {
                                                                    return false;
                                                                }

                                                                public boolean onNestedPreFling(View view, float f, float f2) {
                                                                    return false;
                                                                }

                                                                @Override // androidx.core.view.NestedScrollingParent2
                                                                public void onNestedPreScroll(final View view, int i, int i2, int[] iArr, int i3) {
                                                                    MotionScene.Transition transition;
                                                                    boolean z;
                                                                    boolean z2;
                                                                    TouchResponse touchResponse;
                                                                    float f;
                                                                    float f2;
                                                                    TouchResponse touchResponse2;
                                                                    TouchResponse touchResponse3;
                                                                    TouchResponse touchResponse4;
                                                                    int i4;
                                                                    MotionScene motionScene = this.mScene;
                                                                    if (motionScene != null && (transition = motionScene.mCurrentTransition) != null && (!transition.mDisable)) {
                                                                        int i5 = -1;
                                                                        if (!z || (touchResponse4 = transition.mTouchResponse) == null || (i4 = touchResponse4.mTouchRegionId) == -1 || view.getId() == i4) {
                                                                            MotionScene.Transition transition2 = motionScene.mCurrentTransition;
                                                                            if ((transition2 == null || (touchResponse3 = transition2.mTouchResponse) == null) ? false : touchResponse3.mMoveWhenScrollAtTop) {
                                                                                TouchResponse touchResponse5 = transition.mTouchResponse;
                                                                                if (!(touchResponse5 == null || (touchResponse5.mFlags & 4) == 0)) {
                                                                                    i5 = i2;
                                                                                }
                                                                                float f3 = this.mTransitionPosition;
                                                                                if ((f3 == 1.0f || f3 == 0.0f) && view.canScrollVertically(i5)) {
                                                                                    return;
                                                                                }
                                                                            }
                                                                            TouchResponse touchResponse6 = transition.mTouchResponse;
                                                                            if (!(touchResponse6 == null || (touchResponse6.mFlags & 1) == 0)) {
                                                                                float f4 = (float) i;
                                                                                float f5 = (float) i2;
                                                                                MotionScene.Transition transition3 = motionScene.mCurrentTransition;
                                                                                if (transition3 == null || (touchResponse2 = transition3.mTouchResponse) == null) {
                                                                                    f2 = 0.0f;
                                                                                } else {
                                                                                    touchResponse2.mMotionLayout.getAnchorDpDt(touchResponse2.mTouchAnchorId, touchResponse2.mMotionLayout.getProgress(), touchResponse2.mTouchAnchorX, touchResponse2.mTouchAnchorY, touchResponse2.mAnchorDpDt);
                                                                                    float f6 = touchResponse2.mTouchDirectionX;
                                                                                    if (f6 != 0.0f) {
                                                                                        float[] fArr = touchResponse2.mAnchorDpDt;
                                                                                        if (fArr[0] == 0.0f) {
                                                                                            fArr[0] = 1.0E-7f;
                                                                                        }
                                                                                        f2 = (f4 * f6) / fArr[0];
                                                                                    } else {
                                                                                        float[] fArr2 = touchResponse2.mAnchorDpDt;
                                                                                        if (fArr2[1] == 0.0f) {
                                                                                            fArr2[1] = 1.0E-7f;
                                                                                        }
                                                                                        f2 = (f5 * touchResponse2.mTouchDirectionY) / fArr2[1];
                                                                                    }
                                                                                }
                                                                                float f7 = this.mTransitionLastPosition;
                                                                                if ((f7 <= 0.0f && f2 < 0.0f) || (f7 >= 1.0f && f2 > 0.0f)) {
                                                                                    view.setNestedScrollingEnabled(false);
                                                                                    view.post(new Runnable(this) {
                                                                                        /* class androidx.constraintlayout.motion.widget.MotionLayout.AnonymousClass3 */

                                                                                        public void run() {
                                                                                            view.setNestedScrollingEnabled(true);
                                                                                        }
                                                                                    });
                                                                                    return;
                                                                                }
                                                                            }
                                                                            float f8 = this.mTransitionPosition;
                                                                            long nanoTime = getNanoTime();
                                                                            float f9 = (float) i;
                                                                            this.mScrollTargetDX = f9;
                                                                            float f10 = (float) i2;
                                                                            this.mScrollTargetDY = f10;
                                                                            this.mScrollTargetDT = (float) (((double) (nanoTime - this.mScrollTargetTime)) * 1.0E-9d);
                                                                            this.mScrollTargetTime = nanoTime;
                                                                            MotionScene.Transition transition4 = motionScene.mCurrentTransition;
                                                                            if (!(transition4 == null || (touchResponse = transition4.mTouchResponse) == null)) {
                                                                                float progress = touchResponse.mMotionLayout.getProgress();
                                                                                if (!touchResponse.mDragStarted) {
                                                                                    touchResponse.mDragStarted = true;
                                                                                    touchResponse.mMotionLayout.setProgress(progress);
                                                                                }
                                                                                touchResponse.mMotionLayout.getAnchorDpDt(touchResponse.mTouchAnchorId, progress, touchResponse.mTouchAnchorX, touchResponse.mTouchAnchorY, touchResponse.mAnchorDpDt);
                                                                                float f11 = touchResponse.mTouchDirectionX;
                                                                                float[] fArr3 = touchResponse.mAnchorDpDt;
                                                                                if (((double) Math.abs((touchResponse.mTouchDirectionY * fArr3[1]) + (f11 * fArr3[0]))) < 0.01d) {
                                                                                    float[] fArr4 = touchResponse.mAnchorDpDt;
                                                                                    fArr4[0] = 0.01f;
                                                                                    fArr4[1] = 0.01f;
                                                                                }
                                                                                float f12 = touchResponse.mTouchDirectionX;
                                                                                if (f12 != 0.0f) {
                                                                                    f = (f9 * f12) / touchResponse.mAnchorDpDt[0];
                                                                                } else {
                                                                                    f = (f10 * touchResponse.mTouchDirectionY) / touchResponse.mAnchorDpDt[1];
                                                                                }
                                                                                float max = Math.max(Math.min(progress + f, 1.0f), 0.0f);
                                                                                if (max != touchResponse.mMotionLayout.getProgress()) {
                                                                                    touchResponse.mMotionLayout.setProgress(max);
                                                                                }
                                                                            }
                                                                            if (f8 != this.mTransitionPosition) {
                                                                                iArr[0] = i;
                                                                                z2 = true;
                                                                                iArr[1] = i2;
                                                                            } else {
                                                                                z2 = true;
                                                                            }
                                                                            evaluate(false);
                                                                            if (iArr[0] == 0) {
                                                                                char c = z2 ? 1 : 0;
                                                                                char c2 = z2 ? 1 : 0;
                                                                                char c3 = z2 ? 1 : 0;
                                                                                if (iArr[c] == 0) {
                                                                                    return;
                                                                                }
                                                                            }
                                                                            this.mUndergoingMotion = z2;
                                                                        }
                                                                    }
                                                                }

                                                                @Override // androidx.core.view.NestedScrollingParent2
                                                                public void onNestedScroll(View view, int i, int i2, int i3, int i4, int i5) {
                                                                }

                                                                @Override // androidx.core.view.NestedScrollingParent3
                                                                public void onNestedScroll(View view, int i, int i2, int i3, int i4, int i5, int[] iArr) {
                                                                    if (!(!this.mUndergoingMotion && i == 0 && i2 == 0)) {
                                                                        iArr[0] = iArr[0] + i3;
                                                                        iArr[1] = iArr[1] + i4;
                                                                    }
                                                                    this.mUndergoingMotion = false;
                                                                }

                                                                @Override // androidx.core.view.NestedScrollingParent2
                                                                public void onNestedScrollAccepted(View view, View view2, int i, int i2) {
                                                                    this.mScrollTargetTime = getNanoTime();
                                                                    this.mScrollTargetDT = 0.0f;
                                                                    this.mScrollTargetDX = 0.0f;
                                                                    this.mScrollTargetDY = 0.0f;
                                                                }

                                                                public void onNewStateAttachHandlers() {
                                                                    MotionScene.Transition transition;
                                                                    TouchResponse touchResponse;
                                                                    View view;
                                                                    MotionScene motionScene = this.mScene;
                                                                    if (motionScene != null) {
                                                                        if (motionScene.autoTransition(this, this.mCurrentState)) {
                                                                            requestLayout();
                                                                            return;
                                                                        }
                                                                        int i = this.mCurrentState;
                                                                        if (i != -1) {
                                                                            MotionScene motionScene2 = this.mScene;
                                                                            Iterator<MotionScene.Transition> it = motionScene2.mTransitionList.iterator();
                                                                            while (it.hasNext()) {
                                                                                MotionScene.Transition next = it.next();
                                                                                if (next.mOnClicks.size() > 0) {
                                                                                    Iterator<MotionScene.Transition.TransitionOnClick> it2 = next.mOnClicks.iterator();
                                                                                    while (it2.hasNext()) {
                                                                                        it2.next().removeOnClickListeners(this);
                                                                                    }
                                                                                }
                                                                            }
                                                                            Iterator<MotionScene.Transition> it3 = motionScene2.mAbstractTransitionList.iterator();
                                                                            while (it3.hasNext()) {
                                                                                MotionScene.Transition next2 = it3.next();
                                                                                if (next2.mOnClicks.size() > 0) {
                                                                                    Iterator<MotionScene.Transition.TransitionOnClick> it4 = next2.mOnClicks.iterator();
                                                                                    while (it4.hasNext()) {
                                                                                        it4.next().removeOnClickListeners(this);
                                                                                    }
                                                                                }
                                                                            }
                                                                            Iterator<MotionScene.Transition> it5 = motionScene2.mTransitionList.iterator();
                                                                            while (it5.hasNext()) {
                                                                                MotionScene.Transition next3 = it5.next();
                                                                                if (next3.mOnClicks.size() > 0) {
                                                                                    Iterator<MotionScene.Transition.TransitionOnClick> it6 = next3.mOnClicks.iterator();
                                                                                    while (it6.hasNext()) {
                                                                                        it6.next().addOnClickListeners(this, i, next3);
                                                                                    }
                                                                                }
                                                                            }
                                                                            Iterator<MotionScene.Transition> it7 = motionScene2.mAbstractTransitionList.iterator();
                                                                            while (it7.hasNext()) {
                                                                                MotionScene.Transition next4 = it7.next();
                                                                                if (next4.mOnClicks.size() > 0) {
                                                                                    Iterator<MotionScene.Transition.TransitionOnClick> it8 = next4.mOnClicks.iterator();
                                                                                    while (it8.hasNext()) {
                                                                                        it8.next().addOnClickListeners(this, i, next4);
                                                                                    }
                                                                                }
                                                                            }
                                                                        }
                                                                        if (this.mScene.supportTouch() && (transition = this.mScene.mCurrentTransition) != null && (touchResponse = transition.mTouchResponse) != null) {
                                                                            int i2 = touchResponse.mTouchAnchorId;
                                                                            if (i2 != -1) {
                                                                                view = touchResponse.mMotionLayout.findViewById(i2);
                                                                                if (view == null) {
                                                                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("cannot find TouchAnchorId @id/");
                                                                                    outline25.append(AppCompatDelegateImpl.Api17Impl.getName(touchResponse.mMotionLayout.getContext(), touchResponse.mTouchAnchorId));
                                                                                    Log.e("TouchResponse", outline25.toString());
                                                                                }
                                                                            } else {
                                                                                view = null;
                                                                            }
                                                                            if (view instanceof NestedScrollView) {
                                                                                NestedScrollView nestedScrollView = (NestedScrollView) view;
                                                                                nestedScrollView.setOnTouchListener(
                                                                                /*  JADX ERROR: Method code generation error
                                                                                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0121: INVOKE  
                                                                                      (r1v3 'nestedScrollView' androidx.core.widget.NestedScrollView)
                                                                                      (wrap: androidx.constraintlayout.motion.widget.TouchResponse$1 : 0x011e: CONSTRUCTOR  (r2v2 androidx.constraintlayout.motion.widget.TouchResponse$1) = (r0v7 'touchResponse' androidx.constraintlayout.motion.widget.TouchResponse) call: androidx.constraintlayout.motion.widget.TouchResponse.1.<init>(androidx.constraintlayout.motion.widget.TouchResponse):void type: CONSTRUCTOR)
                                                                                     type: VIRTUAL call: android.widget.FrameLayout.setOnTouchListener(android.view.View$OnTouchListener):void in method: androidx.constraintlayout.motion.widget.MotionLayout.onNewStateAttachHandlers():void, file: classes.dex
                                                                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                                                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                                                                                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                                                                                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                                                                                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                                                                                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                                                                                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                                                                                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                                                                                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                                                                                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                                                                                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                                                                                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                                                                                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                                                                                    Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x011e: CONSTRUCTOR  (r2v2 androidx.constraintlayout.motion.widget.TouchResponse$1) = (r0v7 'touchResponse' androidx.constraintlayout.motion.widget.TouchResponse) call: androidx.constraintlayout.motion.widget.TouchResponse.1.<init>(androidx.constraintlayout.motion.widget.TouchResponse):void type: CONSTRUCTOR in method: androidx.constraintlayout.motion.widget.MotionLayout.onNewStateAttachHandlers():void, file: classes.dex
                                                                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                                                                                    	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                                                                                    	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                                                                                    	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                                                                                    	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                                                                                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                                                                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                                                                                    	... 39 more
                                                                                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.constraintlayout.motion.widget.TouchResponse, state: GENERATED_AND_UNLOADED
                                                                                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                                                                                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                                                                                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                                                                                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                                                                                    	... 45 more
                                                                                    */
                                                                                /*
                                                                                // Method dump skipped, instructions count: 301
                                                                                */
                                                                                throw new UnsupportedOperationException("Method not decompiled: androidx.constraintlayout.motion.widget.MotionLayout.onNewStateAttachHandlers():void");
                                                                            }

                                                                            public void onRtlPropertiesChanged(int i) {
                                                                                TouchResponse touchResponse;
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene != null) {
                                                                                    boolean isRtl = isRtl();
                                                                                    motionScene.mRtl = isRtl;
                                                                                    MotionScene.Transition transition = motionScene.mCurrentTransition;
                                                                                    if (transition != null && (touchResponse = transition.mTouchResponse) != null) {
                                                                                        touchResponse.setRTL(isRtl);
                                                                                    }
                                                                                }
                                                                            }

                                                                            @Override // androidx.core.view.NestedScrollingParent2
                                                                            public boolean onStartNestedScroll(View view, View view2, int i, int i2) {
                                                                                MotionScene.Transition transition;
                                                                                TouchResponse touchResponse;
                                                                                MotionScene motionScene = this.mScene;
                                                                                return (motionScene == null || (transition = motionScene.mCurrentTransition) == null || (touchResponse = transition.mTouchResponse) == null || (touchResponse.mFlags & 2) != 0) ? false : true;
                                                                            }

                                                                            @Override // androidx.core.view.NestedScrollingParent2
                                                                            public void onStopNestedScroll(View view, int i) {
                                                                                TouchResponse touchResponse;
                                                                                float f;
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene != null) {
                                                                                    float f2 = this.mScrollTargetDT;
                                                                                    float f3 = 0.0f;
                                                                                    if (f2 != 0.0f) {
                                                                                        float f4 = this.mScrollTargetDX / f2;
                                                                                        float f5 = this.mScrollTargetDY / f2;
                                                                                        MotionScene.Transition transition = motionScene.mCurrentTransition;
                                                                                        if (transition != null && (touchResponse = transition.mTouchResponse) != null) {
                                                                                            boolean z = false;
                                                                                            touchResponse.mDragStarted = false;
                                                                                            float progress = touchResponse.mMotionLayout.getProgress();
                                                                                            touchResponse.mMotionLayout.getAnchorDpDt(touchResponse.mTouchAnchorId, progress, touchResponse.mTouchAnchorX, touchResponse.mTouchAnchorY, touchResponse.mAnchorDpDt);
                                                                                            float f6 = touchResponse.mTouchDirectionX;
                                                                                            float[] fArr = touchResponse.mAnchorDpDt;
                                                                                            float f7 = fArr[0];
                                                                                            float f8 = touchResponse.mTouchDirectionY;
                                                                                            float f9 = fArr[1];
                                                                                            if (f6 != 0.0f) {
                                                                                                f = (f4 * f6) / fArr[0];
                                                                                            } else {
                                                                                                f = (f5 * f8) / fArr[1];
                                                                                            }
                                                                                            if (!Float.isNaN(f)) {
                                                                                                progress += f / 3.0f;
                                                                                            }
                                                                                            if (progress != 0.0f) {
                                                                                                boolean z2 = progress != 1.0f;
                                                                                                int i2 = touchResponse.mOnTouchUp;
                                                                                                if (i2 != 3) {
                                                                                                    z = true;
                                                                                                }
                                                                                                if (z && z2) {
                                                                                                    MotionLayout motionLayout = touchResponse.mMotionLayout;
                                                                                                    if (((double) progress) >= 0.5d) {
                                                                                                        f3 = 1.0f;
                                                                                                    }
                                                                                                    motionLayout.touchAnimateTo(i2, f3, f);
                                                                                                }
                                                                                            }
                                                                                        }
                                                                                    }
                                                                                }
                                                                            }

                                                                            /* JADX WARNING: Removed duplicated region for block: B:167:0x04e5  */
                                                                            /* JADX WARNING: Removed duplicated region for block: B:168:0x050a  */
                                                                            /* JADX WARNING: Removed duplicated region for block: B:171:0x0527  */
                                                                            /* JADX WARNING: Removed duplicated region for block: B:172:0x0537  */
                                                                            public boolean onTouchEvent(MotionEvent motionEvent) {
                                                                                MotionTracker motionTracker;
                                                                                MotionTracker motionTracker2;
                                                                                TouchResponse touchResponse;
                                                                                char c;
                                                                                char c2;
                                                                                float f;
                                                                                int i;
                                                                                char c3;
                                                                                char c4;
                                                                                char c5;
                                                                                char c6;
                                                                                float f2;
                                                                                int i2;
                                                                                float f3;
                                                                                int i3;
                                                                                int i4;
                                                                                float f4;
                                                                                float f5;
                                                                                int i5;
                                                                                char c7;
                                                                                MotionEvent motionEvent2;
                                                                                MotionScene.Transition transition;
                                                                                int i6;
                                                                                float f6;
                                                                                float f7;
                                                                                Iterator it;
                                                                                RectF rectF;
                                                                                MotionEvent motionEvent3;
                                                                                MotionScene.Transition transition2;
                                                                                TouchResponse touchResponse2;
                                                                                RectF limitBoundsTo;
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene == null || !this.mInteractionEnabled || !motionScene.supportTouch()) {
                                                                                    return super.onTouchEvent(motionEvent);
                                                                                }
                                                                                MotionScene motionScene2 = this.mScene;
                                                                                MotionScene.Transition transition3 = motionScene2.mCurrentTransition;
                                                                                if (transition3 != null && !(!transition3.mDisable)) {
                                                                                    return super.onTouchEvent(motionEvent);
                                                                                }
                                                                                int currentState = getCurrentState();
                                                                                Objects.requireNonNull(motionScene2);
                                                                                RectF rectF2 = new RectF();
                                                                                if (motionScene2.mVelocityTracker == null) {
                                                                                    Objects.requireNonNull(motionScene2.mMotionLayout);
                                                                                    MyTracker.me.tracker = VelocityTracker.obtain();
                                                                                    motionScene2.mVelocityTracker = MyTracker.me;
                                                                                }
                                                                                VelocityTracker velocityTracker = ((MyTracker) motionScene2.mVelocityTracker).tracker;
                                                                                if (velocityTracker != null) {
                                                                                    velocityTracker.addMovement(motionEvent);
                                                                                }
                                                                                if (currentState != -1) {
                                                                                    int action = motionEvent.getAction();
                                                                                    if (action == 0) {
                                                                                        motionScene2.mLastTouchX = motionEvent.getRawX();
                                                                                        motionScene2.mLastTouchY = motionEvent.getRawY();
                                                                                        motionScene2.mLastTouchDown = motionEvent;
                                                                                        motionScene2.mIgnoreTouch = false;
                                                                                        TouchResponse touchResponse3 = motionScene2.mCurrentTransition.mTouchResponse;
                                                                                        if (touchResponse3 == null) {
                                                                                            return true;
                                                                                        }
                                                                                        RectF limitBoundsTo2 = touchResponse3.getLimitBoundsTo(motionScene2.mMotionLayout, rectF2);
                                                                                        if (limitBoundsTo2 == null || limitBoundsTo2.contains(motionScene2.mLastTouchDown.getX(), motionScene2.mLastTouchDown.getY())) {
                                                                                            RectF touchRegion = motionScene2.mCurrentTransition.mTouchResponse.getTouchRegion(motionScene2.mMotionLayout, rectF2);
                                                                                            if (touchRegion == null || touchRegion.contains(motionScene2.mLastTouchDown.getX(), motionScene2.mLastTouchDown.getY())) {
                                                                                                motionScene2.mMotionOutsideRegion = false;
                                                                                            } else {
                                                                                                motionScene2.mMotionOutsideRegion = true;
                                                                                            }
                                                                                            TouchResponse touchResponse4 = motionScene2.mCurrentTransition.mTouchResponse;
                                                                                            float f8 = motionScene2.mLastTouchX;
                                                                                            float f9 = motionScene2.mLastTouchY;
                                                                                            touchResponse4.mLastTouchX = f8;
                                                                                            touchResponse4.mLastTouchY = f9;
                                                                                            return true;
                                                                                        }
                                                                                        motionScene2.mLastTouchDown = null;
                                                                                        motionScene2.mIgnoreTouch = true;
                                                                                        return true;
                                                                                    } else if (action == 2 && !motionScene2.mIgnoreTouch) {
                                                                                        float rawY = motionEvent.getRawY() - motionScene2.mLastTouchY;
                                                                                        float rawX = motionEvent.getRawX() - motionScene2.mLastTouchX;
                                                                                        if ((((double) rawX) == 0.0d && ((double) rawY) == 0.0d) || (motionEvent2 = motionScene2.mLastTouchDown) == null) {
                                                                                            return true;
                                                                                        }
                                                                                        if (currentState != -1) {
                                                                                            StateSet stateSet = motionScene2.mStateSet;
                                                                                            if (stateSet == null || (i6 = stateSet.stateGetConstraintID(currentState, -1, -1)) == -1) {
                                                                                                i6 = currentState;
                                                                                            }
                                                                                            ArrayList arrayList = new ArrayList();
                                                                                            Iterator<MotionScene.Transition> it2 = motionScene2.mTransitionList.iterator();
                                                                                            while (it2.hasNext()) {
                                                                                                MotionScene.Transition next = it2.next();
                                                                                                if (next.mConstraintSetStart == i6 || next.mConstraintSetEnd == i6) {
                                                                                                    arrayList.add(next);
                                                                                                }
                                                                                            }
                                                                                            RectF rectF3 = new RectF();
                                                                                            Iterator it3 = arrayList.iterator();
                                                                                            float f10 = 0.0f;
                                                                                            transition = null;
                                                                                            while (it3.hasNext()) {
                                                                                                MotionScene.Transition transition4 = (MotionScene.Transition) it3.next();
                                                                                                if (!transition4.mDisable && (touchResponse2 = transition4.mTouchResponse) != null) {
                                                                                                    touchResponse2.setRTL(motionScene2.mRtl);
                                                                                                    RectF touchRegion2 = transition4.mTouchResponse.getTouchRegion(motionScene2.mMotionLayout, rectF3);
                                                                                                    if ((touchRegion2 == null || touchRegion2.contains(motionEvent2.getX(), motionEvent2.getY())) && ((limitBoundsTo = transition4.mTouchResponse.getLimitBoundsTo(motionScene2.mMotionLayout, rectF3)) == null || limitBoundsTo.contains(motionEvent2.getX(), motionEvent2.getY()))) {
                                                                                                        TouchResponse touchResponse5 = transition4.mTouchResponse;
                                                                                                        float f11 = (touchResponse5.mTouchDirectionY * rawY) + (touchResponse5.mTouchDirectionX * rawX);
                                                                                                        if (touchResponse5.mIsRotateMode) {
                                                                                                            float x = motionEvent2.getX();
                                                                                                            Objects.requireNonNull(transition4.mTouchResponse);
                                                                                                            float f12 = x - 0.5f;
                                                                                                            float y = motionEvent2.getY();
                                                                                                            rectF = rectF3;
                                                                                                            Objects.requireNonNull(transition4.mTouchResponse);
                                                                                                            float f13 = y - 0.5f;
                                                                                                            it = it3;
                                                                                                            f7 = rawY;
                                                                                                            f6 = rawX;
                                                                                                            double atan2 = Math.atan2((double) (rawY + f13), (double) (rawX + f12));
                                                                                                            double d = (double) f12;
                                                                                                            motionEvent3 = motionEvent2;
                                                                                                            transition2 = transition;
                                                                                                            f11 = ((float) (atan2 - Math.atan2(d, (double) f13))) * 10.0f;
                                                                                                        } else {
                                                                                                            rectF = rectF3;
                                                                                                            it = it3;
                                                                                                            f7 = rawY;
                                                                                                            f6 = rawX;
                                                                                                            motionEvent3 = motionEvent2;
                                                                                                            transition2 = transition;
                                                                                                        }
                                                                                                        float f14 = (transition4.mConstraintSetEnd == currentState ? -1.0f : 1.1f) * f11;
                                                                                                        if (f14 > f10) {
                                                                                                            f10 = f14;
                                                                                                            transition = transition4;
                                                                                                            motionEvent2 = motionEvent3;
                                                                                                            rectF3 = rectF;
                                                                                                            it3 = it;
                                                                                                            rawY = f7;
                                                                                                            rawX = f6;
                                                                                                        }
                                                                                                        transition = transition2;
                                                                                                        motionEvent2 = motionEvent3;
                                                                                                        rectF3 = rectF;
                                                                                                        it3 = it;
                                                                                                        rawY = f7;
                                                                                                        rawX = f6;
                                                                                                    }
                                                                                                }
                                                                                                rectF = rectF3;
                                                                                                it = it3;
                                                                                                f7 = rawY;
                                                                                                f6 = rawX;
                                                                                                motionEvent3 = motionEvent2;
                                                                                                transition2 = transition;
                                                                                                transition = transition2;
                                                                                                motionEvent2 = motionEvent3;
                                                                                                rectF3 = rectF;
                                                                                                it3 = it;
                                                                                                rawY = f7;
                                                                                                rawX = f6;
                                                                                            }
                                                                                        } else {
                                                                                            transition = motionScene2.mCurrentTransition;
                                                                                        }
                                                                                        if (transition != null) {
                                                                                            setTransition(transition);
                                                                                            RectF touchRegion3 = motionScene2.mCurrentTransition.mTouchResponse.getTouchRegion(motionScene2.mMotionLayout, rectF2);
                                                                                            motionScene2.mMotionOutsideRegion = touchRegion3 != null && !touchRegion3.contains(motionScene2.mLastTouchDown.getX(), motionScene2.mLastTouchDown.getY());
                                                                                            TouchResponse touchResponse6 = motionScene2.mCurrentTransition.mTouchResponse;
                                                                                            float f15 = motionScene2.mLastTouchX;
                                                                                            float f16 = motionScene2.mLastTouchY;
                                                                                            touchResponse6.mLastTouchX = f15;
                                                                                            touchResponse6.mLastTouchY = f16;
                                                                                            touchResponse6.mDragStarted = false;
                                                                                        }
                                                                                    }
                                                                                }
                                                                                if (motionScene2.mIgnoreTouch) {
                                                                                    return true;
                                                                                }
                                                                                MotionScene.Transition transition5 = motionScene2.mCurrentTransition;
                                                                                if (!(transition5 == null || (touchResponse = transition5.mTouchResponse) == null || motionScene2.mMotionOutsideRegion)) {
                                                                                    MotionTracker motionTracker3 = motionScene2.mVelocityTracker;
                                                                                    if (touchResponse.mIsRotateMode) {
                                                                                        MyTracker myTracker = (MyTracker) motionTracker3;
                                                                                        VelocityTracker velocityTracker2 = myTracker.tracker;
                                                                                        if (velocityTracker2 != null) {
                                                                                            velocityTracker2.addMovement(motionEvent);
                                                                                        }
                                                                                        int action2 = motionEvent.getAction();
                                                                                        if (action2 == 0) {
                                                                                            touchResponse.mLastTouchX = motionEvent.getRawX();
                                                                                            touchResponse.mLastTouchY = motionEvent.getRawY();
                                                                                            touchResponse.mDragStarted = false;
                                                                                        } else if (action2 == 1) {
                                                                                            touchResponse.mDragStarted = false;
                                                                                            myTracker.computeCurrentVelocity(16);
                                                                                            float xVelocity = myTracker.getXVelocity();
                                                                                            float yVelocity = myTracker.getYVelocity();
                                                                                            float progress = touchResponse.mMotionLayout.getProgress();
                                                                                            float width = ((float) touchResponse.mMotionLayout.getWidth()) / 2.0f;
                                                                                            float height = ((float) touchResponse.mMotionLayout.getHeight()) / 2.0f;
                                                                                            int i7 = touchResponse.mRotationCenterId;
                                                                                            if (i7 != -1) {
                                                                                                View findViewById = touchResponse.mMotionLayout.findViewById(i7);
                                                                                                touchResponse.mMotionLayout.getLocationOnScreen(touchResponse.mTempLoc);
                                                                                                f4 = (((float) (findViewById.getRight() + findViewById.getLeft())) / 2.0f) + ((float) touchResponse.mTempLoc[0]);
                                                                                                f5 = (float) touchResponse.mTempLoc[1];
                                                                                                i4 = findViewById.getTop();
                                                                                                i5 = findViewById.getBottom();
                                                                                            } else {
                                                                                                int i8 = touchResponse.mTouchAnchorId;
                                                                                                if (i8 != -1) {
                                                                                                    MotionLayout motionLayout = touchResponse.mMotionLayout;
                                                                                                    View findViewById2 = touchResponse.mMotionLayout.findViewById(motionLayout.mFrameArrayList.get(motionLayout.findViewById(i8)).mStartMotionPath.mAnimateRelativeTo);
                                                                                                    touchResponse.mMotionLayout.getLocationOnScreen(touchResponse.mTempLoc);
                                                                                                    f4 = (((float) (findViewById2.getRight() + findViewById2.getLeft())) / 2.0f) + ((float) touchResponse.mTempLoc[0]);
                                                                                                    f5 = (float) touchResponse.mTempLoc[1];
                                                                                                    i4 = findViewById2.getTop();
                                                                                                    i5 = findViewById2.getBottom();
                                                                                                }
                                                                                                float rawX2 = motionEvent.getRawX() - width;
                                                                                                float rawY2 = motionEvent.getRawY() - height;
                                                                                                double degrees = Math.toDegrees(Math.atan2((double) rawY2, (double) rawX2));
                                                                                                i2 = touchResponse.mTouchAnchorId;
                                                                                                if (i2 == -1) {
                                                                                                    touchResponse.mMotionLayout.getAnchorDpDt(i2, progress, touchResponse.mTouchAnchorX, touchResponse.mTouchAnchorY, touchResponse.mAnchorDpDt);
                                                                                                    float[] fArr = touchResponse.mAnchorDpDt;
                                                                                                    fArr[1] = (float) Math.toDegrees((double) fArr[1]);
                                                                                                } else {
                                                                                                    touchResponse.mAnchorDpDt[1] = 360.0f;
                                                                                                }
                                                                                                float degrees2 = ((float) (Math.toDegrees(Math.atan2((double) (yVelocity + rawY2), (double) (xVelocity + rawX2))) - degrees)) * 62.5f;
                                                                                                f3 = Float.isNaN(degrees2) ? (((degrees2 * 3.0f) * touchResponse.mDragScale) / touchResponse.mAnchorDpDt[1]) + progress : progress;
                                                                                                if (f3 == 0.0f && f3 != 1.0f && (i3 = touchResponse.mOnTouchUp) != 3) {
                                                                                                    float f17 = (degrees2 * touchResponse.mDragScale) / touchResponse.mAnchorDpDt[1];
                                                                                                    float f18 = ((double) f3) < 0.5d ? 0.0f : 1.0f;
                                                                                                    if (i3 == 6) {
                                                                                                        if (progress + f17 < 0.0f) {
                                                                                                            f17 = Math.abs(f17);
                                                                                                        }
                                                                                                        f18 = 1.0f;
                                                                                                    }
                                                                                                    if (touchResponse.mOnTouchUp == 7) {
                                                                                                        if (progress + f17 > 1.0f) {
                                                                                                            f17 = -Math.abs(f17);
                                                                                                        }
                                                                                                        f18 = 0.0f;
                                                                                                    }
                                                                                                    touchResponse.mMotionLayout.touchAnimateTo(touchResponse.mOnTouchUp, f18, f17 * 3.0f);
                                                                                                    if (0.0f >= progress || 1.0f <= progress) {
                                                                                                        touchResponse.mMotionLayout.setState(TransitionState.FINISHED);
                                                                                                    }
                                                                                                } else if (0.0f >= f3 || 1.0f <= f3) {
                                                                                                    touchResponse.mMotionLayout.setState(TransitionState.FINISHED);
                                                                                                }
                                                                                            }
                                                                                            height = f5 + (((float) (i5 + i4)) / 2.0f);
                                                                                            width = f4;
                                                                                            float rawX22 = motionEvent.getRawX() - width;
                                                                                            float rawY22 = motionEvent.getRawY() - height;
                                                                                            double degrees3 = Math.toDegrees(Math.atan2((double) rawY22, (double) rawX22));
                                                                                            i2 = touchResponse.mTouchAnchorId;
                                                                                            if (i2 == -1) {
                                                                                            }
                                                                                            float degrees22 = ((float) (Math.toDegrees(Math.atan2((double) (yVelocity + rawY22), (double) (xVelocity + rawX22))) - degrees3)) * 62.5f;
                                                                                            if (Float.isNaN(degrees22)) {
                                                                                            }
                                                                                            if (f3 == 0.0f) {
                                                                                            }
                                                                                            touchResponse.mMotionLayout.setState(TransitionState.FINISHED);
                                                                                        } else if (action2 == 2) {
                                                                                            motionEvent.getRawY();
                                                                                            motionEvent.getRawX();
                                                                                            float width2 = ((float) touchResponse.mMotionLayout.getWidth()) / 2.0f;
                                                                                            float height2 = ((float) touchResponse.mMotionLayout.getHeight()) / 2.0f;
                                                                                            int i9 = touchResponse.mRotationCenterId;
                                                                                            if (i9 != -1) {
                                                                                                View findViewById3 = touchResponse.mMotionLayout.findViewById(i9);
                                                                                                touchResponse.mMotionLayout.getLocationOnScreen(touchResponse.mTempLoc);
                                                                                                float right = ((float) touchResponse.mTempLoc[0]) + (((float) (findViewById3.getRight() + findViewById3.getLeft())) / 2.0f);
                                                                                                height2 = (((float) (findViewById3.getBottom() + findViewById3.getTop())) / 2.0f) + ((float) touchResponse.mTempLoc[1]);
                                                                                                width2 = right;
                                                                                            } else {
                                                                                                int i10 = touchResponse.mTouchAnchorId;
                                                                                                if (i10 != -1) {
                                                                                                    MotionLayout motionLayout2 = touchResponse.mMotionLayout;
                                                                                                    View findViewById4 = touchResponse.mMotionLayout.findViewById(motionLayout2.mFrameArrayList.get(motionLayout2.findViewById(i10)).mStartMotionPath.mAnimateRelativeTo);
                                                                                                    if (findViewById4 == null) {
                                                                                                        Log.e("TouchResponse", "could not find view to animate to");
                                                                                                    } else {
                                                                                                        touchResponse.mMotionLayout.getLocationOnScreen(touchResponse.mTempLoc);
                                                                                                        width2 = ((float) touchResponse.mTempLoc[0]) + (((float) (findViewById4.getRight() + findViewById4.getLeft())) / 2.0f);
                                                                                                        height2 = ((float) touchResponse.mTempLoc[1]) + (((float) (findViewById4.getBottom() + findViewById4.getTop())) / 2.0f);
                                                                                                    }
                                                                                                }
                                                                                            }
                                                                                            float rawX3 = motionEvent.getRawX() - width2;
                                                                                            float rawY3 = motionEvent.getRawY() - height2;
                                                                                            double atan22 = Math.atan2((double) (motionEvent.getRawY() - height2), (double) (motionEvent.getRawX() - width2));
                                                                                            float atan23 = (float) (((atan22 - Math.atan2((double) (touchResponse.mLastTouchY - height2), (double) (touchResponse.mLastTouchX - width2))) * 180.0d) / 3.141592653589793d);
                                                                                            if (atan23 > 330.0f) {
                                                                                                atan23 -= 360.0f;
                                                                                            } else if (atan23 < -330.0f) {
                                                                                                atan23 += 360.0f;
                                                                                            }
                                                                                            if (((double) Math.abs(atan23)) > 0.01d || touchResponse.mDragStarted) {
                                                                                                float progress2 = touchResponse.mMotionLayout.getProgress();
                                                                                                if (!touchResponse.mDragStarted) {
                                                                                                    touchResponse.mDragStarted = true;
                                                                                                    touchResponse.mMotionLayout.setProgress(progress2);
                                                                                                }
                                                                                                int i11 = touchResponse.mTouchAnchorId;
                                                                                                if (i11 != -1) {
                                                                                                    touchResponse.mMotionLayout.getAnchorDpDt(i11, progress2, touchResponse.mTouchAnchorX, touchResponse.mTouchAnchorY, touchResponse.mAnchorDpDt);
                                                                                                    float[] fArr2 = touchResponse.mAnchorDpDt;
                                                                                                    c7 = 1;
                                                                                                    fArr2[1] = (float) Math.toDegrees((double) fArr2[1]);
                                                                                                } else {
                                                                                                    c7 = 1;
                                                                                                    touchResponse.mAnchorDpDt[1] = 360.0f;
                                                                                                }
                                                                                                float max = Math.max(Math.min(((atan23 * touchResponse.mDragScale) / touchResponse.mAnchorDpDt[c7]) + progress2, 1.0f), 0.0f);
                                                                                                float progress3 = touchResponse.mMotionLayout.getProgress();
                                                                                                if (max != progress3) {
                                                                                                    int i12 = (progress3 > 0.0f ? 1 : (progress3 == 0.0f ? 0 : -1));
                                                                                                    if (i12 == 0 || progress3 == 1.0f) {
                                                                                                        touchResponse.mMotionLayout.endTrigger(i12 == 0);
                                                                                                    }
                                                                                                    touchResponse.mMotionLayout.setProgress(max);
                                                                                                    myTracker.computeCurrentVelocity(1000);
                                                                                                    float xVelocity2 = myTracker.getXVelocity();
                                                                                                    double yVelocity2 = (double) myTracker.getYVelocity();
                                                                                                    double d2 = (double) xVelocity2;
                                                                                                    touchResponse.mMotionLayout.mLastVelocity = (float) Math.toDegrees((double) ((float) ((Math.sin(Math.atan2(yVelocity2, d2) - atan22) * Math.hypot(yVelocity2, d2)) / Math.hypot((double) rawX3, (double) rawY3))));
                                                                                                } else {
                                                                                                    touchResponse.mMotionLayout.mLastVelocity = 0.0f;
                                                                                                }
                                                                                                touchResponse.mLastTouchX = motionEvent.getRawX();
                                                                                                touchResponse.mLastTouchY = motionEvent.getRawY();
                                                                                            }
                                                                                        }
                                                                                    } else {
                                                                                        MyTracker myTracker2 = (MyTracker) motionTracker3;
                                                                                        VelocityTracker velocityTracker3 = myTracker2.tracker;
                                                                                        if (velocityTracker3 != null) {
                                                                                            velocityTracker3.addMovement(motionEvent);
                                                                                        }
                                                                                        int action3 = motionEvent.getAction();
                                                                                        if (action3 == 0) {
                                                                                            touchResponse.mLastTouchX = motionEvent.getRawX();
                                                                                            touchResponse.mLastTouchY = motionEvent.getRawY();
                                                                                            touchResponse.mDragStarted = false;
                                                                                        } else if (action3 == 1) {
                                                                                            touchResponse.mDragStarted = false;
                                                                                            myTracker2.computeCurrentVelocity(1000);
                                                                                            float xVelocity3 = myTracker2.getXVelocity();
                                                                                            float yVelocity3 = myTracker2.getYVelocity();
                                                                                            float progress4 = touchResponse.mMotionLayout.getProgress();
                                                                                            int i13 = touchResponse.mTouchAnchorId;
                                                                                            if (i13 != -1) {
                                                                                                touchResponse.mMotionLayout.getAnchorDpDt(i13, progress4, touchResponse.mTouchAnchorX, touchResponse.mTouchAnchorY, touchResponse.mAnchorDpDt);
                                                                                                c2 = 0;
                                                                                                c = 1;
                                                                                            } else {
                                                                                                float min = (float) Math.min(touchResponse.mMotionLayout.getWidth(), touchResponse.mMotionLayout.getHeight());
                                                                                                float[] fArr3 = touchResponse.mAnchorDpDt;
                                                                                                c = 1;
                                                                                                fArr3[1] = touchResponse.mTouchDirectionY * min;
                                                                                                c2 = 0;
                                                                                                fArr3[0] = min * touchResponse.mTouchDirectionX;
                                                                                            }
                                                                                            float f19 = touchResponse.mTouchDirectionX;
                                                                                            float[] fArr4 = touchResponse.mAnchorDpDt;
                                                                                            float f20 = fArr4[c2];
                                                                                            float f21 = fArr4[c];
                                                                                            if (f19 != 0.0f) {
                                                                                                f = xVelocity3 / fArr4[c2];
                                                                                            } else {
                                                                                                f = yVelocity3 / fArr4[c];
                                                                                            }
                                                                                            float f22 = !Float.isNaN(f) ? (f / 3.0f) + progress4 : progress4;
                                                                                            if (f22 != 0.0f && f22 != 1.0f && (i = touchResponse.mOnTouchUp) != 3) {
                                                                                                float f23 = ((double) f22) < 0.5d ? 0.0f : 1.0f;
                                                                                                if (i == 6) {
                                                                                                    if (progress4 + f < 0.0f) {
                                                                                                        f = Math.abs(f);
                                                                                                    }
                                                                                                    f23 = 1.0f;
                                                                                                }
                                                                                                if (touchResponse.mOnTouchUp == 7) {
                                                                                                    if (progress4 + f > 1.0f) {
                                                                                                        f = -Math.abs(f);
                                                                                                    }
                                                                                                    f23 = 0.0f;
                                                                                                }
                                                                                                touchResponse.mMotionLayout.touchAnimateTo(touchResponse.mOnTouchUp, f23, f);
                                                                                                if (0.0f >= progress4 || 1.0f <= progress4) {
                                                                                                    touchResponse.mMotionLayout.setState(TransitionState.FINISHED);
                                                                                                }
                                                                                            } else if (0.0f >= f22 || 1.0f <= f22) {
                                                                                                touchResponse.mMotionLayout.setState(TransitionState.FINISHED);
                                                                                            }
                                                                                        } else if (action3 == 2) {
                                                                                            float rawY4 = motionEvent.getRawY() - touchResponse.mLastTouchY;
                                                                                            float rawX4 = motionEvent.getRawX() - touchResponse.mLastTouchX;
                                                                                            if (Math.abs((touchResponse.mTouchDirectionY * rawY4) + (touchResponse.mTouchDirectionX * rawX4)) > touchResponse.mDragThreshold || touchResponse.mDragStarted) {
                                                                                                float progress5 = touchResponse.mMotionLayout.getProgress();
                                                                                                if (!touchResponse.mDragStarted) {
                                                                                                    touchResponse.mDragStarted = true;
                                                                                                    touchResponse.mMotionLayout.setProgress(progress5);
                                                                                                }
                                                                                                int i14 = touchResponse.mTouchAnchorId;
                                                                                                if (i14 != -1) {
                                                                                                    touchResponse.mMotionLayout.getAnchorDpDt(i14, progress5, touchResponse.mTouchAnchorX, touchResponse.mTouchAnchorY, touchResponse.mAnchorDpDt);
                                                                                                    c4 = 0;
                                                                                                    c3 = 1;
                                                                                                } else {
                                                                                                    float min2 = (float) Math.min(touchResponse.mMotionLayout.getWidth(), touchResponse.mMotionLayout.getHeight());
                                                                                                    float[] fArr5 = touchResponse.mAnchorDpDt;
                                                                                                    c3 = 1;
                                                                                                    fArr5[1] = touchResponse.mTouchDirectionY * min2;
                                                                                                    c4 = 0;
                                                                                                    fArr5[0] = min2 * touchResponse.mTouchDirectionX;
                                                                                                }
                                                                                                float f24 = touchResponse.mTouchDirectionX;
                                                                                                float[] fArr6 = touchResponse.mAnchorDpDt;
                                                                                                if (((double) Math.abs(((touchResponse.mTouchDirectionY * fArr6[c3]) + (f24 * fArr6[c4])) * touchResponse.mDragScale)) < 0.01d) {
                                                                                                    float[] fArr7 = touchResponse.mAnchorDpDt;
                                                                                                    c6 = 0;
                                                                                                    fArr7[0] = 0.01f;
                                                                                                    c5 = 1;
                                                                                                    fArr7[1] = 0.01f;
                                                                                                } else {
                                                                                                    c6 = 0;
                                                                                                    c5 = 1;
                                                                                                }
                                                                                                if (touchResponse.mTouchDirectionX != 0.0f) {
                                                                                                    f2 = rawX4 / touchResponse.mAnchorDpDt[c6];
                                                                                                } else {
                                                                                                    f2 = rawY4 / touchResponse.mAnchorDpDt[c5];
                                                                                                }
                                                                                                float max2 = Math.max(Math.min(progress5 + f2, 1.0f), 0.0f);
                                                                                                if (touchResponse.mOnTouchUp == 6) {
                                                                                                    max2 = Math.max(max2, 0.01f);
                                                                                                }
                                                                                                if (touchResponse.mOnTouchUp == 7) {
                                                                                                    max2 = Math.min(max2, 0.99f);
                                                                                                }
                                                                                                float progress6 = touchResponse.mMotionLayout.getProgress();
                                                                                                if (max2 != progress6) {
                                                                                                    int i15 = (progress6 > 0.0f ? 1 : (progress6 == 0.0f ? 0 : -1));
                                                                                                    if (i15 == 0 || progress6 == 1.0f) {
                                                                                                        touchResponse.mMotionLayout.endTrigger(i15 == 0);
                                                                                                    }
                                                                                                    touchResponse.mMotionLayout.setProgress(max2);
                                                                                                    myTracker2.computeCurrentVelocity(1000);
                                                                                                    touchResponse.mMotionLayout.mLastVelocity = touchResponse.mTouchDirectionX != 0.0f ? myTracker2.getXVelocity() / touchResponse.mAnchorDpDt[0] : myTracker2.getYVelocity() / touchResponse.mAnchorDpDt[1];
                                                                                                } else {
                                                                                                    touchResponse.mMotionLayout.mLastVelocity = 0.0f;
                                                                                                }
                                                                                                touchResponse.mLastTouchX = motionEvent.getRawX();
                                                                                                touchResponse.mLastTouchY = motionEvent.getRawY();
                                                                                            }
                                                                                        }
                                                                                    }
                                                                                }
                                                                                motionScene2.mLastTouchX = motionEvent.getRawX();
                                                                                motionScene2.mLastTouchY = motionEvent.getRawY();
                                                                                if (motionEvent.getAction() != 1 || (motionTracker = motionScene2.mVelocityTracker) == null) {
                                                                                    return true;
                                                                                }
                                                                                MyTracker myTracker3 = (MyTracker) motionTracker;
                                                                                VelocityTracker velocityTracker4 = myTracker3.tracker;
                                                                                if (velocityTracker4 != null) {
                                                                                    velocityTracker4.recycle();
                                                                                    motionTracker2 = null;
                                                                                    myTracker3.tracker = null;
                                                                                } else {
                                                                                    motionTracker2 = null;
                                                                                }
                                                                                motionScene2.mVelocityTracker = motionTracker2;
                                                                                int i16 = this.mCurrentState;
                                                                                if (i16 == -1) {
                                                                                    return true;
                                                                                }
                                                                                motionScene2.autoTransition(this, i16);
                                                                                return true;
                                                                            }

                                                                            @Override // androidx.constraintlayout.widget.ConstraintLayout
                                                                            public void onViewAdded(View view) {
                                                                                super.onViewAdded(view);
                                                                                if (view instanceof MotionHelper) {
                                                                                    MotionHelper motionHelper = (MotionHelper) view;
                                                                                    if (this.mTransitionListeners == null) {
                                                                                        this.mTransitionListeners = new CopyOnWriteArrayList<>();
                                                                                    }
                                                                                    this.mTransitionListeners.add(motionHelper);
                                                                                    if (motionHelper.mUseOnShow) {
                                                                                        if (this.mOnShowHelpers == null) {
                                                                                            this.mOnShowHelpers = new ArrayList<>();
                                                                                        }
                                                                                        this.mOnShowHelpers.add(motionHelper);
                                                                                    }
                                                                                    if (motionHelper.mUseOnHide) {
                                                                                        if (this.mOnHideHelpers == null) {
                                                                                            this.mOnHideHelpers = new ArrayList<>();
                                                                                        }
                                                                                        this.mOnHideHelpers.add(motionHelper);
                                                                                    }
                                                                                    if (motionHelper instanceof MotionEffect) {
                                                                                        if (this.mDecoratorsHelpers == null) {
                                                                                            this.mDecoratorsHelpers = new ArrayList<>();
                                                                                        }
                                                                                        this.mDecoratorsHelpers.add(motionHelper);
                                                                                    }
                                                                                }
                                                                            }

                                                                            @Override // androidx.constraintlayout.widget.ConstraintLayout
                                                                            public void onViewRemoved(View view) {
                                                                                super.onViewRemoved(view);
                                                                                ArrayList<MotionHelper> arrayList = this.mOnShowHelpers;
                                                                                if (arrayList != null) {
                                                                                    arrayList.remove(view);
                                                                                }
                                                                                ArrayList<MotionHelper> arrayList2 = this.mOnHideHelpers;
                                                                                if (arrayList2 != null) {
                                                                                    arrayList2.remove(view);
                                                                                }
                                                                            }

                                                                            @Override // androidx.constraintlayout.widget.ConstraintLayout
                                                                            public void parseLayoutDescription(int i) {
                                                                                this.mConstraintLayoutSpec = null;
                                                                            }

                                                                            public final void processTransitionCompleted() {
                                                                                CopyOnWriteArrayList<TransitionListener> copyOnWriteArrayList;
                                                                                if (this.mTransitionListener != null || ((copyOnWriteArrayList = this.mTransitionListeners) != null && !copyOnWriteArrayList.isEmpty())) {
                                                                                    Iterator<Integer> it = this.mTransitionCompleted.iterator();
                                                                                    while (it.hasNext()) {
                                                                                        Integer next = it.next();
                                                                                        TransitionListener transitionListener = this.mTransitionListener;
                                                                                        if (transitionListener != null) {
                                                                                            transitionListener.onTransitionCompleted(this, next.intValue());
                                                                                        }
                                                                                        CopyOnWriteArrayList<TransitionListener> copyOnWriteArrayList2 = this.mTransitionListeners;
                                                                                        if (copyOnWriteArrayList2 != null) {
                                                                                            Iterator<TransitionListener> it2 = copyOnWriteArrayList2.iterator();
                                                                                            while (it2.hasNext()) {
                                                                                                it2.next().onTransitionCompleted(this, next.intValue());
                                                                                            }
                                                                                        }
                                                                                    }
                                                                                    this.mTransitionCompleted.clear();
                                                                                }
                                                                            }

                                                                            public void rebuildScene() {
                                                                                this.mModel.reEvaluateState();
                                                                                invalidate();
                                                                            }

                                                                            @Override // androidx.constraintlayout.widget.ConstraintLayout
                                                                            public void requestLayout() {
                                                                                MotionScene motionScene;
                                                                                MotionScene.Transition transition;
                                                                                if (this.mMeasureDuringTransition || this.mCurrentState != -1 || (motionScene = this.mScene) == null || (transition = motionScene.mCurrentTransition) == null || transition.mLayoutDuringTransition != 0) {
                                                                                    super.requestLayout();
                                                                                }
                                                                            }

                                                                            public void setDebugMode(int i) {
                                                                                this.mDebugPath = i;
                                                                                invalidate();
                                                                            }

                                                                            public void setDelayedApplicationOfInitialState(boolean z) {
                                                                                this.mDelayedApply = z;
                                                                            }

                                                                            public void setInteractionEnabled(boolean z) {
                                                                                this.mInteractionEnabled = z;
                                                                            }

                                                                            public void setInterpolatedProgress(float f) {
                                                                                if (this.mScene != null) {
                                                                                    setState(TransitionState.MOVING);
                                                                                    Interpolator interpolator = this.mScene.getInterpolator();
                                                                                    if (interpolator != null) {
                                                                                        setProgress(interpolator.getInterpolation(f));
                                                                                        return;
                                                                                    }
                                                                                }
                                                                                setProgress(f);
                                                                            }

                                                                            public void setOnHide(float f) {
                                                                                ArrayList<MotionHelper> arrayList = this.mOnHideHelpers;
                                                                                if (arrayList != null) {
                                                                                    int size = arrayList.size();
                                                                                    for (int i = 0; i < size; i++) {
                                                                                        this.mOnHideHelpers.get(i).setProgress(f);
                                                                                    }
                                                                                }
                                                                            }

                                                                            public void setOnShow(float f) {
                                                                                ArrayList<MotionHelper> arrayList = this.mOnShowHelpers;
                                                                                if (arrayList != null) {
                                                                                    int size = arrayList.size();
                                                                                    for (int i = 0; i < size; i++) {
                                                                                        this.mOnShowHelpers.get(i).setProgress(f);
                                                                                    }
                                                                                }
                                                                            }

                                                                            public void setProgress(float f) {
                                                                                int i = (f > 0.0f ? 1 : (f == 0.0f ? 0 : -1));
                                                                                if (i < 0 || f > 1.0f) {
                                                                                    Log.w("MotionLayout", "Warning! Progress is defined for values between 0.0 and 1.0 inclusive");
                                                                                }
                                                                                if (!isAttachedToWindow()) {
                                                                                    if (this.mStateCache == null) {
                                                                                        this.mStateCache = new StateCache();
                                                                                    }
                                                                                    this.mStateCache.mProgress = f;
                                                                                    return;
                                                                                }
                                                                                if (i <= 0) {
                                                                                    if (this.mTransitionLastPosition == 1.0f && this.mCurrentState == this.mEndState) {
                                                                                        setState(TransitionState.MOVING);
                                                                                    }
                                                                                    this.mCurrentState = this.mBeginState;
                                                                                    if (this.mTransitionLastPosition == 0.0f) {
                                                                                        setState(TransitionState.FINISHED);
                                                                                    }
                                                                                } else if (f >= 1.0f) {
                                                                                    if (this.mTransitionLastPosition == 0.0f && this.mCurrentState == this.mBeginState) {
                                                                                        setState(TransitionState.MOVING);
                                                                                    }
                                                                                    this.mCurrentState = this.mEndState;
                                                                                    if (this.mTransitionLastPosition == 1.0f) {
                                                                                        setState(TransitionState.FINISHED);
                                                                                    }
                                                                                } else {
                                                                                    this.mCurrentState = -1;
                                                                                    setState(TransitionState.MOVING);
                                                                                }
                                                                                if (this.mScene != null) {
                                                                                    this.mTransitionInstantly = true;
                                                                                    this.mTransitionGoalPosition = f;
                                                                                    this.mTransitionPosition = f;
                                                                                    this.mTransitionLastTime = -1;
                                                                                    this.mAnimationStartTime = -1;
                                                                                    this.mInterpolator = null;
                                                                                    this.mInTransition = true;
                                                                                    invalidate();
                                                                                }
                                                                            }

                                                                            public void setScene(MotionScene motionScene) {
                                                                                TouchResponse touchResponse;
                                                                                this.mScene = motionScene;
                                                                                boolean isRtl = isRtl();
                                                                                motionScene.mRtl = isRtl;
                                                                                MotionScene.Transition transition = motionScene.mCurrentTransition;
                                                                                if (!(transition == null || (touchResponse = transition.mTouchResponse) == null)) {
                                                                                    touchResponse.setRTL(isRtl);
                                                                                }
                                                                                rebuildScene();
                                                                            }

                                                                            public void setStartState(int i) {
                                                                                if (!isAttachedToWindow()) {
                                                                                    if (this.mStateCache == null) {
                                                                                        this.mStateCache = new StateCache();
                                                                                    }
                                                                                    StateCache stateCache = this.mStateCache;
                                                                                    stateCache.startState = i;
                                                                                    stateCache.endState = i;
                                                                                    return;
                                                                                }
                                                                                this.mCurrentState = i;
                                                                            }

                                                                            public void setState(TransitionState transitionState) {
                                                                                TransitionState transitionState2 = TransitionState.FINISHED;
                                                                                if (transitionState != transitionState2 || this.mCurrentState != -1) {
                                                                                    TransitionState transitionState3 = this.mTransitionState;
                                                                                    this.mTransitionState = transitionState;
                                                                                    TransitionState transitionState4 = TransitionState.MOVING;
                                                                                    if (transitionState3 == transitionState4 && transitionState == transitionState4) {
                                                                                        fireTransitionChange();
                                                                                    }
                                                                                    int ordinal = transitionState3.ordinal();
                                                                                    if (ordinal == 0 || ordinal == 1) {
                                                                                        if (transitionState == transitionState4) {
                                                                                            fireTransitionChange();
                                                                                        }
                                                                                        if (transitionState == transitionState2) {
                                                                                            fireTransitionCompleted();
                                                                                        }
                                                                                    } else if (ordinal == 2 && transitionState == transitionState2) {
                                                                                        fireTransitionCompleted();
                                                                                    }
                                                                                }
                                                                            }

                                                                            public void setTransition(int i, int i2) {
                                                                                if (!isAttachedToWindow()) {
                                                                                    if (this.mStateCache == null) {
                                                                                        this.mStateCache = new StateCache();
                                                                                    }
                                                                                    StateCache stateCache = this.mStateCache;
                                                                                    stateCache.startState = i;
                                                                                    stateCache.endState = i2;
                                                                                    return;
                                                                                }
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene != null) {
                                                                                    this.mBeginState = i;
                                                                                    this.mEndState = i2;
                                                                                    motionScene.setTransition(i, i2);
                                                                                    this.mModel.initFrom(this.mScene.getConstraintSet(i), this.mScene.getConstraintSet(i2));
                                                                                    rebuildScene();
                                                                                    this.mTransitionLastPosition = 0.0f;
                                                                                    animateTo(0.0f);
                                                                                }
                                                                            }

                                                                            public void setTransitionDuration(int i) {
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene == null) {
                                                                                    Log.e("MotionLayout", "MotionScene not defined");
                                                                                    return;
                                                                                }
                                                                                MotionScene.Transition transition = motionScene.mCurrentTransition;
                                                                                if (transition != null) {
                                                                                    transition.mDuration = Math.max(i, 8);
                                                                                } else {
                                                                                    motionScene.mDefaultDuration = i;
                                                                                }
                                                                            }

                                                                            public void setTransitionListener(TransitionListener transitionListener) {
                                                                                this.mTransitionListener = transitionListener;
                                                                            }

                                                                            public void setTransitionState(Bundle bundle) {
                                                                                if (this.mStateCache == null) {
                                                                                    this.mStateCache = new StateCache();
                                                                                }
                                                                                StateCache stateCache = this.mStateCache;
                                                                                Objects.requireNonNull(stateCache);
                                                                                stateCache.mProgress = bundle.getFloat("motion.progress");
                                                                                stateCache.mVelocity = bundle.getFloat("motion.velocity");
                                                                                stateCache.startState = bundle.getInt("motion.StartState");
                                                                                stateCache.endState = bundle.getInt("motion.EndState");
                                                                                if (isAttachedToWindow()) {
                                                                                    this.mStateCache.apply();
                                                                                }
                                                                            }

                                                                            public String toString() {
                                                                                Context context = getContext();
                                                                                return AppCompatDelegateImpl.Api17Impl.getName(context, this.mBeginState) + "->" + AppCompatDelegateImpl.Api17Impl.getName(context, this.mEndState) + " (pos:" + this.mTransitionLastPosition + " Dpos/Dt:" + this.mLastVelocity;
                                                                            }

                                                                            /* JADX WARNING: Code restructure failed: missing block: B:15:0x0041, code lost:
                                                                                if (r15 != 7) goto L_0x0171;
                                                                             */
                                                                            /* JADX WARNING: Code restructure failed: missing block: B:19:0x0060, code lost:
                                                                                if ((((r17 * r6) - (((r3 * r6) * r6) / 2.0f)) + r1) > 1.0f) goto L_0x0074;
                                                                             */
                                                                            /* JADX WARNING: Code restructure failed: missing block: B:21:0x0070, code lost:
                                                                                if ((((((r3 * r6) * r6) / 2.0f) + (r17 * r6)) + r1) < 0.0f) goto L_0x0074;
                                                                             */
                                                                            public void touchAnimateTo(int i, float f, float f2) {
                                                                                TouchResponse touchResponse;
                                                                                TouchResponse touchResponse2;
                                                                                TouchResponse touchResponse3;
                                                                                TouchResponse touchResponse4;
                                                                                TouchResponse touchResponse5;
                                                                                TouchResponse touchResponse6;
                                                                                TouchResponse touchResponse7;
                                                                                TouchResponse touchResponse8;
                                                                                float f3 = f;
                                                                                if (this.mScene != null && this.mTransitionLastPosition != f3) {
                                                                                    boolean z = true;
                                                                                    this.mTemporalInterpolator = true;
                                                                                    this.mAnimationStartTime = getNanoTime();
                                                                                    float duration = ((float) this.mScene.getDuration()) / 1000.0f;
                                                                                    this.mTransitionDuration = duration;
                                                                                    this.mTransitionGoalPosition = f3;
                                                                                    this.mInTransition = true;
                                                                                    if (!(i == 0 || i == 1 || i == 2)) {
                                                                                        if (i == 4) {
                                                                                            DecelerateInterpolator decelerateInterpolator = this.mDecelerateLogic;
                                                                                            float f4 = this.mTransitionLastPosition;
                                                                                            float maxAcceleration = this.mScene.getMaxAcceleration();
                                                                                            decelerateInterpolator.initalV = f2;
                                                                                            decelerateInterpolator.currentP = f4;
                                                                                            decelerateInterpolator.maxA = maxAcceleration;
                                                                                            this.mInterpolator = this.mDecelerateLogic;
                                                                                        } else if (i == 5) {
                                                                                            float f5 = this.mTransitionLastPosition;
                                                                                            float maxAcceleration2 = this.mScene.getMaxAcceleration();
                                                                                            if (f2 > 0.0f) {
                                                                                                float f6 = f2 / maxAcceleration2;
                                                                                            } else {
                                                                                                float f7 = (-f2) / maxAcceleration2;
                                                                                            }
                                                                                            z = false;
                                                                                            if (z) {
                                                                                                DecelerateInterpolator decelerateInterpolator2 = this.mDecelerateLogic;
                                                                                                float f8 = this.mTransitionLastPosition;
                                                                                                float maxAcceleration3 = this.mScene.getMaxAcceleration();
                                                                                                decelerateInterpolator2.initalV = f2;
                                                                                                decelerateInterpolator2.currentP = f8;
                                                                                                decelerateInterpolator2.maxA = maxAcceleration3;
                                                                                                this.mInterpolator = this.mDecelerateLogic;
                                                                                            } else {
                                                                                                StopLogic stopLogic = this.mStopLogic;
                                                                                                float f9 = this.mTransitionLastPosition;
                                                                                                float f10 = this.mTransitionDuration;
                                                                                                float maxAcceleration4 = this.mScene.getMaxAcceleration();
                                                                                                MotionScene.Transition transition = this.mScene.mCurrentTransition;
                                                                                                stopLogic.config(f9, f, f2, f10, maxAcceleration4, (transition == null || (touchResponse8 = transition.mTouchResponse) == null) ? 0.0f : touchResponse8.mMaxVelocity);
                                                                                                this.mLastVelocity = 0.0f;
                                                                                                int i2 = this.mCurrentState;
                                                                                                this.mTransitionGoalPosition = f3;
                                                                                                this.mCurrentState = i2;
                                                                                                this.mInterpolator = this.mStopLogic;
                                                                                            }
                                                                                        } else if (i != 6) {
                                                                                        }
                                                                                        this.mTransitionInstantly = false;
                                                                                        this.mAnimationStartTime = getNanoTime();
                                                                                        invalidate();
                                                                                    }
                                                                                    if (i == 1 || i == 7) {
                                                                                        f3 = 0.0f;
                                                                                    } else if (i == 2 || i == 6) {
                                                                                        f3 = 1.0f;
                                                                                    }
                                                                                    MotionScene motionScene = this.mScene;
                                                                                    MotionScene.Transition transition2 = motionScene.mCurrentTransition;
                                                                                    if (((transition2 == null || (touchResponse7 = transition2.mTouchResponse) == null) ? 0 : touchResponse7.mAutoCompleteMode) == 0) {
                                                                                        StopLogic stopLogic2 = this.mStopLogic;
                                                                                        float f11 = this.mTransitionLastPosition;
                                                                                        float maxAcceleration5 = motionScene.getMaxAcceleration();
                                                                                        MotionScene.Transition transition3 = this.mScene.mCurrentTransition;
                                                                                        stopLogic2.config(f11, f3, f2, duration, maxAcceleration5, (transition3 == null || (touchResponse6 = transition3.mTouchResponse) == null) ? 0.0f : touchResponse6.mMaxVelocity);
                                                                                    } else {
                                                                                        StopLogic stopLogic3 = this.mStopLogic;
                                                                                        float f12 = this.mTransitionLastPosition;
                                                                                        float f13 = (transition2 == null || (touchResponse5 = transition2.mTouchResponse) == null) ? 0.0f : touchResponse5.mSpringMass;
                                                                                        float f14 = (transition2 == null || (touchResponse4 = transition2.mTouchResponse) == null) ? 0.0f : touchResponse4.mSpringStiffness;
                                                                                        float f15 = (transition2 == null || (touchResponse3 = transition2.mTouchResponse) == null) ? 0.0f : touchResponse3.mSpringDamping;
                                                                                        float f16 = (transition2 == null || (touchResponse2 = transition2.mTouchResponse) == null) ? 0.0f : touchResponse2.mSpringStopThreshold;
                                                                                        int i3 = (transition2 == null || (touchResponse = transition2.mTouchResponse) == null) ? 0 : touchResponse.mSpringBoundary;
                                                                                        if (stopLogic3.mSpringStopEngine == null) {
                                                                                            stopLogic3.mSpringStopEngine = new SpringStopEngine();
                                                                                        }
                                                                                        SpringStopEngine springStopEngine = stopLogic3.mSpringStopEngine;
                                                                                        stopLogic3.mEngine = springStopEngine;
                                                                                        springStopEngine.mTargetPos = (double) f3;
                                                                                        springStopEngine.mDamping = (double) f15;
                                                                                        springStopEngine.mPos = f12;
                                                                                        springStopEngine.mStiffness = (double) f14;
                                                                                        springStopEngine.mMass = f13;
                                                                                        springStopEngine.mStopThreshold = f16;
                                                                                        springStopEngine.mBoundaryMode = i3;
                                                                                        springStopEngine.mLastTime = 0.0f;
                                                                                    }
                                                                                    int i4 = this.mCurrentState;
                                                                                    this.mTransitionGoalPosition = f3;
                                                                                    this.mCurrentState = i4;
                                                                                    this.mInterpolator = this.mStopLogic;
                                                                                    this.mTransitionInstantly = false;
                                                                                    this.mAnimationStartTime = getNanoTime();
                                                                                    invalidate();
                                                                                }
                                                                            }

                                                                            public void transitionToEnd() {
                                                                                animateTo(1.0f);
                                                                                this.mOnComplete = null;
                                                                            }

                                                                            public void transitionToState(int i) {
                                                                                if (!isAttachedToWindow()) {
                                                                                    if (this.mStateCache == null) {
                                                                                        this.mStateCache = new StateCache();
                                                                                    }
                                                                                    this.mStateCache.endState = i;
                                                                                    return;
                                                                                }
                                                                                transitionToState(i, -1, -1, -1);
                                                                            }

                                                                            public void updateState(int i, ConstraintSet constraintSet) {
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene != null) {
                                                                                    motionScene.mConstraintSetMap.put(i, constraintSet);
                                                                                }
                                                                                this.mModel.initFrom(this.mScene.getConstraintSet(this.mBeginState), this.mScene.getConstraintSet(this.mEndState));
                                                                                rebuildScene();
                                                                                if (this.mCurrentState == i) {
                                                                                    constraintSet.applyToInternal(this, true);
                                                                                    setConstraintSet(null);
                                                                                    requestLayout();
                                                                                }
                                                                            }

                                                                            public void transitionToState(int i, int i2) {
                                                                                if (!isAttachedToWindow()) {
                                                                                    if (this.mStateCache == null) {
                                                                                        this.mStateCache = new StateCache();
                                                                                    }
                                                                                    this.mStateCache.endState = i;
                                                                                    return;
                                                                                }
                                                                                transitionToState(i, -1, -1, i2);
                                                                            }

                                                                            public void setState(int i, int i2, int i3) {
                                                                                ConstraintSet constraintSet;
                                                                                ConstraintLayoutStates.State state;
                                                                                int findMatch;
                                                                                setState(TransitionState.SETUP);
                                                                                this.mCurrentState = i;
                                                                                this.mBeginState = -1;
                                                                                this.mEndState = -1;
                                                                                ConstraintLayoutStates constraintLayoutStates = this.mConstraintLayoutSpec;
                                                                                ConstraintSet constraintSet2 = null;
                                                                                if (constraintLayoutStates != null) {
                                                                                    float f = (float) i2;
                                                                                    float f2 = (float) i3;
                                                                                    int i4 = constraintLayoutStates.mCurrentStateId;
                                                                                    if (i4 == i) {
                                                                                        if (i == -1) {
                                                                                            state = constraintLayoutStates.mStateList.valueAt(0);
                                                                                        } else {
                                                                                            state = constraintLayoutStates.mStateList.get(i4);
                                                                                        }
                                                                                        int i5 = constraintLayoutStates.mCurrentConstraintNumber;
                                                                                        if ((i5 == -1 || !state.mVariants.get(i5).match(f, f2)) && constraintLayoutStates.mCurrentConstraintNumber != (findMatch = state.findMatch(f, f2))) {
                                                                                            if (findMatch != -1) {
                                                                                                constraintSet2 = state.mVariants.get(findMatch).mConstraintSet;
                                                                                            }
                                                                                            if (findMatch != -1) {
                                                                                                int i6 = state.mVariants.get(findMatch).mConstraintID;
                                                                                            }
                                                                                            if (constraintSet2 != null) {
                                                                                                constraintLayoutStates.mCurrentConstraintNumber = findMatch;
                                                                                                constraintSet2.applyTo(constraintLayoutStates.mConstraintLayout);
                                                                                                return;
                                                                                            }
                                                                                            return;
                                                                                        }
                                                                                        return;
                                                                                    }
                                                                                    constraintLayoutStates.mCurrentStateId = i;
                                                                                    ConstraintLayoutStates.State state2 = constraintLayoutStates.mStateList.get(i);
                                                                                    int findMatch2 = state2.findMatch(f, f2);
                                                                                    if (findMatch2 == -1) {
                                                                                        constraintSet = state2.mConstraintSet;
                                                                                    } else {
                                                                                        constraintSet = state2.mVariants.get(findMatch2).mConstraintSet;
                                                                                    }
                                                                                    if (findMatch2 != -1) {
                                                                                        int i7 = state2.mVariants.get(findMatch2).mConstraintID;
                                                                                    }
                                                                                    if (constraintSet == null) {
                                                                                        Log.v("ConstraintLayoutStates", "NO Constraint set found ! id=" + i + ", dim =" + f + ", " + f2);
                                                                                        return;
                                                                                    }
                                                                                    constraintLayoutStates.mCurrentConstraintNumber = findMatch2;
                                                                                    constraintSet.applyTo(constraintLayoutStates.mConstraintLayout);
                                                                                    return;
                                                                                }
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (motionScene != null) {
                                                                                    motionScene.getConstraintSet(i).applyToInternal(this, true);
                                                                                    setConstraintSet(null);
                                                                                    requestLayout();
                                                                                }
                                                                            }

                                                                            public void transitionToState(int i, int i2, int i3, int i4) {
                                                                                StateSet stateSet;
                                                                                MotionScene motionScene = this.mScene;
                                                                                if (!(motionScene == null || (stateSet = motionScene.mStateSet) == null)) {
                                                                                    int i5 = this.mCurrentState;
                                                                                    float f = (float) i2;
                                                                                    float f2 = (float) i3;
                                                                                    StateSet.State state = stateSet.mStateList.get(i);
                                                                                    if (state == null) {
                                                                                        i5 = i;
                                                                                    } else if (f != -1.0f && f2 != -1.0f) {
                                                                                        Iterator<StateSet.Variant> it = state.mVariants.iterator();
                                                                                        StateSet.Variant variant = null;
                                                                                        while (true) {
                                                                                            if (it.hasNext()) {
                                                                                                StateSet.Variant next = it.next();
                                                                                                if (next.match(f, f2)) {
                                                                                                    if (i5 == next.mConstraintID) {
                                                                                                        break;
                                                                                                    }
                                                                                                    variant = next;
                                                                                                }
                                                                                            } else {
                                                                                                i5 = variant != null ? variant.mConstraintID : state.mConstraintID;
                                                                                            }
                                                                                        }
                                                                                    } else if (state.mConstraintID != i5) {
                                                                                        Iterator<StateSet.Variant> it2 = state.mVariants.iterator();
                                                                                        while (true) {
                                                                                            if (it2.hasNext()) {
                                                                                                if (i5 == it2.next().mConstraintID) {
                                                                                                    break;
                                                                                                }
                                                                                            } else {
                                                                                                i5 = state.mConstraintID;
                                                                                                break;
                                                                                            }
                                                                                        }
                                                                                    }
                                                                                    if (i5 != -1) {
                                                                                        i = i5;
                                                                                    }
                                                                                }
                                                                                int i6 = this.mCurrentState;
                                                                                if (i6 != i) {
                                                                                    if (this.mBeginState == i) {
                                                                                        animateTo(0.0f);
                                                                                        if (i4 > 0) {
                                                                                            this.mTransitionDuration = ((float) i4) / 1000.0f;
                                                                                        }
                                                                                    } else if (this.mEndState == i) {
                                                                                        animateTo(1.0f);
                                                                                        if (i4 > 0) {
                                                                                            this.mTransitionDuration = ((float) i4) / 1000.0f;
                                                                                        }
                                                                                    } else {
                                                                                        this.mEndState = i;
                                                                                        if (i6 != -1) {
                                                                                            setTransition(i6, i);
                                                                                            animateTo(1.0f);
                                                                                            this.mTransitionLastPosition = 0.0f;
                                                                                            transitionToEnd();
                                                                                            if (i4 > 0) {
                                                                                                this.mTransitionDuration = ((float) i4) / 1000.0f;
                                                                                                return;
                                                                                            }
                                                                                            return;
                                                                                        }
                                                                                        this.mTemporalInterpolator = false;
                                                                                        this.mTransitionGoalPosition = 1.0f;
                                                                                        this.mTransitionPosition = 0.0f;
                                                                                        this.mTransitionLastPosition = 0.0f;
                                                                                        this.mTransitionLastTime = getNanoTime();
                                                                                        this.mAnimationStartTime = getNanoTime();
                                                                                        this.mTransitionInstantly = false;
                                                                                        this.mInterpolator = null;
                                                                                        if (i4 == -1) {
                                                                                            this.mTransitionDuration = ((float) this.mScene.getDuration()) / 1000.0f;
                                                                                        }
                                                                                        this.mBeginState = -1;
                                                                                        this.mScene.setTransition(-1, this.mEndState);
                                                                                        SparseArray sparseArray = new SparseArray();
                                                                                        if (i4 == 0) {
                                                                                            this.mTransitionDuration = ((float) this.mScene.getDuration()) / 1000.0f;
                                                                                        } else if (i4 > 0) {
                                                                                            this.mTransitionDuration = ((float) i4) / 1000.0f;
                                                                                        }
                                                                                        int childCount = getChildCount();
                                                                                        this.mFrameArrayList.clear();
                                                                                        for (int i7 = 0; i7 < childCount; i7++) {
                                                                                            View childAt = getChildAt(i7);
                                                                                            this.mFrameArrayList.put(childAt, new MotionController(childAt));
                                                                                            sparseArray.put(childAt.getId(), this.mFrameArrayList.get(childAt));
                                                                                        }
                                                                                        this.mInTransition = true;
                                                                                        this.mModel.initFrom(null, this.mScene.getConstraintSet(i));
                                                                                        rebuildScene();
                                                                                        this.mModel.build();
                                                                                        int childCount2 = getChildCount();
                                                                                        for (int i8 = 0; i8 < childCount2; i8++) {
                                                                                            View childAt2 = getChildAt(i8);
                                                                                            MotionController motionController = this.mFrameArrayList.get(childAt2);
                                                                                            if (motionController != null) {
                                                                                                MotionPaths motionPaths = motionController.mStartMotionPath;
                                                                                                motionPaths.time = 0.0f;
                                                                                                motionPaths.position = 0.0f;
                                                                                                motionPaths.setBounds(childAt2.getX(), childAt2.getY(), (float) childAt2.getWidth(), (float) childAt2.getHeight());
                                                                                                motionController.mStartPoint.setState(childAt2);
                                                                                            }
                                                                                        }
                                                                                        int width = getWidth();
                                                                                        int height = getHeight();
                                                                                        if (this.mDecoratorsHelpers != null) {
                                                                                            for (int i9 = 0; i9 < childCount; i9++) {
                                                                                                MotionController motionController2 = this.mFrameArrayList.get(getChildAt(i9));
                                                                                                if (motionController2 != null) {
                                                                                                    this.mScene.getKeyFrames(motionController2);
                                                                                                }
                                                                                            }
                                                                                            Iterator<MotionHelper> it3 = this.mDecoratorsHelpers.iterator();
                                                                                            while (it3.hasNext()) {
                                                                                                it3.next().onPreSetup(this, this.mFrameArrayList);
                                                                                            }
                                                                                            for (int i10 = 0; i10 < childCount; i10++) {
                                                                                                MotionController motionController3 = this.mFrameArrayList.get(getChildAt(i10));
                                                                                                if (motionController3 != null) {
                                                                                                    motionController3.setup(width, height, getNanoTime());
                                                                                                }
                                                                                            }
                                                                                        } else {
                                                                                            for (int i11 = 0; i11 < childCount; i11++) {
                                                                                                MotionController motionController4 = this.mFrameArrayList.get(getChildAt(i11));
                                                                                                if (motionController4 != null) {
                                                                                                    this.mScene.getKeyFrames(motionController4);
                                                                                                    motionController4.setup(width, height, getNanoTime());
                                                                                                }
                                                                                            }
                                                                                        }
                                                                                        MotionScene.Transition transition = this.mScene.mCurrentTransition;
                                                                                        float f3 = transition != null ? transition.mStagger : 0.0f;
                                                                                        if (f3 != 0.0f) {
                                                                                            float f4 = Float.MAX_VALUE;
                                                                                            float f5 = -3.4028235E38f;
                                                                                            for (int i12 = 0; i12 < childCount; i12++) {
                                                                                                MotionPaths motionPaths2 = this.mFrameArrayList.get(getChildAt(i12)).mEndMotionPath;
                                                                                                float f6 = motionPaths2.y + motionPaths2.x;
                                                                                                f4 = Math.min(f4, f6);
                                                                                                f5 = Math.max(f5, f6);
                                                                                            }
                                                                                            for (int i13 = 0; i13 < childCount; i13++) {
                                                                                                MotionController motionController5 = this.mFrameArrayList.get(getChildAt(i13));
                                                                                                MotionPaths motionPaths3 = motionController5.mEndMotionPath;
                                                                                                float f7 = motionPaths3.x;
                                                                                                float f8 = motionPaths3.y;
                                                                                                motionController5.mStaggerScale = 1.0f / (1.0f - f3);
                                                                                                motionController5.mStaggerOffset = f3 - ((((f7 + f8) - f4) * f3) / (f5 - f4));
                                                                                            }
                                                                                        }
                                                                                        this.mTransitionPosition = 0.0f;
                                                                                        this.mTransitionLastPosition = 0.0f;
                                                                                        this.mInTransition = true;
                                                                                        invalidate();
                                                                                    }
                                                                                }
                                                                            }

                                                                            public void setTransition(int i) {
                                                                                if (this.mScene != null) {
                                                                                    MotionScene.Transition transition = getTransition(i);
                                                                                    this.mBeginState = transition.mConstraintSetStart;
                                                                                    this.mEndState = transition.mConstraintSetEnd;
                                                                                    if (!isAttachedToWindow()) {
                                                                                        if (this.mStateCache == null) {
                                                                                            this.mStateCache = new StateCache();
                                                                                        }
                                                                                        StateCache stateCache = this.mStateCache;
                                                                                        stateCache.startState = this.mBeginState;
                                                                                        stateCache.endState = this.mEndState;
                                                                                        return;
                                                                                    }
                                                                                    float f = Float.NaN;
                                                                                    int i2 = this.mCurrentState;
                                                                                    if (i2 == this.mBeginState) {
                                                                                        f = 0.0f;
                                                                                    } else if (i2 == this.mEndState) {
                                                                                        f = 1.0f;
                                                                                    }
                                                                                    MotionScene motionScene = this.mScene;
                                                                                    motionScene.mCurrentTransition = transition;
                                                                                    TouchResponse touchResponse = transition.mTouchResponse;
                                                                                    if (touchResponse != null) {
                                                                                        touchResponse.setRTL(motionScene.mRtl);
                                                                                    }
                                                                                    this.mModel.initFrom(this.mScene.getConstraintSet(this.mBeginState), this.mScene.getConstraintSet(this.mEndState));
                                                                                    rebuildScene();
                                                                                    if (this.mTransitionLastPosition != f) {
                                                                                        if (f == 0.0f) {
                                                                                            endTrigger(true);
                                                                                            this.mScene.getConstraintSet(this.mBeginState).applyToInternal(this, true);
                                                                                            setConstraintSet(null);
                                                                                            requestLayout();
                                                                                        } else if (f == 1.0f) {
                                                                                            endTrigger(false);
                                                                                            this.mScene.getConstraintSet(this.mEndState).applyToInternal(this, true);
                                                                                            setConstraintSet(null);
                                                                                            requestLayout();
                                                                                        }
                                                                                    }
                                                                                    this.mTransitionLastPosition = Float.isNaN(f) ? 0.0f : f;
                                                                                    if (Float.isNaN(f)) {
                                                                                        Log.v("MotionLayout", AppCompatDelegateImpl.Api17Impl.getLocation() + " transitionToStart ");
                                                                                        animateTo(0.0f);
                                                                                        return;
                                                                                    }
                                                                                    setProgress(f);
                                                                                }
                                                                            }

                                                                            public MotionLayout(Context context, AttributeSet attributeSet) {
                                                                                super(context, attributeSet);
                                                                                init(attributeSet);
                                                                            }

                                                                            public void setTransition(MotionScene.Transition transition) {
                                                                                long j;
                                                                                TouchResponse touchResponse;
                                                                                MotionScene motionScene = this.mScene;
                                                                                motionScene.mCurrentTransition = transition;
                                                                                if (!(transition == null || (touchResponse = transition.mTouchResponse) == null)) {
                                                                                    touchResponse.setRTL(motionScene.mRtl);
                                                                                }
                                                                                setState(TransitionState.SETUP);
                                                                                if (this.mCurrentState == this.mScene.getEndId()) {
                                                                                    this.mTransitionLastPosition = 1.0f;
                                                                                    this.mTransitionPosition = 1.0f;
                                                                                    this.mTransitionGoalPosition = 1.0f;
                                                                                } else {
                                                                                    this.mTransitionLastPosition = 0.0f;
                                                                                    this.mTransitionPosition = 0.0f;
                                                                                    this.mTransitionGoalPosition = 0.0f;
                                                                                }
                                                                                boolean z = true;
                                                                                if ((transition.mTransitionFlags & 1) == 0) {
                                                                                    z = false;
                                                                                }
                                                                                if (z) {
                                                                                    j = -1;
                                                                                } else {
                                                                                    j = getNanoTime();
                                                                                }
                                                                                this.mTransitionLastTime = j;
                                                                                int startId = this.mScene.getStartId();
                                                                                int endId = this.mScene.getEndId();
                                                                                if (startId != this.mBeginState || endId != this.mEndState) {
                                                                                    this.mBeginState = startId;
                                                                                    this.mEndState = endId;
                                                                                    this.mScene.setTransition(startId, endId);
                                                                                    this.mModel.initFrom(this.mScene.getConstraintSet(this.mBeginState), this.mScene.getConstraintSet(this.mEndState));
                                                                                    Model model = this.mModel;
                                                                                    int i = this.mBeginState;
                                                                                    int i2 = this.mEndState;
                                                                                    model.mStartId = i;
                                                                                    model.mEndId = i2;
                                                                                    model.reEvaluateState();
                                                                                    rebuildScene();
                                                                                }
                                                                            }

                                                                            public MotionLayout(Context context, AttributeSet attributeSet, int i) {
                                                                                super(context, attributeSet, i);
                                                                                init(attributeSet);
                                                                            }
                                                                        }
