package androidx.constraintlayout.motion.widget;

import androidx.constraintlayout.core.motion.utils.Easing;
import androidx.constraintlayout.widget.ConstraintAttribute;
import androidx.constraintlayout.widget.ConstraintSet;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.LinkedHashMap;

public class MotionPaths implements Comparable<MotionPaths> {
    public static String[] names = {"position", "x", "y", "width", "height", "pathRotate"};
    public LinkedHashMap<String, ConstraintAttribute> attributes;
    public float height;
    public int mAnimateRelativeTo;
    public int mDrawPath;
    public Easing mKeyFrameEasing;
    public int mMode;
    public int mPathMotionArc;
    public float mPathRotate;
    public float mRelativeAngle;
    public MotionController mRelativeToController;
    public double[] mTempDelta;
    public double[] mTempValue;
    public float position;
    public float time;
    public float width;
    public float x;
    public float y;

    public MotionPaths() {
        this.mDrawPath = 0;
        this.mPathRotate = Float.NaN;
        this.mPathMotionArc = -1;
        this.mAnimateRelativeTo = -1;
        this.mRelativeAngle = Float.NaN;
        this.mRelativeToController = null;
        this.attributes = new LinkedHashMap<>();
        this.mMode = 0;
        this.mTempValue = new double[18];
        this.mTempDelta = new double[18];
    }

    public void applyParameters(ConstraintSet.Constraint constraint) {
        this.mKeyFrameEasing = Easing.getInterpolator(constraint.motion.mTransitionEasing);
        ConstraintSet.Motion motion = constraint.motion;
        this.mPathMotionArc = motion.mPathMotionArc;
        this.mAnimateRelativeTo = motion.mAnimateRelativeTo;
        this.mPathRotate = motion.mPathRotate;
        this.mDrawPath = motion.mDrawPath;
        int i = motion.mAnimateCircleAngleTo;
        float f = constraint.propertySet.mProgress;
        this.mRelativeAngle = constraint.layout.circleAngle;
        for (String str : constraint.mCustomConstraints.keySet()) {
            ConstraintAttribute constraintAttribute = constraint.mCustomConstraints.get(str);
            if (constraintAttribute != null && constraintAttribute.isContinuous()) {
                this.attributes.put(str, constraintAttribute);
            }
        }
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
    @Override // java.lang.Comparable
    public int compareTo(MotionPaths motionPaths) {
        return Float.compare(this.position, motionPaths.position);
    }

    public final boolean diff(float f, float f2) {
        if (Float.isNaN(f) || Float.isNaN(f2)) {
            if (Float.isNaN(f) != Float.isNaN(f2)) {
                return true;
            }
            return false;
        } else if (Math.abs(f - f2) > 1.0E-6f) {
            return true;
        } else {
            return false;
        }
    }

    public void getCenter(double d, int[] iArr, double[] dArr, float[] fArr, int i) {
        float f = this.x;
        float f2 = this.y;
        float f3 = this.width;
        float f4 = this.height;
        for (int i2 = 0; i2 < iArr.length; i2++) {
            float f5 = (float) dArr[i2];
            int i3 = iArr[i2];
            if (i3 == 1) {
                f = f5;
            } else if (i3 == 2) {
                f2 = f5;
            } else if (i3 == 3) {
                f3 = f5;
            } else if (i3 == 4) {
                f4 = f5;
            }
        }
        MotionController motionController = this.mRelativeToController;
        if (motionController != null) {
            float[] fArr2 = new float[2];
            motionController.getCenter(d, fArr2, new float[2]);
            float f6 = fArr2[0];
            float f7 = fArr2[1];
            double d2 = (double) f6;
            double d3 = (double) f;
            double d4 = (double) f2;
            f = (float) (((Math.sin(d4) * d3) + d2) - ((double) (f3 / 2.0f)));
            f2 = (float) ((((double) f7) - (Math.cos(d4) * d3)) - ((double) (f4 / 2.0f)));
        }
        fArr[i] = (f3 / 2.0f) + f + 0.0f;
        fArr[i + 1] = (f4 / 2.0f) + f2 + 0.0f;
    }

    public void setBounds(float f, float f2, float f3, float f4) {
        this.x = f;
        this.y = f2;
        this.width = f3;
        this.height = f4;
    }

    public void setDpDt(float f, float f2, float[] fArr, int[] iArr, double[] dArr, double[] dArr2) {
        float f3 = 0.0f;
        float f4 = 0.0f;
        float f5 = 0.0f;
        float f6 = 0.0f;
        for (int i = 0; i < iArr.length; i++) {
            float f7 = (float) dArr[i];
            double d = dArr2[i];
            int i2 = iArr[i];
            if (i2 == 1) {
                f3 = f7;
            } else if (i2 == 2) {
                f5 = f7;
            } else if (i2 == 3) {
                f4 = f7;
            } else if (i2 == 4) {
                f6 = f7;
            }
        }
        float f8 = f3 - ((0.0f * f4) / 2.0f);
        float f9 = f5 - ((0.0f * f6) / 2.0f);
        fArr[0] = (((f4 * 1.0f) + f8) * f) + ((1.0f - f) * f8) + 0.0f;
        fArr[1] = (((f6 * 1.0f) + f9) * f2) + ((1.0f - f2) * f9) + 0.0f;
    }

    public void setupRelative(MotionController motionController, MotionPaths motionPaths) {
        double d = (double) ((((this.width / 2.0f) + this.x) - motionPaths.x) - (motionPaths.width / 2.0f));
        double d2 = (double) ((((this.height / 2.0f) + this.y) - motionPaths.y) - (motionPaths.height / 2.0f));
        this.mRelativeToController = motionController;
        this.x = (float) Math.hypot(d2, d);
        if (Float.isNaN(this.mRelativeAngle)) {
            this.y = (float) (Math.atan2(d2, d) + 1.5707963267948966d);
        } else {
            this.y = (float) Math.toRadians((double) this.mRelativeAngle);
        }
    }

    public MotionPaths(int i, int i2, KeyPosition keyPosition, MotionPaths motionPaths, MotionPaths motionPaths2) {
        float f;
        int i3;
        float f2;
        float f3;
        this.mDrawPath = 0;
        this.mPathRotate = Float.NaN;
        this.mPathMotionArc = -1;
        this.mAnimateRelativeTo = -1;
        this.mRelativeAngle = Float.NaN;
        this.mRelativeToController = null;
        this.attributes = new LinkedHashMap<>();
        this.mMode = 0;
        this.mTempValue = new double[18];
        this.mTempDelta = new double[18];
        if (motionPaths.mAnimateRelativeTo != -1) {
            float f4 = ((float) keyPosition.mFramePosition) / 100.0f;
            this.time = f4;
            this.mDrawPath = keyPosition.mDrawPath;
            this.mMode = keyPosition.mPositionType;
            float f5 = Float.isNaN(keyPosition.mPercentWidth) ? f4 : keyPosition.mPercentWidth;
            float f6 = Float.isNaN(keyPosition.mPercentHeight) ? f4 : keyPosition.mPercentHeight;
            float f7 = motionPaths2.width;
            float f8 = motionPaths.width;
            float f9 = motionPaths2.height;
            float f10 = motionPaths.height;
            this.position = this.time;
            this.width = (float) ((int) (((f7 - f8) * f5) + f8));
            this.height = (float) ((int) (((f9 - f10) * f6) + f10));
            int i4 = keyPosition.mPositionType;
            if (i4 == 1) {
                float f11 = Float.isNaN(keyPosition.mPercentX) ? f4 : keyPosition.mPercentX;
                float f12 = motionPaths2.x;
                float f13 = motionPaths.x;
                this.x = GeneratedOutlineSupport.outline0(f12, f13, f11, f13);
                f4 = !Float.isNaN(keyPosition.mPercentY) ? keyPosition.mPercentY : f4;
                float f14 = motionPaths2.y;
                float f15 = motionPaths.y;
                this.y = GeneratedOutlineSupport.outline0(f14, f15, f4, f15);
            } else if (i4 != 2) {
                float f16 = Float.isNaN(keyPosition.mPercentX) ? f4 : keyPosition.mPercentX;
                float f17 = motionPaths2.x;
                float f18 = motionPaths.x;
                this.x = GeneratedOutlineSupport.outline0(f17, f18, f16, f18);
                f4 = !Float.isNaN(keyPosition.mPercentY) ? keyPosition.mPercentY : f4;
                float f19 = motionPaths2.y;
                float f20 = motionPaths.y;
                this.y = GeneratedOutlineSupport.outline0(f19, f20, f4, f20);
            } else {
                if (Float.isNaN(keyPosition.mPercentX)) {
                    float f21 = motionPaths2.x;
                    float f22 = motionPaths.x;
                    f2 = GeneratedOutlineSupport.outline0(f21, f22, f4, f22);
                } else {
                    f2 = keyPosition.mPercentX * Math.min(f6, f5);
                }
                this.x = f2;
                if (Float.isNaN(keyPosition.mPercentY)) {
                    float f23 = motionPaths2.y;
                    float f24 = motionPaths.y;
                    f3 = GeneratedOutlineSupport.outline0(f23, f24, f4, f24);
                } else {
                    f3 = keyPosition.mPercentY;
                }
                this.y = f3;
            }
            this.mAnimateRelativeTo = motionPaths.mAnimateRelativeTo;
            this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
            this.mPathMotionArc = keyPosition.mPathMotionArc;
            return;
        }
        int i5 = keyPosition.mPositionType;
        if (i5 == 1) {
            float f25 = ((float) keyPosition.mFramePosition) / 100.0f;
            this.time = f25;
            this.mDrawPath = keyPosition.mDrawPath;
            float f26 = Float.isNaN(keyPosition.mPercentWidth) ? f25 : keyPosition.mPercentWidth;
            float f27 = Float.isNaN(keyPosition.mPercentHeight) ? f25 : keyPosition.mPercentHeight;
            float f28 = motionPaths2.width - motionPaths.width;
            float f29 = motionPaths2.height - motionPaths.height;
            this.position = this.time;
            f25 = !Float.isNaN(keyPosition.mPercentX) ? keyPosition.mPercentX : f25;
            float f30 = motionPaths.x;
            float f31 = motionPaths.width;
            float f32 = motionPaths.y;
            float f33 = motionPaths.height;
            float f34 = ((motionPaths2.width / 2.0f) + motionPaths2.x) - ((f31 / 2.0f) + f30);
            float f35 = ((motionPaths2.height / 2.0f) + motionPaths2.y) - ((f33 / 2.0f) + f32);
            float f36 = f34 * f25;
            float f37 = f28 * f26;
            float f38 = f37 / 2.0f;
            this.x = (float) ((int) ((f30 + f36) - f38));
            float f39 = f25 * f35;
            float f40 = f29 * f27;
            float f41 = f40 / 2.0f;
            this.y = (float) ((int) ((f32 + f39) - f41));
            this.width = (float) ((int) (f31 + f37));
            this.height = (float) ((int) (f33 + f40));
            float f42 = Float.isNaN(keyPosition.mPercentY) ? 0.0f : keyPosition.mPercentY;
            this.mMode = 1;
            float f43 = (float) ((int) ((motionPaths.x + f36) - f38));
            this.x = f43;
            float f44 = (float) ((int) ((motionPaths.y + f39) - f41));
            this.y = f44;
            this.x = f43 + ((-f35) * f42);
            this.y = f44 + (f34 * f42);
            this.mAnimateRelativeTo = this.mAnimateRelativeTo;
            this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
            this.mPathMotionArc = keyPosition.mPathMotionArc;
        } else if (i5 != 2) {
            float f45 = ((float) keyPosition.mFramePosition) / 100.0f;
            this.time = f45;
            this.mDrawPath = keyPosition.mDrawPath;
            float f46 = Float.isNaN(keyPosition.mPercentWidth) ? f45 : keyPosition.mPercentWidth;
            float f47 = Float.isNaN(keyPosition.mPercentHeight) ? f45 : keyPosition.mPercentHeight;
            float f48 = motionPaths2.width;
            float f49 = motionPaths.width;
            float f50 = f48 - f49;
            float f51 = motionPaths2.height;
            float f52 = motionPaths.height;
            float f53 = f51 - f52;
            this.position = this.time;
            float f54 = motionPaths.x;
            float f55 = motionPaths.y;
            float f56 = ((f48 / 2.0f) + motionPaths2.x) - ((f49 / 2.0f) + f54);
            float f57 = ((f51 / 2.0f) + motionPaths2.y) - ((f52 / 2.0f) + f55);
            float f58 = f50 * f46;
            float f59 = f58 / 2.0f;
            this.x = (float) ((int) (((f56 * f45) + f54) - f59));
            float f60 = (f57 * f45) + f55;
            float f61 = f53 * f47;
            float f62 = f61 / 2.0f;
            this.y = (float) ((int) (f60 - f62));
            this.width = (float) ((int) (f49 + f58));
            this.height = (float) ((int) (f52 + f61));
            float f63 = Float.isNaN(keyPosition.mPercentX) ? f45 : keyPosition.mPercentX;
            float f64 = Float.isNaN(keyPosition.mAltPercentY) ? 0.0f : keyPosition.mAltPercentY;
            f45 = !Float.isNaN(keyPosition.mPercentY) ? keyPosition.mPercentY : f45;
            if (Float.isNaN(keyPosition.mAltPercentX)) {
                i3 = 0;
                f = 0.0f;
            } else {
                f = keyPosition.mAltPercentX;
                i3 = 0;
            }
            this.mMode = i3;
            this.x = (float) ((int) (((f * f57) + ((f63 * f56) + motionPaths.x)) - f59));
            this.y = (float) ((int) (((f57 * f45) + ((f56 * f64) + motionPaths.y)) - f62));
            this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
            this.mPathMotionArc = keyPosition.mPathMotionArc;
        } else {
            float f65 = ((float) keyPosition.mFramePosition) / 100.0f;
            this.time = f65;
            this.mDrawPath = keyPosition.mDrawPath;
            float f66 = Float.isNaN(keyPosition.mPercentWidth) ? f65 : keyPosition.mPercentWidth;
            float f67 = Float.isNaN(keyPosition.mPercentHeight) ? f65 : keyPosition.mPercentHeight;
            float f68 = motionPaths2.width;
            float f69 = motionPaths.width;
            float f70 = f68 - f69;
            float f71 = motionPaths2.height;
            float f72 = motionPaths.height;
            float f73 = f71 - f72;
            this.position = this.time;
            float f74 = motionPaths.x;
            float f75 = motionPaths.y;
            float f76 = (f68 / 2.0f) + motionPaths2.x;
            float f77 = (f71 / 2.0f) + motionPaths2.y;
            float f78 = f70 * f66;
            this.x = (float) ((int) ((((f76 - ((f69 / 2.0f) + f74)) * f65) + f74) - (f78 / 2.0f)));
            float f79 = f73 * f67;
            this.y = (float) ((int) ((((f77 - ((f72 / 2.0f) + f75)) * f65) + f75) - (f79 / 2.0f)));
            this.width = (float) ((int) (f69 + f78));
            this.height = (float) ((int) (f72 + f79));
            this.mMode = 2;
            if (!Float.isNaN(keyPosition.mPercentX)) {
                this.x = (float) ((int) (keyPosition.mPercentX * ((float) ((int) (((float) i) - this.width)))));
            }
            if (!Float.isNaN(keyPosition.mPercentY)) {
                this.y = (float) ((int) (keyPosition.mPercentY * ((float) ((int) (((float) i2) - this.height)))));
            }
            this.mAnimateRelativeTo = this.mAnimateRelativeTo;
            this.mKeyFrameEasing = Easing.getInterpolator(keyPosition.mTransitionEasing);
            this.mPathMotionArc = keyPosition.mPathMotionArc;
        }
    }
}
