package androidx.constraintlayout.widget;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.util.Log;
import android.util.SparseArray;
import android.util.SparseIntArray;
import android.view.View;
import android.view.ViewGroup;
import androidx.constraintlayout.core.LinearSystem;
import androidx.constraintlayout.core.widgets.Barrier;
import androidx.constraintlayout.core.widgets.ConstraintAnchor;
import androidx.constraintlayout.core.widgets.ConstraintWidget;
import androidx.constraintlayout.core.widgets.ConstraintWidgetContainer;
import androidx.constraintlayout.core.widgets.Guideline;
import androidx.constraintlayout.core.widgets.Helper;
import androidx.constraintlayout.core.widgets.HelperWidget;
import androidx.constraintlayout.core.widgets.Optimizer;
import androidx.constraintlayout.core.widgets.VirtualLayout;
import androidx.constraintlayout.core.widgets.WidgetContainer;
import androidx.constraintlayout.core.widgets.analyzer.BasicMeasure;
import androidx.constraintlayout.core.widgets.analyzer.ChainRun;
import androidx.constraintlayout.core.widgets.analyzer.DependencyGraph;
import androidx.constraintlayout.core.widgets.analyzer.GuidelineReference;
import androidx.constraintlayout.core.widgets.analyzer.HorizontalWidgetRun;
import androidx.constraintlayout.core.widgets.analyzer.VerticalWidgetRun;
import androidx.constraintlayout.core.widgets.analyzer.WidgetRun;
import androidx.recyclerview.widget.LinearLayoutManager;
import io.netty.buffer.AbstractByteBufAllocator;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Objects;

public class ConstraintLayout extends ViewGroup {
    public static SharedValues sSharedValues;
    public SparseArray<View> mChildrenByIds = new SparseArray<>();
    public ArrayList<ConstraintHelper> mConstraintHelpers = new ArrayList<>(4);
    public ConstraintLayoutStates mConstraintLayoutSpec = null;
    public ConstraintSet mConstraintSet = null;
    public int mConstraintSetId = -1;
    public HashMap<String, Integer> mDesignIds = new HashMap<>();
    public boolean mDirtyHierarchy = true;
    public int mLastMeasureHeight = -1;
    public int mLastMeasureWidth = -1;
    public ConstraintWidgetContainer mLayoutWidget = new ConstraintWidgetContainer();
    public int mMaxHeight = Integer.MAX_VALUE;
    public int mMaxWidth = Integer.MAX_VALUE;
    public Measurer mMeasurer = new Measurer(this);
    public int mMinHeight = 0;
    public int mMinWidth = 0;
    public int mOnMeasureHeightMeasureSpec = 0;
    public int mOnMeasureWidthMeasureSpec = 0;
    public int mOptimizationLevel = 257;
    public SparseArray<ConstraintWidget> mTempMapIdToWidget = new SparseArray<>();

    public class Measurer implements BasicMeasure.Measurer {
        public ConstraintLayout layout;
        public int layoutHeightSpec;
        public int layoutWidthSpec;
        public int paddingBottom;
        public int paddingHeight;
        public int paddingTop;
        public int paddingWidth;

        public Measurer(ConstraintLayout constraintLayout) {
            this.layout = constraintLayout;
        }

        public final boolean isSimilarSpec(int i, int i2, int i3) {
            if (i == i2) {
                return true;
            }
            int mode = View.MeasureSpec.getMode(i);
            View.MeasureSpec.getSize(i);
            int mode2 = View.MeasureSpec.getMode(i2);
            int size = View.MeasureSpec.getSize(i2);
            if (mode2 != 1073741824) {
                return false;
            }
            if ((mode == Integer.MIN_VALUE || mode == 0) && i3 == size) {
                return true;
            }
            return false;
        }

        /* JADX WARNING: Removed duplicated region for block: B:117:0x01a3  */
        /* JADX WARNING: Removed duplicated region for block: B:121:0x01b8  */
        /* JADX WARNING: Removed duplicated region for block: B:122:0x01ba  */
        /* JADX WARNING: Removed duplicated region for block: B:124:0x01bd  */
        /* JADX WARNING: Removed duplicated region for block: B:125:0x01bf  */
        /* JADX WARNING: Removed duplicated region for block: B:149:0x01ef A[RETURN] */
        /* JADX WARNING: Removed duplicated region for block: B:150:0x01f0  */
        @SuppressLint({"WrongCall"})
        public final void measure(ConstraintWidget constraintWidget, BasicMeasure.Measure measure) {
            int i;
            int i2;
            int i3;
            int i4;
            int i5;
            int i6;
            int i7;
            int i8;
            int i9;
            if (constraintWidget != null) {
                int i10 = 0;
                if (constraintWidget.mVisibility == 8 && !constraintWidget.inPlaceholder) {
                    measure.measuredWidth = 0;
                    measure.measuredHeight = 0;
                    measure.measuredBaseline = 0;
                } else if (constraintWidget.mParent != null) {
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour = measure.horizontalBehavior;
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour2 = measure.verticalBehavior;
                    int i11 = measure.horizontalDimension;
                    int i12 = measure.verticalDimension;
                    int i13 = this.paddingTop + this.paddingBottom;
                    int i14 = this.paddingWidth;
                    View view = (View) constraintWidget.mCompanionWidget;
                    int ordinal = dimensionBehaviour.ordinal();
                    if (ordinal == 0) {
                        i10 = View.MeasureSpec.makeMeasureSpec(i11, 1073741824);
                    } else if (ordinal == 1) {
                        i10 = ViewGroup.getChildMeasureSpec(this.layoutWidthSpec, i14, -2);
                    } else if (ordinal == 2) {
                        i10 = ViewGroup.getChildMeasureSpec(this.layoutWidthSpec, i14, -2);
                        boolean z = constraintWidget.mMatchConstraintDefaultWidth == 1;
                        int i15 = measure.measureStrategy;
                        if (i15 == 1 || i15 == 2) {
                            if (measure.measureStrategy == 2 || !z || (z && (view.getMeasuredHeight() == constraintWidget.getHeight())) || (view instanceof Placeholder) || constraintWidget.isResolvedHorizontally()) {
                                i10 = View.MeasureSpec.makeMeasureSpec(constraintWidget.getWidth(), 1073741824);
                            }
                        }
                    } else if (ordinal == 3) {
                        int i16 = this.layoutWidthSpec;
                        ConstraintAnchor constraintAnchor = constraintWidget.mLeft;
                        int i17 = constraintAnchor != null ? constraintAnchor.mMargin + 0 : 0;
                        ConstraintAnchor constraintAnchor2 = constraintWidget.mRight;
                        if (constraintAnchor2 != null) {
                            i17 += constraintAnchor2.mMargin;
                        }
                        i10 = ViewGroup.getChildMeasureSpec(i16, i14 + i17, -1);
                    }
                    int ordinal2 = dimensionBehaviour2.ordinal();
                    if (ordinal2 == 0) {
                        i9 = View.MeasureSpec.makeMeasureSpec(i12, 1073741824);
                    } else if (ordinal2 == 1) {
                        i9 = ViewGroup.getChildMeasureSpec(this.layoutHeightSpec, i13, -2);
                    } else if (ordinal2 == 2) {
                        i9 = ViewGroup.getChildMeasureSpec(this.layoutHeightSpec, i13, -2);
                        boolean z2 = constraintWidget.mMatchConstraintDefaultHeight == 1;
                        int i18 = measure.measureStrategy;
                        if (i18 == 1 || i18 == 2) {
                            if (measure.measureStrategy == 2 || !z2 || (z2 && (view.getMeasuredWidth() == constraintWidget.getWidth())) || (view instanceof Placeholder) || constraintWidget.isResolvedVertically()) {
                                i9 = View.MeasureSpec.makeMeasureSpec(constraintWidget.getHeight(), 1073741824);
                            }
                        }
                    } else if (ordinal2 != 3) {
                        i = 0;
                        ConstraintWidgetContainer constraintWidgetContainer = (ConstraintWidgetContainer) constraintWidget.mParent;
                        if (constraintWidgetContainer != null && Optimizer.enabled(ConstraintLayout.this.mOptimizationLevel, 256) && view.getMeasuredWidth() == constraintWidget.getWidth() && view.getMeasuredWidth() < constraintWidgetContainer.getWidth() && view.getMeasuredHeight() == constraintWidget.getHeight() && view.getMeasuredHeight() < constraintWidgetContainer.getHeight() && view.getBaseline() == constraintWidget.mBaselineDistance && !constraintWidget.isMeasureRequested()) {
                            if (!isSimilarSpec(constraintWidget.mLastHorizontalMeasureSpec, i10, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.mLastVerticalMeasureSpec, i, constraintWidget.getHeight())) {
                                measure.measuredWidth = constraintWidget.getWidth();
                                measure.measuredHeight = constraintWidget.getHeight();
                                measure.measuredBaseline = constraintWidget.mBaselineDistance;
                                return;
                            }
                        }
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                        boolean z3 = dimensionBehaviour != dimensionBehaviour3;
                        boolean z4 = dimensionBehaviour2 != dimensionBehaviour3;
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                        boolean z5 = dimensionBehaviour2 != dimensionBehaviour4 || dimensionBehaviour2 == ConstraintWidget.DimensionBehaviour.FIXED;
                        boolean z6 = dimensionBehaviour != dimensionBehaviour4 || dimensionBehaviour == ConstraintWidget.DimensionBehaviour.FIXED;
                        boolean z7 = !z3 && constraintWidget.mDimensionRatio > 0.0f;
                        boolean z8 = !z4 && constraintWidget.mDimensionRatio > 0.0f;
                        if (view == null) {
                            LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
                            int i19 = measure.measureStrategy;
                            if (i19 == 1 || i19 == 2 || !z3 || constraintWidget.mMatchConstraintDefaultWidth != 0 || !z4 || constraintWidget.mMatchConstraintDefaultHeight != 0) {
                                if (!(view instanceof VirtualLayout) || !(constraintWidget instanceof VirtualLayout)) {
                                    view.measure(i10, i);
                                } else {
                                    ((VirtualLayout) view).onMeasure((VirtualLayout) constraintWidget, i10, i);
                                }
                                constraintWidget.mLastHorizontalMeasureSpec = i10;
                                constraintWidget.mLastVerticalMeasureSpec = i;
                                constraintWidget.mMeasureRequested = false;
                                int measuredWidth = view.getMeasuredWidth();
                                int measuredHeight = view.getMeasuredHeight();
                                i4 = view.getBaseline();
                                int i20 = constraintWidget.mMatchConstraintMinWidth;
                                i3 = i20 > 0 ? Math.max(i20, measuredWidth) : measuredWidth;
                                int i21 = constraintWidget.mMatchConstraintMaxWidth;
                                if (i21 > 0) {
                                    i3 = Math.min(i21, i3);
                                }
                                int i22 = constraintWidget.mMatchConstraintMinHeight;
                                if (i22 > 0) {
                                    i2 = Math.max(i22, measuredHeight);
                                    i6 = i10;
                                } else {
                                    i6 = i10;
                                    i2 = measuredHeight;
                                }
                                int i23 = constraintWidget.mMatchConstraintMaxHeight;
                                if (i23 > 0) {
                                    i2 = Math.min(i23, i2);
                                }
                                if (!Optimizer.enabled(ConstraintLayout.this.mOptimizationLevel, 1)) {
                                    if (z7 && z5) {
                                        i3 = (int) ((((float) i2) * constraintWidget.mDimensionRatio) + 0.5f);
                                    } else if (z8 && z6) {
                                        i2 = (int) ((((float) i3) / constraintWidget.mDimensionRatio) + 0.5f);
                                    }
                                }
                                if (measuredWidth == i3 && measuredHeight == i2) {
                                    i5 = -1;
                                } else {
                                    if (measuredWidth != i3) {
                                        i8 = 1073741824;
                                        i7 = View.MeasureSpec.makeMeasureSpec(i3, 1073741824);
                                    } else {
                                        i8 = 1073741824;
                                        i7 = i6;
                                    }
                                    if (measuredHeight != i2) {
                                        i = View.MeasureSpec.makeMeasureSpec(i2, i8);
                                    }
                                    view.measure(i7, i);
                                    constraintWidget.mLastHorizontalMeasureSpec = i7;
                                    constraintWidget.mLastVerticalMeasureSpec = i;
                                    constraintWidget.mMeasureRequested = false;
                                    i3 = view.getMeasuredWidth();
                                    i2 = view.getMeasuredHeight();
                                    i4 = view.getBaseline();
                                    i5 = -1;
                                }
                            } else {
                                i5 = -1;
                                i4 = 0;
                                i3 = 0;
                                i2 = 0;
                            }
                            boolean z9 = i4 != i5;
                            measure.measuredNeedsSolverPass = (i3 == measure.horizontalDimension && i2 == measure.verticalDimension) ? false : true;
                            if (layoutParams.needsBaseline) {
                                z9 = true;
                            }
                            if (!(!z9 || i4 == -1 || constraintWidget.mBaselineDistance == i4)) {
                                measure.measuredNeedsSolverPass = true;
                            }
                            measure.measuredWidth = i3;
                            measure.measuredHeight = i2;
                            measure.measuredHasBaseline = z9;
                            measure.measuredBaseline = i4;
                            return;
                        }
                        return;
                    } else {
                        int i24 = this.layoutHeightSpec;
                        int i25 = constraintWidget.mLeft != null ? constraintWidget.mTop.mMargin + 0 : 0;
                        if (constraintWidget.mRight != null) {
                            i25 += constraintWidget.mBottom.mMargin;
                        }
                        i9 = ViewGroup.getChildMeasureSpec(i24, i13 + i25, -1);
                    }
                    i = i9;
                    ConstraintWidgetContainer constraintWidgetContainer2 = (ConstraintWidgetContainer) constraintWidget.mParent;
                    if (!isSimilarSpec(constraintWidget.mLastHorizontalMeasureSpec, i10, constraintWidget.getWidth()) && isSimilarSpec(constraintWidget.mLastVerticalMeasureSpec, i, constraintWidget.getHeight())) {
                    }
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour32 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                    if (dimensionBehaviour != dimensionBehaviour32) {
                    }
                    if (dimensionBehaviour2 != dimensionBehaviour32) {
                    }
                    ConstraintWidget.DimensionBehaviour dimensionBehaviour42 = ConstraintWidget.DimensionBehaviour.MATCH_PARENT;
                    if (dimensionBehaviour2 != dimensionBehaviour42) {
                    }
                    if (dimensionBehaviour != dimensionBehaviour42) {
                    }
                    if (!z3) {
                    }
                    if (!z4) {
                    }
                    if (view == null) {
                    }
                }
            }
        }
    }

    public ConstraintLayout(Context context) {
        super(context);
        init(null, 0, 0);
    }

    private int getPaddingWidth() {
        int max = Math.max(0, getPaddingRight()) + Math.max(0, getPaddingLeft());
        int max2 = Math.max(0, getPaddingEnd()) + Math.max(0, getPaddingStart());
        return max2 > 0 ? max2 : max;
    }

    public static SharedValues getSharedValues() {
        if (sSharedValues == null) {
            sSharedValues = new SharedValues();
        }
        return sSharedValues;
    }

    /* JADX WARNING: Removed duplicated region for block: B:152:0x02d6  */
    public void applyConstraintsFromLayoutParams(boolean z, View view, ConstraintWidget constraintWidget, LayoutParams layoutParams, SparseArray<ConstraintWidget> sparseArray) {
        float f;
        int i;
        int i2;
        float f2;
        int i3;
        ConstraintWidget constraintWidget2;
        ConstraintWidget constraintWidget3;
        ConstraintWidget constraintWidget4;
        ConstraintWidget constraintWidget5;
        layoutParams.validate();
        constraintWidget.mVisibility = view.getVisibility();
        if (layoutParams.isInPlaceholder) {
            constraintWidget.inPlaceholder = true;
            constraintWidget.mVisibility = 8;
        }
        constraintWidget.mCompanionWidget = view;
        if (view instanceof ConstraintHelper) {
            ((ConstraintHelper) view).resolveRtl(constraintWidget, this.mLayoutWidget.mIsRtl);
        }
        int i4 = -1;
        if (layoutParams.isGuideline) {
            Guideline guideline = (Guideline) constraintWidget;
            int i5 = layoutParams.resolvedGuideBegin;
            int i6 = layoutParams.resolvedGuideEnd;
            float f3 = layoutParams.resolvedGuidePercent;
            int i7 = (f3 > -1.0f ? 1 : (f3 == -1.0f ? 0 : -1));
            if (i7 != 0) {
                if (i7 > 0) {
                    guideline.mRelativePercent = f3;
                    guideline.mRelativeBegin = -1;
                    guideline.mRelativeEnd = -1;
                }
            } else if (i5 != -1) {
                if (i5 > -1) {
                    guideline.mRelativePercent = -1.0f;
                    guideline.mRelativeBegin = i5;
                    guideline.mRelativeEnd = -1;
                }
            } else if (i6 != -1 && i6 > -1) {
                guideline.mRelativePercent = -1.0f;
                guideline.mRelativeBegin = -1;
                guideline.mRelativeEnd = i6;
            }
        } else {
            int i8 = layoutParams.resolvedLeftToLeft;
            int i9 = layoutParams.resolvedLeftToRight;
            int i10 = layoutParams.resolvedRightToLeft;
            int i11 = layoutParams.resolvedRightToRight;
            int i12 = layoutParams.resolveGoneLeftMargin;
            int i13 = layoutParams.resolveGoneRightMargin;
            float f4 = layoutParams.resolvedHorizontalBias;
            int i14 = layoutParams.circleConstraint;
            if (i14 != -1) {
                ConstraintWidget constraintWidget6 = sparseArray.get(i14);
                if (constraintWidget6 != null) {
                    float f5 = layoutParams.circleAngle;
                    int i15 = layoutParams.circleRadius;
                    ConstraintAnchor.Type type = ConstraintAnchor.Type.CENTER;
                    constraintWidget.immediateConnect(type, constraintWidget6, type, i15, 0);
                    constraintWidget.mCircleConstraintAngle = f5;
                }
                f = 0.0f;
            } else {
                if (i8 != -1) {
                    ConstraintWidget constraintWidget7 = sparseArray.get(i8);
                    if (constraintWidget7 != null) {
                        ConstraintAnchor.Type type2 = ConstraintAnchor.Type.LEFT;
                        f = 0.0f;
                        constraintWidget.immediateConnect(type2, constraintWidget7, type2, ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin, i12);
                    } else {
                        f = 0.0f;
                    }
                } else {
                    f = 0.0f;
                    if (!(i9 == -1 || (constraintWidget5 = sparseArray.get(i9)) == null)) {
                        constraintWidget.immediateConnect(ConstraintAnchor.Type.LEFT, constraintWidget5, ConstraintAnchor.Type.RIGHT, ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin, i12);
                    }
                }
                if (i10 != -1) {
                    ConstraintWidget constraintWidget8 = sparseArray.get(i10);
                    if (constraintWidget8 != null) {
                        constraintWidget.immediateConnect(ConstraintAnchor.Type.RIGHT, constraintWidget8, ConstraintAnchor.Type.LEFT, ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin, i13);
                    }
                } else if (!(i11 == -1 || (constraintWidget4 = sparseArray.get(i11)) == null)) {
                    ConstraintAnchor.Type type3 = ConstraintAnchor.Type.RIGHT;
                    constraintWidget.immediateConnect(type3, constraintWidget4, type3, ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin, i13);
                }
                int i16 = layoutParams.topToTop;
                if (i16 != -1) {
                    ConstraintWidget constraintWidget9 = sparseArray.get(i16);
                    if (constraintWidget9 != null) {
                        ConstraintAnchor.Type type4 = ConstraintAnchor.Type.TOP;
                        constraintWidget.immediateConnect(type4, constraintWidget9, type4, ((ViewGroup.MarginLayoutParams) layoutParams).topMargin, layoutParams.goneTopMargin);
                    }
                } else {
                    int i17 = layoutParams.topToBottom;
                    if (!(i17 == -1 || (constraintWidget3 = sparseArray.get(i17)) == null)) {
                        constraintWidget.immediateConnect(ConstraintAnchor.Type.TOP, constraintWidget3, ConstraintAnchor.Type.BOTTOM, ((ViewGroup.MarginLayoutParams) layoutParams).topMargin, layoutParams.goneTopMargin);
                    }
                }
                int i18 = layoutParams.bottomToTop;
                if (i18 != -1) {
                    ConstraintWidget constraintWidget10 = sparseArray.get(i18);
                    if (constraintWidget10 != null) {
                        constraintWidget.immediateConnect(ConstraintAnchor.Type.BOTTOM, constraintWidget10, ConstraintAnchor.Type.TOP, ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin, layoutParams.goneBottomMargin);
                    }
                } else {
                    int i19 = layoutParams.bottomToBottom;
                    if (!(i19 == -1 || (constraintWidget2 = sparseArray.get(i19)) == null)) {
                        ConstraintAnchor.Type type5 = ConstraintAnchor.Type.BOTTOM;
                        constraintWidget.immediateConnect(type5, constraintWidget2, type5, ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin, layoutParams.goneBottomMargin);
                    }
                }
                int i20 = layoutParams.baselineToBaseline;
                if (i20 != -1) {
                    setWidgetBaseline(constraintWidget, layoutParams, sparseArray, i20, ConstraintAnchor.Type.BASELINE);
                } else {
                    int i21 = layoutParams.baselineToTop;
                    if (i21 != -1) {
                        setWidgetBaseline(constraintWidget, layoutParams, sparseArray, i21, ConstraintAnchor.Type.TOP);
                    } else {
                        int i22 = layoutParams.baselineToBottom;
                        if (i22 != -1) {
                            setWidgetBaseline(constraintWidget, layoutParams, sparseArray, i22, ConstraintAnchor.Type.BOTTOM);
                        }
                    }
                }
                if (f4 >= f) {
                    constraintWidget.mHorizontalBiasPercent = f4;
                }
                float f6 = layoutParams.verticalBias;
                if (f6 >= f) {
                    constraintWidget.mVerticalBiasPercent = f6;
                }
            }
            if (z && !((i3 = layoutParams.editorAbsoluteX) == -1 && layoutParams.editorAbsoluteY == -1)) {
                int i23 = layoutParams.editorAbsoluteY;
                constraintWidget.mX = i3;
                constraintWidget.mY = i23;
            }
            int i24 = 0;
            if (layoutParams.horizontalDimensionFixed) {
                constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                constraintWidget.setWidth(((ViewGroup.MarginLayoutParams) layoutParams).width);
                if (((ViewGroup.MarginLayoutParams) layoutParams).width == -2) {
                    constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.WRAP_CONTENT);
                }
            } else if (((ViewGroup.MarginLayoutParams) layoutParams).width == -1) {
                if (layoutParams.constrainedWidth) {
                    constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT);
                } else {
                    constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_PARENT);
                }
                constraintWidget.getAnchor(ConstraintAnchor.Type.LEFT).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).leftMargin;
                constraintWidget.getAnchor(ConstraintAnchor.Type.RIGHT).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).rightMargin;
            } else {
                constraintWidget.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT);
                constraintWidget.setWidth(0);
            }
            if (layoutParams.verticalDimensionFixed) {
                constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                constraintWidget.setHeight(((ViewGroup.MarginLayoutParams) layoutParams).height);
                if (((ViewGroup.MarginLayoutParams) layoutParams).height == -2) {
                    constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.WRAP_CONTENT);
                }
            } else if (((ViewGroup.MarginLayoutParams) layoutParams).height == -1) {
                if (layoutParams.constrainedHeight) {
                    constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT);
                } else {
                    constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_PARENT);
                }
                constraintWidget.getAnchor(ConstraintAnchor.Type.TOP).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).topMargin;
                constraintWidget.getAnchor(ConstraintAnchor.Type.BOTTOM).mMargin = ((ViewGroup.MarginLayoutParams) layoutParams).bottomMargin;
            } else {
                constraintWidget.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT);
                constraintWidget.setHeight(0);
            }
            String str = layoutParams.dimensionRatio;
            if (str == null || str.length() == 0) {
                constraintWidget.mDimensionRatio = f;
            } else {
                int length = str.length();
                int indexOf = str.indexOf(44);
                if (indexOf <= 0 || indexOf >= length - 1) {
                    i = 1;
                    i2 = 0;
                } else {
                    String substring = str.substring(0, indexOf);
                    if (substring.equalsIgnoreCase("W")) {
                        i = 1;
                        i4 = 0;
                    } else if (substring.equalsIgnoreCase("H")) {
                        i = 1;
                        i4 = 1;
                    } else {
                        i = 1;
                    }
                    i2 = indexOf + i;
                }
                int indexOf2 = str.indexOf(58);
                if (indexOf2 < 0 || indexOf2 >= length - i) {
                    String substring2 = str.substring(i2);
                    if (substring2.length() > 0) {
                        f2 = Float.parseFloat(substring2);
                        if (f2 > f) {
                            constraintWidget.mDimensionRatio = f2;
                            constraintWidget.mDimensionRatioSide = i4;
                        }
                    }
                } else {
                    String substring3 = str.substring(i2, indexOf2);
                    String substring4 = str.substring(indexOf2 + i);
                    if (substring3.length() > 0 && substring4.length() > 0) {
                        try {
                            float parseFloat = Float.parseFloat(substring3);
                            float parseFloat2 = Float.parseFloat(substring4);
                            if (parseFloat > f && parseFloat2 > f) {
                                f2 = i4 == 1 ? Math.abs(parseFloat2 / parseFloat) : Math.abs(parseFloat / parseFloat2);
                                if (f2 > f) {
                                }
                            }
                        } catch (NumberFormatException unused) {
                        }
                    }
                }
                f2 = 0.0f;
                if (f2 > f) {
                }
            }
            float f7 = layoutParams.horizontalWeight;
            float[] fArr = constraintWidget.mWeight;
            fArr[0] = f7;
            fArr[1] = layoutParams.verticalWeight;
            constraintWidget.mHorizontalChainStyle = layoutParams.horizontalChainStyle;
            constraintWidget.mVerticalChainStyle = layoutParams.verticalChainStyle;
            int i25 = layoutParams.wrapBehaviorInParent;
            if (i25 >= 0 && i25 <= 3) {
                constraintWidget.mWrapBehaviorInParent = i25;
            }
            int i26 = layoutParams.matchConstraintDefaultWidth;
            int i27 = layoutParams.matchConstraintMinWidth;
            int i28 = layoutParams.matchConstraintMaxWidth;
            float f8 = layoutParams.matchConstraintPercentWidth;
            constraintWidget.mMatchConstraintDefaultWidth = i26;
            constraintWidget.mMatchConstraintMinWidth = i27;
            if (i28 == Integer.MAX_VALUE) {
                i28 = 0;
            }
            constraintWidget.mMatchConstraintMaxWidth = i28;
            constraintWidget.mMatchConstraintPercentWidth = f8;
            if (f8 > f && f8 < 1.0f && i26 == 0) {
                constraintWidget.mMatchConstraintDefaultWidth = 2;
            }
            int i29 = layoutParams.matchConstraintDefaultHeight;
            int i30 = layoutParams.matchConstraintMinHeight;
            int i31 = layoutParams.matchConstraintMaxHeight;
            float f9 = layoutParams.matchConstraintPercentHeight;
            constraintWidget.mMatchConstraintDefaultHeight = i29;
            constraintWidget.mMatchConstraintMinHeight = i30;
            if (i31 != Integer.MAX_VALUE) {
                i24 = i31;
            }
            constraintWidget.mMatchConstraintMaxHeight = i24;
            constraintWidget.mMatchConstraintPercentHeight = f9;
            if (f9 > f && f9 < 1.0f && i29 == 0) {
                constraintWidget.mMatchConstraintDefaultHeight = 2;
            }
        }
    }

    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof LayoutParams;
    }

    public void dispatchDraw(Canvas canvas) {
        Object tag;
        int size;
        ArrayList<ConstraintHelper> arrayList = this.mConstraintHelpers;
        if (arrayList != null && (size = arrayList.size()) > 0) {
            for (int i = 0; i < size; i++) {
                this.mConstraintHelpers.get(i).updatePreDraw(this);
            }
        }
        super.dispatchDraw(canvas);
        if (isInEditMode()) {
            float width = (float) getWidth();
            float height = (float) getHeight();
            int childCount = getChildCount();
            for (int i2 = 0; i2 < childCount; i2++) {
                View childAt = getChildAt(i2);
                if (!(childAt.getVisibility() == 8 || (tag = childAt.getTag()) == null || !(tag instanceof String))) {
                    String[] split = ((String) tag).split(",");
                    if (split.length == 4) {
                        int parseInt = Integer.parseInt(split[0]);
                        int parseInt2 = Integer.parseInt(split[1]);
                        int parseInt3 = Integer.parseInt(split[2]);
                        int i3 = (int) ((((float) parseInt) / 1080.0f) * width);
                        int i4 = (int) ((((float) parseInt2) / 1920.0f) * height);
                        Paint paint = new Paint();
                        paint.setColor(-65536);
                        float f = (float) i3;
                        float f2 = (float) i4;
                        float f3 = (float) (i3 + ((int) ((((float) parseInt3) / 1080.0f) * width)));
                        canvas.drawLine(f, f2, f3, f2, paint);
                        float parseInt4 = (float) (i4 + ((int) ((((float) Integer.parseInt(split[3])) / 1920.0f) * height)));
                        canvas.drawLine(f3, f2, f3, parseInt4, paint);
                        canvas.drawLine(f3, parseInt4, f, parseInt4, paint);
                        canvas.drawLine(f, parseInt4, f, f2, paint);
                        paint.setColor(-16711936);
                        canvas.drawLine(f, f2, f3, parseInt4, paint);
                        canvas.drawLine(f, parseInt4, f3, f2, paint);
                    }
                }
            }
        }
    }

    public void forceLayout() {
        this.mDirtyHierarchy = true;
        this.mLastMeasureWidth = -1;
        this.mLastMeasureHeight = -1;
        super.forceLayout();
    }

    @Override // android.view.ViewGroup
    public ViewGroup.LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }

    public Object getDesignInformation(int i, Object obj) {
        if (i != 0 || !(obj instanceof String)) {
            return null;
        }
        String str = (String) obj;
        HashMap<String, Integer> hashMap = this.mDesignIds;
        if (hashMap == null || !hashMap.containsKey(str)) {
            return null;
        }
        return this.mDesignIds.get(str);
    }

    public int getMaxHeight() {
        return this.mMaxHeight;
    }

    public int getMaxWidth() {
        return this.mMaxWidth;
    }

    public int getMinHeight() {
        return this.mMinHeight;
    }

    public int getMinWidth() {
        return this.mMinWidth;
    }

    public int getOptimizationLevel() {
        return this.mLayoutWidget.mOptimizationLevel;
    }

    public View getViewById(int i) {
        return this.mChildrenByIds.get(i);
    }

    public final ConstraintWidget getViewWidget(View view) {
        if (view == this) {
            return this.mLayoutWidget;
        }
        if (view == null) {
            return null;
        }
        if (view.getLayoutParams() instanceof LayoutParams) {
            return ((LayoutParams) view.getLayoutParams()).widget;
        }
        view.setLayoutParams(generateLayoutParams(view.getLayoutParams()));
        if (view.getLayoutParams() instanceof LayoutParams) {
            return ((LayoutParams) view.getLayoutParams()).widget;
        }
        return null;
    }

    public final void init(AttributeSet attributeSet, int i, int i2) {
        ConstraintWidgetContainer constraintWidgetContainer = this.mLayoutWidget;
        constraintWidgetContainer.mCompanionWidget = this;
        constraintWidgetContainer.setMeasurer(this.mMeasurer);
        this.mChildrenByIds.put(getId(), this);
        this.mConstraintSet = null;
        if (attributeSet != null) {
            TypedArray obtainStyledAttributes = getContext().obtainStyledAttributes(attributeSet, R$styleable.ConstraintLayout_Layout, i, i2);
            int indexCount = obtainStyledAttributes.getIndexCount();
            for (int i3 = 0; i3 < indexCount; i3++) {
                int index = obtainStyledAttributes.getIndex(i3);
                if (index == R$styleable.ConstraintLayout_Layout_android_minWidth) {
                    this.mMinWidth = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMinWidth);
                } else if (index == R$styleable.ConstraintLayout_Layout_android_minHeight) {
                    this.mMinHeight = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMinHeight);
                } else if (index == R$styleable.ConstraintLayout_Layout_android_maxWidth) {
                    this.mMaxWidth = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMaxWidth);
                } else if (index == R$styleable.ConstraintLayout_Layout_android_maxHeight) {
                    this.mMaxHeight = obtainStyledAttributes.getDimensionPixelOffset(index, this.mMaxHeight);
                } else if (index == R$styleable.ConstraintLayout_Layout_layout_optimizationLevel) {
                    this.mOptimizationLevel = obtainStyledAttributes.getInt(index, this.mOptimizationLevel);
                } else if (index == R$styleable.ConstraintLayout_Layout_layoutDescription) {
                    int resourceId = obtainStyledAttributes.getResourceId(index, 0);
                    if (resourceId != 0) {
                        try {
                            parseLayoutDescription(resourceId);
                        } catch (Resources.NotFoundException unused) {
                            this.mConstraintLayoutSpec = null;
                        }
                    }
                } else if (index == R$styleable.ConstraintLayout_Layout_constraintSet) {
                    int resourceId2 = obtainStyledAttributes.getResourceId(index, 0);
                    try {
                        ConstraintSet constraintSet = new ConstraintSet();
                        this.mConstraintSet = constraintSet;
                        constraintSet.load(getContext(), resourceId2);
                    } catch (Resources.NotFoundException unused2) {
                        this.mConstraintSet = null;
                    }
                    this.mConstraintSetId = resourceId2;
                }
            }
            obtainStyledAttributes.recycle();
        }
        this.mLayoutWidget.setOptimizationLevel(this.mOptimizationLevel);
    }

    public boolean isRtl() {
        if (!((getContext().getApplicationInfo().flags & AbstractByteBufAllocator.CALCULATE_THRESHOLD) != 0) || 1 != getLayoutDirection()) {
            return false;
        }
        return true;
    }

    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        View content;
        int childCount = getChildCount();
        boolean isInEditMode = isInEditMode();
        for (int i5 = 0; i5 < childCount; i5++) {
            View childAt = getChildAt(i5);
            LayoutParams layoutParams = (LayoutParams) childAt.getLayoutParams();
            ConstraintWidget constraintWidget = layoutParams.widget;
            if ((childAt.getVisibility() != 8 || layoutParams.isGuideline || layoutParams.isHelper || isInEditMode) && !layoutParams.isInPlaceholder) {
                int x = constraintWidget.getX();
                int y = constraintWidget.getY();
                int width = constraintWidget.getWidth() + x;
                int height = constraintWidget.getHeight() + y;
                childAt.layout(x, y, width, height);
                if ((childAt instanceof Placeholder) && (content = ((Placeholder) childAt).getContent()) != null) {
                    content.setVisibility(0);
                    content.layout(x, y, width, height);
                }
            }
        }
        int size = this.mConstraintHelpers.size();
        if (size > 0) {
            for (int i6 = 0; i6 < size; i6++) {
                this.mConstraintHelpers.get(i6).updatePostLayout(this);
            }
        }
    }

    public void onMeasure(int i, int i2) {
        boolean z;
        String str;
        int findId;
        ConstraintWidget constraintWidget;
        if (this.mOnMeasureWidthMeasureSpec == i) {
            int i3 = this.mOnMeasureHeightMeasureSpec;
        }
        if (!this.mDirtyHierarchy) {
            int childCount = getChildCount();
            int i4 = 0;
            while (true) {
                if (i4 >= childCount) {
                    break;
                } else if (getChildAt(i4).isLayoutRequested()) {
                    this.mDirtyHierarchy = true;
                    break;
                } else {
                    i4++;
                }
            }
        }
        boolean z2 = this.mDirtyHierarchy;
        this.mOnMeasureWidthMeasureSpec = i;
        this.mOnMeasureHeightMeasureSpec = i2;
        this.mLayoutWidget.mIsRtl = isRtl();
        if (this.mDirtyHierarchy) {
            this.mDirtyHierarchy = false;
            int childCount2 = getChildCount();
            int i5 = 0;
            while (true) {
                if (i5 >= childCount2) {
                    z = false;
                    break;
                } else if (getChildAt(i5).isLayoutRequested()) {
                    z = true;
                    break;
                } else {
                    i5++;
                }
            }
            if (z) {
                boolean isInEditMode = isInEditMode();
                int childCount3 = getChildCount();
                for (int i6 = 0; i6 < childCount3; i6++) {
                    ConstraintWidget viewWidget = getViewWidget(getChildAt(i6));
                    if (viewWidget != null) {
                        viewWidget.reset();
                    }
                }
                if (isInEditMode) {
                    for (int i7 = 0; i7 < childCount3; i7++) {
                        View childAt = getChildAt(i7);
                        try {
                            String resourceName = getResources().getResourceName(childAt.getId());
                            setDesignInformation(0, resourceName, Integer.valueOf(childAt.getId()));
                            int indexOf = resourceName.indexOf(47);
                            if (indexOf != -1) {
                                resourceName = resourceName.substring(indexOf + 1);
                            }
                            int id = childAt.getId();
                            if (id == 0) {
                                constraintWidget = this.mLayoutWidget;
                            } else {
                                View view = this.mChildrenByIds.get(id);
                                if (view == null && (view = findViewById(id)) != null && view != this && view.getParent() == this) {
                                    onViewAdded(view);
                                }
                                constraintWidget = view == this ? this.mLayoutWidget : view == null ? null : ((LayoutParams) view.getLayoutParams()).widget;
                            }
                            constraintWidget.mDebugName = resourceName;
                        } catch (Resources.NotFoundException unused) {
                        }
                    }
                }
                if (this.mConstraintSetId != -1) {
                    for (int i8 = 0; i8 < childCount3; i8++) {
                        View childAt2 = getChildAt(i8);
                        if (childAt2.getId() == this.mConstraintSetId && (childAt2 instanceof Constraints)) {
                            this.mConstraintSet = ((Constraints) childAt2).getConstraintSet();
                        }
                    }
                }
                ConstraintSet constraintSet = this.mConstraintSet;
                if (constraintSet != null) {
                    constraintSet.applyToInternal(this, true);
                }
                this.mLayoutWidget.mChildren.clear();
                int size = this.mConstraintHelpers.size();
                if (size > 0) {
                    for (int i9 = 0; i9 < size; i9++) {
                        ConstraintHelper constraintHelper = this.mConstraintHelpers.get(i9);
                        if (constraintHelper.isInEditMode()) {
                            constraintHelper.setIds(constraintHelper.mReferenceIds);
                        }
                        Helper helper = constraintHelper.mHelperWidget;
                        if (helper != null) {
                            ((HelperWidget) helper).removeAllIds();
                            for (int i10 = 0; i10 < constraintHelper.mCount; i10++) {
                                int i11 = constraintHelper.mIds[i10];
                                View viewById = getViewById(i11);
                                if (viewById == null && (findId = constraintHelper.findId(this, (str = constraintHelper.mMap.get(Integer.valueOf(i11))))) != 0) {
                                    constraintHelper.mIds[i10] = findId;
                                    constraintHelper.mMap.put(Integer.valueOf(findId), str);
                                    viewById = getViewById(findId);
                                }
                                if (viewById != null) {
                                    ((HelperWidget) constraintHelper.mHelperWidget).add(getViewWidget(viewById));
                                }
                            }
                            constraintHelper.mHelperWidget.updateConstraints(this.mLayoutWidget);
                        }
                    }
                }
                for (int i12 = 0; i12 < childCount3; i12++) {
                    View childAt3 = getChildAt(i12);
                    if (childAt3 instanceof Placeholder) {
                        Placeholder placeholder = (Placeholder) childAt3;
                        if (placeholder.mContentId == -1 && !placeholder.isInEditMode()) {
                            placeholder.setVisibility(placeholder.mEmptyVisibility);
                        }
                        View findViewById = findViewById(placeholder.mContentId);
                        placeholder.mContent = findViewById;
                        if (findViewById != null) {
                            ((LayoutParams) findViewById.getLayoutParams()).isInPlaceholder = true;
                            placeholder.mContent.setVisibility(0);
                            placeholder.setVisibility(0);
                        }
                    }
                }
                this.mTempMapIdToWidget.clear();
                this.mTempMapIdToWidget.put(0, this.mLayoutWidget);
                this.mTempMapIdToWidget.put(getId(), this.mLayoutWidget);
                for (int i13 = 0; i13 < childCount3; i13++) {
                    View childAt4 = getChildAt(i13);
                    this.mTempMapIdToWidget.put(childAt4.getId(), getViewWidget(childAt4));
                }
                for (int i14 = 0; i14 < childCount3; i14++) {
                    View childAt5 = getChildAt(i14);
                    ConstraintWidget viewWidget2 = getViewWidget(childAt5);
                    if (viewWidget2 != null) {
                        LayoutParams layoutParams = (LayoutParams) childAt5.getLayoutParams();
                        ConstraintWidgetContainer constraintWidgetContainer = this.mLayoutWidget;
                        constraintWidgetContainer.mChildren.add(viewWidget2);
                        ConstraintWidget constraintWidget2 = viewWidget2.mParent;
                        if (constraintWidget2 != null) {
                            ((WidgetContainer) constraintWidget2).mChildren.remove(viewWidget2);
                            viewWidget2.reset();
                        }
                        viewWidget2.mParent = constraintWidgetContainer;
                        applyConstraintsFromLayoutParams(isInEditMode, childAt5, viewWidget2, layoutParams, this.mTempMapIdToWidget);
                    }
                }
            }
            if (z) {
                ConstraintWidgetContainer constraintWidgetContainer2 = this.mLayoutWidget;
                constraintWidgetContainer2.mBasicMeasureSolver.updateHierarchy(constraintWidgetContainer2);
            }
        }
        resolveSystem(this.mLayoutWidget, this.mOptimizationLevel, i, i2);
        int width = this.mLayoutWidget.getWidth();
        int height = this.mLayoutWidget.getHeight();
        ConstraintWidgetContainer constraintWidgetContainer3 = this.mLayoutWidget;
        resolveMeasuredDimension(i, i2, width, height, constraintWidgetContainer3.mWidthMeasuredTooSmall, constraintWidgetContainer3.mHeightMeasuredTooSmall);
    }

    public void onViewAdded(View view) {
        super.onViewAdded(view);
        ConstraintWidget viewWidget = getViewWidget(view);
        if ((view instanceof Guideline) && !(viewWidget instanceof Guideline)) {
            LayoutParams layoutParams = (LayoutParams) view.getLayoutParams();
            Guideline guideline = new Guideline();
            layoutParams.widget = guideline;
            layoutParams.isGuideline = true;
            guideline.setOrientation(layoutParams.orientation);
        }
        if (view instanceof ConstraintHelper) {
            ConstraintHelper constraintHelper = (ConstraintHelper) view;
            constraintHelper.validateParams();
            ((LayoutParams) view.getLayoutParams()).isHelper = true;
            if (!this.mConstraintHelpers.contains(constraintHelper)) {
                this.mConstraintHelpers.add(constraintHelper);
            }
        }
        this.mChildrenByIds.put(view.getId(), view);
        this.mDirtyHierarchy = true;
    }

    public void onViewRemoved(View view) {
        super.onViewRemoved(view);
        this.mChildrenByIds.remove(view.getId());
        ConstraintWidget viewWidget = getViewWidget(view);
        this.mLayoutWidget.mChildren.remove(viewWidget);
        viewWidget.reset();
        this.mConstraintHelpers.remove(view);
        this.mDirtyHierarchy = true;
    }

    public void parseLayoutDescription(int i) {
        this.mConstraintLayoutSpec = new ConstraintLayoutStates(getContext(), this, i);
    }

    public void requestLayout() {
        this.mDirtyHierarchy = true;
        this.mLastMeasureWidth = -1;
        this.mLastMeasureHeight = -1;
        super.requestLayout();
    }

    public void resolveMeasuredDimension(int i, int i2, int i3, int i4, boolean z, boolean z2) {
        Measurer measurer = this.mMeasurer;
        int i5 = measurer.paddingHeight;
        int resolveSizeAndState = ViewGroup.resolveSizeAndState(i3 + measurer.paddingWidth, i, 0);
        int min = Math.min(this.mMaxWidth, resolveSizeAndState & 16777215);
        int min2 = Math.min(this.mMaxHeight, ViewGroup.resolveSizeAndState(i4 + i5, i2, 0) & 16777215);
        if (z) {
            min |= 16777216;
        }
        if (z2) {
            min2 |= 16777216;
        }
        setMeasuredDimension(min, min2);
        this.mLastMeasureWidth = min;
        this.mLastMeasureHeight = min2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:193:0x046a  */
    /* JADX WARNING: Removed duplicated region for block: B:195:0x0474  */
    /* JADX WARNING: Removed duplicated region for block: B:199:0x047b  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x00b1  */
    /* JADX WARNING: Removed duplicated region for block: B:252:0x0511  */
    /* JADX WARNING: Removed duplicated region for block: B:267:0x0561  */
    /* JADX WARNING: Removed duplicated region for block: B:269:0x0566  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x00d1  */
    /* JADX WARNING: Removed duplicated region for block: B:378:0x0515 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0147  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x0153  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x01ae A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:85:0x01b8  */
    public void resolveSystem(ConstraintWidgetContainer constraintWidgetContainer, int i, int i2, int i3) {
        int i4;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour;
        int i5;
        int i6;
        BasicMeasure basicMeasure;
        int size;
        boolean z;
        boolean z2;
        int i7;
        BasicMeasure.Measurer measurer;
        boolean z3;
        boolean z4;
        int i8;
        int size2;
        int i9;
        boolean z5;
        int i10;
        BasicMeasure.Measurer measurer2;
        boolean z6;
        HorizontalWidgetRun horizontalWidgetRun;
        VerticalWidgetRun verticalWidgetRun;
        int i11;
        int i12;
        boolean z7;
        int i13;
        int i14;
        boolean z8;
        boolean z9;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour2;
        int i15;
        ConstraintWidgetContainer constraintWidgetContainer2 = constraintWidgetContainer;
        int mode = View.MeasureSpec.getMode(i2);
        int size3 = View.MeasureSpec.getSize(i2);
        int mode2 = View.MeasureSpec.getMode(i3);
        int size4 = View.MeasureSpec.getSize(i3);
        int max = Math.max(0, getPaddingTop());
        int max2 = Math.max(0, getPaddingBottom());
        int i16 = max + max2;
        int paddingWidth = getPaddingWidth();
        Measurer measurer3 = this.mMeasurer;
        measurer3.paddingTop = max;
        measurer3.paddingBottom = max2;
        measurer3.paddingWidth = paddingWidth;
        measurer3.paddingHeight = i16;
        measurer3.layoutWidthSpec = i2;
        measurer3.layoutHeightSpec = i3;
        int max3 = Math.max(0, getPaddingStart());
        int max4 = Math.max(0, getPaddingEnd());
        if (max3 <= 0 && max4 <= 0) {
            max3 = Math.max(0, getPaddingLeft());
        } else if (isRtl()) {
            max3 = max4;
        }
        int i17 = size3 - paddingWidth;
        int i18 = size4 - i16;
        Measurer measurer4 = this.mMeasurer;
        int i19 = measurer4.paddingHeight;
        int i20 = measurer4.paddingWidth;
        ConstraintWidget.DimensionBehaviour dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.FIXED;
        int childCount = getChildCount();
        if (mode != Integer.MIN_VALUE) {
            if (mode == 0) {
                dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                if (childCount == 0) {
                    i15 = Math.max(0, this.mMinWidth);
                }
            } else if (mode != 1073741824) {
                dimensionBehaviour2 = dimensionBehaviour3;
            } else {
                i4 = Math.min(this.mMaxWidth - i20, i17);
                dimensionBehaviour = dimensionBehaviour3;
                i5 = LinearLayoutManager.INVALID_OFFSET;
                if (mode2 == i5) {
                    if (mode2 == 0) {
                        dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                        if (childCount == 0) {
                            i6 = Math.max(0, this.mMinHeight);
                        }
                    } else if (mode2 == 1073741824) {
                        i6 = Math.min(this.mMaxHeight - i19, i18);
                    }
                    i6 = 0;
                } else {
                    dimensionBehaviour3 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                    i6 = childCount == 0 ? Math.max(0, this.mMinHeight) : i18;
                }
                if (!(i4 == constraintWidgetContainer.getWidth() && i6 == constraintWidgetContainer.getHeight())) {
                    constraintWidgetContainer2.mDependencyGraph.mNeedRedoMeasures = true;
                }
                constraintWidgetContainer2.mX = 0;
                constraintWidgetContainer2.mY = 0;
                int[] iArr = constraintWidgetContainer2.mMaxDimension;
                iArr[0] = this.mMaxWidth - i20;
                iArr[1] = this.mMaxHeight - i19;
                constraintWidgetContainer2.setMinWidth(0);
                constraintWidgetContainer2.setMinHeight(0);
                constraintWidgetContainer2.setHorizontalDimensionBehaviour(dimensionBehaviour);
                constraintWidgetContainer2.setWidth(i4);
                constraintWidgetContainer2.setVerticalDimensionBehaviour(dimensionBehaviour3);
                constraintWidgetContainer2.setHeight(i6);
                constraintWidgetContainer2.setMinWidth(this.mMinWidth - i20);
                constraintWidgetContainer2.setMinHeight(this.mMinHeight - i19);
                constraintWidgetContainer2.mPaddingLeft = max3;
                constraintWidgetContainer2.mPaddingTop = max;
                basicMeasure = constraintWidgetContainer2.mBasicMeasureSolver;
                Objects.requireNonNull(basicMeasure);
                BasicMeasure.Measurer measurer5 = constraintWidgetContainer2.mMeasurer;
                size = constraintWidgetContainer2.mChildren.size();
                int width = constraintWidgetContainer.getWidth();
                int height = constraintWidgetContainer.getHeight();
                boolean enabled = Optimizer.enabled(i, 128);
                z = !enabled || Optimizer.enabled(i, 64);
                if (z) {
                    int i21 = 0;
                    while (true) {
                        if (i21 >= size) {
                            break;
                        }
                        ConstraintWidget constraintWidget = constraintWidgetContainer2.mChildren.get(i21);
                        ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour = constraintWidget.getHorizontalDimensionBehaviour();
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour4 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                        boolean z10 = (horizontalDimensionBehaviour == dimensionBehaviour4) && (constraintWidget.getVerticalDimensionBehaviour() == dimensionBehaviour4) && constraintWidget.mDimensionRatio > 0.0f;
                        if ((!constraintWidget.isInHorizontalChain() || !z10) && ((!constraintWidget.isInVerticalChain() || !z10) && !(constraintWidget instanceof VirtualLayout) && !constraintWidget.isInHorizontalChain() && !constraintWidget.isInVerticalChain())) {
                            i21++;
                        }
                    }
                    z = false;
                }
                z2 = z & ((mode != 1073741824 && mode2 == 1073741824) || enabled);
                if (!z2) {
                    int min = Math.min(constraintWidgetContainer2.mMaxDimension[0], i17);
                    int min2 = Math.min(constraintWidgetContainer2.mMaxDimension[1], i18);
                    if (mode == 1073741824 && constraintWidgetContainer.getWidth() != min) {
                        constraintWidgetContainer2.setWidth(min);
                        constraintWidgetContainer.invalidateGraph();
                    }
                    if (mode2 == 1073741824 && constraintWidgetContainer.getHeight() != min2) {
                        constraintWidgetContainer2.setHeight(min2);
                        constraintWidgetContainer.invalidateGraph();
                    }
                    if (mode == 1073741824 && mode2 == 1073741824) {
                        DependencyGraph dependencyGraph = constraintWidgetContainer2.mDependencyGraph;
                        boolean z11 = enabled & true;
                        if (dependencyGraph.mNeedBuildGraph || dependencyGraph.mNeedRedoMeasures) {
                            Iterator<ConstraintWidget> it = dependencyGraph.container.mChildren.iterator();
                            while (it.hasNext()) {
                                ConstraintWidget next = it.next();
                                next.ensureWidgetRuns();
                                next.measured = false;
                                next.horizontalRun.reset();
                                next.verticalRun.reset();
                            }
                            i14 = 0;
                            dependencyGraph.container.ensureWidgetRuns();
                            ConstraintWidgetContainer constraintWidgetContainer3 = dependencyGraph.container;
                            constraintWidgetContainer3.measured = false;
                            constraintWidgetContainer3.horizontalRun.reset();
                            dependencyGraph.container.verticalRun.reset();
                            dependencyGraph.mNeedRedoMeasures = false;
                        } else {
                            i14 = 0;
                        }
                        dependencyGraph.basicMeasureWidgets(dependencyGraph.mContainer);
                        ConstraintWidgetContainer constraintWidgetContainer4 = dependencyGraph.container;
                        constraintWidgetContainer4.mX = i14;
                        constraintWidgetContainer4.mY = i14;
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour5 = constraintWidgetContainer4.getDimensionBehaviour(i14);
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour6 = dependencyGraph.container.getDimensionBehaviour(1);
                        if (dependencyGraph.mNeedBuildGraph) {
                            dependencyGraph.buildGraph();
                        }
                        int x = dependencyGraph.container.getX();
                        int y = dependencyGraph.container.getY();
                        dependencyGraph.container.horizontalRun.start.resolve(x);
                        dependencyGraph.container.verticalRun.start.resolve(y);
                        dependencyGraph.measureWidgets();
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour7 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                        if (dimensionBehaviour5 == dimensionBehaviour7 || dimensionBehaviour6 == dimensionBehaviour7) {
                            if (z11) {
                                Iterator<WidgetRun> it2 = dependencyGraph.mRuns.iterator();
                                while (true) {
                                    if (it2.hasNext()) {
                                        if (!it2.next().supportsWrapComputation()) {
                                            z11 = false;
                                            break;
                                        }
                                    } else {
                                        break;
                                    }
                                }
                            }
                            if (!z11 || dimensionBehaviour5 != ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                                z3 = z2;
                                measurer = measurer5;
                            } else {
                                z3 = z2;
                                dependencyGraph.container.setHorizontalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                                ConstraintWidgetContainer constraintWidgetContainer5 = dependencyGraph.container;
                                measurer = measurer5;
                                constraintWidgetContainer5.setWidth(dependencyGraph.computeWrap(constraintWidgetContainer5, 0));
                                ConstraintWidgetContainer constraintWidgetContainer6 = dependencyGraph.container;
                                constraintWidgetContainer6.horizontalRun.dimension.resolve(constraintWidgetContainer6.getWidth());
                            }
                            if (z11 && dimensionBehaviour6 == ConstraintWidget.DimensionBehaviour.WRAP_CONTENT) {
                                dependencyGraph.container.setVerticalDimensionBehaviour(ConstraintWidget.DimensionBehaviour.FIXED);
                                ConstraintWidgetContainer constraintWidgetContainer7 = dependencyGraph.container;
                                constraintWidgetContainer7.setHeight(dependencyGraph.computeWrap(constraintWidgetContainer7, 1));
                                ConstraintWidgetContainer constraintWidgetContainer8 = dependencyGraph.container;
                                constraintWidgetContainer8.verticalRun.dimension.resolve(constraintWidgetContainer8.getHeight());
                            }
                        } else {
                            z3 = z2;
                            measurer = measurer5;
                        }
                        ConstraintWidgetContainer constraintWidgetContainer9 = dependencyGraph.container;
                        ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr = constraintWidgetContainer9.mListDimensionBehaviors;
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour8 = dimensionBehaviourArr[0];
                        i7 = width;
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour9 = ConstraintWidget.DimensionBehaviour.FIXED;
                        if (dimensionBehaviour8 == dimensionBehaviour9 || dimensionBehaviourArr[0] == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                            int width2 = constraintWidgetContainer9.getWidth() + x;
                            dependencyGraph.container.horizontalRun.end.resolve(width2);
                            dependencyGraph.container.horizontalRun.dimension.resolve(width2 - x);
                            dependencyGraph.measureWidgets();
                            ConstraintWidgetContainer constraintWidgetContainer10 = dependencyGraph.container;
                            ConstraintWidget.DimensionBehaviour[] dimensionBehaviourArr2 = constraintWidgetContainer10.mListDimensionBehaviors;
                            if (dimensionBehaviourArr2[1] == dimensionBehaviour9 || dimensionBehaviourArr2[1] == ConstraintWidget.DimensionBehaviour.MATCH_PARENT) {
                                int height2 = constraintWidgetContainer10.getHeight() + y;
                                dependencyGraph.container.verticalRun.end.resolve(height2);
                                dependencyGraph.container.verticalRun.dimension.resolve(height2 - y);
                            }
                            dependencyGraph.measureWidgets();
                            z8 = true;
                        } else {
                            z8 = false;
                        }
                        Iterator<WidgetRun> it3 = dependencyGraph.mRuns.iterator();
                        while (it3.hasNext()) {
                            WidgetRun next2 = it3.next();
                            if (next2.widget != dependencyGraph.container || next2.resolved) {
                                next2.applyToWidget();
                            }
                        }
                        Iterator<WidgetRun> it4 = dependencyGraph.mRuns.iterator();
                        while (true) {
                            if (!it4.hasNext()) {
                                z9 = true;
                                break;
                            }
                            WidgetRun next3 = it4.next();
                            if ((z8 || next3.widget != dependencyGraph.container) && (!next3.start.resolved || ((!next3.end.resolved && !(next3 instanceof GuidelineReference)) || (!next3.dimension.resolved && !(next3 instanceof ChainRun) && !(next3 instanceof GuidelineReference))))) {
                                z9 = false;
                            }
                        }
                        z9 = false;
                        dependencyGraph.container.setHorizontalDimensionBehaviour(dimensionBehaviour5);
                        dependencyGraph.container.setVerticalDimensionBehaviour(dimensionBehaviour6);
                        z4 = z9;
                        i11 = 1073741824;
                        i8 = 2;
                    } else {
                        z3 = z2;
                        measurer = measurer5;
                        i7 = width;
                        DependencyGraph dependencyGraph2 = constraintWidgetContainer2.mDependencyGraph;
                        if (dependencyGraph2.mNeedBuildGraph) {
                            Iterator<ConstraintWidget> it5 = dependencyGraph2.container.mChildren.iterator();
                            while (it5.hasNext()) {
                                ConstraintWidget next4 = it5.next();
                                next4.ensureWidgetRuns();
                                next4.measured = false;
                                HorizontalWidgetRun horizontalWidgetRun2 = next4.horizontalRun;
                                horizontalWidgetRun2.dimension.resolved = false;
                                horizontalWidgetRun2.resolved = false;
                                horizontalWidgetRun2.reset();
                                VerticalWidgetRun verticalWidgetRun2 = next4.verticalRun;
                                verticalWidgetRun2.dimension.resolved = false;
                                verticalWidgetRun2.resolved = false;
                                verticalWidgetRun2.reset();
                            }
                            i12 = 0;
                            dependencyGraph2.container.ensureWidgetRuns();
                            ConstraintWidgetContainer constraintWidgetContainer11 = dependencyGraph2.container;
                            constraintWidgetContainer11.measured = false;
                            HorizontalWidgetRun horizontalWidgetRun3 = constraintWidgetContainer11.horizontalRun;
                            horizontalWidgetRun3.dimension.resolved = false;
                            horizontalWidgetRun3.resolved = false;
                            horizontalWidgetRun3.reset();
                            VerticalWidgetRun verticalWidgetRun3 = dependencyGraph2.container.verticalRun;
                            verticalWidgetRun3.dimension.resolved = false;
                            verticalWidgetRun3.resolved = false;
                            verticalWidgetRun3.reset();
                            dependencyGraph2.buildGraph();
                        } else {
                            i12 = 0;
                        }
                        dependencyGraph2.basicMeasureWidgets(dependencyGraph2.mContainer);
                        ConstraintWidgetContainer constraintWidgetContainer12 = dependencyGraph2.container;
                        constraintWidgetContainer12.mX = i12;
                        constraintWidgetContainer12.mY = i12;
                        constraintWidgetContainer12.horizontalRun.start.resolve(i12);
                        dependencyGraph2.container.verticalRun.start.resolve(i12);
                        i11 = 1073741824;
                        if (mode == 1073741824) {
                            i13 = 1;
                            z7 = constraintWidgetContainer2.directMeasureWithOrientation(enabled, i12) & true;
                            i8 = 1;
                        } else {
                            i13 = 1;
                            i8 = 0;
                            z7 = true;
                        }
                        if (mode2 == 1073741824) {
                            z4 = z7 & constraintWidgetContainer2.directMeasureWithOrientation(enabled, i13);
                            i8++;
                        } else {
                            z4 = z7;
                        }
                    }
                    if (z4) {
                        constraintWidgetContainer2.updateFromRuns(mode == i11, mode2 == i11);
                    }
                } else {
                    z3 = z2;
                    measurer = measurer5;
                    i7 = width;
                    i8 = 0;
                    z4 = false;
                }
                if (z4 || i8 != 2) {
                    int i22 = constraintWidgetContainer2.mOptimizationLevel;
                    if (size > 0) {
                        int size5 = constraintWidgetContainer2.mChildren.size();
                        boolean optimizeFor = constraintWidgetContainer2.optimizeFor(64);
                        BasicMeasure.Measurer measurer6 = constraintWidgetContainer2.mMeasurer;
                        for (int i23 = 0; i23 < size5; i23++) {
                            ConstraintWidget constraintWidget2 = constraintWidgetContainer2.mChildren.get(i23);
                            if (!(constraintWidget2 instanceof Guideline) && !(constraintWidget2 instanceof Barrier) && !constraintWidget2.mInVirtualLayout && (!optimizeFor || (horizontalWidgetRun = constraintWidget2.horizontalRun) == null || (verticalWidgetRun = constraintWidget2.verticalRun) == null || !horizontalWidgetRun.dimension.resolved || !verticalWidgetRun.dimension.resolved)) {
                                ConstraintWidget.DimensionBehaviour dimensionBehaviour10 = constraintWidget2.getDimensionBehaviour(0);
                                ConstraintWidget.DimensionBehaviour dimensionBehaviour11 = constraintWidget2.getDimensionBehaviour(1);
                                ConstraintWidget.DimensionBehaviour dimensionBehaviour12 = ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                                boolean z12 = dimensionBehaviour10 == dimensionBehaviour12 && constraintWidget2.mMatchConstraintDefaultWidth != 1 && dimensionBehaviour11 == dimensionBehaviour12 && constraintWidget2.mMatchConstraintDefaultHeight != 1;
                                if (!z12 && constraintWidgetContainer2.optimizeFor(1) && !(constraintWidget2 instanceof VirtualLayout)) {
                                    if (dimensionBehaviour10 == dimensionBehaviour12 && constraintWidget2.mMatchConstraintDefaultWidth == 0 && dimensionBehaviour11 != dimensionBehaviour12 && !constraintWidget2.isInHorizontalChain()) {
                                        z12 = true;
                                    }
                                    if (dimensionBehaviour11 == dimensionBehaviour12 && constraintWidget2.mMatchConstraintDefaultHeight == 0 && dimensionBehaviour10 != dimensionBehaviour12 && !constraintWidget2.isInHorizontalChain()) {
                                        z12 = true;
                                    }
                                    if (dimensionBehaviour10 == dimensionBehaviour12 || dimensionBehaviour11 == dimensionBehaviour12) {
                                        if (constraintWidget2.mDimensionRatio > 0.0f) {
                                            z12 = true;
                                        }
                                        if (z12) {
                                            basicMeasure.measure(measurer6, constraintWidget2, 0);
                                        }
                                    }
                                }
                                if (z12) {
                                }
                            }
                        }
                        Measurer measurer7 = (Measurer) measurer6;
                        int childCount2 = measurer7.layout.getChildCount();
                        for (int i24 = 0; i24 < childCount2; i24++) {
                            View childAt = measurer7.layout.getChildAt(i24);
                            if (childAt instanceof Placeholder) {
                                ((Placeholder) childAt).updatePostMeasure();
                            }
                        }
                        int size6 = measurer7.layout.mConstraintHelpers.size();
                        if (size6 > 0) {
                            for (int i25 = 0; i25 < size6; i25++) {
                                measurer7.layout.mConstraintHelpers.get(i25).updatePostMeasure();
                            }
                        }
                    }
                    basicMeasure.updateHierarchy(constraintWidgetContainer2);
                    size2 = basicMeasure.mVariableDimensionsWidgets.size();
                    if (size > 0) {
                        basicMeasure.solveLinearSystem(constraintWidgetContainer2, 0, i7, height);
                    }
                    if (size2 > 0) {
                        ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour2 = constraintWidgetContainer.getHorizontalDimensionBehaviour();
                        ConstraintWidget.DimensionBehaviour dimensionBehaviour13 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
                        boolean z13 = horizontalDimensionBehaviour2 == dimensionBehaviour13;
                        boolean z14 = constraintWidgetContainer.getVerticalDimensionBehaviour() == dimensionBehaviour13;
                        int max5 = Math.max(constraintWidgetContainer.getWidth(), basicMeasure.constraintWidgetContainer.mMinWidth);
                        int max6 = Math.max(constraintWidgetContainer.getHeight(), basicMeasure.constraintWidgetContainer.mMinHeight);
                        int i26 = 0;
                        boolean z15 = false;
                        while (i26 < size2) {
                            ConstraintWidget constraintWidget3 = basicMeasure.mVariableDimensionsWidgets.get(i26);
                            if (!(constraintWidget3 instanceof VirtualLayout)) {
                                i10 = i22;
                                measurer2 = measurer;
                            } else {
                                int width3 = constraintWidget3.getWidth();
                                int height3 = constraintWidget3.getHeight();
                                i10 = i22;
                                measurer2 = measurer;
                                boolean measure = z15 | basicMeasure.measure(measurer2, constraintWidget3, 1);
                                int width4 = constraintWidget3.getWidth();
                                int height4 = constraintWidget3.getHeight();
                                if (width4 != width3) {
                                    constraintWidget3.setWidth(width4);
                                    if (z13 && constraintWidget3.getRight() > max5) {
                                        max5 = Math.max(max5, constraintWidget3.getAnchor(ConstraintAnchor.Type.RIGHT).getMargin() + constraintWidget3.getRight());
                                    }
                                    z6 = true;
                                } else {
                                    z6 = measure;
                                }
                                if (height4 != height3) {
                                    constraintWidget3.setHeight(height4);
                                    if (z14 && constraintWidget3.getBottom() > max6) {
                                        max6 = Math.max(max6, constraintWidget3.getAnchor(ConstraintAnchor.Type.BOTTOM).getMargin() + constraintWidget3.getBottom());
                                    }
                                    z6 = true;
                                }
                                z15 = ((VirtualLayout) constraintWidget3).mNeedsCallFromSolver | z6;
                            }
                            i26++;
                            measurer = measurer2;
                            i22 = i10;
                        }
                        int i27 = 0;
                        int i28 = 2;
                        while (true) {
                            if (i27 >= i28) {
                                break;
                            }
                            boolean z16 = z15;
                            int i29 = 0;
                            while (i29 < size2) {
                                ConstraintWidget constraintWidget4 = basicMeasure.mVariableDimensionsWidgets.get(i29);
                                if ((!(constraintWidget4 instanceof Helper) || (constraintWidget4 instanceof VirtualLayout)) && !(constraintWidget4 instanceof Guideline) && constraintWidget4.mVisibility != 8 && ((!z3 || !constraintWidget4.horizontalRun.dimension.resolved || !constraintWidget4.verticalRun.dimension.resolved) && !(constraintWidget4 instanceof VirtualLayout))) {
                                    int width5 = constraintWidget4.getWidth();
                                    int height5 = constraintWidget4.getHeight();
                                    i9 = size2;
                                    int i30 = constraintWidget4.mBaselineDistance;
                                    int i31 = 1;
                                    if (i27 == 1) {
                                        i31 = 2;
                                    }
                                    boolean measure2 = basicMeasure.measure(measurer, constraintWidget4, i31) | z16;
                                    int width6 = constraintWidget4.getWidth();
                                    int height6 = constraintWidget4.getHeight();
                                    if (width6 != width5) {
                                        constraintWidget4.setWidth(width6);
                                        if (z13 && constraintWidget4.getRight() > max5) {
                                            max5 = Math.max(max5, constraintWidget4.getAnchor(ConstraintAnchor.Type.RIGHT).getMargin() + constraintWidget4.getRight());
                                        }
                                        z5 = true;
                                    } else {
                                        z5 = measure2;
                                    }
                                    if (height6 != height5) {
                                        constraintWidget4.setHeight(height6);
                                        if (z14 && constraintWidget4.getBottom() > max6) {
                                            max6 = Math.max(max6, constraintWidget4.getAnchor(ConstraintAnchor.Type.BOTTOM).getMargin() + constraintWidget4.getBottom());
                                        }
                                        z5 = true;
                                    }
                                    z16 = (!constraintWidget4.hasBaseline || i30 == constraintWidget4.mBaselineDistance) ? z5 : true;
                                } else {
                                    i9 = size2;
                                }
                                i29++;
                                size2 = i9;
                            }
                            if (!z16) {
                                constraintWidgetContainer2 = constraintWidgetContainer;
                                break;
                            }
                            i27++;
                            constraintWidgetContainer2 = constraintWidgetContainer;
                            basicMeasure.solveLinearSystem(constraintWidgetContainer2, i27, i7, height);
                            size2 = size2;
                            i28 = 2;
                            z15 = false;
                        }
                        i22 = i22;
                    }
                    constraintWidgetContainer2.setOptimizationLevel(i22);
                }
                return;
            }
            dimensionBehaviour = dimensionBehaviour2;
            i5 = LinearLayoutManager.INVALID_OFFSET;
            i4 = 0;
            if (mode2 == i5) {
            }
            constraintWidgetContainer2.mDependencyGraph.mNeedRedoMeasures = true;
            constraintWidgetContainer2.mX = 0;
            constraintWidgetContainer2.mY = 0;
            int[] iArr2 = constraintWidgetContainer2.mMaxDimension;
            iArr2[0] = this.mMaxWidth - i20;
            iArr2[1] = this.mMaxHeight - i19;
            constraintWidgetContainer2.setMinWidth(0);
            constraintWidgetContainer2.setMinHeight(0);
            constraintWidgetContainer2.setHorizontalDimensionBehaviour(dimensionBehaviour);
            constraintWidgetContainer2.setWidth(i4);
            constraintWidgetContainer2.setVerticalDimensionBehaviour(dimensionBehaviour3);
            constraintWidgetContainer2.setHeight(i6);
            constraintWidgetContainer2.setMinWidth(this.mMinWidth - i20);
            constraintWidgetContainer2.setMinHeight(this.mMinHeight - i19);
            constraintWidgetContainer2.mPaddingLeft = max3;
            constraintWidgetContainer2.mPaddingTop = max;
            basicMeasure = constraintWidgetContainer2.mBasicMeasureSolver;
            Objects.requireNonNull(basicMeasure);
            BasicMeasure.Measurer measurer52 = constraintWidgetContainer2.mMeasurer;
            size = constraintWidgetContainer2.mChildren.size();
            int width7 = constraintWidgetContainer.getWidth();
            int height7 = constraintWidgetContainer.getHeight();
            boolean enabled2 = Optimizer.enabled(i, 128);
            if (!enabled2) {
            }
            if (z) {
            }
            z2 = z & ((mode != 1073741824 && mode2 == 1073741824) || enabled2);
            if (!z2) {
            }
            if (z4) {
            }
            int i222 = constraintWidgetContainer2.mOptimizationLevel;
            if (size > 0) {
            }
            basicMeasure.updateHierarchy(constraintWidgetContainer2);
            size2 = basicMeasure.mVariableDimensionsWidgets.size();
            if (size > 0) {
            }
            if (size2 > 0) {
            }
            constraintWidgetContainer2.setOptimizationLevel(i222);
        }
        dimensionBehaviour2 = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
        if (childCount == 0) {
            i15 = Math.max(0, this.mMinWidth);
        } else {
            dimensionBehaviour = dimensionBehaviour2;
            i5 = LinearLayoutManager.INVALID_OFFSET;
            i4 = i17;
            if (mode2 == i5) {
            }
            constraintWidgetContainer2.mDependencyGraph.mNeedRedoMeasures = true;
            constraintWidgetContainer2.mX = 0;
            constraintWidgetContainer2.mY = 0;
            int[] iArr22 = constraintWidgetContainer2.mMaxDimension;
            iArr22[0] = this.mMaxWidth - i20;
            iArr22[1] = this.mMaxHeight - i19;
            constraintWidgetContainer2.setMinWidth(0);
            constraintWidgetContainer2.setMinHeight(0);
            constraintWidgetContainer2.setHorizontalDimensionBehaviour(dimensionBehaviour);
            constraintWidgetContainer2.setWidth(i4);
            constraintWidgetContainer2.setVerticalDimensionBehaviour(dimensionBehaviour3);
            constraintWidgetContainer2.setHeight(i6);
            constraintWidgetContainer2.setMinWidth(this.mMinWidth - i20);
            constraintWidgetContainer2.setMinHeight(this.mMinHeight - i19);
            constraintWidgetContainer2.mPaddingLeft = max3;
            constraintWidgetContainer2.mPaddingTop = max;
            basicMeasure = constraintWidgetContainer2.mBasicMeasureSolver;
            Objects.requireNonNull(basicMeasure);
            BasicMeasure.Measurer measurer522 = constraintWidgetContainer2.mMeasurer;
            size = constraintWidgetContainer2.mChildren.size();
            int width72 = constraintWidgetContainer.getWidth();
            int height72 = constraintWidgetContainer.getHeight();
            boolean enabled22 = Optimizer.enabled(i, 128);
            if (!enabled22) {
            }
            if (z) {
            }
            z2 = z & ((mode != 1073741824 && mode2 == 1073741824) || enabled22);
            if (!z2) {
            }
            if (z4) {
            }
            int i2222 = constraintWidgetContainer2.mOptimizationLevel;
            if (size > 0) {
            }
            basicMeasure.updateHierarchy(constraintWidgetContainer2);
            size2 = basicMeasure.mVariableDimensionsWidgets.size();
            if (size > 0) {
            }
            if (size2 > 0) {
            }
            constraintWidgetContainer2.setOptimizationLevel(i2222);
        }
        i5 = LinearLayoutManager.INVALID_OFFSET;
        i4 = i15;
        dimensionBehaviour = dimensionBehaviour2;
        if (mode2 == i5) {
        }
        constraintWidgetContainer2.mDependencyGraph.mNeedRedoMeasures = true;
        constraintWidgetContainer2.mX = 0;
        constraintWidgetContainer2.mY = 0;
        int[] iArr222 = constraintWidgetContainer2.mMaxDimension;
        iArr222[0] = this.mMaxWidth - i20;
        iArr222[1] = this.mMaxHeight - i19;
        constraintWidgetContainer2.setMinWidth(0);
        constraintWidgetContainer2.setMinHeight(0);
        constraintWidgetContainer2.setHorizontalDimensionBehaviour(dimensionBehaviour);
        constraintWidgetContainer2.setWidth(i4);
        constraintWidgetContainer2.setVerticalDimensionBehaviour(dimensionBehaviour3);
        constraintWidgetContainer2.setHeight(i6);
        constraintWidgetContainer2.setMinWidth(this.mMinWidth - i20);
        constraintWidgetContainer2.setMinHeight(this.mMinHeight - i19);
        constraintWidgetContainer2.mPaddingLeft = max3;
        constraintWidgetContainer2.mPaddingTop = max;
        basicMeasure = constraintWidgetContainer2.mBasicMeasureSolver;
        Objects.requireNonNull(basicMeasure);
        BasicMeasure.Measurer measurer5222 = constraintWidgetContainer2.mMeasurer;
        size = constraintWidgetContainer2.mChildren.size();
        int width722 = constraintWidgetContainer.getWidth();
        int height722 = constraintWidgetContainer.getHeight();
        boolean enabled222 = Optimizer.enabled(i, 128);
        if (!enabled222) {
        }
        if (z) {
        }
        z2 = z & ((mode != 1073741824 && mode2 == 1073741824) || enabled222);
        if (!z2) {
        }
        if (z4) {
        }
        int i22222 = constraintWidgetContainer2.mOptimizationLevel;
        if (size > 0) {
        }
        basicMeasure.updateHierarchy(constraintWidgetContainer2);
        size2 = basicMeasure.mVariableDimensionsWidgets.size();
        if (size > 0) {
        }
        if (size2 > 0) {
        }
        constraintWidgetContainer2.setOptimizationLevel(i22222);
    }

    public void setConstraintSet(ConstraintSet constraintSet) {
        this.mConstraintSet = constraintSet;
    }

    public void setDesignInformation(int i, Object obj, Object obj2) {
        if (i == 0 && (obj instanceof String) && (obj2 instanceof Integer)) {
            if (this.mDesignIds == null) {
                this.mDesignIds = new HashMap<>();
            }
            String str = (String) obj;
            int indexOf = str.indexOf("/");
            if (indexOf != -1) {
                str = str.substring(indexOf + 1);
            }
            this.mDesignIds.put(str, Integer.valueOf(((Integer) obj2).intValue()));
        }
    }

    public void setId(int i) {
        this.mChildrenByIds.remove(getId());
        super.setId(i);
        this.mChildrenByIds.put(getId(), this);
    }

    public void setMaxHeight(int i) {
        if (i != this.mMaxHeight) {
            this.mMaxHeight = i;
            requestLayout();
        }
    }

    public void setMaxWidth(int i) {
        if (i != this.mMaxWidth) {
            this.mMaxWidth = i;
            requestLayout();
        }
    }

    public void setMinHeight(int i) {
        if (i != this.mMinHeight) {
            this.mMinHeight = i;
            requestLayout();
        }
    }

    public void setMinWidth(int i) {
        if (i != this.mMinWidth) {
            this.mMinWidth = i;
            requestLayout();
        }
    }

    public void setOnConstraintsChanged(ConstraintsChangedListener constraintsChangedListener) {
        ConstraintLayoutStates constraintLayoutStates = this.mConstraintLayoutSpec;
        if (constraintLayoutStates != null) {
            Objects.requireNonNull(constraintLayoutStates);
        }
    }

    public void setOptimizationLevel(int i) {
        this.mOptimizationLevel = i;
        ConstraintWidgetContainer constraintWidgetContainer = this.mLayoutWidget;
        constraintWidgetContainer.mOptimizationLevel = i;
        LinearSystem.USE_DEPENDENCY_ORDERING = constraintWidgetContainer.optimizeFor(512);
    }

    public final void setWidgetBaseline(ConstraintWidget constraintWidget, LayoutParams layoutParams, SparseArray<ConstraintWidget> sparseArray, int i, ConstraintAnchor.Type type) {
        View view = this.mChildrenByIds.get(i);
        ConstraintWidget constraintWidget2 = sparseArray.get(i);
        if (constraintWidget2 != null && view != null && (view.getLayoutParams() instanceof LayoutParams)) {
            layoutParams.needsBaseline = true;
            ConstraintAnchor.Type type2 = ConstraintAnchor.Type.BASELINE;
            if (type == type2) {
                LayoutParams layoutParams2 = (LayoutParams) view.getLayoutParams();
                layoutParams2.needsBaseline = true;
                layoutParams2.widget.hasBaseline = true;
            }
            constraintWidget.getAnchor(type2).connect(constraintWidget2.getAnchor(type), layoutParams.baselineMargin, layoutParams.goneBaselineMargin, true);
            constraintWidget.hasBaseline = true;
            constraintWidget.getAnchor(ConstraintAnchor.Type.TOP).reset();
            constraintWidget.getAnchor(ConstraintAnchor.Type.BOTTOM).reset();
        }
    }

    public boolean shouldDelayChildPressedState() {
        return false;
    }

    public LayoutParams generateDefaultLayoutParams() {
        return new LayoutParams(-2, -2);
    }

    @Override // android.view.ViewGroup
    public ViewGroup.LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return new LayoutParams(layoutParams);
    }

    public ConstraintLayout(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        init(attributeSet, 0, 0);
    }

    public ConstraintLayout(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        init(attributeSet, i, 0);
    }

    public static class LayoutParams extends ViewGroup.MarginLayoutParams {
        public int baselineMargin = 0;
        public int baselineToBaseline = -1;
        public int baselineToBottom = -1;
        public int baselineToTop = -1;
        public int bottomToBottom = -1;
        public int bottomToTop = -1;
        public float circleAngle = 0.0f;
        public int circleConstraint = -1;
        public int circleRadius = 0;
        public boolean constrainedHeight = false;
        public boolean constrainedWidth = false;
        public String constraintTag = null;
        public String dimensionRatio = null;
        public int editorAbsoluteX = -1;
        public int editorAbsoluteY = -1;
        public int endToEnd = -1;
        public int endToStart = -1;
        public int goneBaselineMargin = LinearLayoutManager.INVALID_OFFSET;
        public int goneBottomMargin = LinearLayoutManager.INVALID_OFFSET;
        public int goneEndMargin = LinearLayoutManager.INVALID_OFFSET;
        public int goneLeftMargin = LinearLayoutManager.INVALID_OFFSET;
        public int goneRightMargin = LinearLayoutManager.INVALID_OFFSET;
        public int goneStartMargin = LinearLayoutManager.INVALID_OFFSET;
        public int goneTopMargin = LinearLayoutManager.INVALID_OFFSET;
        public int guideBegin = -1;
        public int guideEnd = -1;
        public float guidePercent = -1.0f;
        public float horizontalBias = 0.5f;
        public int horizontalChainStyle = 0;
        public boolean horizontalDimensionFixed = true;
        public float horizontalWeight = -1.0f;
        public boolean isGuideline = false;
        public boolean isHelper = false;
        public boolean isInPlaceholder = false;
        public int leftToLeft = -1;
        public int leftToRight = -1;
        public int matchConstraintDefaultHeight = 0;
        public int matchConstraintDefaultWidth = 0;
        public int matchConstraintMaxHeight = 0;
        public int matchConstraintMaxWidth = 0;
        public int matchConstraintMinHeight = 0;
        public int matchConstraintMinWidth = 0;
        public float matchConstraintPercentHeight = 1.0f;
        public float matchConstraintPercentWidth = 1.0f;
        public boolean needsBaseline = false;
        public int orientation = -1;
        public int resolveGoneLeftMargin = LinearLayoutManager.INVALID_OFFSET;
        public int resolveGoneRightMargin = LinearLayoutManager.INVALID_OFFSET;
        public int resolvedGuideBegin;
        public int resolvedGuideEnd;
        public float resolvedGuidePercent;
        public float resolvedHorizontalBias = 0.5f;
        public int resolvedLeftToLeft = -1;
        public int resolvedLeftToRight = -1;
        public int resolvedRightToLeft = -1;
        public int resolvedRightToRight = -1;
        public int rightToLeft = -1;
        public int rightToRight = -1;
        public int startToEnd = -1;
        public int startToStart = -1;
        public int topToBottom = -1;
        public int topToTop = -1;
        public float verticalBias = 0.5f;
        public int verticalChainStyle = 0;
        public boolean verticalDimensionFixed = true;
        public float verticalWeight = -1.0f;
        public ConstraintWidget widget = new ConstraintWidget();
        public int wrapBehaviorInParent = 0;

        public abstract class Table {
            public static final SparseIntArray map;

            static {
                SparseIntArray sparseIntArray = new SparseIntArray();
                map = sparseIntArray;
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintWidth, 64);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHeight, 65);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintLeft_toLeftOf, 8);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintLeft_toRightOf, 9);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintRight_toLeftOf, 10);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintRight_toRightOf, 11);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintTop_toTopOf, 12);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintTop_toBottomOf, 13);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintBottom_toTopOf, 14);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintBottom_toBottomOf, 15);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintBaseline_toBaselineOf, 16);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintBaseline_toTopOf, 52);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintBaseline_toBottomOf, 53);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintCircle, 2);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintCircleRadius, 3);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintCircleAngle, 4);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_editor_absoluteX, 49);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_editor_absoluteY, 50);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintGuide_begin, 5);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintGuide_end, 6);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintGuide_percent, 7);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_android_orientation, 1);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintStart_toEndOf, 17);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintStart_toStartOf, 18);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintEnd_toStartOf, 19);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintEnd_toEndOf, 20);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginLeft, 21);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginTop, 22);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginRight, 23);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginBottom, 24);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginStart, 25);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginEnd, 26);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_goneMarginBaseline, 55);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_marginBaseline, 54);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHorizontal_bias, 29);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintVertical_bias, 30);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintDimensionRatio, 44);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHorizontal_weight, 45);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintVertical_weight, 46);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHorizontal_chainStyle, 47);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintVertical_chainStyle, 48);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constrainedWidth, 27);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constrainedHeight, 28);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintWidth_default, 31);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHeight_default, 32);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintWidth_min, 33);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintWidth_max, 34);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintWidth_percent, 35);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHeight_min, 36);
                sparseIntArray.append(R$styleable.ConstraintLayout_Layout_layout_constraintHeight_max, 37);
                SparseIntArray sparseIntArray2 = map;
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintHeight_percent, 38);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintLeft_creator, 39);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintTop_creator, 40);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintRight_creator, 41);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintBottom_creator, 42);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintBaseline_creator, 43);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_constraintTag, 51);
                sparseIntArray2.append(R$styleable.ConstraintLayout_Layout_layout_wrapBehaviorInParent, 66);
            }
        }

        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
            TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R$styleable.ConstraintLayout_Layout);
            int indexCount = obtainStyledAttributes.getIndexCount();
            for (int i = 0; i < indexCount; i++) {
                int index = obtainStyledAttributes.getIndex(i);
                int i2 = Table.map.get(index);
                switch (i2) {
                    case 1:
                        this.orientation = obtainStyledAttributes.getInt(index, this.orientation);
                        break;
                    case 2:
                        int resourceId = obtainStyledAttributes.getResourceId(index, this.circleConstraint);
                        this.circleConstraint = resourceId;
                        if (resourceId == -1) {
                            this.circleConstraint = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 3:
                        this.circleRadius = obtainStyledAttributes.getDimensionPixelSize(index, this.circleRadius);
                        break;
                    case 4:
                        float f = obtainStyledAttributes.getFloat(index, this.circleAngle) % 360.0f;
                        this.circleAngle = f;
                        if (f < 0.0f) {
                            this.circleAngle = (360.0f - f) % 360.0f;
                            break;
                        } else {
                            break;
                        }
                    case 5:
                        this.guideBegin = obtainStyledAttributes.getDimensionPixelOffset(index, this.guideBegin);
                        break;
                    case 6:
                        this.guideEnd = obtainStyledAttributes.getDimensionPixelOffset(index, this.guideEnd);
                        break;
                    case 7:
                        this.guidePercent = obtainStyledAttributes.getFloat(index, this.guidePercent);
                        break;
                    case 8:
                        int resourceId2 = obtainStyledAttributes.getResourceId(index, this.leftToLeft);
                        this.leftToLeft = resourceId2;
                        if (resourceId2 == -1) {
                            this.leftToLeft = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 9:
                        int resourceId3 = obtainStyledAttributes.getResourceId(index, this.leftToRight);
                        this.leftToRight = resourceId3;
                        if (resourceId3 == -1) {
                            this.leftToRight = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 10:
                        int resourceId4 = obtainStyledAttributes.getResourceId(index, this.rightToLeft);
                        this.rightToLeft = resourceId4;
                        if (resourceId4 == -1) {
                            this.rightToLeft = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 11:
                        int resourceId5 = obtainStyledAttributes.getResourceId(index, this.rightToRight);
                        this.rightToRight = resourceId5;
                        if (resourceId5 == -1) {
                            this.rightToRight = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 12:
                        int resourceId6 = obtainStyledAttributes.getResourceId(index, this.topToTop);
                        this.topToTop = resourceId6;
                        if (resourceId6 == -1) {
                            this.topToTop = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 13:
                        int resourceId7 = obtainStyledAttributes.getResourceId(index, this.topToBottom);
                        this.topToBottom = resourceId7;
                        if (resourceId7 == -1) {
                            this.topToBottom = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 14:
                        int resourceId8 = obtainStyledAttributes.getResourceId(index, this.bottomToTop);
                        this.bottomToTop = resourceId8;
                        if (resourceId8 == -1) {
                            this.bottomToTop = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 15:
                        int resourceId9 = obtainStyledAttributes.getResourceId(index, this.bottomToBottom);
                        this.bottomToBottom = resourceId9;
                        if (resourceId9 == -1) {
                            this.bottomToBottom = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 16:
                        int resourceId10 = obtainStyledAttributes.getResourceId(index, this.baselineToBaseline);
                        this.baselineToBaseline = resourceId10;
                        if (resourceId10 == -1) {
                            this.baselineToBaseline = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 17:
                        int resourceId11 = obtainStyledAttributes.getResourceId(index, this.startToEnd);
                        this.startToEnd = resourceId11;
                        if (resourceId11 == -1) {
                            this.startToEnd = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 18:
                        int resourceId12 = obtainStyledAttributes.getResourceId(index, this.startToStart);
                        this.startToStart = resourceId12;
                        if (resourceId12 == -1) {
                            this.startToStart = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 19:
                        int resourceId13 = obtainStyledAttributes.getResourceId(index, this.endToStart);
                        this.endToStart = resourceId13;
                        if (resourceId13 == -1) {
                            this.endToStart = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 20:
                        int resourceId14 = obtainStyledAttributes.getResourceId(index, this.endToEnd);
                        this.endToEnd = resourceId14;
                        if (resourceId14 == -1) {
                            this.endToEnd = obtainStyledAttributes.getInt(index, -1);
                            break;
                        } else {
                            break;
                        }
                    case 21:
                        this.goneLeftMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneLeftMargin);
                        break;
                    case 22:
                        this.goneTopMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneTopMargin);
                        break;
                    case 23:
                        this.goneRightMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneRightMargin);
                        break;
                    case 24:
                        this.goneBottomMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneBottomMargin);
                        break;
                    case 25:
                        this.goneStartMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneStartMargin);
                        break;
                    case 26:
                        this.goneEndMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneEndMargin);
                        break;
                    case 27:
                        this.constrainedWidth = obtainStyledAttributes.getBoolean(index, this.constrainedWidth);
                        break;
                    case 28:
                        this.constrainedHeight = obtainStyledAttributes.getBoolean(index, this.constrainedHeight);
                        break;
                    case 29:
                        this.horizontalBias = obtainStyledAttributes.getFloat(index, this.horizontalBias);
                        break;
                    case 30:
                        this.verticalBias = obtainStyledAttributes.getFloat(index, this.verticalBias);
                        break;
                    case 31:
                        int i3 = obtainStyledAttributes.getInt(index, 0);
                        this.matchConstraintDefaultWidth = i3;
                        if (i3 == 1) {
                            Log.e("ConstraintLayout", "layout_constraintWidth_default=\"wrap\" is deprecated.\nUse layout_width=\"WRAP_CONTENT\" and layout_constrainedWidth=\"true\" instead.");
                            break;
                        } else {
                            break;
                        }
                    case 32:
                        int i4 = obtainStyledAttributes.getInt(index, 0);
                        this.matchConstraintDefaultHeight = i4;
                        if (i4 == 1) {
                            Log.e("ConstraintLayout", "layout_constraintHeight_default=\"wrap\" is deprecated.\nUse layout_height=\"WRAP_CONTENT\" and layout_constrainedHeight=\"true\" instead.");
                            break;
                        } else {
                            break;
                        }
                    case 33:
                        try {
                            this.matchConstraintMinWidth = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMinWidth);
                            break;
                        } catch (Exception unused) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMinWidth) == -2) {
                                this.matchConstraintMinWidth = -2;
                                break;
                            } else {
                                break;
                            }
                        }
                    case 34:
                        try {
                            this.matchConstraintMaxWidth = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMaxWidth);
                            break;
                        } catch (Exception unused2) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMaxWidth) == -2) {
                                this.matchConstraintMaxWidth = -2;
                                break;
                            } else {
                                break;
                            }
                        }
                    case 35:
                        this.matchConstraintPercentWidth = Math.max(0.0f, obtainStyledAttributes.getFloat(index, this.matchConstraintPercentWidth));
                        this.matchConstraintDefaultWidth = 2;
                        break;
                    case 36:
                        try {
                            this.matchConstraintMinHeight = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMinHeight);
                            break;
                        } catch (Exception unused3) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMinHeight) == -2) {
                                this.matchConstraintMinHeight = -2;
                                break;
                            } else {
                                break;
                            }
                        }
                    case 37:
                        try {
                            this.matchConstraintMaxHeight = obtainStyledAttributes.getDimensionPixelSize(index, this.matchConstraintMaxHeight);
                            break;
                        } catch (Exception unused4) {
                            if (obtainStyledAttributes.getInt(index, this.matchConstraintMaxHeight) == -2) {
                                this.matchConstraintMaxHeight = -2;
                                break;
                            } else {
                                break;
                            }
                        }
                    case 38:
                        this.matchConstraintPercentHeight = Math.max(0.0f, obtainStyledAttributes.getFloat(index, this.matchConstraintPercentHeight));
                        this.matchConstraintDefaultHeight = 2;
                        break;
                    default:
                        switch (i2) {
                            case 44:
                                ConstraintSet.parseDimensionRatioString(this, obtainStyledAttributes.getString(index));
                                continue;
                            case 45:
                                this.horizontalWeight = obtainStyledAttributes.getFloat(index, this.horizontalWeight);
                                continue;
                            case 46:
                                this.verticalWeight = obtainStyledAttributes.getFloat(index, this.verticalWeight);
                                continue;
                            case 47:
                                this.horizontalChainStyle = obtainStyledAttributes.getInt(index, 0);
                                continue;
                            case 48:
                                this.verticalChainStyle = obtainStyledAttributes.getInt(index, 0);
                                continue;
                            case 49:
                                this.editorAbsoluteX = obtainStyledAttributes.getDimensionPixelOffset(index, this.editorAbsoluteX);
                                continue;
                            case 50:
                                this.editorAbsoluteY = obtainStyledAttributes.getDimensionPixelOffset(index, this.editorAbsoluteY);
                                continue;
                            case 51:
                                this.constraintTag = obtainStyledAttributes.getString(index);
                                continue;
                            case 52:
                                int resourceId15 = obtainStyledAttributes.getResourceId(index, this.baselineToTop);
                                this.baselineToTop = resourceId15;
                                if (resourceId15 == -1) {
                                    this.baselineToTop = obtainStyledAttributes.getInt(index, -1);
                                    break;
                                } else {
                                    continue;
                                }
                            case 53:
                                int resourceId16 = obtainStyledAttributes.getResourceId(index, this.baselineToBottom);
                                this.baselineToBottom = resourceId16;
                                if (resourceId16 == -1) {
                                    this.baselineToBottom = obtainStyledAttributes.getInt(index, -1);
                                    break;
                                } else {
                                    continue;
                                }
                            case 54:
                                this.baselineMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.baselineMargin);
                                continue;
                            case 55:
                                this.goneBaselineMargin = obtainStyledAttributes.getDimensionPixelSize(index, this.goneBaselineMargin);
                                continue;
                            default:
                                switch (i2) {
                                    case 64:
                                        ConstraintSet.parseDimensionConstraints(this, obtainStyledAttributes, index, 0);
                                        continue;
                                        continue;
                                    case 65:
                                        ConstraintSet.parseDimensionConstraints(this, obtainStyledAttributes, index, 1);
                                        continue;
                                    case 66:
                                        this.wrapBehaviorInParent = obtainStyledAttributes.getInt(index, this.wrapBehaviorInParent);
                                        continue;
                                }
                        }
                }
            }
            obtainStyledAttributes.recycle();
            validate();
        }

        /* JADX WARNING: Removed duplicated region for block: B:15:0x004e  */
        /* JADX WARNING: Removed duplicated region for block: B:18:0x0055  */
        /* JADX WARNING: Removed duplicated region for block: B:21:0x005c  */
        /* JADX WARNING: Removed duplicated region for block: B:24:0x0062  */
        /* JADX WARNING: Removed duplicated region for block: B:27:0x0068  */
        /* JADX WARNING: Removed duplicated region for block: B:34:0x007a  */
        /* JADX WARNING: Removed duplicated region for block: B:35:0x0082  */
        @TargetApi(17)
        public void resolveLayoutDirection(int i) {
            int i2;
            int i3;
            int i4;
            int i5;
            int i6 = ((ViewGroup.MarginLayoutParams) this).leftMargin;
            int i7 = ((ViewGroup.MarginLayoutParams) this).rightMargin;
            super.resolveLayoutDirection(i);
            boolean z = false;
            boolean z2 = 1 == getLayoutDirection();
            this.resolvedRightToLeft = -1;
            this.resolvedRightToRight = -1;
            this.resolvedLeftToLeft = -1;
            this.resolvedLeftToRight = -1;
            this.resolveGoneLeftMargin = -1;
            this.resolveGoneRightMargin = -1;
            this.resolveGoneLeftMargin = this.goneLeftMargin;
            this.resolveGoneRightMargin = this.goneRightMargin;
            float f = this.horizontalBias;
            this.resolvedHorizontalBias = f;
            int i8 = this.guideBegin;
            this.resolvedGuideBegin = i8;
            int i9 = this.guideEnd;
            this.resolvedGuideEnd = i9;
            float f2 = this.guidePercent;
            this.resolvedGuidePercent = f2;
            if (z2) {
                int i10 = this.startToEnd;
                if (i10 != -1) {
                    this.resolvedRightToLeft = i10;
                } else {
                    int i11 = this.startToStart;
                    if (i11 != -1) {
                        this.resolvedRightToRight = i11;
                    }
                    i2 = this.endToStart;
                    if (i2 != -1) {
                        this.resolvedLeftToRight = i2;
                        z = true;
                    }
                    i3 = this.endToEnd;
                    if (i3 != -1) {
                        this.resolvedLeftToLeft = i3;
                        z = true;
                    }
                    i4 = this.goneStartMargin;
                    if (i4 != Integer.MIN_VALUE) {
                        this.resolveGoneRightMargin = i4;
                    }
                    i5 = this.goneEndMargin;
                    if (i5 != Integer.MIN_VALUE) {
                        this.resolveGoneLeftMargin = i5;
                    }
                    if (z) {
                        this.resolvedHorizontalBias = 1.0f - f;
                    }
                    if (this.isGuideline && this.orientation == 1) {
                        if (f2 == -1.0f) {
                            this.resolvedGuidePercent = 1.0f - f2;
                            this.resolvedGuideBegin = -1;
                            this.resolvedGuideEnd = -1;
                        } else if (i8 != -1) {
                            this.resolvedGuideEnd = i8;
                            this.resolvedGuideBegin = -1;
                            this.resolvedGuidePercent = -1.0f;
                        } else if (i9 != -1) {
                            this.resolvedGuideBegin = i9;
                            this.resolvedGuideEnd = -1;
                            this.resolvedGuidePercent = -1.0f;
                        }
                    }
                }
                z = true;
                i2 = this.endToStart;
                if (i2 != -1) {
                }
                i3 = this.endToEnd;
                if (i3 != -1) {
                }
                i4 = this.goneStartMargin;
                if (i4 != Integer.MIN_VALUE) {
                }
                i5 = this.goneEndMargin;
                if (i5 != Integer.MIN_VALUE) {
                }
                if (z) {
                }
                if (f2 == -1.0f) {
                }
            } else {
                int i12 = this.startToEnd;
                if (i12 != -1) {
                    this.resolvedLeftToRight = i12;
                }
                int i13 = this.startToStart;
                if (i13 != -1) {
                    this.resolvedLeftToLeft = i13;
                }
                int i14 = this.endToStart;
                if (i14 != -1) {
                    this.resolvedRightToLeft = i14;
                }
                int i15 = this.endToEnd;
                if (i15 != -1) {
                    this.resolvedRightToRight = i15;
                }
                int i16 = this.goneStartMargin;
                if (i16 != Integer.MIN_VALUE) {
                    this.resolveGoneLeftMargin = i16;
                }
                int i17 = this.goneEndMargin;
                if (i17 != Integer.MIN_VALUE) {
                    this.resolveGoneRightMargin = i17;
                }
            }
            if (this.endToStart == -1 && this.endToEnd == -1 && this.startToStart == -1 && this.startToEnd == -1) {
                int i18 = this.rightToLeft;
                if (i18 != -1) {
                    this.resolvedRightToLeft = i18;
                    if (((ViewGroup.MarginLayoutParams) this).rightMargin <= 0 && i7 > 0) {
                        ((ViewGroup.MarginLayoutParams) this).rightMargin = i7;
                    }
                } else {
                    int i19 = this.rightToRight;
                    if (i19 != -1) {
                        this.resolvedRightToRight = i19;
                        if (((ViewGroup.MarginLayoutParams) this).rightMargin <= 0 && i7 > 0) {
                            ((ViewGroup.MarginLayoutParams) this).rightMargin = i7;
                        }
                    }
                }
                int i20 = this.leftToLeft;
                if (i20 != -1) {
                    this.resolvedLeftToLeft = i20;
                    if (((ViewGroup.MarginLayoutParams) this).leftMargin <= 0 && i6 > 0) {
                        ((ViewGroup.MarginLayoutParams) this).leftMargin = i6;
                        return;
                    }
                    return;
                }
                int i21 = this.leftToRight;
                if (i21 != -1) {
                    this.resolvedLeftToRight = i21;
                    if (((ViewGroup.MarginLayoutParams) this).leftMargin <= 0 && i6 > 0) {
                        ((ViewGroup.MarginLayoutParams) this).leftMargin = i6;
                    }
                }
            }
        }

        public void validate() {
            this.isGuideline = false;
            this.horizontalDimensionFixed = true;
            this.verticalDimensionFixed = true;
            int i = ((ViewGroup.MarginLayoutParams) this).width;
            if (i == -2 && this.constrainedWidth) {
                this.horizontalDimensionFixed = false;
                if (this.matchConstraintDefaultWidth == 0) {
                    this.matchConstraintDefaultWidth = 1;
                }
            }
            int i2 = ((ViewGroup.MarginLayoutParams) this).height;
            if (i2 == -2 && this.constrainedHeight) {
                this.verticalDimensionFixed = false;
                if (this.matchConstraintDefaultHeight == 0) {
                    this.matchConstraintDefaultHeight = 1;
                }
            }
            if (i == 0 || i == -1) {
                this.horizontalDimensionFixed = false;
                if (i == 0 && this.matchConstraintDefaultWidth == 1) {
                    ((ViewGroup.MarginLayoutParams) this).width = -2;
                    this.constrainedWidth = true;
                }
            }
            if (i2 == 0 || i2 == -1) {
                this.verticalDimensionFixed = false;
                if (i2 == 0 && this.matchConstraintDefaultHeight == 1) {
                    ((ViewGroup.MarginLayoutParams) this).height = -2;
                    this.constrainedHeight = true;
                }
            }
            if (this.guidePercent != -1.0f || this.guideBegin != -1 || this.guideEnd != -1) {
                this.isGuideline = true;
                this.horizontalDimensionFixed = true;
                this.verticalDimensionFixed = true;
                if (!(this.widget instanceof Guideline)) {
                    this.widget = new Guideline();
                }
                ((Guideline) this.widget).setOrientation(this.orientation);
            }
        }

        public LayoutParams(int i, int i2) {
            super(i, i2);
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }
    }
}
