package androidx.core.content.res;

import android.content.Context;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Typeface;
import android.os.Handler;
import android.util.AttributeSet;
import android.util.Log;
import android.util.TypedValue;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.core.graphics.TypefaceCompat;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.IOException;
import java.lang.reflect.Method;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

public abstract class ResourcesCompat$ThemeCompat {

    public abstract class ImplApi23 {
        public static Method sRebaseMethod;
        public static boolean sRebaseMethodFetched;
        public static final Object sRebaseMethodLock = new Object();
    }

    public static int getAttr(Context context, int i, int i2) {
        TypedValue typedValue = new TypedValue();
        context.getTheme().resolveAttribute(i, typedValue, true);
        return typedValue.resourceId != 0 ? i : i2;
    }

    public static boolean getBoolean(TypedArray typedArray, int i, int i2, boolean z) {
        return typedArray.getBoolean(i, typedArray.getBoolean(i2, z));
    }

    public static ComplexColorCompat getNamedComplexColor(TypedArray typedArray, XmlPullParser xmlPullParser, Resources.Theme theme, String str, int i, int i2) {
        ComplexColorCompat complexColorCompat;
        if (hasAttribute(xmlPullParser, str)) {
            TypedValue typedValue = new TypedValue();
            typedArray.getValue(i, typedValue);
            int i3 = typedValue.type;
            if (i3 >= 28 && i3 <= 31) {
                return new ComplexColorCompat(null, null, typedValue.data);
            }
            try {
                complexColorCompat = ComplexColorCompat.createFromXml(typedArray.getResources(), typedArray.getResourceId(i, 0), theme);
            } catch (Exception e) {
                Log.e("ComplexColorCompat", "Failed to inflate ComplexColor.", e);
                complexColorCompat = null;
            }
            if (complexColorCompat != null) {
                return complexColorCompat;
            }
        }
        return new ComplexColorCompat(null, null, i2);
    }

    public static String getNamedString(TypedArray typedArray, XmlPullParser xmlPullParser, String str, int i) {
        if (!hasAttribute(xmlPullParser, str)) {
            return null;
        }
        return typedArray.getString(i);
    }

    public static int getResourceId(TypedArray typedArray, int i, int i2, int i3) {
        return typedArray.getResourceId(i, typedArray.getResourceId(i2, i3));
    }

    public static String getString(TypedArray typedArray, int i, int i2) {
        String string = typedArray.getString(i);
        return string == null ? typedArray.getString(i2) : string;
    }

    public static CharSequence[] getTextArray(TypedArray typedArray, int i, int i2) {
        CharSequence[] textArray = typedArray.getTextArray(i);
        return textArray == null ? typedArray.getTextArray(i2) : textArray;
    }

    public static boolean hasAttribute(XmlPullParser xmlPullParser, String str) {
        return xmlPullParser.getAttributeValue("http://schemas.android.com/apk/res/android", str) != null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:31:0x00b8  */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x00bd A[ADDED_TO_REGION] */
    public static Typeface loadFont(Context context, int i, TypedValue typedValue, int i2, ResourcesCompat$FontCallback resourcesCompat$FontCallback, Handler handler, boolean z, boolean z2) {
        Resources resources = context.getResources();
        resources.getValue(i, typedValue, true);
        CharSequence charSequence = typedValue.string;
        if (charSequence != null) {
            String charSequence2 = charSequence.toString();
            Typeface typeface = null;
            if (charSequence2.startsWith("res/")) {
                Typeface typeface2 = TypefaceCompat.sTypefaceCache.get(TypefaceCompat.createResourceUid(resources, i, i2));
                if (typeface2 != null) {
                    if (resourcesCompat$FontCallback != null) {
                        resourcesCompat$FontCallback.callbackSuccessAsync(typeface2, handler);
                    }
                } else if (!z2) {
                    try {
                        if (charSequence2.toLowerCase().endsWith(".xml")) {
                            FontResourcesParserCompat$FamilyResourceEntry parse = AppCompatDelegateImpl.Api17Impl.parse(resources.getXml(i), resources);
                            if (parse == null) {
                                Log.e("ResourcesCompat", "Failed to find font-family tag");
                                if (resourcesCompat$FontCallback != null) {
                                    resourcesCompat$FontCallback.callbackFailAsync(-3, handler);
                                }
                            } else {
                                typeface = TypefaceCompat.createFromResourcesFamilyXml(context, parse, resources, i, i2, resourcesCompat$FontCallback, handler, z);
                            }
                        } else {
                            typeface2 = TypefaceCompat.createFromResourcesFontFile(context, resources, i, charSequence2, i2);
                            if (resourcesCompat$FontCallback != null) {
                                if (typeface2 != null) {
                                    resourcesCompat$FontCallback.callbackSuccessAsync(typeface2, handler);
                                } else {
                                    resourcesCompat$FontCallback.callbackFailAsync(-3, handler);
                                }
                            }
                        }
                    } catch (XmlPullParserException e) {
                        Log.e("ResourcesCompat", "Failed to parse xml resource " + charSequence2, e);
                        if (resourcesCompat$FontCallback != null) {
                            resourcesCompat$FontCallback.callbackFailAsync(-3, handler);
                        }
                        if (typeface == null) {
                        }
                        return typeface;
                    } catch (IOException e2) {
                        Log.e("ResourcesCompat", "Failed to read xml resource " + charSequence2, e2);
                        if (resourcesCompat$FontCallback != null) {
                        }
                        if (typeface == null) {
                        }
                        return typeface;
                    }
                }
                typeface = typeface2;
            } else if (resourcesCompat$FontCallback != null) {
                resourcesCompat$FontCallback.callbackFailAsync(-3, handler);
            }
            if (typeface == null || resourcesCompat$FontCallback != null || z2) {
                return typeface;
            }
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Font resource ID #0x");
            outline25.append(Integer.toHexString(i));
            outline25.append(" could not be retrieved.");
            throw new Resources.NotFoundException(outline25.toString());
        }
        StringBuilder outline252 = GeneratedOutlineSupport.outline25("Resource \"");
        outline252.append(resources.getResourceName(i));
        outline252.append("\" (");
        outline252.append(Integer.toHexString(i));
        outline252.append(") is not a Font: ");
        outline252.append(typedValue);
        throw new Resources.NotFoundException(outline252.toString());
    }

    public static TypedArray obtainAttributes(Resources resources, Resources.Theme theme, AttributeSet attributeSet, int[] iArr) {
        if (theme == null) {
            return resources.obtainAttributes(attributeSet, iArr);
        }
        return theme.obtainStyledAttributes(attributeSet, iArr, 0, 0);
    }
}
