package androidx.core.provider;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.pm.PackageManager;
import android.graphics.Typeface;
import androidx.collection.LruCache;
import androidx.collection.SimpleArrayMap;
import androidx.core.graphics.TypefaceCompat;
import androidx.core.util.Consumer;
import java.util.ArrayList;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.LinkedBlockingDeque;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

public abstract class FontRequestWorker {
    public static final ExecutorService DEFAULT_EXECUTOR_SERVICE;
    public static final Object LOCK = new Object();
    public static final SimpleArrayMap<String, ArrayList<Consumer<TypefaceResult>>> PENDING_REPLIES = new SimpleArrayMap<>();
    public static final LruCache<String, Typeface> sTypefaceCache = new LruCache<>(16);

    static {
        ThreadPoolExecutor threadPoolExecutor = new ThreadPoolExecutor(0, 1, (long) 10000, TimeUnit.MILLISECONDS, new LinkedBlockingDeque(), new RequestExecutor$DefaultThreadFactory("fonts-androidx", 10));
        threadPoolExecutor.allowCoreThreadTimeOut(true);
        DEFAULT_EXECUTOR_SERVICE = threadPoolExecutor;
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x0046  */
    public static TypefaceResult getFontSync(String str, Context context, FontRequest fontRequest, int i) {
        int i2;
        Typeface typeface = sTypefaceCache.get(str);
        if (typeface != null) {
            return new TypefaceResult(typeface);
        }
        try {
            FontsContractCompat$FontFamilyResult fontFamilyResult = FontProvider.getFontFamilyResult(context, fontRequest, null);
            int i3 = fontFamilyResult.mStatusCode;
            int i4 = 1;
            if (i3 == 0) {
                FontsContractCompat$FontInfo[] fontsContractCompat$FontInfoArr = fontFamilyResult.mFonts;
                if (!(fontsContractCompat$FontInfoArr == null || fontsContractCompat$FontInfoArr.length == 0)) {
                    for (FontsContractCompat$FontInfo fontsContractCompat$FontInfo : fontsContractCompat$FontInfoArr) {
                        int i5 = fontsContractCompat$FontInfo.mResultCode;
                        if (i5 != 0) {
                            if (i5 >= 0) {
                                i2 = i5;
                                if (i2 == 0) {
                                }
                            }
                        }
                    }
                    i4 = 0;
                }
                i2 = i4;
                if (i2 == 0) {
                }
            } else if (i3 == 1) {
                i2 = -2;
                if (i2 == 0) {
                    return new TypefaceResult(i2);
                }
                Typeface createFromFontInfo = TypefaceCompat.sTypefaceCompatImpl.createFromFontInfo(context, null, fontFamilyResult.mFonts, i);
                if (createFromFontInfo == null) {
                    return new TypefaceResult(-3);
                }
                sTypefaceCache.put(str, createFromFontInfo);
                return new TypefaceResult(createFromFontInfo);
            }
            i2 = -3;
            if (i2 == 0) {
            }
        } catch (PackageManager.NameNotFoundException unused) {
            return new TypefaceResult(-1);
        }
    }

    public final class TypefaceResult {
        public final int mResult;
        public final Typeface mTypeface;

        public TypefaceResult(int i) {
            this.mTypeface = null;
            this.mResult = i;
        }

        @SuppressLint({"WrongConstant"})
        public TypefaceResult(Typeface typeface) {
            this.mTypeface = typeface;
            this.mResult = 0;
        }
    }
}
