package androidx.core.text;

import android.text.SpannableStringBuilder;
import android.text.TextUtils;
import androidx.core.text.TextDirectionHeuristicsCompat;
import java.util.Locale;

public final class BidiFormatter {
    public static final BidiFormatter DEFAULT_LTR_INSTANCE;
    public static final BidiFormatter DEFAULT_RTL_INSTANCE;
    public static final TextDirectionHeuristicsCompat.TextDirectionHeuristicImpl DEFAULT_TEXT_DIRECTION_HEURISTIC;
    public static final String LRM_STRING = Character.toString(8206);
    public static final String RLM_STRING = Character.toString(8207);
    public final TextDirectionHeuristicsCompat.TextDirectionHeuristicImpl mDefaultTextDirectionHeuristicCompat;
    public final int mFlags;
    public final boolean mIsRtlContext;

    public class DirectionalityEstimator {
        public static final byte[] DIR_TYPE_CACHE = new byte[1792];
        public int charIndex;
        public char lastChar;
        public final int length;
        public final CharSequence text;

        static {
            for (int i = 0; i < 1792; i++) {
                DIR_TYPE_CACHE[i] = Character.getDirectionality(i);
            }
        }

        public DirectionalityEstimator(CharSequence charSequence, boolean z) {
            this.text = charSequence;
            this.length = charSequence.length();
        }

        public byte dirTypeBackward() {
            char charAt = this.text.charAt(this.charIndex - 1);
            this.lastChar = charAt;
            if (Character.isLowSurrogate(charAt)) {
                int codePointBefore = Character.codePointBefore(this.text, this.charIndex);
                this.charIndex -= Character.charCount(codePointBefore);
                return Character.getDirectionality(codePointBefore);
            }
            this.charIndex--;
            char c = this.lastChar;
            return c < 1792 ? DIR_TYPE_CACHE[c] : Character.getDirectionality(c);
        }
    }

    static {
        TextDirectionHeuristicsCompat.TextDirectionHeuristicImpl textDirectionHeuristicImpl = TextDirectionHeuristicsCompat.FIRSTSTRONG_LTR;
        DEFAULT_TEXT_DIRECTION_HEURISTIC = textDirectionHeuristicImpl;
        DEFAULT_LTR_INSTANCE = new BidiFormatter(false, 2, textDirectionHeuristicImpl);
        DEFAULT_RTL_INSTANCE = new BidiFormatter(true, 2, textDirectionHeuristicImpl);
    }

    public BidiFormatter(boolean z, int i, TextDirectionHeuristicsCompat.TextDirectionHeuristicImpl textDirectionHeuristicImpl) {
        this.mIsRtlContext = z;
        this.mFlags = i;
        this.mDefaultTextDirectionHeuristicCompat = textDirectionHeuristicImpl;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:33:0x0088, code lost:
        return 1;
     */
    public static int getEntryDir(CharSequence charSequence) {
        byte b;
        DirectionalityEstimator directionalityEstimator = new DirectionalityEstimator(charSequence, false);
        directionalityEstimator.charIndex = 0;
        int i = 0;
        int i2 = 0;
        int i3 = 0;
        while (true) {
            int i4 = directionalityEstimator.charIndex;
            if (i4 < directionalityEstimator.length && i == 0) {
                char charAt = directionalityEstimator.text.charAt(i4);
                directionalityEstimator.lastChar = charAt;
                if (Character.isHighSurrogate(charAt)) {
                    int codePointAt = Character.codePointAt(directionalityEstimator.text, directionalityEstimator.charIndex);
                    directionalityEstimator.charIndex = Character.charCount(codePointAt) + directionalityEstimator.charIndex;
                    b = Character.getDirectionality(codePointAt);
                } else {
                    directionalityEstimator.charIndex++;
                    char c = directionalityEstimator.lastChar;
                    b = c < 1792 ? DirectionalityEstimator.DIR_TYPE_CACHE[c] : Character.getDirectionality(c);
                }
                if (b != 0) {
                    if (b == 1 || b == 2) {
                        if (i3 == 0) {
                        }
                    } else if (b != 9) {
                        switch (b) {
                            case 14:
                            case 15:
                                i3++;
                                i2 = -1;
                                break;
                            case 16:
                            case 17:
                                i3++;
                                i2 = 1;
                                break;
                            case 18:
                                i3--;
                                i2 = 0;
                                break;
                        }
                    }
                } else if (i3 == 0) {
                }
                i = i3;
            } else if (i == 0) {
                return 0;
            } else {
                if (i2 != 0) {
                    return i2;
                }
                while (directionalityEstimator.charIndex > 0) {
                    switch (directionalityEstimator.dirTypeBackward()) {
                        case 14:
                        case 15:
                            if (i == i3) {
                                break;
                            }
                            break;
                        case 16:
                        case 17:
                            if (i == i3) {
                                break;
                            }
                            break;
                        case 18:
                            i3++;
                            continue;
                    }
                    i3--;
                }
                return 0;
            }
        }
        return -1;
    }

    public static int getExitDir(CharSequence charSequence) {
        DirectionalityEstimator directionalityEstimator = new DirectionalityEstimator(charSequence, false);
        directionalityEstimator.charIndex = directionalityEstimator.length;
        int i = 0;
        int i2 = 0;
        while (directionalityEstimator.charIndex > 0) {
            byte dirTypeBackward = directionalityEstimator.dirTypeBackward();
            if (dirTypeBackward != 0) {
                if (dirTypeBackward == 1 || dirTypeBackward == 2) {
                    if (i != 0) {
                        if (i2 != 0) {
                        }
                        i2 = i;
                    }
                } else if (dirTypeBackward != 9) {
                    switch (dirTypeBackward) {
                        case 14:
                        case 15:
                            if (i2 == i) {
                                break;
                            }
                            i--;
                            break;
                        case 16:
                        case 17:
                            if (i2 == i) {
                                break;
                            }
                            i--;
                            break;
                        case 18:
                            i++;
                            break;
                        default:
                            if (i2 != 0) {
                                break;
                            }
                            i2 = i;
                            break;
                    }
                } else {
                    continue;
                }
                return 1;
            } else if (i != 0) {
                if (i2 != 0) {
                }
                i2 = i;
            }
            return -1;
        }
        return 0;
    }

    public static BidiFormatter getInstance() {
        Locale locale = Locale.getDefault();
        Locale locale2 = TextUtilsCompat.ROOT;
        boolean z = true;
        if (TextUtils.getLayoutDirectionFromLocale(locale) != 1) {
            z = false;
        }
        TextDirectionHeuristicsCompat.TextDirectionHeuristicImpl textDirectionHeuristicImpl = DEFAULT_TEXT_DIRECTION_HEURISTIC;
        if (textDirectionHeuristicImpl == DEFAULT_TEXT_DIRECTION_HEURISTIC) {
            return z ? DEFAULT_RTL_INSTANCE : DEFAULT_LTR_INSTANCE;
        }
        return new BidiFormatter(z, 2, textDirectionHeuristicImpl);
    }

    public CharSequence unicodeWrap(CharSequence charSequence, TextDirectionHeuristicsCompat.TextDirectionHeuristicImpl textDirectionHeuristicImpl, boolean z) {
        String str;
        if (charSequence == null) {
            return null;
        }
        boolean isRtl = textDirectionHeuristicImpl.isRtl(charSequence, 0, charSequence.length());
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        String str2 = "";
        if (((this.mFlags & 2) != 0) && z) {
            boolean isRtl2 = (isRtl ? TextDirectionHeuristicsCompat.RTL : TextDirectionHeuristicsCompat.LTR).isRtl(charSequence, 0, charSequence.length());
            if (this.mIsRtlContext || (!isRtl2 && getEntryDir(charSequence) != 1)) {
                str = (!this.mIsRtlContext || (isRtl2 && getEntryDir(charSequence) != -1)) ? str2 : RLM_STRING;
            } else {
                str = LRM_STRING;
            }
            spannableStringBuilder.append((CharSequence) str);
        }
        if (isRtl != this.mIsRtlContext) {
            spannableStringBuilder.append(isRtl ? (char) 8235 : 8234);
            spannableStringBuilder.append(charSequence);
            spannableStringBuilder.append((char) 8236);
        } else {
            spannableStringBuilder.append(charSequence);
        }
        if (z) {
            boolean isRtl3 = (isRtl ? TextDirectionHeuristicsCompat.RTL : TextDirectionHeuristicsCompat.LTR).isRtl(charSequence, 0, charSequence.length());
            if (!this.mIsRtlContext && (isRtl3 || getExitDir(charSequence) == 1)) {
                str2 = LRM_STRING;
            } else if (this.mIsRtlContext && (!isRtl3 || getExitDir(charSequence) == -1)) {
                str2 = RLM_STRING;
            }
            spannableStringBuilder.append((CharSequence) str2);
        }
        return spannableStringBuilder;
    }
}
