package androidx.dynamicanimation.animation;

import android.os.SystemClock;
import android.view.Choreographer;
import androidx.collection.SimpleArrayMap;
import androidx.dynamicanimation.animation.DynamicAnimation;
import java.util.ArrayList;
import java.util.Objects;

public class AnimationHandler {
    public static final ThreadLocal<AnimationHandler> sAnimatorHandler = new ThreadLocal<>();
    public final ArrayList<AnimationFrameCallback> mAnimationCallbacks = new ArrayList<>();
    public final AnimationCallbackDispatcher mCallbackDispatcher = new AnimationCallbackDispatcher();
    public long mCurrentFrameTime = 0;
    public final SimpleArrayMap<AnimationFrameCallback, Long> mDelayedCallbackStartTime = new SimpleArrayMap<>();
    public boolean mListDirty = false;
    public AnimationFrameCallbackProvider mProvider;

    public class AnimationCallbackDispatcher {
        public AnimationCallbackDispatcher() {
        }

        /* JADX WARNING: Removed duplicated region for block: B:14:0x0047  */
        public void dispatchAnimationFrame() {
            int i;
            boolean z;
            float f;
            boolean z2;
            AnimationHandler.this.mCurrentFrameTime = SystemClock.uptimeMillis();
            AnimationHandler animationHandler = AnimationHandler.this;
            long j = animationHandler.mCurrentFrameTime;
            long uptimeMillis = SystemClock.uptimeMillis();
            int i2 = 0;
            while (i2 < animationHandler.mAnimationCallbacks.size()) {
                AnimationFrameCallback animationFrameCallback = animationHandler.mAnimationCallbacks.get(i2);
                if (animationFrameCallback != null) {
                    Long orDefault = animationHandler.mDelayedCallbackStartTime.getOrDefault(animationFrameCallback, null);
                    if (orDefault != null) {
                        if (orDefault.longValue() < uptimeMillis) {
                            animationHandler.mDelayedCallbackStartTime.remove(animationFrameCallback);
                        } else {
                            z = false;
                            if (z) {
                                DynamicAnimation dynamicAnimation = (DynamicAnimation) animationFrameCallback;
                                long j2 = dynamicAnimation.mLastFrameTime;
                                if (j2 == 0) {
                                    dynamicAnimation.mLastFrameTime = j;
                                    dynamicAnimation.setPropertyValue(dynamicAnimation.mValue);
                                } else {
                                    long j3 = j - j2;
                                    dynamicAnimation.mLastFrameTime = j;
                                    SpringAnimation springAnimation = (SpringAnimation) dynamicAnimation;
                                    if (springAnimation.mPendingPosition != Float.MAX_VALUE) {
                                        SpringForce springForce = springAnimation.mSpring;
                                        double d = springForce.mFinalPosition;
                                        i = i2;
                                        long j4 = j3 / 2;
                                        DynamicAnimation.MassState updateValues = springForce.updateValues((double) springAnimation.mValue, (double) springAnimation.mVelocity, j4);
                                        SpringForce springForce2 = springAnimation.mSpring;
                                        springForce2.mFinalPosition = (double) springAnimation.mPendingPosition;
                                        springAnimation.mPendingPosition = Float.MAX_VALUE;
                                        DynamicAnimation.MassState updateValues2 = springForce2.updateValues((double) updateValues.mValue, (double) updateValues.mVelocity, j4);
                                        springAnimation.mValue = updateValues2.mValue;
                                        springAnimation.mVelocity = updateValues2.mVelocity;
                                        f = Float.MAX_VALUE;
                                    } else {
                                        i = i2;
                                        f = Float.MAX_VALUE;
                                        DynamicAnimation.MassState updateValues3 = springAnimation.mSpring.updateValues((double) springAnimation.mValue, (double) springAnimation.mVelocity, j3);
                                        springAnimation.mValue = updateValues3.mValue;
                                        springAnimation.mVelocity = updateValues3.mVelocity;
                                    }
                                    float max = Math.max(springAnimation.mValue, springAnimation.mMinValue);
                                    springAnimation.mValue = max;
                                    float min = Math.min(max, f);
                                    springAnimation.mValue = min;
                                    float f2 = springAnimation.mVelocity;
                                    SpringForce springForce3 = springAnimation.mSpring;
                                    Objects.requireNonNull(springForce3);
                                    if (((double) Math.abs(f2)) < springForce3.mVelocityThreshold && ((double) Math.abs(min - ((float) springForce3.mFinalPosition))) < springForce3.mValueThreshold) {
                                        springAnimation.mValue = (float) springAnimation.mSpring.mFinalPosition;
                                        springAnimation.mVelocity = 0.0f;
                                        z2 = true;
                                    } else {
                                        z2 = false;
                                    }
                                    float min2 = Math.min(dynamicAnimation.mValue, f);
                                    dynamicAnimation.mValue = min2;
                                    float max2 = Math.max(min2, dynamicAnimation.mMinValue);
                                    dynamicAnimation.mValue = max2;
                                    dynamicAnimation.setPropertyValue(max2);
                                    if (z2) {
                                        dynamicAnimation.endAnimationInternal(false);
                                    }
                                    i2 = i + 1;
                                }
                            }
                        }
                    }
                    z = true;
                    if (z) {
                    }
                }
                i = i2;
                i2 = i + 1;
            }
            if (animationHandler.mListDirty) {
                int size = animationHandler.mAnimationCallbacks.size();
                while (true) {
                    size--;
                    if (size < 0) {
                        break;
                    } else if (animationHandler.mAnimationCallbacks.get(size) == null) {
                        animationHandler.mAnimationCallbacks.remove(size);
                    }
                }
                animationHandler.mListDirty = false;
            }
            if (AnimationHandler.this.mAnimationCallbacks.size() > 0) {
                AnimationHandler animationHandler2 = AnimationHandler.this;
                if (animationHandler2.mProvider == null) {
                    animationHandler2.mProvider = new FrameCallbackProvider16(animationHandler2.mCallbackDispatcher);
                }
                FrameCallbackProvider16 frameCallbackProvider16 = (FrameCallbackProvider16) animationHandler2.mProvider;
                frameCallbackProvider16.mChoreographer.postFrameCallback(frameCallbackProvider16.mChoreographerCallback);
            }
        }
    }

    public interface AnimationFrameCallback {
    }

    public abstract class AnimationFrameCallbackProvider {
        public final AnimationCallbackDispatcher mDispatcher;

        public AnimationFrameCallbackProvider(AnimationCallbackDispatcher animationCallbackDispatcher) {
            this.mDispatcher = animationCallbackDispatcher;
        }
    }

    public class FrameCallbackProvider16 extends AnimationFrameCallbackProvider {
        public final Choreographer mChoreographer = Choreographer.getInstance();
        public final Choreographer.FrameCallback mChoreographerCallback = new Choreographer.FrameCallback() {
            /* class androidx.dynamicanimation.animation.AnimationHandler.FrameCallbackProvider16.AnonymousClass1 */

            public void doFrame(long j) {
                FrameCallbackProvider16.this.mDispatcher.dispatchAnimationFrame();
            }
        };

        public FrameCallbackProvider16(AnimationCallbackDispatcher animationCallbackDispatcher) {
            super(animationCallbackDispatcher);
        }
    }

    public static AnimationHandler getInstance() {
        ThreadLocal<AnimationHandler> threadLocal = sAnimatorHandler;
        if (threadLocal.get() == null) {
            threadLocal.set(new AnimationHandler());
        }
        return threadLocal.get();
    }
}
