package androidx.recyclerview.widget;

import android.graphics.PointF;
import android.util.DisplayMetrics;
import android.view.View;
import android.view.animation.DecelerateInterpolator;
import android.widget.Scroller;
import androidx.recyclerview.widget.RecyclerView;

public class PagerSnapHelper extends RecyclerView.OnFlingListener {
    public OrientationHelper mHorizontalHelper;
    public RecyclerView mRecyclerView;
    public final RecyclerView.OnScrollListener mScrollListener = new SnapHelper$1(this);
    public OrientationHelper mVerticalHelper;

    public void attachToRecyclerView(RecyclerView recyclerView) {
        RecyclerView recyclerView2 = this.mRecyclerView;
        if (recyclerView2 != recyclerView) {
            if (recyclerView2 != null) {
                destroyCallbacks();
            }
            this.mRecyclerView = recyclerView;
            if (recyclerView != null) {
                setupCallbacks();
                new Scroller(this.mRecyclerView.getContext(), new DecelerateInterpolator());
                snapToTargetExistingView();
            }
        }
    }

    public int[] calculateDistanceToFinalSnap(RecyclerView.LayoutManager layoutManager, View view) {
        int[] iArr = new int[2];
        if (layoutManager.canScrollHorizontally()) {
            iArr[0] = distanceToCenter(view, getHorizontalHelper(layoutManager));
        } else {
            iArr[0] = 0;
        }
        if (layoutManager.canScrollVertically()) {
            iArr[1] = distanceToCenter(view, getVerticalHelper(layoutManager));
        } else {
            iArr[1] = 0;
        }
        return iArr;
    }

    public final void destroyCallbacks() {
        this.mRecyclerView.removeOnScrollListener(this.mScrollListener);
        this.mRecyclerView.setOnFlingListener(null);
    }

    public final int distanceToCenter(View view, OrientationHelper orientationHelper) {
        return ((orientationHelper.getDecoratedMeasurement(view) / 2) + orientationHelper.getDecoratedStart(view)) - ((orientationHelper.getTotalSpace() / 2) + orientationHelper.getStartAfterPadding());
    }

    public final View findCenterView(RecyclerView.LayoutManager layoutManager, OrientationHelper orientationHelper) {
        int childCount = layoutManager.getChildCount();
        View view = null;
        if (childCount == 0) {
            return null;
        }
        int totalSpace = (orientationHelper.getTotalSpace() / 2) + orientationHelper.getStartAfterPadding();
        int i = Integer.MAX_VALUE;
        for (int i2 = 0; i2 < childCount; i2++) {
            View childAt = layoutManager.getChildAt(i2);
            int abs = Math.abs(((orientationHelper.getDecoratedMeasurement(childAt) / 2) + orientationHelper.getDecoratedStart(childAt)) - totalSpace);
            if (abs < i) {
                view = childAt;
                i = abs;
            }
        }
        return view;
    }

    public View findSnapView(RecyclerView.LayoutManager layoutManager) {
        if (layoutManager.canScrollVertically()) {
            return findCenterView(layoutManager, getVerticalHelper(layoutManager));
        }
        if (layoutManager.canScrollHorizontally()) {
            return findCenterView(layoutManager, getHorizontalHelper(layoutManager));
        }
        return null;
    }

    public final OrientationHelper getHorizontalHelper(RecyclerView.LayoutManager layoutManager) {
        OrientationHelper orientationHelper = this.mHorizontalHelper;
        if (orientationHelper == null || orientationHelper.mLayoutManager != layoutManager) {
            this.mHorizontalHelper = 
            /*  JADX ERROR: Method code generation error
                jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x000d: IPUT  
                  (wrap: androidx.recyclerview.widget.OrientationHelper$1 : 0x000a: CONSTRUCTOR  (r0v1 androidx.recyclerview.widget.OrientationHelper$1) = (r2v0 'layoutManager' androidx.recyclerview.widget.RecyclerView$LayoutManager) call: androidx.recyclerview.widget.OrientationHelper.1.<init>(androidx.recyclerview.widget.RecyclerView$LayoutManager):void type: CONSTRUCTOR)
                  (r1v0 'this' androidx.recyclerview.widget.PagerSnapHelper A[IMMUTABLE_TYPE, THIS])
                 androidx.recyclerview.widget.PagerSnapHelper.mHorizontalHelper androidx.recyclerview.widget.OrientationHelper in method: androidx.recyclerview.widget.PagerSnapHelper.getHorizontalHelper(androidx.recyclerview.widget.RecyclerView$LayoutManager):androidx.recyclerview.widget.OrientationHelper, file: classes.dex
                	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                	at java.util.ArrayList.forEach(ArrayList.java:1259)
                	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x000a: CONSTRUCTOR  (r0v1 androidx.recyclerview.widget.OrientationHelper$1) = (r2v0 'layoutManager' androidx.recyclerview.widget.RecyclerView$LayoutManager) call: androidx.recyclerview.widget.OrientationHelper.1.<init>(androidx.recyclerview.widget.RecyclerView$LayoutManager):void type: CONSTRUCTOR in method: androidx.recyclerview.widget.PagerSnapHelper.getHorizontalHelper(androidx.recyclerview.widget.RecyclerView$LayoutManager):androidx.recyclerview.widget.OrientationHelper, file: classes.dex
                	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:428)
                	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                	... 19 more
                Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.recyclerview.widget.OrientationHelper, state: GENERATED_AND_UNLOADED
                	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                	... 23 more
                */
            /*
                this = this;
                androidx.recyclerview.widget.OrientationHelper r0 = r1.mHorizontalHelper
                if (r0 == 0) goto L_0x0008
                androidx.recyclerview.widget.RecyclerView$LayoutManager r0 = r0.mLayoutManager
                if (r0 == r2) goto L_0x000f
            L_0x0008:
                androidx.recyclerview.widget.OrientationHelper$1 r0 = new androidx.recyclerview.widget.OrientationHelper$1
                r0.<init>(r2)
                r1.mHorizontalHelper = r0
            L_0x000f:
                androidx.recyclerview.widget.OrientationHelper r2 = r1.mHorizontalHelper
                return r2
            */
            throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.PagerSnapHelper.getHorizontalHelper(androidx.recyclerview.widget.RecyclerView$LayoutManager):androidx.recyclerview.widget.OrientationHelper");
        }

        public final OrientationHelper getVerticalHelper(RecyclerView.LayoutManager layoutManager) {
            OrientationHelper orientationHelper = this.mVerticalHelper;
            if (orientationHelper == null || orientationHelper.mLayoutManager != layoutManager) {
                this.mVerticalHelper = 
                /*  JADX ERROR: Method code generation error
                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x000d: IPUT  
                      (wrap: androidx.recyclerview.widget.OrientationHelper$2 : 0x000a: CONSTRUCTOR  (r0v1 androidx.recyclerview.widget.OrientationHelper$2) = (r2v0 'layoutManager' androidx.recyclerview.widget.RecyclerView$LayoutManager) call: androidx.recyclerview.widget.OrientationHelper.2.<init>(androidx.recyclerview.widget.RecyclerView$LayoutManager):void type: CONSTRUCTOR)
                      (r1v0 'this' androidx.recyclerview.widget.PagerSnapHelper A[IMMUTABLE_TYPE, THIS])
                     androidx.recyclerview.widget.PagerSnapHelper.mVerticalHelper androidx.recyclerview.widget.OrientationHelper in method: androidx.recyclerview.widget.PagerSnapHelper.getVerticalHelper(androidx.recyclerview.widget.RecyclerView$LayoutManager):androidx.recyclerview.widget.OrientationHelper, file: classes.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeIf(RegionGen.java:143)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:63)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:183)
                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:395)
                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                    Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x000a: CONSTRUCTOR  (r0v1 androidx.recyclerview.widget.OrientationHelper$2) = (r2v0 'layoutManager' androidx.recyclerview.widget.RecyclerView$LayoutManager) call: androidx.recyclerview.widget.OrientationHelper.2.<init>(androidx.recyclerview.widget.RecyclerView$LayoutManager):void type: CONSTRUCTOR in method: androidx.recyclerview.widget.PagerSnapHelper.getVerticalHelper(androidx.recyclerview.widget.RecyclerView$LayoutManager):androidx.recyclerview.widget.OrientationHelper, file: classes.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                    	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:428)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                    	... 19 more
                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: androidx.recyclerview.widget.OrientationHelper, state: GENERATED_AND_UNLOADED
                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                    	... 23 more
                    */
                /*
                    this = this;
                    androidx.recyclerview.widget.OrientationHelper r0 = r1.mVerticalHelper
                    if (r0 == 0) goto L_0x0008
                    androidx.recyclerview.widget.RecyclerView$LayoutManager r0 = r0.mLayoutManager
                    if (r0 == r2) goto L_0x000f
                L_0x0008:
                    androidx.recyclerview.widget.OrientationHelper$2 r0 = new androidx.recyclerview.widget.OrientationHelper$2
                    r0.<init>(r2)
                    r1.mVerticalHelper = r0
                L_0x000f:
                    androidx.recyclerview.widget.OrientationHelper r2 = r1.mVerticalHelper
                    return r2
                */
                throw new UnsupportedOperationException("Method not decompiled: androidx.recyclerview.widget.PagerSnapHelper.getVerticalHelper(androidx.recyclerview.widget.RecyclerView$LayoutManager):androidx.recyclerview.widget.OrientationHelper");
            }

            public final void setupCallbacks() {
                if (this.mRecyclerView.getOnFlingListener() == null) {
                    this.mRecyclerView.addOnScrollListener(this.mScrollListener);
                    this.mRecyclerView.setOnFlingListener(this);
                    return;
                }
                throw new IllegalStateException("An instance of OnFlingListener already set.");
            }

            /* JADX WARNING: Code restructure failed: missing block: B:59:0x00c1, code lost:
                if (r2 < r7) goto L_0x00c4;
             */
            /* JADX WARNING: Removed duplicated region for block: B:63:0x00c8  */
            public final boolean snapFromFling(RecyclerView.LayoutManager layoutManager, int i, int i2) {
                int i3;
                OrientationHelper orientationHelper;
                PointF computeScrollVectorForPosition;
                boolean z = layoutManager instanceof RecyclerView.SmoothScroller.ScrollVectorProvider;
                if (z) {
                    View view = null;
                    AnonymousClass1 r6 = !z ? null : new LinearSmoothScroller(this.mRecyclerView.getContext()) {
                        /* class androidx.recyclerview.widget.PagerSnapHelper.AnonymousClass1 */

                        @Override // androidx.recyclerview.widget.LinearSmoothScroller
                        public float calculateSpeedPerPixel(DisplayMetrics displayMetrics) {
                            return 100.0f / ((float) displayMetrics.densityDpi);
                        }

                        @Override // androidx.recyclerview.widget.LinearSmoothScroller
                        public int calculateTimeForScrolling(int i) {
                            return Math.min(100, super.calculateTimeForScrolling(i));
                        }

                        @Override // androidx.recyclerview.widget.LinearSmoothScroller, androidx.recyclerview.widget.RecyclerView.SmoothScroller
                        public void onTargetFound(View view, RecyclerView.State state, RecyclerView.SmoothScroller.Action action) {
                            PagerSnapHelper pagerSnapHelper = PagerSnapHelper.this;
                            int[] calculateDistanceToFinalSnap = pagerSnapHelper.calculateDistanceToFinalSnap(pagerSnapHelper.mRecyclerView.getLayoutManager(), view);
                            int i = calculateDistanceToFinalSnap[0];
                            int i2 = calculateDistanceToFinalSnap[1];
                            int ceil = (int) Math.ceil(((double) calculateTimeForScrolling(Math.max(Math.abs(i), Math.abs(i2)))) / 0.3356d);
                            if (ceil > 0) {
                                action.update(i, i2, ceil, this.mDecelerateInterpolator);
                            }
                        }
                    };
                    if (r6 != null) {
                        int itemCount = layoutManager.getItemCount();
                        if (itemCount != 0) {
                            if (layoutManager.canScrollVertically()) {
                                orientationHelper = getVerticalHelper(layoutManager);
                            } else {
                                orientationHelper = layoutManager.canScrollHorizontally() ? getHorizontalHelper(layoutManager) : null;
                            }
                            if (orientationHelper != null) {
                                int childCount = layoutManager.getChildCount();
                                View view2 = null;
                                int i4 = LinearLayoutManager.INVALID_OFFSET;
                                int i5 = Integer.MAX_VALUE;
                                for (int i6 = 0; i6 < childCount; i6++) {
                                    View childAt = layoutManager.getChildAt(i6);
                                    if (childAt != null) {
                                        int distanceToCenter = distanceToCenter(childAt, orientationHelper);
                                        if (distanceToCenter <= 0 && distanceToCenter > i4) {
                                            i4 = distanceToCenter;
                                            view2 = childAt;
                                        }
                                        if (distanceToCenter >= 0 && distanceToCenter < i5) {
                                            i5 = distanceToCenter;
                                            view = childAt;
                                        }
                                    }
                                }
                                boolean z2 = !layoutManager.canScrollHorizontally() ? i2 > 0 : i > 0;
                                if (z2 && view != null) {
                                    i3 = layoutManager.getPosition(view);
                                    if (i3 != -1) {
                                    }
                                } else if (z2 || view2 == null) {
                                    if (z2) {
                                        view = view2;
                                    }
                                    if (view != null) {
                                        i3 = ((z && (computeScrollVectorForPosition = ((RecyclerView.SmoothScroller.ScrollVectorProvider) layoutManager).computeScrollVectorForPosition(layoutManager.getItemCount() - 1)) != null && ((computeScrollVectorForPosition.x > 0.0f ? 1 : (computeScrollVectorForPosition.x == 0.0f ? 0 : -1)) < 0 || (computeScrollVectorForPosition.y > 0.0f ? 1 : (computeScrollVectorForPosition.y == 0.0f ? 0 : -1)) < 0)) == z2 ? -1 : 1) + layoutManager.getPosition(view);
                                        if (i3 >= 0) {
                                        }
                                    }
                                } else {
                                    i3 = layoutManager.getPosition(view2);
                                    if (i3 != -1) {
                                        r6.mTargetPosition = i3;
                                        layoutManager.startSmoothScroll(r6);
                                        return true;
                                    }
                                }
                            }
                        }
                        i3 = -1;
                        if (i3 != -1) {
                        }
                    }
                }
                return false;
            }

            public void snapToTargetExistingView() {
                RecyclerView.LayoutManager layoutManager;
                View findSnapView;
                RecyclerView recyclerView = this.mRecyclerView;
                if (recyclerView != null && (layoutManager = recyclerView.getLayoutManager()) != null && (findSnapView = findSnapView(layoutManager)) != null) {
                    int[] calculateDistanceToFinalSnap = calculateDistanceToFinalSnap(layoutManager, findSnapView);
                    if (calculateDistanceToFinalSnap[0] != 0 || calculateDistanceToFinalSnap[1] != 0) {
                        this.mRecyclerView.smoothScrollBy(calculateDistanceToFinalSnap[0], calculateDistanceToFinalSnap[1], null, LinearLayoutManager.INVALID_OFFSET, false);
                    }
                }
            }
        }
