package androidx.room;

import android.annotation.SuppressLint;
import android.database.Cursor;
import android.database.sqlite.SQLiteException;
import android.os.RemoteException;
import android.util.Log;
import androidx.arch.core.internal.SafeIterableMap;
import androidx.room.MultiInstanceInvalidationClient;
import androidx.sqlite.db.SimpleSQLiteQuery;
import androidx.sqlite.db.SupportSQLiteDatabase;
import androidx.sqlite.db.SupportSQLiteStatement;
import com.allpayx.sdk.util.HttpUtil;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.locks.Lock;

public class InvalidationTracker {
    public static final String[] TRIGGERS = {"UPDATE", HttpUtil.METHOD_DELETE, "INSERT"};
    public AutoCloser mAutoCloser;
    public volatile SupportSQLiteStatement mCleanupStatement;
    public final RoomDatabase mDatabase;
    public volatile boolean mInitialized = false;
    public MultiInstanceInvalidationClient mMultiInstanceInvalidationClient;
    public ObservedTableTracker mObservedTableTracker;
    @SuppressLint({"RestrictedApi"})
    public final SafeIterableMap<MultiInstanceInvalidationClient.AnonymousClass5, ObserverWrapper> mObserverMap = new SafeIterableMap<>();
    public AtomicBoolean mPendingRefresh = new AtomicBoolean(false);
    public Runnable mRefreshRunnable = new Runnable() {
        /* class androidx.room.InvalidationTracker.AnonymousClass1 */

        /* JADX INFO: finally extract failed */
        public final Set<Integer> checkUpdatedTable() {
            HashSet hashSet = new HashSet();
            Cursor query = InvalidationTracker.this.mDatabase.query(new SimpleSQLiteQuery("SELECT * FROM room_table_modification_log WHERE invalidated = 1;"));
            while (query.moveToNext()) {
                try {
                    hashSet.add(Integer.valueOf(query.getInt(0)));
                } catch (Throwable th) {
                    query.close();
                    throw th;
                }
            }
            query.close();
            if (!hashSet.isEmpty()) {
                InvalidationTracker.this.mCleanupStatement.executeUpdateDelete();
            }
            return hashSet;
        }

        /* JADX DEBUG: Multi-variable search result rejected for r5v3, resolved type: boolean */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARNING: Removed duplicated region for block: B:52:0x009d  */
        /* JADX WARNING: Removed duplicated region for block: B:77:0x00fe  */
        /* JADX WARNING: Removed duplicated region for block: B:90:? A[ADDED_TO_REGION, ORIG_RETURN, RETURN, SYNTHETIC] */
        public void run() {
            Set<Integer> set;
            Set<Integer> set2;
            Throwable e;
            Set<Integer> set3;
            Throwable th;
            Lock closeLock = InvalidationTracker.this.mDatabase.getCloseLock();
            closeLock.lock();
            try {
                if (!InvalidationTracker.this.ensureInitialization()) {
                    closeLock.unlock();
                    if (InvalidationTracker.this.mAutoCloser != null) {
                        throw null;
                    }
                } else if (!InvalidationTracker.this.mPendingRefresh.compareAndSet(true, false)) {
                    closeLock.unlock();
                    if (InvalidationTracker.this.mAutoCloser != null) {
                        throw null;
                    }
                } else if (InvalidationTracker.this.mDatabase.inTransaction()) {
                    closeLock.unlock();
                    if (InvalidationTracker.this.mAutoCloser != null) {
                        throw null;
                    }
                } else {
                    RoomDatabase roomDatabase = InvalidationTracker.this.mDatabase;
                    boolean z = roomDatabase.mWriteAheadLoggingEnabled;
                    if (z != 0) {
                        SupportSQLiteDatabase writableDatabase = roomDatabase.getOpenHelper().getWritableDatabase();
                        writableDatabase.beginTransactionNonExclusive();
                        try {
                            set3 = checkUpdatedTable();
                            try {
                                writableDatabase.setTransactionSuccessful();
                                try {
                                    writableDatabase.endTransaction();
                                } catch (IllegalStateException e2) {
                                    e = e2;
                                    set2 = z;
                                    try {
                                        Log.e("ROOM", "Cannot run invalidation tracker. Is the db closed?", e);
                                        closeLock.unlock();
                                        set = set2;
                                        if (InvalidationTracker.this.mAutoCloser != null) {
                                        }
                                        if (set == null) {
                                        }
                                    } catch (Throwable th2) {
                                        closeLock.unlock();
                                        if (InvalidationTracker.this.mAutoCloser != null) {
                                            throw null;
                                        }
                                        throw th2;
                                    }
                                } catch (SQLiteException e3) {
                                    e = e3;
                                    set2 = z;
                                    Log.e("ROOM", "Cannot run invalidation tracker. Is the db closed?", e);
                                    closeLock.unlock();
                                    set = set2;
                                    if (InvalidationTracker.this.mAutoCloser != null) {
                                    }
                                    if (set == null) {
                                    }
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                writableDatabase.endTransaction();
                                throw th;
                            }
                        } catch (Throwable th4) {
                            th = th4;
                            writableDatabase.endTransaction();
                            throw th;
                        }
                    } else {
                        set3 = checkUpdatedTable();
                    }
                    closeLock.unlock();
                    set = set3;
                    if (InvalidationTracker.this.mAutoCloser != null) {
                        throw null;
                    }
                    if (!(set == null || set.isEmpty())) {
                        synchronized (InvalidationTracker.this.mObserverMap) {
                            Iterator<Map.Entry<MultiInstanceInvalidationClient.AnonymousClass5, ObserverWrapper>> it = InvalidationTracker.this.mObserverMap.iterator();
                            while (true) {
                                SafeIterableMap.ListIterator listIterator = (SafeIterableMap.ListIterator) it;
                                if (listIterator.hasNext()) {
                                    ObserverWrapper observerWrapper = (ObserverWrapper) ((Map.Entry) listIterator.next()).getValue();
                                    int length = observerWrapper.mTableIds.length;
                                    Set<String> set4 = null;
                                    for (int i = 0; i < length; i++) {
                                        if (set.contains(Integer.valueOf(observerWrapper.mTableIds[i]))) {
                                            if (length == 1) {
                                                set4 = observerWrapper.mSingleTableSet;
                                            } else {
                                                if (set4 == null) {
                                                    set4 = new HashSet<>(length);
                                                }
                                                set4.add(observerWrapper.mTableNames[i]);
                                            }
                                        }
                                    }
                                    if (set4 != null) {
                                        observerWrapper.mObserver.onInvalidated(set4);
                                    }
                                }
                            }
                        }
                    }
                }
            } catch (SQLiteException | IllegalStateException e4) {
                e = e4;
                set2 = null;
                Log.e("ROOM", "Cannot run invalidation tracker. Is the db closed?", e);
                closeLock.unlock();
                set = set2;
                if (InvalidationTracker.this.mAutoCloser != null) {
                    throw null;
                }
                if (set == null) {
                }
            }
        }
    };
    public final HashMap<String, Integer> mTableIdLookup;
    public final String[] mTableNames;
    public Map<String, Set<String>> mViewTables;

    public class ObservedTableTracker {
        public boolean mNeedsSync;
        public boolean mPendingSync;
        public final long[] mTableObservers;
        public final int[] mTriggerStateChanges;
        public final boolean[] mTriggerStates;

        public ObservedTableTracker(int i) {
            long[] jArr = new long[i];
            this.mTableObservers = jArr;
            boolean[] zArr = new boolean[i];
            this.mTriggerStates = zArr;
            this.mTriggerStateChanges = new int[i];
            Arrays.fill(jArr, 0L);
            Arrays.fill(zArr, false);
        }

        public int[] getTablesToSync() {
            synchronized (this) {
                if (this.mNeedsSync) {
                    if (!this.mPendingSync) {
                        int length = this.mTableObservers.length;
                        int i = 0;
                        while (true) {
                            int i2 = 1;
                            if (i < length) {
                                boolean z = this.mTableObservers[i] > 0;
                                boolean[] zArr = this.mTriggerStates;
                                if (z != zArr[i]) {
                                    int[] iArr = this.mTriggerStateChanges;
                                    if (!z) {
                                        i2 = 2;
                                    }
                                    iArr[i] = i2;
                                } else {
                                    this.mTriggerStateChanges[i] = 0;
                                }
                                zArr[i] = z;
                                i++;
                            } else {
                                this.mPendingSync = true;
                                this.mNeedsSync = false;
                                return this.mTriggerStateChanges;
                            }
                        }
                    }
                }
                return null;
            }
        }
    }

    public class ObserverWrapper {
        public final MultiInstanceInvalidationClient.AnonymousClass5 mObserver;
        public final Set<String> mSingleTableSet;
        public final int[] mTableIds;
        public final String[] mTableNames;

        public ObserverWrapper(MultiInstanceInvalidationClient.AnonymousClass5 r1, int[] iArr, String[] strArr) {
            this.mObserver = r1;
            this.mTableIds = iArr;
            this.mTableNames = strArr;
            if (iArr.length == 1) {
                HashSet hashSet = new HashSet();
                hashSet.add(strArr[0]);
                this.mSingleTableSet = Collections.unmodifiableSet(hashSet);
                return;
            }
            this.mSingleTableSet = null;
        }
    }

    public InvalidationTracker(RoomDatabase roomDatabase, Map<String, String> map, Map<String, Set<String>> map2, String... strArr) {
        this.mDatabase = roomDatabase;
        this.mObservedTableTracker = new ObservedTableTracker(strArr.length);
        this.mTableIdLookup = new HashMap<>();
        this.mViewTables = map2;
        Collections.newSetFromMap(new IdentityHashMap());
        int length = strArr.length;
        this.mTableNames = new String[length];
        for (int i = 0; i < length; i++) {
            String str = strArr[i];
            Locale locale = Locale.US;
            String lowerCase = str.toLowerCase(locale);
            this.mTableIdLookup.put(lowerCase, Integer.valueOf(i));
            String str2 = map.get(strArr[i]);
            if (str2 != null) {
                this.mTableNames[i] = str2.toLowerCase(locale);
            } else {
                this.mTableNames[i] = lowerCase;
            }
        }
        for (Map.Entry<String, String> entry : map.entrySet()) {
            Locale locale2 = Locale.US;
            String lowerCase2 = entry.getValue().toLowerCase(locale2);
            if (this.mTableIdLookup.containsKey(lowerCase2)) {
                String lowerCase3 = entry.getKey().toLowerCase(locale2);
                HashMap<String, Integer> hashMap = this.mTableIdLookup;
                hashMap.put(lowerCase3, hashMap.get(lowerCase2));
            }
        }
    }

    @SuppressLint({"RestrictedApi"})
    public void addObserver(MultiInstanceInvalidationClient.AnonymousClass5 r11) {
        ObserverWrapper putIfAbsent;
        boolean z;
        String[] strArr = r11.mTables;
        HashSet hashSet = new HashSet();
        for (String str : strArr) {
            String lowerCase = str.toLowerCase(Locale.US);
            if (this.mViewTables.containsKey(lowerCase)) {
                hashSet.addAll(this.mViewTables.get(lowerCase));
            } else {
                hashSet.add(str);
            }
        }
        String[] strArr2 = (String[]) hashSet.toArray(new String[hashSet.size()]);
        int length = strArr2.length;
        int[] iArr = new int[length];
        int length2 = strArr2.length;
        for (int i = 0; i < length2; i++) {
            Integer num = this.mTableIdLookup.get(strArr2[i].toLowerCase(Locale.US));
            if (num != null) {
                iArr[i] = num.intValue();
            } else {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("There is no table with name ");
                outline25.append(strArr2[i]);
                throw new IllegalArgumentException(outline25.toString());
            }
        }
        ObserverWrapper observerWrapper = new ObserverWrapper(r11, iArr, strArr2);
        synchronized (this.mObserverMap) {
            putIfAbsent = this.mObserverMap.putIfAbsent(r11, observerWrapper);
        }
        if (putIfAbsent == null) {
            ObservedTableTracker observedTableTracker = this.mObservedTableTracker;
            synchronized (observedTableTracker) {
                z = false;
                for (int i2 = 0; i2 < length; i2++) {
                    int i3 = iArr[i2];
                    long[] jArr = observedTableTracker.mTableObservers;
                    long j = jArr[i3];
                    jArr[i3] = 1 + j;
                    if (j == 0) {
                        observedTableTracker.mNeedsSync = true;
                        z = true;
                    }
                }
            }
            if (z) {
                syncTriggers();
            }
        }
    }

    public boolean ensureInitialization() {
        if (!this.mDatabase.isOpen()) {
            return false;
        }
        if (!this.mInitialized) {
            this.mDatabase.getOpenHelper().getWritableDatabase();
        }
        if (this.mInitialized) {
            return true;
        }
        Log.e("ROOM", "database is not initialized even though it is open");
        return false;
    }

    @SuppressLint({"RestrictedApi"})
    public void removeObserver(MultiInstanceInvalidationClient.AnonymousClass5 r13) {
        ObserverWrapper remove;
        boolean z;
        synchronized (this.mObserverMap) {
            remove = this.mObserverMap.remove(r13);
        }
        if (remove != null) {
            ObservedTableTracker observedTableTracker = this.mObservedTableTracker;
            int[] iArr = remove.mTableIds;
            synchronized (observedTableTracker) {
                z = false;
                for (int i : iArr) {
                    long[] jArr = observedTableTracker.mTableObservers;
                    long j = jArr[i];
                    jArr[i] = j - 1;
                    if (j == 1) {
                        observedTableTracker.mNeedsSync = true;
                        z = true;
                    }
                }
            }
            if (z) {
                syncTriggers();
            }
        }
    }

    public final void startTrackingTable(SupportSQLiteDatabase supportSQLiteDatabase, int i) {
        supportSQLiteDatabase.execSQL("INSERT OR IGNORE INTO room_table_modification_log VALUES(" + i + ", 0)");
        String str = this.mTableNames[i];
        StringBuilder sb = new StringBuilder();
        String[] strArr = TRIGGERS;
        for (String str2 : strArr) {
            sb.setLength(0);
            sb.append("CREATE TEMP TRIGGER IF NOT EXISTS ");
            sb.append("`");
            sb.append("room_table_modification_trigger_");
            GeneratedOutlineSupport.outline33(sb, str, "_", str2, "`");
            GeneratedOutlineSupport.outline33(sb, " AFTER ", str2, " ON `", str);
            GeneratedOutlineSupport.outline33(sb, "` BEGIN UPDATE ", "room_table_modification_log", " SET ", "invalidated");
            GeneratedOutlineSupport.outline33(sb, " = 1", " WHERE ", "table_id", " = ");
            sb.append(i);
            sb.append(" AND ");
            sb.append("invalidated");
            sb.append(" = 0");
            sb.append("; END");
            supportSQLiteDatabase.execSQL(sb.toString());
        }
    }

    public void stopMultiInstanceInvalidation() {
        MultiInstanceInvalidationClient multiInstanceInvalidationClient = this.mMultiInstanceInvalidationClient;
        if (multiInstanceInvalidationClient != null) {
            if (multiInstanceInvalidationClient.mStopped.compareAndSet(false, true)) {
                multiInstanceInvalidationClient.mInvalidationTracker.removeObserver(multiInstanceInvalidationClient.mObserver);
                try {
                    IMultiInstanceInvalidationService iMultiInstanceInvalidationService = multiInstanceInvalidationClient.mService;
                    if (iMultiInstanceInvalidationService != null) {
                        iMultiInstanceInvalidationService.unregisterCallback(multiInstanceInvalidationClient.mCallback, multiInstanceInvalidationClient.mClientId);
                    }
                } catch (RemoteException e) {
                    Log.w("ROOM", "Cannot unregister multi-instance invalidation callback", e);
                }
                multiInstanceInvalidationClient.mAppContext.unbindService(multiInstanceInvalidationClient.mServiceConnection);
            }
            this.mMultiInstanceInvalidationClient = null;
        }
    }

    public final void stopTrackingTable(SupportSQLiteDatabase supportSQLiteDatabase, int i) {
        String str = this.mTableNames[i];
        StringBuilder sb = new StringBuilder();
        String[] strArr = TRIGGERS;
        for (String str2 : strArr) {
            sb.setLength(0);
            sb.append("DROP TRIGGER IF EXISTS ");
            sb.append("`");
            sb.append("room_table_modification_trigger_");
            sb.append(str);
            sb.append("_");
            sb.append(str2);
            sb.append("`");
            supportSQLiteDatabase.execSQL(sb.toString());
        }
    }

    public void syncTriggers(SupportSQLiteDatabase supportSQLiteDatabase) {
        if (!supportSQLiteDatabase.inTransaction()) {
            while (true) {
                try {
                    Lock closeLock = this.mDatabase.getCloseLock();
                    closeLock.lock();
                    try {
                        int[] tablesToSync = this.mObservedTableTracker.getTablesToSync();
                        if (tablesToSync == null) {
                            closeLock.unlock();
                            return;
                        }
                        int length = tablesToSync.length;
                        if (supportSQLiteDatabase.isWriteAheadLoggingEnabled()) {
                            supportSQLiteDatabase.beginTransactionNonExclusive();
                        } else {
                            supportSQLiteDatabase.beginTransaction();
                        }
                        for (int i = 0; i < length; i++) {
                            try {
                                int i2 = tablesToSync[i];
                                if (i2 == 1) {
                                    startTrackingTable(supportSQLiteDatabase, i);
                                } else if (i2 == 2) {
                                    stopTrackingTable(supportSQLiteDatabase, i);
                                }
                            } catch (Throwable th) {
                                supportSQLiteDatabase.endTransaction();
                                throw th;
                            }
                        }
                        supportSQLiteDatabase.setTransactionSuccessful();
                        supportSQLiteDatabase.endTransaction();
                        ObservedTableTracker observedTableTracker = this.mObservedTableTracker;
                        synchronized (observedTableTracker) {
                            observedTableTracker.mPendingSync = false;
                        }
                    } finally {
                        closeLock.unlock();
                    }
                } catch (SQLiteException | IllegalStateException e) {
                    Log.e("ROOM", "Cannot run invalidation tracker. Is the db closed?", e);
                    return;
                }
            }
        }
    }

    public void syncTriggers() {
        if (this.mDatabase.isOpen()) {
            syncTriggers(this.mDatabase.getOpenHelper().getWritableDatabase());
        }
    }
}
