package androidx.room;

import android.database.Cursor;
import androidx.room.RoomDatabase;
import androidx.room.migration.Migration;
import androidx.sqlite.db.SimpleSQLiteQuery;
import androidx.sqlite.db.SupportSQLiteDatabase;
import androidx.sqlite.db.SupportSQLiteOpenHelper;
import androidx.sqlite.db.framework.FrameworkSQLiteDatabase;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.TreeMap;

public class RoomOpenHelper extends SupportSQLiteOpenHelper.Callback {
    public DatabaseConfiguration mConfiguration;
    public final Delegate mDelegate;
    public final String mIdentityHash;
    public final String mLegacyHash;

    public static abstract class Delegate {
        public final int version;

        public Delegate(int i) {
            this.version = i;
        }

        public abstract void createAllTables(SupportSQLiteDatabase supportSQLiteDatabase);

        public abstract void dropAllTables(SupportSQLiteDatabase supportSQLiteDatabase);

        public abstract void onCreate(SupportSQLiteDatabase supportSQLiteDatabase);

        public abstract void onOpen(SupportSQLiteDatabase supportSQLiteDatabase);

        public abstract void onPostMigrate(SupportSQLiteDatabase supportSQLiteDatabase);

        public abstract void onPreMigrate(SupportSQLiteDatabase supportSQLiteDatabase);

        public abstract ValidationResult onValidateSchema(SupportSQLiteDatabase supportSQLiteDatabase);

        @Deprecated
        public void validateMigration(SupportSQLiteDatabase supportSQLiteDatabase) {
            throw new UnsupportedOperationException("validateMigration is deprecated");
        }
    }

    public static class ValidationResult {
        public final String expectedFoundMsg;
        public final boolean isValid;

        public ValidationResult(boolean z, String str) {
            this.isValid = z;
            this.expectedFoundMsg = str;
        }
    }

    public RoomOpenHelper(DatabaseConfiguration databaseConfiguration, Delegate delegate, String str, String str2) {
        super(delegate.version);
        this.mConfiguration = databaseConfiguration;
        this.mDelegate = delegate;
        this.mIdentityHash = str;
        this.mLegacyHash = str2;
    }

    @Override // androidx.sqlite.db.SupportSQLiteOpenHelper.Callback
    public void onConfigure(SupportSQLiteDatabase supportSQLiteDatabase) {
    }

    /* JADX INFO: finally extract failed */
    @Override // androidx.sqlite.db.SupportSQLiteOpenHelper.Callback
    public void onCreate(SupportSQLiteDatabase supportSQLiteDatabase) {
        Cursor query = ((FrameworkSQLiteDatabase) supportSQLiteDatabase).query(new SimpleSQLiteQuery("SELECT count(*) FROM sqlite_master WHERE name != 'android_metadata'"));
        try {
            boolean z = false;
            if (query.moveToFirst() && query.getInt(0) == 0) {
                z = true;
            }
            query.close();
            this.mDelegate.createAllTables(supportSQLiteDatabase);
            if (!z) {
                ValidationResult onValidateSchema = this.mDelegate.onValidateSchema(supportSQLiteDatabase);
                if (!onValidateSchema.isValid) {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Pre-packaged database has an invalid schema: ");
                    outline25.append(onValidateSchema.expectedFoundMsg);
                    throw new IllegalStateException(outline25.toString());
                }
            }
            updateIdentity(supportSQLiteDatabase);
            this.mDelegate.onCreate(supportSQLiteDatabase);
        } catch (Throwable th) {
            query.close();
            throw th;
        }
    }

    @Override // androidx.sqlite.db.SupportSQLiteOpenHelper.Callback
    public void onDowngrade(SupportSQLiteDatabase supportSQLiteDatabase, int i, int i2) {
        onUpgrade(supportSQLiteDatabase, i, i2);
    }

    /* JADX INFO: finally extract failed */
    @Override // androidx.sqlite.db.SupportSQLiteOpenHelper.Callback
    public void onOpen(SupportSQLiteDatabase supportSQLiteDatabase) {
        Cursor query = ((FrameworkSQLiteDatabase) supportSQLiteDatabase).query(new SimpleSQLiteQuery("SELECT 1 FROM sqlite_master WHERE type = 'table' AND name='room_master_table'"));
        try {
            boolean z = query.moveToFirst() && query.getInt(0) != 0;
            query.close();
            if (z) {
                Cursor query2 = ((FrameworkSQLiteDatabase) supportSQLiteDatabase).query(new SimpleSQLiteQuery("SELECT identity_hash FROM room_master_table WHERE id = 42 LIMIT 1"));
                try {
                    String string = query2.moveToFirst() ? query2.getString(0) : null;
                    query2.close();
                    if (!this.mIdentityHash.equals(string) && !this.mLegacyHash.equals(string)) {
                        throw new IllegalStateException("Room cannot verify the data integrity. Looks like you've changed schema but forgot to update the version number. You can simply fix this by increasing the version number.");
                    }
                } catch (Throwable th) {
                    query2.close();
                    throw th;
                }
            } else {
                ValidationResult onValidateSchema = this.mDelegate.onValidateSchema(supportSQLiteDatabase);
                if (onValidateSchema.isValid) {
                    this.mDelegate.onPostMigrate(supportSQLiteDatabase);
                    updateIdentity(supportSQLiteDatabase);
                } else {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Pre-packaged database has an invalid schema: ");
                    outline25.append(onValidateSchema.expectedFoundMsg);
                    throw new IllegalStateException(outline25.toString());
                }
            }
            this.mDelegate.onOpen(supportSQLiteDatabase);
            this.mConfiguration = null;
        } catch (Throwable th2) {
            query.close();
            throw th2;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:34:0x007b, code lost:
        r0 = r3;
     */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00c2  */
    /* JADX WARNING: Removed duplicated region for block: B:63:? A[ORIG_RETURN, RETURN, SYNTHETIC] */
    @Override // androidx.sqlite.db.SupportSQLiteOpenHelper.Callback
    public void onUpgrade(SupportSQLiteDatabase supportSQLiteDatabase, int i, int i2) {
        List<Migration> list;
        Set<Integer> set;
        int i3;
        boolean z;
        boolean z2;
        DatabaseConfiguration databaseConfiguration = this.mConfiguration;
        boolean z3 = true;
        if (databaseConfiguration != null) {
            RoomDatabase.MigrationContainer migrationContainer = databaseConfiguration.migrationContainer;
            Objects.requireNonNull(migrationContainer);
            if (i == i2) {
                list = Collections.emptyList();
            } else {
                boolean z4 = i2 > i;
                ArrayList arrayList = new ArrayList();
                int i4 = i;
                while (true) {
                    if (z4) {
                        if (i4 >= i2) {
                            break;
                        }
                    } else if (i4 <= i2) {
                        break;
                    }
                    TreeMap<Integer, Migration> treeMap = migrationContainer.mMigrations.get(Integer.valueOf(i4));
                    if (treeMap == null) {
                        break;
                    }
                    if (z4) {
                        set = treeMap.descendingKeySet();
                    } else {
                        set = treeMap.keySet();
                    }
                    Iterator<Integer> it = set.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            i3 = i4;
                            z = false;
                            break;
                        }
                        i3 = it.next().intValue();
                        if (!z4 ? i3 < i2 || i3 >= i4 : i3 > i2 || i3 <= i4) {
                            z2 = false;
                            continue;
                        } else {
                            z2 = true;
                            continue;
                        }
                        if (z2) {
                            arrayList.add(treeMap.get(Integer.valueOf(i3)));
                            z = true;
                            break;
                        }
                    }
                    if (!z) {
                        break;
                    }
                    i4 = i3;
                }
                list = null;
            }
            if (list != null) {
                this.mDelegate.onPreMigrate(supportSQLiteDatabase);
                for (Migration migration : list) {
                    migration.migrate(supportSQLiteDatabase);
                }
                ValidationResult onValidateSchema = this.mDelegate.onValidateSchema(supportSQLiteDatabase);
                if (onValidateSchema.isValid) {
                    this.mDelegate.onPostMigrate(supportSQLiteDatabase);
                    updateIdentity(supportSQLiteDatabase);
                    if (z3) {
                        DatabaseConfiguration databaseConfiguration2 = this.mConfiguration;
                        if (databaseConfiguration2 == null || databaseConfiguration2.isMigrationRequired(i, i2)) {
                            throw new IllegalStateException("A migration from " + i + " to " + i2 + " was required but not found. Please provide the necessary Migration path via RoomDatabase.Builder.addMigration(Migration ...) or allow for destructive migrations via one of the RoomDatabase.Builder.fallbackToDestructiveMigration* methods.");
                        }
                        this.mDelegate.dropAllTables(supportSQLiteDatabase);
                        this.mDelegate.createAllTables(supportSQLiteDatabase);
                        return;
                    }
                    return;
                }
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("Migration didn't properly handle: ");
                outline25.append(onValidateSchema.expectedFoundMsg);
                throw new IllegalStateException(outline25.toString());
            }
        }
        z3 = false;
        if (z3) {
        }
    }

    public final void updateIdentity(SupportSQLiteDatabase supportSQLiteDatabase) {
        supportSQLiteDatabase.execSQL("CREATE TABLE IF NOT EXISTS room_master_table (id INTEGER PRIMARY KEY,identity_hash TEXT)");
        String str = this.mIdentityHash;
        supportSQLiteDatabase.execSQL("INSERT OR REPLACE INTO room_master_table (id,identity_hash) VALUES(42, '" + str + "')");
    }
}
