package androidx.work.impl.background.systemalarm;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import androidx.work.Constraints;
import androidx.work.Logger$LogcatLogger;
import androidx.work.NetworkType;
import androidx.work.impl.ExecutionListener;
import androidx.work.impl.WorkDatabase;
import androidx.work.impl.WorkManagerImpl;
import androidx.work.impl.background.systemalarm.SystemAlarmDispatcher;
import androidx.work.impl.model.SystemIdInfo;
import androidx.work.impl.model.SystemIdInfoDao_Impl;
import androidx.work.impl.model.WorkSpec;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class CommandHandler implements ExecutionListener {
    public static final String TAG = Logger$LogcatLogger.tagWithPrefix("CommandHandler");
    public final Context mContext;
    public final Object mLock = new Object();
    public final Map<String, ExecutionListener> mPendingDelayMet = new HashMap();

    public CommandHandler(Context context) {
        this.mContext = context;
    }

    public static Intent createConstraintsChangedIntent(Context context) {
        Intent intent = new Intent(context, SystemAlarmService.class);
        intent.setAction("ACTION_CONSTRAINTS_CHANGED");
        return intent;
    }

    public static Intent createDelayMetIntent(Context context, String str) {
        Intent intent = new Intent(context, SystemAlarmService.class);
        intent.setAction("ACTION_DELAY_MET");
        intent.putExtra("KEY_WORKSPEC_ID", str);
        return intent;
    }

    public static Intent createScheduleWorkIntent(Context context, String str) {
        Intent intent = new Intent(context, SystemAlarmService.class);
        intent.setAction("ACTION_SCHEDULE_WORK");
        intent.putExtra("KEY_WORKSPEC_ID", str);
        return intent;
    }

    @Override // androidx.work.impl.ExecutionListener
    public void onExecuted(String str, boolean z) {
        synchronized (this.mLock) {
            ExecutionListener remove = this.mPendingDelayMet.remove(str);
            if (remove != null) {
                remove.onExecuted(str, z);
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:44:0x016c  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x0187  */
    public void onHandleIntent(Intent intent, int i, SystemAlarmDispatcher systemAlarmDispatcher) {
        boolean z;
        String action = intent.getAction();
        if ("ACTION_CONSTRAINTS_CHANGED".equals(action)) {
            Logger$LogcatLogger.get().debug(TAG, String.format("Handling constraints changed %s", intent), new Throwable[0]);
            Context context = this.mContext;
            ConstraintsCommandHandler constraintsCommandHandler = new ConstraintsCommandHandler(context, i, systemAlarmDispatcher);
            List<WorkSpec> scheduledWork = systemAlarmDispatcher.mWorkManager.mWorkDatabase.workSpecDao().getScheduledWork();
            String str = ConstraintProxy.TAG;
            ArrayList arrayList = (ArrayList) scheduledWork;
            Iterator it = arrayList.iterator();
            boolean z2 = false;
            boolean z3 = false;
            boolean z4 = false;
            boolean z5 = false;
            while (it.hasNext()) {
                Constraints constraints = ((WorkSpec) it.next()).constraints;
                z2 |= constraints.mRequiresBatteryNotLow;
                z3 |= constraints.mRequiresCharging;
                z4 |= constraints.mRequiresStorageNotLow;
                z5 |= constraints.mRequiredNetworkType != NetworkType.NOT_REQUIRED;
                if (z2 && z3 && z4 && z5) {
                    break;
                }
            }
            String str2 = ConstraintProxyUpdateReceiver.TAG;
            Intent intent2 = new Intent("androidx.work.impl.background.systemalarm.UpdateProxies");
            intent2.setComponent(new ComponentName(context, ConstraintProxyUpdateReceiver.class));
            intent2.putExtra("KEY_BATTERY_NOT_LOW_PROXY_ENABLED", z2).putExtra("KEY_BATTERY_CHARGING_PROXY_ENABLED", z3).putExtra("KEY_STORAGE_NOT_LOW_PROXY_ENABLED", z4).putExtra("KEY_NETWORK_STATE_PROXY_ENABLED", z5);
            context.sendBroadcast(intent2);
            constraintsCommandHandler.mWorkConstraintsTracker.replace(scheduledWork);
            ArrayList arrayList2 = new ArrayList(arrayList.size());
            long currentTimeMillis = System.currentTimeMillis();
            Iterator it2 = arrayList.iterator();
            while (it2.hasNext()) {
                WorkSpec workSpec = (WorkSpec) it2.next();
                String str3 = workSpec.id;
                if (currentTimeMillis >= workSpec.calculateNextRunTime() && (!workSpec.hasConstraints() || constraintsCommandHandler.mWorkConstraintsTracker.areAllConstraintsMet(str3))) {
                    arrayList2.add(workSpec);
                }
            }
            Iterator it3 = arrayList2.iterator();
            while (it3.hasNext()) {
                String str4 = ((WorkSpec) it3.next()).id;
                Intent createDelayMetIntent = createDelayMetIntent(constraintsCommandHandler.mContext, str4);
                Logger$LogcatLogger.get().debug(ConstraintsCommandHandler.TAG, String.format("Creating a delay_met command for workSpec with id (%s)", str4), new Throwable[0]);
                SystemAlarmDispatcher systemAlarmDispatcher2 = constraintsCommandHandler.mDispatcher;
                systemAlarmDispatcher2.mMainHandler.post(new SystemAlarmDispatcher.AddRunnable(systemAlarmDispatcher2, createDelayMetIntent, constraintsCommandHandler.mStartId));
            }
            constraintsCommandHandler.mWorkConstraintsTracker.reset();
        } else if ("ACTION_RESCHEDULE".equals(action)) {
            Logger$LogcatLogger.get().debug(TAG, String.format("Handling reschedule %s, %s", intent, Integer.valueOf(i)), new Throwable[0]);
            systemAlarmDispatcher.mWorkManager.rescheduleEligibleWork();
        } else {
            Bundle extras = intent.getExtras();
            String[] strArr = {"KEY_WORKSPEC_ID"};
            if (extras != null && !extras.isEmpty()) {
                int i2 = 0;
                while (true) {
                    if (i2 >= 1) {
                        z = true;
                        break;
                    } else if (extras.get(strArr[i2]) == null) {
                        break;
                    } else {
                        i2++;
                    }
                }
                if (z) {
                    Logger$LogcatLogger.get().error(TAG, String.format("Invalid request for %s, requires %s.", action, "KEY_WORKSPEC_ID"), new Throwable[0]);
                    return;
                } else if ("ACTION_SCHEDULE_WORK".equals(action)) {
                    String string = intent.getExtras().getString("KEY_WORKSPEC_ID");
                    Logger$LogcatLogger logger$LogcatLogger = Logger$LogcatLogger.get();
                    String str5 = TAG;
                    logger$LogcatLogger.debug(str5, String.format("Handling schedule work for %s", string), new Throwable[0]);
                    WorkDatabase workDatabase = systemAlarmDispatcher.mWorkManager.mWorkDatabase;
                    workDatabase.beginTransaction();
                    try {
                        WorkSpec workSpec2 = workDatabase.workSpecDao().getWorkSpec(string);
                        if (workSpec2 == null) {
                            Logger$LogcatLogger logger$LogcatLogger2 = Logger$LogcatLogger.get();
                            logger$LogcatLogger2.warning(str5, "Skipping scheduling " + string + " because it's no longer in the DB", new Throwable[0]);
                        } else if (workSpec2.state.isFinished()) {
                            Logger$LogcatLogger logger$LogcatLogger3 = Logger$LogcatLogger.get();
                            logger$LogcatLogger3.warning(str5, "Skipping scheduling " + string + "because it is finished.", new Throwable[0]);
                        } else {
                            long calculateNextRunTime = workSpec2.calculateNextRunTime();
                            if (!workSpec2.hasConstraints()) {
                                Logger$LogcatLogger.get().debug(str5, String.format("Setting up Alarms for %s at %s", string, Long.valueOf(calculateNextRunTime)), new Throwable[0]);
                                Alarms.setAlarm(this.mContext, systemAlarmDispatcher.mWorkManager, string, calculateNextRunTime);
                            } else {
                                Logger$LogcatLogger.get().debug(str5, String.format("Opportunistically setting an alarm for %s at %s", string, Long.valueOf(calculateNextRunTime)), new Throwable[0]);
                                Alarms.setAlarm(this.mContext, systemAlarmDispatcher.mWorkManager, string, calculateNextRunTime);
                                systemAlarmDispatcher.mMainHandler.post(new SystemAlarmDispatcher.AddRunnable(systemAlarmDispatcher, createConstraintsChangedIntent(this.mContext), i));
                            }
                            workDatabase.setTransactionSuccessful();
                        }
                        return;
                    } finally {
                        workDatabase.endTransaction();
                    }
                } else if ("ACTION_DELAY_MET".equals(action)) {
                    Bundle extras2 = intent.getExtras();
                    synchronized (this.mLock) {
                        String string2 = extras2.getString("KEY_WORKSPEC_ID");
                        Logger$LogcatLogger logger$LogcatLogger4 = Logger$LogcatLogger.get();
                        String str6 = TAG;
                        logger$LogcatLogger4.debug(str6, String.format("Handing delay met for %s", string2), new Throwable[0]);
                        if (!this.mPendingDelayMet.containsKey(string2)) {
                            DelayMetCommandHandler delayMetCommandHandler = new DelayMetCommandHandler(this.mContext, i, string2, systemAlarmDispatcher);
                            this.mPendingDelayMet.put(string2, delayMetCommandHandler);
                            delayMetCommandHandler.handleProcessWork();
                        } else {
                            Logger$LogcatLogger.get().debug(str6, String.format("WorkSpec %s is already being handled for ACTION_DELAY_MET", string2), new Throwable[0]);
                        }
                    }
                    return;
                } else if ("ACTION_STOP_WORK".equals(action)) {
                    String string3 = intent.getExtras().getString("KEY_WORKSPEC_ID");
                    Logger$LogcatLogger.get().debug(TAG, String.format("Handing stopWork work for %s", string3), new Throwable[0]);
                    systemAlarmDispatcher.mWorkManager.stopWork(string3);
                    Context context2 = this.mContext;
                    WorkManagerImpl workManagerImpl = systemAlarmDispatcher.mWorkManager;
                    String str7 = Alarms.TAG;
                    SystemIdInfoDao_Impl systemIdInfoDao = workManagerImpl.mWorkDatabase.systemIdInfoDao();
                    SystemIdInfo systemIdInfo = systemIdInfoDao.getSystemIdInfo(string3);
                    if (systemIdInfo != null) {
                        Alarms.cancelExactAlarm(context2, string3, systemIdInfo.systemId);
                        Logger$LogcatLogger.get().debug(Alarms.TAG, String.format("Removing SystemIdInfo for workSpecId (%s)", string3), new Throwable[0]);
                        systemIdInfoDao.removeSystemIdInfo(string3);
                    }
                    systemAlarmDispatcher.onExecuted(string3, false);
                    return;
                } else if ("ACTION_EXECUTION_COMPLETED".equals(action)) {
                    Bundle extras3 = intent.getExtras();
                    String string4 = extras3.getString("KEY_WORKSPEC_ID");
                    boolean z6 = extras3.getBoolean("KEY_NEEDS_RESCHEDULE");
                    Logger$LogcatLogger.get().debug(TAG, String.format("Handling onExecutionCompleted %s, %s", intent, Integer.valueOf(i)), new Throwable[0]);
                    onExecuted(string4, z6);
                    return;
                } else {
                    Logger$LogcatLogger.get().warning(TAG, String.format("Ignoring intent %s", intent), new Throwable[0]);
                    return;
                }
            }
            z = false;
            if (z) {
            }
        }
    }
}
