package com.bumptech.glide;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.util.Log;
import android.widget.ImageView;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.load.resource.bitmap.CenterCrop;
import com.bumptech.glide.load.resource.bitmap.CenterInside;
import com.bumptech.glide.load.resource.bitmap.DownsampleStrategy;
import com.bumptech.glide.load.resource.bitmap.FitCenter;
import com.bumptech.glide.manager.RequestTracker;
import com.bumptech.glide.request.BaseRequestOptions;
import com.bumptech.glide.request.ErrorRequestCoordinator;
import com.bumptech.glide.request.Request;
import com.bumptech.glide.request.RequestCoordinator;
import com.bumptech.glide.request.RequestListener;
import com.bumptech.glide.request.RequestOptions;
import com.bumptech.glide.request.SingleRequest;
import com.bumptech.glide.request.ThumbnailRequestCoordinator;
import com.bumptech.glide.request.target.BitmapImageViewTarget;
import com.bumptech.glide.request.target.DrawableImageViewTarget;
import com.bumptech.glide.request.target.ImageViewTarget;
import com.bumptech.glide.request.target.Target;
import com.bumptech.glide.util.Executors;
import com.bumptech.glide.util.Util;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.Executor;

public class RequestBuilder<TranscodeType> extends BaseRequestOptions<RequestBuilder<TranscodeType>> implements Cloneable {
    public final Context context;
    public RequestBuilder<TranscodeType> errorBuilder;
    public final GlideContext glideContext;
    public boolean isDefaultTransitionOptionsSet = true;
    public boolean isModelSet;
    public boolean isThumbnailBuilt;
    public Object model;
    public List<RequestListener<TranscodeType>> requestListeners;
    public final RequestManager requestManager;
    public RequestBuilder<TranscodeType> thumbnailBuilder;
    public final Class<TranscodeType> transcodeClass;
    public GenericTransitionOptions<?, ? super TranscodeType> transitionOptions;

    /* renamed from: com.bumptech.glide.RequestBuilder$1  reason: invalid class name */
    public abstract /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$android$widget$ImageView$ScaleType;
        public static final /* synthetic */ int[] $SwitchMap$com$bumptech$glide$Priority;

        /* JADX WARNING: Can't wrap try/catch for region: R(25:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|15|16|17|18|19|20|21|22|23|24|25|26|27|28|(3:29|30|32)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(26:0|1|2|3|(2:5|6)|7|9|10|11|12|13|15|16|17|18|19|20|21|22|23|24|25|26|27|28|(3:29|30|32)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(29:0|1|2|3|5|6|7|9|10|11|12|13|15|16|17|18|19|20|21|22|23|24|25|26|27|28|29|30|32) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x0027 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x0042 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x004c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x0056 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0060 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x006b */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x0076 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0081 */
        static {
            Priority.values();
            int[] iArr = new int[4];
            $SwitchMap$com$bumptech$glide$Priority = iArr;
            try {
                iArr[Priority.LOW.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                $SwitchMap$com$bumptech$glide$Priority[Priority.NORMAL.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            $SwitchMap$com$bumptech$glide$Priority[Priority.HIGH.ordinal()] = 3;
            $SwitchMap$com$bumptech$glide$Priority[Priority.IMMEDIATE.ordinal()] = 4;
            int[] iArr2 = new int[ImageView.ScaleType.values().length];
            $SwitchMap$android$widget$ImageView$ScaleType = iArr2;
            iArr2[ImageView.ScaleType.CENTER_CROP.ordinal()] = 1;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.CENTER_INSIDE.ordinal()] = 2;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_CENTER.ordinal()] = 3;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_START.ordinal()] = 4;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_END.ordinal()] = 5;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.FIT_XY.ordinal()] = 6;
            $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.CENTER.ordinal()] = 7;
            try {
                $SwitchMap$android$widget$ImageView$ScaleType[ImageView.ScaleType.MATRIX.ordinal()] = 8;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    static {
        RequestOptions requestOptions = (RequestOptions) ((RequestOptions) ((RequestOptions) new RequestOptions().diskCacheStrategy(DiskCacheStrategy.DATA)).priority(Priority.LOW)).skipMemoryCache(true);
    }

    @SuppressLint({"CheckResult"})
    public RequestBuilder(Glide glide, RequestManager requestManager2, Class<TranscodeType> cls, Context context2) {
        RequestOptions requestOptions;
        this.requestManager = requestManager2;
        this.transcodeClass = cls;
        this.context = context2;
        GlideContext glideContext2 = requestManager2.glide.glideContext;
        GenericTransitionOptions<?, ?> genericTransitionOptions = glideContext2.defaultTransitionOptions.get(cls);
        if (genericTransitionOptions == null) {
            for (Map.Entry<Class<?>, GenericTransitionOptions<?, ?>> entry : glideContext2.defaultTransitionOptions.entrySet()) {
                if (entry.getKey().isAssignableFrom(cls)) {
                    genericTransitionOptions = (GenericTransitionOptions<?, ? super TranscodeType>) entry.getValue();
                }
            }
        }
        this.transitionOptions = (GenericTransitionOptions<?, ? super TranscodeType>) (genericTransitionOptions == null ? (GenericTransitionOptions<?, ? super TranscodeType>) GlideContext.DEFAULT_TRANSITION_OPTIONS : genericTransitionOptions);
        this.glideContext = glide.glideContext;
        for (RequestListener<Object> requestListener : requestManager2.defaultRequestListeners) {
            addListener(requestListener);
        }
        synchronized (requestManager2) {
            requestOptions = requestManager2.requestOptions;
        }
        apply((BaseRequestOptions<?>) requestOptions);
    }

    public RequestBuilder<TranscodeType> addListener(RequestListener<TranscodeType> requestListener) {
        if (this.isAutoCloneEnabled) {
            return clone().addListener(requestListener);
        }
        if (requestListener != null) {
            if (this.requestListeners == null) {
                this.requestListeners = new ArrayList();
            }
            this.requestListeners.add(requestListener);
        }
        selfOrThrowIfLocked();
        return this;
    }

    @Override // com.bumptech.glide.request.BaseRequestOptions
    public RequestBuilder<TranscodeType> apply(BaseRequestOptions<?> baseRequestOptions) {
        Objects.requireNonNull(baseRequestOptions, "Argument must not be null");
        return (RequestBuilder) super.apply(baseRequestOptions);
    }

    public final Request buildRequestRecursive(Object obj, Target<TranscodeType> target, RequestListener<TranscodeType> requestListener, RequestCoordinator requestCoordinator, GenericTransitionOptions<?, ? super TranscodeType> genericTransitionOptions, Priority priority, int i, int i2, BaseRequestOptions<?> baseRequestOptions, Executor executor) {
        ErrorRequestCoordinator errorRequestCoordinator;
        ErrorRequestCoordinator errorRequestCoordinator2;
        ThumbnailRequestCoordinator thumbnailRequestCoordinator;
        int i3;
        int i4;
        Priority priority2;
        int i5;
        int i6;
        if (this.errorBuilder != null) {
            ErrorRequestCoordinator errorRequestCoordinator3 = new ErrorRequestCoordinator(obj, requestCoordinator);
            errorRequestCoordinator = errorRequestCoordinator3;
            errorRequestCoordinator2 = errorRequestCoordinator3;
        } else {
            errorRequestCoordinator = null;
            errorRequestCoordinator2 = requestCoordinator;
        }
        RequestBuilder<TranscodeType> requestBuilder = this.thumbnailBuilder;
        if (requestBuilder == null) {
            thumbnailRequestCoordinator = obtainRequest(obj, target, requestListener, baseRequestOptions, errorRequestCoordinator2, genericTransitionOptions, priority, i, i2, executor);
        } else if (!this.isThumbnailBuilt) {
            GenericTransitionOptions<?, ? super TranscodeType> genericTransitionOptions2 = requestBuilder.isDefaultTransitionOptionsSet ? genericTransitionOptions : requestBuilder.transitionOptions;
            if (BaseRequestOptions.isSet(requestBuilder.fields, 8)) {
                priority2 = this.thumbnailBuilder.priority;
            } else {
                priority2 = getThumbnailPriority(priority);
            }
            RequestBuilder<TranscodeType> requestBuilder2 = this.thumbnailBuilder;
            int i7 = requestBuilder2.overrideWidth;
            int i8 = requestBuilder2.overrideHeight;
            if (Util.isValidDimensions(i, i2)) {
                RequestBuilder<TranscodeType> requestBuilder3 = this.thumbnailBuilder;
                if (!Util.isValidDimensions(requestBuilder3.overrideWidth, requestBuilder3.overrideHeight)) {
                    i6 = baseRequestOptions.overrideWidth;
                    i5 = baseRequestOptions.overrideHeight;
                    ThumbnailRequestCoordinator thumbnailRequestCoordinator2 = new ThumbnailRequestCoordinator(obj, errorRequestCoordinator2);
                    Request obtainRequest = obtainRequest(obj, target, requestListener, baseRequestOptions, thumbnailRequestCoordinator2, genericTransitionOptions, priority, i, i2, executor);
                    this.isThumbnailBuilt = true;
                    RequestBuilder<TranscodeType> requestBuilder4 = this.thumbnailBuilder;
                    Request buildRequestRecursive = requestBuilder4.buildRequestRecursive(obj, target, requestListener, thumbnailRequestCoordinator2, genericTransitionOptions2, priority2, i6, i5, requestBuilder4, executor);
                    this.isThumbnailBuilt = false;
                    thumbnailRequestCoordinator2.full = obtainRequest;
                    thumbnailRequestCoordinator2.thumb = buildRequestRecursive;
                    thumbnailRequestCoordinator = thumbnailRequestCoordinator2;
                }
            }
            i5 = i8;
            i6 = i7;
            ThumbnailRequestCoordinator thumbnailRequestCoordinator22 = new ThumbnailRequestCoordinator(obj, errorRequestCoordinator2);
            Request obtainRequest2 = obtainRequest(obj, target, requestListener, baseRequestOptions, thumbnailRequestCoordinator22, genericTransitionOptions, priority, i, i2, executor);
            this.isThumbnailBuilt = true;
            RequestBuilder<TranscodeType> requestBuilder42 = this.thumbnailBuilder;
            Request buildRequestRecursive2 = requestBuilder42.buildRequestRecursive(obj, target, requestListener, thumbnailRequestCoordinator22, genericTransitionOptions2, priority2, i6, i5, requestBuilder42, executor);
            this.isThumbnailBuilt = false;
            thumbnailRequestCoordinator22.full = obtainRequest2;
            thumbnailRequestCoordinator22.thumb = buildRequestRecursive2;
            thumbnailRequestCoordinator = thumbnailRequestCoordinator22;
        } else {
            throw new IllegalStateException("You cannot use a request as both the main request and a thumbnail, consider using clone() on the request(s) passed to thumbnail()");
        }
        if (errorRequestCoordinator == null) {
            return thumbnailRequestCoordinator;
        }
        RequestBuilder<TranscodeType> requestBuilder5 = this.errorBuilder;
        int i9 = requestBuilder5.overrideWidth;
        int i10 = requestBuilder5.overrideHeight;
        if (Util.isValidDimensions(i, i2)) {
            RequestBuilder<TranscodeType> requestBuilder6 = this.errorBuilder;
            if (!Util.isValidDimensions(requestBuilder6.overrideWidth, requestBuilder6.overrideHeight)) {
                i4 = baseRequestOptions.overrideWidth;
                i3 = baseRequestOptions.overrideHeight;
                RequestBuilder<TranscodeType> requestBuilder7 = this.errorBuilder;
                Request buildRequestRecursive3 = requestBuilder7.buildRequestRecursive(obj, target, requestListener, errorRequestCoordinator, requestBuilder7.transitionOptions, requestBuilder7.priority, i4, i3, requestBuilder7, executor);
                errorRequestCoordinator.primary = thumbnailRequestCoordinator;
                errorRequestCoordinator.error = buildRequestRecursive3;
                return errorRequestCoordinator;
            }
        }
        i3 = i10;
        i4 = i9;
        RequestBuilder<TranscodeType> requestBuilder72 = this.errorBuilder;
        Request buildRequestRecursive32 = requestBuilder72.buildRequestRecursive(obj, target, requestListener, errorRequestCoordinator, requestBuilder72.transitionOptions, requestBuilder72.priority, i4, i3, requestBuilder72, executor);
        errorRequestCoordinator.primary = thumbnailRequestCoordinator;
        errorRequestCoordinator.error = buildRequestRecursive32;
        return errorRequestCoordinator;
    }

    public final Priority getThumbnailPriority(Priority priority) {
        int ordinal = priority.ordinal();
        if (ordinal == 0 || ordinal == 1) {
            return Priority.IMMEDIATE;
        }
        if (ordinal == 2) {
            return Priority.HIGH;
        }
        if (ordinal == 3) {
            return Priority.NORMAL;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("unknown priority: ");
        outline25.append(this.priority);
        throw new IllegalArgumentException(outline25.toString());
    }

    public final <Y extends Target<TranscodeType>> Y into(Y y, RequestListener<TranscodeType> requestListener, BaseRequestOptions<?> baseRequestOptions, Executor executor) {
        Objects.requireNonNull(y, "Argument must not be null");
        if (this.isModelSet) {
            Request buildRequestRecursive = buildRequestRecursive(new Object(), y, requestListener, null, this.transitionOptions, baseRequestOptions.priority, baseRequestOptions.overrideWidth, baseRequestOptions.overrideHeight, baseRequestOptions, executor);
            Request request = y.getRequest();
            if (buildRequestRecursive.isEquivalentTo(request)) {
                if (!(!baseRequestOptions.isCacheable && request.isComplete())) {
                    Objects.requireNonNull(request, "Argument must not be null");
                    if (!request.isRunning()) {
                        request.begin();
                    }
                    return y;
                }
            }
            this.requestManager.clear(y);
            y.setRequest(buildRequestRecursive);
            RequestManager requestManager2 = this.requestManager;
            synchronized (requestManager2) {
                requestManager2.targetTracker.targets.add(y);
                RequestTracker requestTracker = requestManager2.requestTracker;
                requestTracker.requests.add(buildRequestRecursive);
                if (!requestTracker.isPaused) {
                    buildRequestRecursive.begin();
                } else {
                    buildRequestRecursive.clear();
                    if (Log.isLoggable("RequestTracker", 2)) {
                        Log.v("RequestTracker", "Paused, delaying request");
                    }
                    requestTracker.pendingRequests.add(buildRequestRecursive);
                }
            }
            return y;
        }
        throw new IllegalArgumentException("You must call #load() before calling #into()");
    }

    public RequestBuilder<TranscodeType> listener(RequestListener<TranscodeType> requestListener) {
        if (this.isAutoCloneEnabled) {
            return clone().listener(requestListener);
        }
        this.requestListeners = null;
        return addListener(requestListener);
    }

    public final RequestBuilder<TranscodeType> loadGeneric(Object obj) {
        if (this.isAutoCloneEnabled) {
            return clone().loadGeneric(obj);
        }
        this.model = obj;
        this.isModelSet = true;
        selfOrThrowIfLocked();
        return this;
    }

    public final Request obtainRequest(Object obj, Target<TranscodeType> target, RequestListener<TranscodeType> requestListener, BaseRequestOptions<?> baseRequestOptions, RequestCoordinator requestCoordinator, GenericTransitionOptions<?, ? super TranscodeType> genericTransitionOptions, Priority priority, int i, int i2, Executor executor) {
        Context context2 = this.context;
        GlideContext glideContext2 = this.glideContext;
        return new SingleRequest(context2, glideContext2, obj, this.model, this.transcodeClass, baseRequestOptions, i, i2, priority, target, requestListener, this.requestListeners, requestCoordinator, glideContext2.engine, genericTransitionOptions.transitionFactory, executor);
    }

    @Override // com.bumptech.glide.request.BaseRequestOptions, com.bumptech.glide.request.BaseRequestOptions, java.lang.Object
    public RequestBuilder<TranscodeType> clone() {
        RequestBuilder<TranscodeType> requestBuilder = (RequestBuilder) super.clone();
        requestBuilder.transitionOptions = requestBuilder.transitionOptions.clone();
        if (requestBuilder.requestListeners != null) {
            requestBuilder.requestListeners = new ArrayList(requestBuilder.requestListeners);
        }
        RequestBuilder<TranscodeType> requestBuilder2 = requestBuilder.thumbnailBuilder;
        if (requestBuilder2 != null) {
            requestBuilder.thumbnailBuilder = requestBuilder2.clone();
        }
        RequestBuilder<TranscodeType> requestBuilder3 = requestBuilder.errorBuilder;
        if (requestBuilder3 != null) {
            requestBuilder.errorBuilder = requestBuilder3.clone();
        }
        return requestBuilder;
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x0085  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x008b  */
    public ImageViewTarget<ImageView, TranscodeType> into(ImageView imageView) {
        BaseRequestOptions<?> baseRequestOptions;
        Class<TranscodeType> cls;
        ImageViewTarget<ImageView, TranscodeType> imageViewTarget;
        Util.assertMainThread();
        Objects.requireNonNull(imageView, "Argument must not be null");
        if (!BaseRequestOptions.isSet(this.fields, 2048) && this.isTransformationAllowed && imageView.getScaleType() != null) {
            switch (AnonymousClass1.$SwitchMap$android$widget$ImageView$ScaleType[imageView.getScaleType().ordinal()]) {
                case 1:
                    baseRequestOptions = clone().optionalTransform(DownsampleStrategy.CENTER_OUTSIDE, new CenterCrop());
                    break;
                case 2:
                    baseRequestOptions = clone().optionalTransform(DownsampleStrategy.CENTER_INSIDE, new CenterInside());
                    baseRequestOptions.isScaleOnlyOrNoTransform = true;
                    break;
                case 3:
                case 4:
                case 5:
                    baseRequestOptions = clone().optionalTransform(DownsampleStrategy.FIT_CENTER, new FitCenter());
                    baseRequestOptions.isScaleOnlyOrNoTransform = true;
                    break;
                case 6:
                    baseRequestOptions = clone().optionalTransform(DownsampleStrategy.CENTER_INSIDE, new CenterInside());
                    baseRequestOptions.isScaleOnlyOrNoTransform = true;
                    break;
            }
            GlideContext glideContext2 = this.glideContext;
            cls = this.transcodeClass;
            Objects.requireNonNull(glideContext2.imageViewTargetFactory);
            if (!Bitmap.class.equals(cls)) {
                imageViewTarget = new BitmapImageViewTarget(imageView);
            } else if (Drawable.class.isAssignableFrom(cls)) {
                imageViewTarget = new DrawableImageViewTarget(imageView);
            } else {
                throw new IllegalArgumentException("Unhandled class: " + cls + ", try .as*(Class).transcode(ResourceTranscoder)");
            }
            into(imageViewTarget, null, baseRequestOptions, Executors.MAIN_THREAD_EXECUTOR);
            return imageViewTarget;
        }
        baseRequestOptions = this;
        GlideContext glideContext22 = this.glideContext;
        cls = this.transcodeClass;
        Objects.requireNonNull(glideContext22.imageViewTargetFactory);
        if (!Bitmap.class.equals(cls)) {
        }
        into(imageViewTarget, null, baseRequestOptions, Executors.MAIN_THREAD_EXECUTOR);
        return imageViewTarget;
    }
}
