package com.bumptech.glide.load.engine;

import android.os.Process;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.engine.EngineResource;
import java.lang.ref.ReferenceQueue;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import java.util.concurrent.Executor;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.ThreadFactory;

public final class ActiveResources {
    public final Map<Key, ResourceWeakReference> activeEngineResources = new HashMap();
    public final boolean isActiveResourceRetentionAllowed;
    public EngineResource.ResourceListener listener;
    public final Executor monitorClearedResourcesExecutor;
    public final ReferenceQueue<EngineResource<?>> resourceReferenceQueue = new ReferenceQueue<>();

    public final class ResourceWeakReference extends WeakReference<EngineResource<?>> {
        public final boolean isCacheable;
        public final Key key;
        public Resource<?> resource;

        /* JADX WARN: Multi-variable type inference failed */
        /* JADX DEBUG: Type inference failed for r1v4. Raw type applied. Possible types: com.bumptech.glide.load.engine.Resource<Z> */
        public ResourceWeakReference(Key key2, EngineResource<?> engineResource, ReferenceQueue<? super EngineResource<?>> referenceQueue, boolean z) {
            super(engineResource, referenceQueue);
            Resource resource2;
            Objects.requireNonNull(key2, "Argument must not be null");
            this.key = key2;
            if (!engineResource.isMemoryCacheable || !z) {
                resource2 = (Resource<Z>) false;
            } else {
                Resource resource3 = (Resource<Z>) engineResource.resource;
                Objects.requireNonNull(resource3, "Argument must not be null");
                resource2 = resource3;
            }
            this.resource = resource2;
            this.isCacheable = engineResource.isMemoryCacheable;
        }
    }

    public ActiveResources(boolean z) {
        ExecutorService newSingleThreadExecutor = Executors.newSingleThreadExecutor(new ThreadFactory() {
            /* class com.bumptech.glide.load.engine.ActiveResources.AnonymousClass1 */

            public Thread newThread(final Runnable runnable) {
                return new Thread(new Runnable(this) {
                    /* class com.bumptech.glide.load.engine.ActiveResources.AnonymousClass1.AnonymousClass1 */

                    public void run() {
                        Process.setThreadPriority(10);
                        runnable.run();
                    }
                }, "glide-active-resources");
            }
        });
        this.isActiveResourceRetentionAllowed = z;
        this.monitorClearedResourcesExecutor = newSingleThreadExecutor;
        newSingleThreadExecutor.execute(new Runnable() {
            /* class com.bumptech.glide.load.engine.ActiveResources.AnonymousClass2 */

            public void run() {
                ActiveResources activeResources = ActiveResources.this;
                Objects.requireNonNull(activeResources);
                while (true) {
                    try {
                        activeResources.cleanupActiveReference((ResourceWeakReference) activeResources.resourceReferenceQueue.remove());
                    } catch (InterruptedException unused) {
                        Thread.currentThread().interrupt();
                    }
                }
            }
        });
    }

    public synchronized void activate(Key key, EngineResource<?> engineResource) {
        ResourceWeakReference put = this.activeEngineResources.put(key, new ResourceWeakReference(key, engineResource, this.resourceReferenceQueue, this.isActiveResourceRetentionAllowed));
        if (put != null) {
            put.resource = null;
            put.clear();
        }
    }

    public void cleanupActiveReference(ResourceWeakReference resourceWeakReference) {
        synchronized (this) {
            this.activeEngineResources.remove(resourceWeakReference.key);
            if (resourceWeakReference.isCacheable) {
                Resource<?> resource = resourceWeakReference.resource;
                if (resource != null) {
                    EngineResource<?> engineResource = new EngineResource<>(resource, true, false, resourceWeakReference.key, this.listener);
                    ((Engine) this.listener).onResourceReleased(resourceWeakReference.key, engineResource);
                }
            }
        }
    }
}
