package com.bumptech.glide.load.engine;

import androidx.collection.SimpleArrayMap;
import com.bumptech.glide.GlideContext;
import com.bumptech.glide.Priority;
import com.bumptech.glide.Registry;
import com.bumptech.glide.load.Encoder;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.Transformation;
import com.bumptech.glide.load.engine.Engine;
import com.bumptech.glide.load.engine.cache.DiskCache;
import com.bumptech.glide.load.model.ModelLoader;
import com.bumptech.glide.load.resource.UnitTransformation;
import com.bumptech.glide.load.resource.transcode.ResourceTranscoder;
import com.bumptech.glide.load.resource.transcode.TranscoderRegistry;
import com.bumptech.glide.load.resource.transcode.UnitTranscoder;
import com.bumptech.glide.provider.EncoderRegistry;
import com.bumptech.glide.provider.LoadPathCache;
import com.bumptech.glide.provider.ResourceDecoderRegistry;
import com.bumptech.glide.util.MultiClassKey;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Objects;

public final class DecodeHelper<Transcode> {
    public final List<Key> cacheKeys = new ArrayList();
    public Engine.LazyDiskCacheProvider diskCacheProvider;
    public DiskCacheStrategy diskCacheStrategy;
    public GlideContext glideContext;
    public int height;
    public boolean isCacheKeysSet;
    public boolean isLoadDataSet;
    public boolean isScaleOnlyOrNoTransform;
    public boolean isTransformationRequired;
    public final List<ModelLoader.LoadData<?>> loadData = new ArrayList();
    public Object model;
    public Options options;
    public Priority priority;
    public Class<?> resourceClass;
    public Key signature;
    public Class<Transcode> transcodeClass;
    public Map<Class<?>, Transformation<?>> transformations;
    public int width;

    public List<Key> getCacheKeys() {
        if (!this.isCacheKeysSet) {
            this.isCacheKeysSet = true;
            this.cacheKeys.clear();
            List<ModelLoader.LoadData<?>> loadData2 = getLoadData();
            int size = loadData2.size();
            for (int i = 0; i < size; i++) {
                ModelLoader.LoadData<?> loadData3 = loadData2.get(i);
                if (!this.cacheKeys.contains(loadData3.sourceKey)) {
                    this.cacheKeys.add(loadData3.sourceKey);
                }
                for (int i2 = 0; i2 < loadData3.alternateKeys.size(); i2++) {
                    if (!this.cacheKeys.contains(loadData3.alternateKeys.get(i2))) {
                        this.cacheKeys.add(loadData3.alternateKeys.get(i2));
                    }
                }
            }
        }
        return this.cacheKeys;
    }

    public DiskCache getDiskCache() {
        return this.diskCacheProvider.getDiskCache();
    }

    public List<ModelLoader.LoadData<?>> getLoadData() {
        if (!this.isLoadDataSet) {
            this.isLoadDataSet = true;
            this.loadData.clear();
            List modelLoaders = this.glideContext.registry.getModelLoaders(this.model);
            int size = modelLoaders.size();
            for (int i = 0; i < size; i++) {
                ModelLoader.LoadData<?> buildLoadData = ((ModelLoader) modelLoaders.get(i)).buildLoadData(this.model, this.width, this.height, this.options);
                if (buildLoadData != null) {
                    this.loadData.add(buildLoadData);
                }
            }
        }
        return this.loadData;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r19v0, resolved type: java.lang.Class<Data> */
    /* JADX WARN: Multi-variable type inference failed */
    public <Data> LoadPath<Data, ?, Transcode> getLoadPath(Class<Data> cls) {
        LoadPath<Data, ?, Transcode> loadPath;
        LoadPath<Data, ?, Transcode> loadPath2;
        Object obj;
        ArrayList arrayList;
        ResourceTranscoder resourceTranscoder;
        Registry registry = this.glideContext.registry;
        Class<?> cls2 = this.resourceClass;
        Class cls3 = (Class<Transcode>) this.transcodeClass;
        LoadPathCache loadPathCache = registry.loadPathCache;
        MultiClassKey andSet = loadPathCache.keyRef.getAndSet(null);
        if (andSet == null) {
            andSet = new MultiClassKey();
        }
        andSet.first = cls;
        andSet.second = cls2;
        andSet.third = cls3;
        synchronized (loadPathCache.cache) {
            loadPath = (LoadPath<Data, ?, Transcode>) loadPathCache.cache.getOrDefault(andSet, null);
        }
        loadPathCache.keyRef.set(andSet);
        Objects.requireNonNull(registry.loadPathCache);
        if (LoadPathCache.NO_PATHS_SIGNAL.equals(loadPath)) {
            return null;
        }
        if (loadPath != null) {
            return loadPath;
        }
        ArrayList arrayList2 = new ArrayList();
        Iterator it = ((ArrayList) registry.decoderRegistry.getResourceClasses(cls, cls2)).iterator();
        while (it.hasNext()) {
            Class<?> cls4 = (Class) it.next();
            Iterator it2 = ((ArrayList) registry.transcoderRegistry.getTranscodeClasses(cls4, cls3)).iterator();
            while (true) {
                if (it2.hasNext()) {
                    Class<?> cls5 = (Class) it2.next();
                    ResourceDecoderRegistry resourceDecoderRegistry = registry.decoderRegistry;
                    synchronized (resourceDecoderRegistry) {
                        arrayList = new ArrayList();
                        for (String str : resourceDecoderRegistry.bucketPriorityList) {
                            List<ResourceDecoderRegistry.Entry<?, ?>> list = resourceDecoderRegistry.decoders.get(str);
                            if (list != null) {
                                for (ResourceDecoderRegistry.Entry<?, ?> entry : list) {
                                    if (entry.handles(cls, cls4)) {
                                        arrayList.add(entry.decoder);
                                    }
                                }
                            }
                        }
                    }
                    TranscoderRegistry transcoderRegistry = registry.transcoderRegistry;
                    synchronized (transcoderRegistry) {
                        if (cls5.isAssignableFrom(cls4)) {
                            resourceTranscoder = UnitTranscoder.UNIT_TRANSCODER;
                        } else {
                            for (TranscoderRegistry.Entry<?, ?> entry2 : transcoderRegistry.transcoders) {
                                if (entry2.handles(cls4, cls5)) {
                                    resourceTranscoder = entry2.transcoder;
                                }
                            }
                            throw new IllegalArgumentException("No transcoder registered to transcode from " + cls4 + " to " + cls5);
                        }
                    }
                    arrayList2.add(new DecodePath(cls, cls4, cls5, arrayList, resourceTranscoder, registry.throwableListPool));
                }
            }
        }
        if (arrayList2.isEmpty()) {
            loadPath2 = null;
        } else {
            loadPath2 = new LoadPath<>(cls, cls2, cls3, arrayList2, registry.throwableListPool);
        }
        LoadPathCache loadPathCache2 = registry.loadPathCache;
        synchronized (loadPathCache2.cache) {
            SimpleArrayMap simpleArrayMap = loadPathCache2.cache;
            MultiClassKey multiClassKey = new MultiClassKey(cls, cls2, cls3);
            if (loadPath2 != null) {
                obj = loadPath2;
            } else {
                obj = LoadPathCache.NO_PATHS_SIGNAL;
            }
            simpleArrayMap.put(multiClassKey, obj);
        }
        return loadPath2;
    }

    public <X> Encoder<X> getSourceEncoder(X x) {
        Object obj;
        EncoderRegistry encoderRegistry = this.glideContext.registry.encoderRegistry;
        Class<?> cls = x.getClass();
        synchronized (encoderRegistry) {
            Iterator<EncoderRegistry.Entry<?>> it = encoderRegistry.encoders.iterator();
            while (true) {
                if (!it.hasNext()) {
                    obj = (Encoder<X>) null;
                    break;
                }
                EncoderRegistry.Entry<?> next = it.next();
                if (next.dataClass.isAssignableFrom(cls)) {
                    obj = (Encoder<T>) next.encoder;
                    break;
                }
            }
        }
        if (obj != null) {
            return (Encoder<X>) obj;
        }
        throw new Registry.NoSourceEncoderAvailableException(x.getClass());
    }

    public <Z> Transformation<Z> getTransformation(Class<Z> cls) {
        Transformation<Z> transformation = (Transformation<Z>) this.transformations.get(cls);
        if (transformation == null) {
            Iterator<Map.Entry<Class<?>, Transformation<?>>> it = this.transformations.entrySet().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Map.Entry<Class<?>, Transformation<?>> next = it.next();
                if (next.getKey().isAssignableFrom(cls)) {
                    transformation = (Transformation<Z>) next.getValue();
                    break;
                }
            }
        }
        if (transformation != null) {
            return transformation;
        }
        if (!this.transformations.isEmpty() || !this.isTransformationRequired) {
            return (UnitTransformation) UnitTransformation.TRANSFORMATION;
        }
        throw new IllegalArgumentException("Missing transformation for " + cls + ". If you wish to ignore unknown resource types, use the optional transformation methods.");
    }

    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: java.lang.Class<?> */
    /* JADX WARN: Multi-variable type inference failed */
    public boolean hasLoadPath(Class<?> cls) {
        return getLoadPath(cls) != null;
    }
}
