package com.bumptech.glide.load.engine;

import android.os.Build;
import android.os.SystemClock;
import android.util.Log;
import androidx.core.util.Pools$Pool;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.GlideContext;
import com.bumptech.glide.Priority;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.Option;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.ResourceEncoder;
import com.bumptech.glide.load.data.DataFetcher;
import com.bumptech.glide.load.data.DataRewinder;
import com.bumptech.glide.load.data.DataRewinderRegistry;
import com.bumptech.glide.load.engine.DataFetcherGenerator;
import com.bumptech.glide.load.engine.DecodePath;
import com.bumptech.glide.load.engine.Engine;
import com.bumptech.glide.load.engine.EngineJob;
import com.bumptech.glide.load.engine.EngineResource;
import com.bumptech.glide.load.resource.bitmap.Downsampler;
import com.bumptech.glide.util.LogTime;
import com.bumptech.glide.util.pool.FactoryPools;
import com.bumptech.glide.util.pool.StateVerifier$DefaultStateVerifier;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

public class DecodeJob<R> implements DataFetcherGenerator.FetcherReadyCallback, Runnable, Comparable<DecodeJob<?>>, FactoryPools.Poolable {
    public Callback<R> callback;
    public Key currentAttemptingKey;
    public Object currentData;
    public DataSource currentDataSource;
    public DataFetcher<?> currentFetcher;
    public volatile DataFetcherGenerator currentGenerator;
    public Key currentSourceKey;
    public Thread currentThread;
    public final DecodeHelper<R> decodeHelper = new DecodeHelper<>();
    public final DeferredEncodeManager<?> deferredEncodeManager = new DeferredEncodeManager<>();
    public final Engine.LazyDiskCacheProvider diskCacheProvider;
    public DiskCacheStrategy diskCacheStrategy;
    public GlideContext glideContext;
    public int height;
    public volatile boolean isCallbackNotified;
    public volatile boolean isCancelled;
    public boolean isLoadingFromAlternateCacheKey;
    public EngineKey loadKey;
    public Object model;
    public boolean onlyRetrieveFromCache;
    public Options options;
    public int order;
    public final Pools$Pool<DecodeJob<?>> pool;
    public Priority priority;
    public final ReleaseManager releaseManager = new ReleaseManager();
    public RunReason runReason;
    public Key signature;
    public Stage stage;
    public long startFetchTime;
    public final StateVerifier$DefaultStateVerifier stateVerifier = new StateVerifier$DefaultStateVerifier();
    public final List<Throwable> throwables = new ArrayList();
    public int width;

    public interface Callback<R> {
    }

    public final class DecodeCallback<Z> implements DecodePath.DecodeCallback<Z> {
        public final DataSource dataSource;

        public DecodeCallback(DataSource dataSource2) {
            this.dataSource = dataSource2;
        }
    }

    public class DeferredEncodeManager<Z> {
        public ResourceEncoder<Z> encoder;
        public Key key;
        public LockedResource<Z> toEncode;
    }

    public class ReleaseManager {
        public boolean isEncodeComplete;
        public boolean isFailed;
        public boolean isReleased;

        public final boolean isComplete(boolean z) {
            return (this.isFailed || z || this.isEncodeComplete) && this.isReleased;
        }
    }

    public enum RunReason {
        INITIALIZE,
        SWITCH_TO_SOURCE_SERVICE,
        DECODE_DATA
    }

    public enum Stage {
        INITIALIZE,
        RESOURCE_CACHE,
        DATA_CACHE,
        SOURCE,
        ENCODE,
        FINISHED
    }

    public DecodeJob(Engine.LazyDiskCacheProvider lazyDiskCacheProvider, Pools$Pool<DecodeJob<?>> pools$Pool) {
        this.diskCacheProvider = lazyDiskCacheProvider;
        this.pool = pools$Pool;
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
    @Override // java.lang.Comparable
    public int compareTo(DecodeJob<?> decodeJob) {
        DecodeJob<?> decodeJob2 = decodeJob;
        int ordinal = this.priority.ordinal() - decodeJob2.priority.ordinal();
        return ordinal == 0 ? this.order - decodeJob2.order : ordinal;
    }

    public final <Data> Resource<R> decodeFromData(DataFetcher<?> dataFetcher, Data data, DataSource dataSource) {
        if (data == null) {
            dataFetcher.cleanup();
            return null;
        }
        try {
            int i = LogTime.$r8$clinit;
            long elapsedRealtimeNanos = SystemClock.elapsedRealtimeNanos();
            Resource<R> decodeFromFetcher = decodeFromFetcher(data, dataSource);
            if (Log.isLoggable("DecodeJob", 2)) {
                logWithTimeAndKey("Decoded result " + decodeFromFetcher, elapsedRealtimeNanos, null);
            }
            return decodeFromFetcher;
        } finally {
            dataFetcher.cleanup();
        }
    }

    public final <Data> Resource<R> decodeFromFetcher(Data data, DataSource dataSource) {
        DataRewinder<Data> build;
        LoadPath<Data, ?, R> loadPath = this.decodeHelper.getLoadPath(data.getClass());
        Options options2 = this.options;
        if (Build.VERSION.SDK_INT >= 26) {
            boolean z = dataSource == DataSource.RESOURCE_DISK_CACHE || this.decodeHelper.isScaleOnlyOrNoTransform;
            Option<Boolean> option = Downsampler.ALLOW_HARDWARE_CONFIG;
            Boolean bool = (Boolean) options2.get(option);
            if (bool == null || (bool.booleanValue() && !z)) {
                options2 = new Options();
                options2.putAll(this.options);
                options2.values.put(option, Boolean.valueOf(z));
            }
        }
        DataRewinderRegistry dataRewinderRegistry = this.glideContext.registry.dataRewinderRegistry;
        synchronized (dataRewinderRegistry) {
            DataRewinder.Factory<?> factory = dataRewinderRegistry.rewinders.get(data.getClass());
            if (factory == null) {
                Iterator<DataRewinder.Factory<?>> it = dataRewinderRegistry.rewinders.values().iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    DataRewinder.Factory<?> next = it.next();
                    if (next.getDataClass().isAssignableFrom(data.getClass())) {
                        factory = next;
                        break;
                    }
                }
            }
            if (factory == null) {
                factory = DataRewinderRegistry.DEFAULT_FACTORY;
            }
            build = factory.build(data);
        }
        try {
            return loadPath.load(build, options2, this.width, this.height, new DecodeCallback(dataSource));
        } finally {
            build.cleanup();
        }
    }

    public final void decodeFromRetrievedData() {
        Resource resource;
        boolean isComplete;
        if (Log.isLoggable("DecodeJob", 2)) {
            long j = this.startFetchTime;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("data: ");
            outline25.append(this.currentData);
            outline25.append(", cache key: ");
            outline25.append(this.currentSourceKey);
            outline25.append(", fetcher: ");
            outline25.append(this.currentFetcher);
            logWithTimeAndKey("Retrieved data", j, outline25.toString());
        }
        LockedResource lockedResource = null;
        try {
            resource = (Resource<R>) decodeFromData(this.currentFetcher, this.currentData, this.currentDataSource);
        } catch (GlideException e) {
            e.setLoggingDetails(this.currentAttemptingKey, this.currentDataSource);
            this.throwables.add(e);
            resource = lockedResource;
        }
        if (resource != null) {
            DataSource dataSource = this.currentDataSource;
            boolean z = this.isLoadingFromAlternateCacheKey;
            if (resource instanceof Initializable) {
                ((Initializable) resource).initialize();
            }
            if (this.deferredEncodeManager.toEncode != null) {
                lockedResource = LockedResource.obtain(resource);
                resource = lockedResource;
            }
            setNotifiedOrThrow();
            EngineJob<?> engineJob = (EngineJob) this.callback;
            synchronized (engineJob) {
                engineJob.resource = resource;
                engineJob.dataSource = dataSource;
                engineJob.isLoadedFromAlternateCacheKey = z;
            }
            synchronized (engineJob) {
                engineJob.stateVerifier.throwIfRecycled();
                if (engineJob.isCancelled) {
                    engineJob.resource.recycle();
                    engineJob.release();
                } else if (engineJob.cbs.isEmpty()) {
                    throw new IllegalStateException("Received a resource without any callbacks to notify");
                } else if (!engineJob.hasResource) {
                    EngineJob.EngineResourceFactory engineResourceFactory = engineJob.engineResourceFactory;
                    Resource<?> resource2 = engineJob.resource;
                    boolean z2 = engineJob.isCacheable;
                    Key key = engineJob.key;
                    EngineResource.ResourceListener resourceListener = engineJob.resourceListener;
                    Objects.requireNonNull(engineResourceFactory);
                    engineJob.engineResource = new EngineResource<>(resource2, z2, true, key, resourceListener);
                    engineJob.hasResource = true;
                    EngineJob.ResourceCallbacksAndExecutors resourceCallbacksAndExecutors = engineJob.cbs;
                    Objects.requireNonNull(resourceCallbacksAndExecutors);
                    ArrayList arrayList = new ArrayList(resourceCallbacksAndExecutors.callbacksAndExecutors);
                    engineJob.incrementPendingCallbacks(arrayList.size() + 1);
                    ((Engine) engineJob.engineJobListener).onEngineJobComplete(engineJob, engineJob.key, engineJob.engineResource);
                    Iterator it = arrayList.iterator();
                    while (it.hasNext()) {
                        EngineJob.ResourceCallbackAndExecutor resourceCallbackAndExecutor = (EngineJob.ResourceCallbackAndExecutor) it.next();
                        resourceCallbackAndExecutor.executor.execute(new EngineJob.CallResourceReady(resourceCallbackAndExecutor.cb));
                    }
                    engineJob.decrementPendingCallbacks();
                } else {
                    throw new IllegalStateException("Already have resource");
                }
            }
            this.stage = Stage.ENCODE;
            try {
                DeferredEncodeManager<?> deferredEncodeManager2 = this.deferredEncodeManager;
                if (deferredEncodeManager2.toEncode != null) {
                    try {
                        this.diskCacheProvider.getDiskCache().put(deferredEncodeManager2.key, new DataCacheWriter(deferredEncodeManager2.encoder, deferredEncodeManager2.toEncode, this.options));
                    } finally {
                        deferredEncodeManager2.toEncode.unlock();
                    }
                }
                ReleaseManager releaseManager2 = this.releaseManager;
                synchronized (releaseManager2) {
                    releaseManager2.isEncodeComplete = true;
                    isComplete = releaseManager2.isComplete(false);
                }
                if (isComplete) {
                    releaseInternal();
                }
            } finally {
                if (lockedResource != null) {
                    lockedResource.unlock();
                }
            }
        } else {
            runGenerators();
        }
    }

    public final DataFetcherGenerator getNextGenerator() {
        int ordinal = this.stage.ordinal();
        if (ordinal == 1) {
            return new ResourceCacheGenerator(this.decodeHelper, this);
        }
        if (ordinal == 2) {
            return new DataCacheGenerator(this.decodeHelper, this);
        }
        if (ordinal == 3) {
            return new SourceGenerator(this.decodeHelper, this);
        }
        if (ordinal == 5) {
            return null;
        }
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Unrecognized stage: ");
        outline25.append(this.stage);
        throw new IllegalStateException(outline25.toString());
    }

    public final Stage getNextStage(Stage stage2) {
        int ordinal = stage2.ordinal();
        if (ordinal != 0) {
            if (ordinal != 1) {
                if (ordinal == 2) {
                    return this.onlyRetrieveFromCache ? Stage.FINISHED : Stage.SOURCE;
                }
                if (ordinal == 3 || ordinal == 5) {
                    return Stage.FINISHED;
                }
                throw new IllegalArgumentException("Unrecognized stage: " + stage2);
            } else if (this.diskCacheStrategy.decodeCachedData()) {
                return Stage.DATA_CACHE;
            } else {
                return getNextStage(Stage.DATA_CACHE);
            }
        } else if (this.diskCacheStrategy.decodeCachedResource()) {
            return Stage.RESOURCE_CACHE;
        } else {
            return getNextStage(Stage.RESOURCE_CACHE);
        }
    }

    @Override // com.bumptech.glide.util.pool.FactoryPools.Poolable
    public StateVerifier$DefaultStateVerifier getVerifier() {
        return this.stateVerifier;
    }

    public final void logWithTimeAndKey(String str, long j, String str2) {
        StringBuilder outline28 = GeneratedOutlineSupport.outline28(str, " in ");
        outline28.append(LogTime.getElapsedMillis(j));
        outline28.append(", load key: ");
        outline28.append(this.loadKey);
        outline28.append(str2 != null ? GeneratedOutlineSupport.outline18(", ", str2) : "");
        outline28.append(", thread: ");
        outline28.append(Thread.currentThread().getName());
        Log.v("DecodeJob", outline28.toString());
    }

    public final void notifyFailed() {
        boolean isComplete;
        setNotifiedOrThrow();
        GlideException glideException = new GlideException("Failed to load resource", new ArrayList(this.throwables));
        EngineJob<?> engineJob = (EngineJob) this.callback;
        synchronized (engineJob) {
            engineJob.exception = glideException;
        }
        synchronized (engineJob) {
            engineJob.stateVerifier.throwIfRecycled();
            if (engineJob.isCancelled) {
                engineJob.release();
            } else if (engineJob.cbs.isEmpty()) {
                throw new IllegalStateException("Received an exception without any callbacks to notify");
            } else if (!engineJob.hasLoadFailed) {
                engineJob.hasLoadFailed = true;
                Key key = engineJob.key;
                EngineJob.ResourceCallbacksAndExecutors resourceCallbacksAndExecutors = engineJob.cbs;
                Objects.requireNonNull(resourceCallbacksAndExecutors);
                ArrayList arrayList = new ArrayList(resourceCallbacksAndExecutors.callbacksAndExecutors);
                engineJob.incrementPendingCallbacks(arrayList.size() + 1);
                ((Engine) engineJob.engineJobListener).onEngineJobComplete(engineJob, key, null);
                Iterator it = arrayList.iterator();
                while (it.hasNext()) {
                    EngineJob.ResourceCallbackAndExecutor resourceCallbackAndExecutor = (EngineJob.ResourceCallbackAndExecutor) it.next();
                    resourceCallbackAndExecutor.executor.execute(new EngineJob.CallLoadFailed(resourceCallbackAndExecutor.cb));
                }
                engineJob.decrementPendingCallbacks();
            } else {
                throw new IllegalStateException("Already failed once");
            }
        }
        ReleaseManager releaseManager2 = this.releaseManager;
        synchronized (releaseManager2) {
            releaseManager2.isFailed = true;
            isComplete = releaseManager2.isComplete(false);
        }
        if (isComplete) {
            releaseInternal();
        }
    }

    @Override // com.bumptech.glide.load.engine.DataFetcherGenerator.FetcherReadyCallback
    public void onDataFetcherFailed(Key key, Exception exc, DataFetcher<?> dataFetcher, DataSource dataSource) {
        dataFetcher.cleanup();
        GlideException glideException = new GlideException("Fetching data failed", exc);
        glideException.setLoggingDetails(key, dataSource, dataFetcher.getDataClass());
        this.throwables.add(glideException);
        if (Thread.currentThread() != this.currentThread) {
            this.runReason = RunReason.SWITCH_TO_SOURCE_SERVICE;
            ((EngineJob) this.callback).reschedule(this);
            return;
        }
        runGenerators();
    }

    @Override // com.bumptech.glide.load.engine.DataFetcherGenerator.FetcherReadyCallback
    public void onDataFetcherReady(Key key, Object obj, DataFetcher<?> dataFetcher, DataSource dataSource, Key key2) {
        this.currentSourceKey = key;
        this.currentData = obj;
        this.currentFetcher = dataFetcher;
        this.currentDataSource = dataSource;
        this.currentAttemptingKey = key2;
        boolean z = false;
        if (key != this.decodeHelper.getCacheKeys().get(0)) {
            z = true;
        }
        this.isLoadingFromAlternateCacheKey = z;
        if (Thread.currentThread() != this.currentThread) {
            this.runReason = RunReason.DECODE_DATA;
            ((EngineJob) this.callback).reschedule(this);
            return;
        }
        decodeFromRetrievedData();
    }

    public final void releaseInternal() {
        ReleaseManager releaseManager2 = this.releaseManager;
        synchronized (releaseManager2) {
            releaseManager2.isEncodeComplete = false;
            releaseManager2.isReleased = false;
            releaseManager2.isFailed = false;
        }
        DeferredEncodeManager<?> deferredEncodeManager2 = this.deferredEncodeManager;
        deferredEncodeManager2.key = null;
        deferredEncodeManager2.encoder = null;
        deferredEncodeManager2.toEncode = null;
        DecodeHelper<R> decodeHelper2 = this.decodeHelper;
        decodeHelper2.glideContext = null;
        decodeHelper2.model = null;
        decodeHelper2.signature = null;
        decodeHelper2.resourceClass = null;
        decodeHelper2.transcodeClass = null;
        decodeHelper2.options = null;
        decodeHelper2.priority = null;
        decodeHelper2.transformations = null;
        decodeHelper2.diskCacheStrategy = null;
        decodeHelper2.loadData.clear();
        decodeHelper2.isLoadDataSet = false;
        decodeHelper2.cacheKeys.clear();
        decodeHelper2.isCacheKeysSet = false;
        this.isCallbackNotified = false;
        this.glideContext = null;
        this.signature = null;
        this.options = null;
        this.priority = null;
        this.loadKey = null;
        this.callback = null;
        this.stage = null;
        this.currentGenerator = null;
        this.currentThread = null;
        this.currentSourceKey = null;
        this.currentData = null;
        this.currentDataSource = null;
        this.currentFetcher = null;
        this.startFetchTime = 0;
        this.isCancelled = false;
        this.model = null;
        this.throwables.clear();
        this.pool.release(this);
    }

    @Override // com.bumptech.glide.load.engine.DataFetcherGenerator.FetcherReadyCallback
    public void reschedule() {
        this.runReason = RunReason.SWITCH_TO_SOURCE_SERVICE;
        ((EngineJob) this.callback).reschedule(this);
    }

    public void run() {
        DataFetcher<?> dataFetcher = this.currentFetcher;
        try {
            if (this.isCancelled) {
                notifyFailed();
                if (dataFetcher != null) {
                    dataFetcher.cleanup();
                    return;
                }
                return;
            }
            runWrapped();
            if (dataFetcher != null) {
                dataFetcher.cleanup();
            }
        } catch (CallbackException e) {
            throw e;
        } catch (Throwable th) {
            if (dataFetcher != null) {
                dataFetcher.cleanup();
            }
            throw th;
        }
    }

    public final void runGenerators() {
        this.currentThread = Thread.currentThread();
        int i = LogTime.$r8$clinit;
        this.startFetchTime = SystemClock.elapsedRealtimeNanos();
        boolean z = false;
        while (!this.isCancelled && this.currentGenerator != null && !(z = this.currentGenerator.startNext())) {
            this.stage = getNextStage(this.stage);
            this.currentGenerator = getNextGenerator();
            if (this.stage == Stage.SOURCE) {
                this.runReason = RunReason.SWITCH_TO_SOURCE_SERVICE;
                ((EngineJob) this.callback).reschedule(this);
                return;
            }
        }
        if ((this.stage == Stage.FINISHED || this.isCancelled) && !z) {
            notifyFailed();
        }
    }

    public final void runWrapped() {
        int ordinal = this.runReason.ordinal();
        if (ordinal == 0) {
            this.stage = getNextStage(Stage.INITIALIZE);
            this.currentGenerator = getNextGenerator();
            runGenerators();
        } else if (ordinal == 1) {
            runGenerators();
        } else if (ordinal == 2) {
            decodeFromRetrievedData();
        } else {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Unrecognized run reason: ");
            outline25.append(this.runReason);
            throw new IllegalStateException(outline25.toString());
        }
    }

    public final void setNotifiedOrThrow() {
        Throwable th;
        this.stateVerifier.throwIfRecycled();
        if (this.isCallbackNotified) {
            if (this.throwables.isEmpty()) {
                th = null;
            } else {
                List<Throwable> list = this.throwables;
                th = list.get(list.size() - 1);
            }
            throw new IllegalStateException("Already notified", th);
        }
        this.isCallbackNotified = true;
    }
}
