package com.bumptech.glide.load.engine;

import android.util.Log;
import androidx.core.util.Pools$Pool;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.bumptech.glide.Registry;
import com.bumptech.glide.load.DataSource;
import com.bumptech.glide.load.EncodeStrategy;
import com.bumptech.glide.load.Key;
import com.bumptech.glide.load.Options;
import com.bumptech.glide.load.ResourceDecoder;
import com.bumptech.glide.load.ResourceEncoder;
import com.bumptech.glide.load.Transformation;
import com.bumptech.glide.load.data.DataRewinder;
import com.bumptech.glide.load.engine.DecodeJob;
import com.bumptech.glide.load.model.ModelLoader;
import com.bumptech.glide.load.resource.transcode.ResourceTranscoder;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

public class DecodePath<DataType, ResourceType, Transcode> {
    public final Class<DataType> dataClass;
    public final List<? extends ResourceDecoder<DataType, ResourceType>> decoders;
    public final String failureMessage;
    public final Pools$Pool<List<Throwable>> listPool;
    public final ResourceTranscoder<ResourceType, Transcode> transcoder;

    public interface DecodeCallback<ResourceType> {
    }

    public DecodePath(Class<DataType> cls, Class<ResourceType> cls2, Class<Transcode> cls3, List<? extends ResourceDecoder<DataType, ResourceType>> list, ResourceTranscoder<ResourceType, Transcode> resourceTranscoder, Pools$Pool<List<Throwable>> pools$Pool) {
        this.dataClass = cls;
        this.decoders = list;
        this.transcoder = resourceTranscoder;
        this.listPool = pools$Pool;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed DecodePath{");
        outline25.append(cls.getSimpleName());
        outline25.append("->");
        outline25.append(cls2.getSimpleName());
        outline25.append("->");
        outline25.append(cls3.getSimpleName());
        outline25.append("}");
        this.failureMessage = outline25.toString();
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v9, types: [com.bumptech.glide.load.engine.Resource] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public Resource<Transcode> decode(DataRewinder<DataType> dataRewinder, int i, int i2, Options options, DecodeCallback<ResourceType> decodeCallback) {
        LockedResource<Z> lockedResource;
        Transformation<Z> transformation;
        EncodeStrategy encodeStrategy;
        Key key;
        List<Throwable> acquire = this.listPool.acquire();
        Objects.requireNonNull(acquire, "Argument must not be null");
        List<Throwable> list = acquire;
        try {
            Resource<ResourceType> decodeResourceWithList = decodeResourceWithList(dataRewinder, i, i2, options, list);
            this.listPool.release(list);
            DecodeJob.DecodeCallback decodeCallback2 = (DecodeJob.DecodeCallback) decodeCallback;
            DecodeJob decodeJob = DecodeJob.this;
            DataSource dataSource = decodeCallback2.dataSource;
            Objects.requireNonNull(decodeJob);
            Class<?> cls = decodeResourceWithList.get().getClass();
            ResourceEncoder<Z> resourceEncoder = null;
            if (dataSource != DataSource.RESOURCE_DISK_CACHE) {
                Transformation<Z> transformation2 = decodeJob.decodeHelper.getTransformation(cls);
                transformation = transformation2;
                lockedResource = transformation2.transform(decodeJob.glideContext, decodeResourceWithList, decodeJob.width, decodeJob.height);
            } else {
                lockedResource = (LockedResource<Z>) decodeResourceWithList;
                transformation = null;
            }
            if (!decodeResourceWithList.equals(lockedResource)) {
                decodeResourceWithList.recycle();
            }
            boolean z = false;
            if (decodeJob.decodeHelper.glideContext.registry.resourceEncoderRegistry.get(lockedResource.getResourceClass()) != null) {
                resourceEncoder = decodeJob.decodeHelper.glideContext.registry.resourceEncoderRegistry.get(lockedResource.getResourceClass());
                if (resourceEncoder != null) {
                    encodeStrategy = resourceEncoder.getEncodeStrategy(decodeJob.options);
                } else {
                    throw new Registry.NoResultEncoderAvailableException(lockedResource.getResourceClass());
                }
            } else {
                encodeStrategy = EncodeStrategy.NONE;
            }
            DecodeHelper<R> decodeHelper = decodeJob.decodeHelper;
            Key key2 = decodeJob.currentSourceKey;
            List<ModelLoader.LoadData<?>> loadData = decodeHelper.getLoadData();
            int size = loadData.size();
            int i3 = 0;
            while (true) {
                if (i3 >= size) {
                    break;
                } else if (loadData.get(i3).sourceKey.equals(key2)) {
                    z = true;
                    break;
                } else {
                    i3++;
                }
            }
            if (decodeJob.diskCacheStrategy.isResourceCacheable(!z, dataSource, encodeStrategy)) {
                if (resourceEncoder != null) {
                    int ordinal = encodeStrategy.ordinal();
                    if (ordinal == 0) {
                        key = new DataCacheKey(decodeJob.currentSourceKey, decodeJob.signature);
                    } else if (ordinal == 1) {
                        key = new ResourceCacheKey(decodeJob.decodeHelper.glideContext.arrayPool, decodeJob.currentSourceKey, decodeJob.signature, decodeJob.width, decodeJob.height, transformation, cls, decodeJob.options);
                    } else {
                        throw new IllegalArgumentException("Unknown strategy: " + encodeStrategy);
                    }
                    lockedResource = LockedResource.obtain(lockedResource);
                    DecodeJob.DeferredEncodeManager<?> deferredEncodeManager = decodeJob.deferredEncodeManager;
                    deferredEncodeManager.key = key;
                    deferredEncodeManager.encoder = resourceEncoder;
                    deferredEncodeManager.toEncode = lockedResource;
                } else {
                    throw new Registry.NoResultEncoderAvailableException(lockedResource.get().getClass());
                }
            }
            return this.transcoder.transcode(lockedResource, options);
        } catch (Throwable th) {
            this.listPool.release(list);
            throw th;
        }
    }

    public final Resource<ResourceType> decodeResourceWithList(DataRewinder<DataType> dataRewinder, int i, int i2, Options options, List<Throwable> list) {
        int size = this.decoders.size();
        Resource<ResourceType> resource = null;
        for (int i3 = 0; i3 < size; i3++) {
            ResourceDecoder resourceDecoder = (ResourceDecoder) this.decoders.get(i3);
            try {
                if (resourceDecoder.handles(dataRewinder.rewindAndGet(), options)) {
                    resource = resourceDecoder.decode(dataRewinder.rewindAndGet(), i, i2, options);
                }
            } catch (IOException | OutOfMemoryError | RuntimeException e) {
                if (Log.isLoggable("DecodePath", 2)) {
                    Log.v("DecodePath", "Failed to decode data for " + resourceDecoder, e);
                }
                list.add(e);
            }
            if (resource != null) {
                break;
            }
        }
        if (resource != null) {
            return resource;
        }
        throw new GlideException(this.failureMessage, new ArrayList(list));
    }

    public String toString() {
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("DecodePath{ dataClass=");
        outline25.append(this.dataClass);
        outline25.append(", decoders=");
        outline25.append(this.decoders);
        outline25.append(", transcoder=");
        outline25.append(this.transcoder);
        outline25.append('}');
        return outline25.toString();
    }
}
