package com.faster.cheetah.adapter;

import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import androidx.recyclerview.widget.RecyclerView;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.MainApplication;
import com.faster.cheetah.adapter.MessageListAdapter;
import com.faster.cheetah.entity.MessageEntity;
import com.faster.cheetah.ui.MessageDetailActivity;
import com.faster.cheetah.ui.MessageListActivity;
import com.zfast.xyz.R;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;

public class MessageListAdapter extends RecyclerView.Adapter<ViewHolder> {
    public final MainApplication application;
    public List<MessageEntity> messageEntityList;
    public final MessageListActivity messageListActivity;
    public final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.getDefault());

    public class ViewHolder extends RecyclerView.ViewHolder {
        public ImageView imgRedHot;
        public View itemView;
        public LinearLayout layLine;
        public TextView tvPublishTime;
        public TextView tvTitle;

        public ViewHolder(View view) {
            super(view);
            this.itemView = view;
            this.imgRedHot = (ImageView) view.findViewById(R.id.img_red_hot);
            this.tvTitle = (TextView) view.findViewById(R.id.tv_title);
            this.tvPublishTime = (TextView) view.findViewById(R.id.tv_publish_time);
            this.layLine = (LinearLayout) view.findViewById(R.id.layout_line);
        }
    }

    public MessageListAdapter(MessageListActivity messageListActivity2, List<MessageEntity> list) {
        this.messageListActivity = messageListActivity2;
        this.messageEntityList = null;
        this.application = (MainApplication) messageListActivity2.getApplication();
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        List<MessageEntity> list = this.messageEntityList;
        if (list != null) {
            return list.size();
        }
        return 0;
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [androidx.recyclerview.widget.RecyclerView$ViewHolder, int] */
    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public void onBindViewHolder(ViewHolder viewHolder, int i) {
        ViewHolder viewHolder2 = viewHolder;
        List<MessageEntity> list = this.messageEntityList;
        if (list != null && list.size() > i) {
            MessageEntity messageEntity = this.messageEntityList.get(i);
            viewHolder2.tvTitle.setText(messageEntity.title);
            viewHolder2.tvPublishTime.setText(this.simpleDateFormat.format(new Date(messageEntity.publishTime * 1000)));
            if (this.application.isReadMessage(messageEntity.id)) {
                viewHolder2.imgRedHot.setVisibility(4);
            } else {
                viewHolder2.imgRedHot.setVisibility(0);
            }
            if (i + 1 == this.messageEntityList.size()) {
                viewHolder2.layLine.setVisibility(4);
            }
            viewHolder2.itemView.setOnClickListener(new View.OnClickListener(messageEntity, viewHolder2) {
                /* class com.faster.cheetah.adapter.$$Lambda$MessageListAdapter$YkCE8dho44RRL9RFnJjM4E7f6NE */
                public final /* synthetic */ MessageEntity f$1;
                public final /* synthetic */ MessageListAdapter.ViewHolder f$2;

                {
                    this.f$1 = r2;
                    this.f$2 = r3;
                }

                public final void onClick(View view) {
                    MessageListAdapter messageListAdapter = MessageListAdapter.this;
                    MessageEntity messageEntity = this.f$1;
                    MessageListAdapter.ViewHolder viewHolder = this.f$2;
                    MainApplication mainApplication = messageListAdapter.application;
                    int i = messageEntity.id;
                    if (!mainApplication.isReadMessage(i)) {
                        mainApplication.sharedPreferencesHelper.put("read_message_id_set", ((String) mainApplication.sharedPreferencesHelper.getSharedPreference("read_message_id_set", "")) + "," + i);
                        Intent intent = new Intent();
                        intent.setAction("com.flybird.alcedo.action.message.refresh");
                        mainApplication.sendBroadcast(intent);
                    }
                    viewHolder.imgRedHot.setVisibility(4);
                    if (TextUtils.isEmpty(messageEntity.redirectUrl)) {
                        Intent intent2 = new Intent(messageListAdapter.messageListActivity, MessageDetailActivity.class);
                        intent2.putExtra("messageID", messageEntity.id);
                        messageListAdapter.messageListActivity.startActivity(intent2);
                        return;
                    }
                    messageListAdapter.messageListActivity.startActivity(new Intent("android.intent.action.VIEW", Uri.parse(messageEntity.redirectUrl)));
                }
            });
        }
    }

    /* Return type fixed from 'androidx.recyclerview.widget.RecyclerView$ViewHolder' to match base method */
    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i) {
        return new ViewHolder(GeneratedOutlineSupport.outline5(viewGroup, R.layout.list_item_message, viewGroup, false));
    }
}
