package com.faster.cheetah.sdk.strongswan.logic;

import android.app.Service;
import android.content.Context;
import android.content.Intent;
import android.os.Binder;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.IBinder;
import android.os.Message;
import android.os.SystemClock;
import androidx.core.content.ContextCompat;
import com.faster.cheetah.sdk.strongswan.data.VpnProfile;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import com.faster.cheetah.sdk.strongswan.data.VpnType;
import com.faster.cheetah.sdk.strongswan.logic.imc.ImcState;
import com.faster.cheetah.sdk.strongswan.logic.imc.RemediationInstruction;
import java.lang.ref.WeakReference;
import java.util.Collections;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.concurrent.Callable;

public class VpnStateService extends Service {
    private static long MAX_RETRY_INTERVAL = 120000;
    private static long RETRY_INTERVAL = 1000;
    private static int RETRY_MSG = 1;
    private final IBinder mBinder = new LocalBinder();
    private long mConnectionID = 0;
    private ErrorState mError = ErrorState.NO_ERROR;
    private Handler mHandler;
    private ImcState mImcState = ImcState.UNKNOWN;
    private final HashSet<VpnStateListener> mListeners = new HashSet<>();
    private VpnProfile mProfile;
    private final LinkedList<RemediationInstruction> mRemediationInstructions = new LinkedList<>();
    private long mRetryIn;
    private long mRetryTimeout;
    private State mState = State.DISABLED;
    private RetryTimeoutProvider mTimeoutProvider = new RetryTimeoutProvider();

    /* renamed from: com.faster.cheetah.sdk.strongswan.logic.VpnStateService$7  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass7 {
        public static final /* synthetic */ int[] $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState;

        /* JADX WARNING: Can't wrap try/catch for region: R(14:0|1|2|3|4|5|6|7|8|9|10|11|12|14) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x003e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0028 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0033 */
        static {
            ErrorState.values();
            int[] iArr = new int[8];
            $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState = iArr;
            iArr[ErrorState.AUTH_FAILED.ordinal()] = 1;
            $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState[ErrorState.PEER_AUTH_FAILED.ordinal()] = 2;
            $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState[ErrorState.LOOKUP_FAILED.ordinal()] = 3;
            $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState[ErrorState.UNREACHABLE.ordinal()] = 4;
            $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState[ErrorState.PASSWORD_MISSING.ordinal()] = 5;
            try {
                $SwitchMap$com$faster$cheetah$sdk$strongswan$logic$VpnStateService$ErrorState[ErrorState.CERTIFICATE_UNAVAILABLE.ordinal()] = 6;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public enum ErrorState {
        NO_ERROR,
        AUTH_FAILED,
        PEER_AUTH_FAILED,
        LOOKUP_FAILED,
        UNREACHABLE,
        GENERIC_ERROR,
        PASSWORD_MISSING,
        CERTIFICATE_UNAVAILABLE
    }

    public class LocalBinder extends Binder {
        public LocalBinder() {
        }

        public VpnStateService getService() {
            return VpnStateService.this;
        }
    }

    public static class RetryHandler extends Handler {
        public WeakReference<VpnStateService> mService;

        public RetryHandler(VpnStateService vpnStateService) {
            this.mService = new WeakReference<>(vpnStateService);
        }

        public void handleMessage(Message message) {
            if (this.mService.get().mRetryTimeout > 0) {
                VpnStateService.access$1222(this.mService.get(), VpnStateService.RETRY_INTERVAL);
                if (this.mService.get().mRetryIn > 0) {
                    long uptimeMillis = VpnStateService.RETRY_INTERVAL + SystemClock.uptimeMillis();
                    Iterator it = this.mService.get().mListeners.iterator();
                    while (it.hasNext()) {
                        ((VpnStateListener) it.next()).stateChanged();
                    }
                    sendMessageAtTime(obtainMessage(VpnStateService.RETRY_MSG), uptimeMillis);
                    return;
                }
                this.mService.get().connect(null, false);
            }
        }
    }

    public static class RetryTimeoutProvider {
        private long mRetry;

        private RetryTimeoutProvider() {
        }

        private long getBaseTimeout(ErrorState errorState) {
            int ordinal = errorState.ordinal();
            if (ordinal == 2 || ordinal == 3 || ordinal == 4) {
                return 5000;
            }
            if (ordinal != 6) {
                return ordinal != 7 ? 10000 : 5000;
            }
            return 0;
        }

        public long getTimeout(ErrorState errorState) {
            long j = this.mRetry;
            this.mRetry = 1 + j;
            return Math.min((((long) (Math.pow(2.0d, (double) j) * ((double) getBaseTimeout(errorState)))) / 1000) * 1000, VpnStateService.MAX_RETRY_INTERVAL);
        }

        public void reset() {
            this.mRetry = 0;
        }
    }

    public enum State {
        DISABLED,
        CONNECTING,
        CONNECTED,
        DISCONNECTING
    }

    public interface VpnStateListener {
        void stateChanged();
    }

    public static /* synthetic */ long access$1222(VpnStateService vpnStateService, long j) {
        long j2 = vpnStateService.mRetryIn - j;
        vpnStateService.mRetryIn = j2;
        return j2;
    }

    public static /* synthetic */ long access$308(VpnStateService vpnStateService) {
        long j = vpnStateService.mConnectionID;
        vpnStateService.mConnectionID = 1 + j;
        return j;
    }

    private void notifyListeners(final Callable<Boolean> callable) {
        this.mHandler.post(new Runnable() {
            /* class com.faster.cheetah.sdk.strongswan.logic.VpnStateService.AnonymousClass1 */

            public void run() {
                try {
                    if (((Boolean) callable.call()).booleanValue()) {
                        Iterator it = VpnStateService.this.mListeners.iterator();
                        while (it.hasNext()) {
                            ((VpnStateListener) it.next()).stateChanged();
                        }
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void resetRetryTimer() {
        this.mRetryTimeout = 0;
        this.mRetryIn = 0;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void setRetryTimer(ErrorState errorState) {
        long timeout = this.mTimeoutProvider.getTimeout(errorState);
        this.mRetryIn = timeout;
        this.mRetryTimeout = timeout;
        if (timeout > 0) {
            Handler handler = this.mHandler;
            handler.sendMessageAtTime(handler.obtainMessage(RETRY_MSG), SystemClock.uptimeMillis() + RETRY_INTERVAL);
        }
    }

    public void addRemediationInstruction(final RemediationInstruction remediationInstruction) {
        this.mHandler.post(new Runnable() {
            /* class com.faster.cheetah.sdk.strongswan.logic.VpnStateService.AnonymousClass6 */

            public void run() {
                VpnStateService.this.mRemediationInstructions.add(remediationInstruction);
            }
        });
    }

    public void connect(Bundle bundle, boolean z) {
        Context applicationContext = getApplicationContext();
        Intent intent = new Intent(applicationContext, CharonVpnService.class);
        if (bundle == null) {
            bundle = new Bundle();
            bundle.putString(VpnProfileDataSource.KEY_UUID, this.mProfile.getUUID().toString());
            bundle.putString(VpnProfileDataSource.KEY_PASSWORD, this.mProfile.getPassword());
        }
        if (z) {
            this.mTimeoutProvider.reset();
        } else {
            bundle.putBoolean(CharonVpnService.KEY_IS_RETRY, true);
        }
        intent.putExtras(bundle);
        Object obj = ContextCompat.sLock;
        if (Build.VERSION.SDK_INT >= 26) {
            applicationContext.startForegroundService(intent);
        } else {
            applicationContext.startService(intent);
        }
    }

    public void disconnect() {
        resetRetryTimer();
        setError(ErrorState.NO_ERROR);
        Context applicationContext = getApplicationContext();
        Intent intent = new Intent(applicationContext, CharonVpnService.class);
        intent.setAction(CharonVpnService.DISCONNECT_ACTION);
        applicationContext.startService(intent);
    }

    public long getConnectionID() {
        return this.mConnectionID;
    }

    public ErrorState getErrorState() {
        return this.mError;
    }

    public ImcState getImcState() {
        return this.mImcState;
    }

    public VpnProfile getProfile() {
        return this.mProfile;
    }

    public List<RemediationInstruction> getRemediationInstructions() {
        return Collections.unmodifiableList(this.mRemediationInstructions);
    }

    public int getRetryIn() {
        return (int) (this.mRetryIn / 1000);
    }

    public int getRetryTimeout() {
        return (int) (this.mRetryTimeout / 1000);
    }

    public State getState() {
        return this.mState;
    }

    public IBinder onBind(Intent intent) {
        return this.mBinder;
    }

    public void onCreate() {
        this.mHandler = new RetryHandler(this);
    }

    public void onDestroy() {
    }

    public void reconnect() {
        VpnProfile vpnProfile = this.mProfile;
        if (vpnProfile != null) {
            if (!vpnProfile.getVpnType().has(VpnType.VpnTypeFeature.USER_PASS) || !(this.mProfile.getPassword() == null || this.mError == ErrorState.AUTH_FAILED)) {
                connect(null, true);
            }
        }
    }

    public void registerListener(VpnStateListener vpnStateListener) {
        this.mListeners.add(vpnStateListener);
    }

    public void setError(final ErrorState errorState) {
        notifyListeners(new Callable<Boolean>() {
            /* class com.faster.cheetah.sdk.strongswan.logic.VpnStateService.AnonymousClass4 */

            @Override // java.util.concurrent.Callable
            public Boolean call() {
                if (VpnStateService.this.mError == errorState) {
                    return Boolean.FALSE;
                }
                ErrorState errorState = VpnStateService.this.mError;
                ErrorState errorState2 = ErrorState.NO_ERROR;
                if (errorState == errorState2) {
                    VpnStateService.this.setRetryTimer(errorState);
                } else if (errorState == errorState2) {
                    VpnStateService.this.resetRetryTimer();
                }
                VpnStateService.this.mError = errorState;
                return Boolean.TRUE;
            }
        });
    }

    public void setImcState(final ImcState imcState) {
        notifyListeners(new Callable<Boolean>() {
            /* class com.faster.cheetah.sdk.strongswan.logic.VpnStateService.AnonymousClass5 */

            @Override // java.util.concurrent.Callable
            public Boolean call() {
                if (imcState == ImcState.UNKNOWN) {
                    VpnStateService.this.mRemediationInstructions.clear();
                }
                ImcState imcState = VpnStateService.this.mImcState;
                ImcState imcState2 = imcState;
                if (imcState == imcState2) {
                    return Boolean.FALSE;
                }
                VpnStateService.this.mImcState = imcState2;
                return Boolean.TRUE;
            }
        });
    }

    public void setState(final State state) {
        notifyListeners(new Callable<Boolean>() {
            /* class com.faster.cheetah.sdk.strongswan.logic.VpnStateService.AnonymousClass3 */

            @Override // java.util.concurrent.Callable
            public Boolean call() {
                if (state == State.CONNECTED) {
                    VpnStateService.this.mTimeoutProvider.reset();
                }
                State state = VpnStateService.this.mState;
                State state2 = state;
                if (state == state2) {
                    return Boolean.FALSE;
                }
                VpnStateService.this.mState = state2;
                return Boolean.TRUE;
            }
        });
    }

    public void startConnection(final VpnProfile vpnProfile) {
        notifyListeners(new Callable<Boolean>() {
            /* class com.faster.cheetah.sdk.strongswan.logic.VpnStateService.AnonymousClass2 */

            @Override // java.util.concurrent.Callable
            public Boolean call() {
                VpnStateService.this.resetRetryTimer();
                VpnStateService.access$308(VpnStateService.this);
                VpnStateService.this.mProfile = vpnProfile;
                VpnStateService.this.mState = State.CONNECTING;
                VpnStateService.this.mError = ErrorState.NO_ERROR;
                VpnStateService.this.mImcState = ImcState.UNKNOWN;
                VpnStateService.this.mRemediationInstructions.clear();
                return Boolean.TRUE;
            }
        });
    }

    public void unregisterListener(VpnStateListener vpnStateListener) {
        this.mListeners.remove(vpnStateListener);
    }
}
