package com.github.shadowsocks.net;

import android.net.ConnectivityManager;
import android.net.Network;
import android.net.NetworkCapabilities;
import android.net.NetworkRequest;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.github.shadowsocks.Core;
import java.net.UnknownHostException;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.CoroutineContext;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.CompletableDeferred;
import kotlinx.coroutines.CompletableDeferredImpl;
import kotlinx.coroutines.CoroutineContextKt;
import kotlinx.coroutines.CoroutineDispatcher;
import kotlinx.coroutines.CoroutineStart;
import kotlinx.coroutines.Dispatchers;
import kotlinx.coroutines.GlobalScope;
import kotlinx.coroutines.channels.ActorCoroutine;
import kotlinx.coroutines.channels.Channel;
import kotlinx.coroutines.channels.LazyActorCoroutine;
import kotlinx.coroutines.channels.SendChannel;

/* compiled from: DefaultNetworkListener.kt */
public final class DefaultNetworkListener {
    public static final DefaultNetworkListener INSTANCE = new DefaultNetworkListener();
    public static boolean fallback;
    public static final SendChannel<NetworkMessage> networkActor;
    public static final NetworkRequest request;

    /* compiled from: DefaultNetworkListener.kt */
    public final class Callback extends ConnectivityManager.NetworkCallback {
        public static final Callback INSTANCE = new Callback();

        public void onAvailable(Network network) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            ViewGroupUtilsApi14.runBlocking$default(null, new DefaultNetworkListener$Callback$onAvailable$1(network, null), 1, null);
        }

        public void onCapabilitiesChanged(Network network, NetworkCapabilities networkCapabilities) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            ViewGroupUtilsApi14.runBlocking$default(null, new DefaultNetworkListener$Callback$onCapabilitiesChanged$1(network, null), 1, null);
        }

        public void onLost(Network network) {
            Intrinsics.checkParameterIsNotNull(network, "network");
            ViewGroupUtilsApi14.runBlocking$default(null, new DefaultNetworkListener$Callback$onLost$1(network, null), 1, null);
        }
    }

    /* compiled from: DefaultNetworkListener.kt */
    public abstract class NetworkMessage {

        /* compiled from: DefaultNetworkListener.kt */
        public final class Get extends NetworkMessage {
            public final CompletableDeferred<Network> response = ViewGroupUtilsApi14.CompletableDeferred$default(null, 1);

            public Get() {
                super(null);
            }
        }

        /* compiled from: DefaultNetworkListener.kt */
        public final class Lost extends NetworkMessage {
            public final Network network;

            /* JADX INFO: super call moved to the top of the method (can break code semantics) */
            public Lost(Network network2) {
                super(null);
                Intrinsics.checkParameterIsNotNull(network2, "network");
                this.network = network2;
            }
        }

        /* compiled from: DefaultNetworkListener.kt */
        public final class Put extends NetworkMessage {
            public final Network network;

            /* JADX INFO: super call moved to the top of the method (can break code semantics) */
            public Put(Network network2) {
                super(null);
                Intrinsics.checkParameterIsNotNull(network2, "network");
                this.network = network2;
            }
        }

        /* compiled from: DefaultNetworkListener.kt */
        public final class Start extends NetworkMessage {
            public final Object key;
            public final Function1<Network, Unit> listener;

            /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: kotlin.jvm.functions.Function1<? super android.net.Network, kotlin.Unit> */
            /* JADX WARN: Multi-variable type inference failed */
            /* JADX INFO: super call moved to the top of the method (can break code semantics) */
            public Start(Object obj, Function1<? super Network, Unit> function1) {
                super(null);
                Intrinsics.checkParameterIsNotNull(obj, "key");
                Intrinsics.checkParameterIsNotNull(function1, "listener");
                this.key = obj;
                this.listener = function1;
            }
        }

        /* compiled from: DefaultNetworkListener.kt */
        public final class Stop extends NetworkMessage {
            public final Object key;

            /* JADX INFO: super call moved to the top of the method (can break code semantics) */
            public Stop(Object obj) {
                super(null);
                Intrinsics.checkParameterIsNotNull(obj, "key");
                this.key = obj;
            }
        }

        /* compiled from: DefaultNetworkListener.kt */
        public final class Update extends NetworkMessage {
            public final Network network;

            /* JADX INFO: super call moved to the top of the method (can break code semantics) */
            public Update(Network network2) {
                super(null);
                Intrinsics.checkParameterIsNotNull(network2, "network");
                this.network = network2;
            }
        }

        public NetworkMessage(DefaultConstructorMarker defaultConstructorMarker) {
        }
    }

    static {
        ActorCoroutine actorCoroutine;
        GlobalScope globalScope = GlobalScope.INSTANCE;
        CoroutineDispatcher coroutineDispatcher = Dispatchers.Unconfined;
        DefaultNetworkListener$networkActor$1 defaultNetworkListener$networkActor$1 = new DefaultNetworkListener$networkActor$1(null);
        CoroutineStart coroutineStart = CoroutineStart.DEFAULT;
        Intrinsics.checkParameterIsNotNull(globalScope, "$this$actor");
        Intrinsics.checkParameterIsNotNull(coroutineDispatcher, "context");
        Intrinsics.checkParameterIsNotNull(coroutineStart, "start");
        Intrinsics.checkParameterIsNotNull(defaultNetworkListener$networkActor$1, "block");
        CoroutineContext newCoroutineContext = CoroutineContextKt.newCoroutineContext(globalScope, coroutineDispatcher);
        Channel Channel = ViewGroupUtilsApi14.Channel(0);
        if (coroutineStart.isLazy()) {
            actorCoroutine = new LazyActorCoroutine(newCoroutineContext, Channel, defaultNetworkListener$networkActor$1);
        } else {
            actorCoroutine = new ActorCoroutine(newCoroutineContext, Channel, true);
        }
        Intrinsics.checkParameterIsNotNull(coroutineStart, "start");
        Intrinsics.checkParameterIsNotNull(defaultNetworkListener$networkActor$1, "block");
        actorCoroutine.initParentJob$kotlinx_coroutines_core();
        coroutineStart.invoke(defaultNetworkListener$networkActor$1, actorCoroutine, actorCoroutine);
        networkActor = actorCoroutine;
        NetworkRequest.Builder builder = new NetworkRequest.Builder();
        builder.addCapability(12);
        builder.addCapability(13);
        request = builder.build();
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x0046  */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0085 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0022  */
    public final Object get(Continuation<? super Network> continuation) {
        DefaultNetworkListener$get$1 defaultNetworkListener$get$1;
        Object obj;
        CoroutineSingletons coroutineSingletons;
        int i;
        DefaultNetworkListener defaultNetworkListener;
        NetworkMessage.Get get;
        if (continuation instanceof DefaultNetworkListener$get$1) {
            defaultNetworkListener$get$1 = (DefaultNetworkListener$get$1) continuation;
            int i2 = defaultNetworkListener$get$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                defaultNetworkListener$get$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                obj = defaultNetworkListener$get$1.result;
                coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                i = defaultNetworkListener$get$1.label;
                if (i != 0) {
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    if (fallback) {
                        Network activeNetwork = Core.INSTANCE.getConnectivity().getActiveNetwork();
                        if (activeNetwork != null) {
                            return activeNetwork;
                        }
                        throw new UnknownHostException();
                    }
                    get = new NetworkMessage.Get();
                    SendChannel<NetworkMessage> sendChannel = networkActor;
                    defaultNetworkListener$get$1.L$0 = this;
                    defaultNetworkListener$get$1.L$1 = get;
                    defaultNetworkListener$get$1.label = 1;
                    if (sendChannel.send(get, defaultNetworkListener$get$1) == coroutineSingletons) {
                        return coroutineSingletons;
                    }
                    defaultNetworkListener = this;
                } else if (i == 1) {
                    get = (NetworkMessage.Get) defaultNetworkListener$get$1.L$1;
                    defaultNetworkListener = (DefaultNetworkListener) defaultNetworkListener$get$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                } else if (i == 2) {
                    NetworkMessage.Get get2 = (NetworkMessage.Get) defaultNetworkListener$get$1.L$1;
                    DefaultNetworkListener defaultNetworkListener2 = (DefaultNetworkListener) defaultNetworkListener$get$1.L$0;
                    ViewGroupUtilsApi14.throwOnFailure(obj);
                    return (Network) obj;
                } else {
                    throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
                CompletableDeferred<Network> completableDeferred = get.response;
                defaultNetworkListener$get$1.L$0 = defaultNetworkListener;
                defaultNetworkListener$get$1.L$1 = get;
                defaultNetworkListener$get$1.label = 2;
                obj = ((CompletableDeferredImpl) completableDeferred).await(defaultNetworkListener$get$1);
                if (obj == coroutineSingletons) {
                    return coroutineSingletons;
                }
                return (Network) obj;
            }
        }
        defaultNetworkListener$get$1 = new DefaultNetworkListener$get$1(this, continuation);
        obj = defaultNetworkListener$get$1.result;
        coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
        i = defaultNetworkListener$get$1.label;
        if (i != 0) {
        }
        CompletableDeferred<Network> completableDeferred2 = get.response;
        defaultNetworkListener$get$1.L$0 = defaultNetworkListener;
        defaultNetworkListener$get$1.L$1 = get;
        defaultNetworkListener$get$1.label = 2;
        obj = ((CompletableDeferredImpl) completableDeferred2).await(defaultNetworkListener$get$1);
        if (obj == coroutineSingletons) {
        }
        return (Network) obj;
    }
}
