package com.github.shadowsocks.net;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.github.shadowsocks.utils.UtilsKt;
import java.io.EOFException;
import java.io.IOException;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.nio.ByteBuffer;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.Charsets;

/* compiled from: Socks5Endpoint.kt */
public final class Socks5Endpoint {
    public final byte[] dest;
    public final int headerReserved;

    public Socks5Endpoint(String str, int i) {
        byte[] bArr;
        int i2;
        Intrinsics.checkParameterIsNotNull(str, "host");
        InetAddress parseNumericAddress = UtilsKt.parseNumericAddress(str);
        int i3 = 0;
        if (parseNumericAddress == null || (bArr = parseNumericAddress.getAddress()) == null) {
            bArr = str.getBytes(Charsets.UTF_8);
            Intrinsics.checkExpressionValueIsNotNull(bArr, "(this as java.lang.String).getBytes(charset)");
            if (!(bArr.length < 256)) {
                throw new IllegalStateException("Hostname too long".toString());
            }
        }
        if (parseNumericAddress == null) {
            i2 = 3;
        } else if (parseNumericAddress instanceof Inet4Address) {
            i2 = 1;
        } else if (parseNumericAddress instanceof Inet6Address) {
            i2 = 4;
        } else {
            throw new IllegalStateException(("Unsupported address type " + parseNumericAddress).toString());
        }
        ByteBuffer allocate = ByteBuffer.allocate(bArr.length + (parseNumericAddress == null ? 1 : i3) + 3);
        allocate.put((byte) i2);
        if (parseNumericAddress == null) {
            allocate.put((byte) bArr.length);
        }
        allocate.put(bArr);
        allocate.putShort((short) i);
        byte[] array = allocate.array();
        this.dest = array;
        this.headerReserved = Math.max(22, array.length + 3);
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0039  */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x0056  */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:13:0x0096  */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x00b3  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x00d0  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x00ed  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x010a  */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x012c  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x015e  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0182  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x01a1  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x01c3  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x01e2  */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x01ec  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0234 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x0235  */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x0257  */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x028b  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x02b5  */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x02cd  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x02e2  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x02f9  */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x0031  */
    public final Object tcpUnwrap(ByteBuffer byteBuffer, Function1<? super ByteBuffer, Integer> function1, Function1<? super Continuation<? super Unit>, ? extends Object> function12, Continuation<? super Unit> continuation) {
        Socks5Endpoint$tcpUnwrap$1 socks5Endpoint$tcpUnwrap$1;
        ByteBuffer byteBuffer2;
        Socks5Endpoint socks5Endpoint;
        Function1<? super ByteBuffer, Integer> function13;
        Function1<? super Continuation<? super Unit>, ? extends Object> function14;
        int i;
        Socks5Endpoint$tcpUnwrap$2 socks5Endpoint$tcpUnwrap$2;
        Socks5Endpoint$tcpUnwrap$3 socks5Endpoint$tcpUnwrap$3;
        int position;
        Socks5Endpoint socks5Endpoint2;
        ByteBuffer byteBuffer3;
        Function1<? super ByteBuffer, Integer> function15;
        Socks5Endpoint$tcpUnwrap$2 socks5Endpoint$tcpUnwrap$22;
        Socks5Endpoint$tcpUnwrap$3 socks5Endpoint$tcpUnwrap$32;
        int intValue;
        byte byteValue;
        Socks5Endpoint socks5Endpoint3;
        Socks5Endpoint socks5Endpoint4;
        ByteBuffer byteBuffer4;
        Object obj;
        Socks5Endpoint$tcpUnwrap$2 socks5Endpoint$tcpUnwrap$23;
        Function1<? super ByteBuffer, Integer> function16 = function1;
        Function1<? super Continuation<? super Unit>, ? extends Object> function17 = function12;
        if (continuation instanceof Socks5Endpoint$tcpUnwrap$1) {
            socks5Endpoint$tcpUnwrap$1 = (Socks5Endpoint$tcpUnwrap$1) continuation;
            int i2 = socks5Endpoint$tcpUnwrap$1.label;
            if ((i2 & LinearLayoutManager.INVALID_OFFSET) != 0) {
                socks5Endpoint$tcpUnwrap$1.label = i2 - LinearLayoutManager.INVALID_OFFSET;
                Object obj2 = socks5Endpoint$tcpUnwrap$1.result;
                CoroutineSingletons coroutineSingletons = CoroutineSingletons.COROUTINE_SUSPENDED;
                int i3 = 1;
                switch (socks5Endpoint$tcpUnwrap$1.label) {
                    case 0:
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        socks5Endpoint$tcpUnwrap$23 = new Socks5Endpoint$tcpUnwrap$2(byteBuffer, function16, function17, null);
                        Socks5Endpoint$tcpUnwrap$3 socks5Endpoint$tcpUnwrap$33 = new Socks5Endpoint$tcpUnwrap$3(socks5Endpoint$tcpUnwrap$23, byteBuffer, null);
                        socks5Endpoint$tcpUnwrap$1.L$0 = this;
                        socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer;
                        socks5Endpoint$tcpUnwrap$1.L$2 = function16;
                        socks5Endpoint$tcpUnwrap$1.L$3 = function17;
                        socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$23;
                        socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$33;
                        socks5Endpoint$tcpUnwrap$1.label = 1;
                        obj = socks5Endpoint$tcpUnwrap$33.invoke(0, socks5Endpoint$tcpUnwrap$1);
                        if (obj == coroutineSingletons) {
                            return coroutineSingletons;
                        }
                        socks5Endpoint4 = this;
                        byteBuffer4 = byteBuffer;
                        socks5Endpoint$tcpUnwrap$32 = socks5Endpoint$tcpUnwrap$33;
                        if (((Number) obj).byteValue() != ((byte) 5)) {
                            socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint4;
                            socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer4;
                            socks5Endpoint$tcpUnwrap$1.L$2 = function16;
                            socks5Endpoint$tcpUnwrap$1.L$3 = function17;
                            socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$23;
                            socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$32;
                            socks5Endpoint$tcpUnwrap$1.label = 2;
                            Object invoke = socks5Endpoint$tcpUnwrap$32.invoke(1, socks5Endpoint$tcpUnwrap$1);
                            if (invoke == coroutineSingletons) {
                                return coroutineSingletons;
                            }
                            function15 = function16;
                            socks5Endpoint$tcpUnwrap$22 = socks5Endpoint$tcpUnwrap$23;
                            obj2 = invoke;
                            if (((Number) obj2).byteValue() != ((byte) 0)) {
                                socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint4;
                                socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer4;
                                socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                                socks5Endpoint$tcpUnwrap$1.L$3 = function17;
                                socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$22;
                                socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$32;
                                socks5Endpoint$tcpUnwrap$1.label = 3;
                                obj2 = socks5Endpoint$tcpUnwrap$32.invoke(2, socks5Endpoint$tcpUnwrap$1);
                                if (obj2 == coroutineSingletons) {
                                    return coroutineSingletons;
                                }
                                if (((Number) obj2).byteValue() != ((byte) 5)) {
                                    socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint4;
                                    socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer4;
                                    socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                                    socks5Endpoint$tcpUnwrap$1.L$3 = function17;
                                    socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$22;
                                    socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$32;
                                    socks5Endpoint$tcpUnwrap$1.label = 4;
                                    obj2 = socks5Endpoint$tcpUnwrap$32.invoke(3, socks5Endpoint$tcpUnwrap$1);
                                    if (obj2 == coroutineSingletons) {
                                        return coroutineSingletons;
                                    }
                                    byteBuffer3 = byteBuffer4;
                                    socks5Endpoint3 = socks5Endpoint4;
                                    if (((Number) obj2).byteValue() != ((byte) 0)) {
                                        socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint3;
                                        socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer3;
                                        socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                                        socks5Endpoint$tcpUnwrap$1.L$3 = function17;
                                        socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$22;
                                        socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$32;
                                        socks5Endpoint$tcpUnwrap$1.label = 5;
                                        obj2 = socks5Endpoint$tcpUnwrap$32.invoke(5, socks5Endpoint$tcpUnwrap$1);
                                        if (obj2 == coroutineSingletons) {
                                            return coroutineSingletons;
                                        }
                                        socks5Endpoint2 = socks5Endpoint3;
                                        byteValue = ((Number) obj2).byteValue();
                                        if (byteValue != ((byte) 1)) {
                                            intValue = 4;
                                        } else if (byteValue == ((byte) 3)) {
                                            socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint2;
                                            socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer3;
                                            socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                                            socks5Endpoint$tcpUnwrap$1.L$3 = function17;
                                            socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$22;
                                            socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$32;
                                            socks5Endpoint$tcpUnwrap$1.B$0 = byteValue;
                                            socks5Endpoint$tcpUnwrap$1.I$0 = 1;
                                            socks5Endpoint$tcpUnwrap$1.label = 6;
                                            obj2 = socks5Endpoint$tcpUnwrap$32.invoke(6, socks5Endpoint$tcpUnwrap$1);
                                            if (obj2 == coroutineSingletons) {
                                                return coroutineSingletons;
                                            }
                                            intValue = ((Number) obj2).intValue() + i3;
                                        } else if (byteValue == ((byte) 4)) {
                                            intValue = 16;
                                        } else {
                                            throw new IOException(GeneratedOutlineSupport.outline11("Unsupported address type ", byteValue));
                                        }
                                        socks5Endpoint = socks5Endpoint2;
                                        socks5Endpoint$tcpUnwrap$3 = socks5Endpoint$tcpUnwrap$32;
                                        function14 = function17;
                                        socks5Endpoint$tcpUnwrap$2 = socks5Endpoint$tcpUnwrap$22;
                                        i = intValue + 8;
                                        socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint;
                                        socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer3;
                                        socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                                        socks5Endpoint$tcpUnwrap$1.L$3 = function14;
                                        socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$2;
                                        socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$3;
                                        socks5Endpoint$tcpUnwrap$1.I$0 = i;
                                        socks5Endpoint$tcpUnwrap$1.label = 7;
                                        if (socks5Endpoint$tcpUnwrap$2.invoke(i + 2, socks5Endpoint$tcpUnwrap$1) == coroutineSingletons) {
                                            return coroutineSingletons;
                                        }
                                        function13 = function15;
                                        byteBuffer2 = byteBuffer3;
                                        byteBuffer2.limit(byteBuffer2.position());
                                        byteBuffer2.position(i);
                                        int i4 = byteBuffer2.getShort() & 65535;
                                        position = byteBuffer2.position() + i4;
                                        if (position > byteBuffer2.capacity()) {
                                            byteBuffer2.mark();
                                            byteBuffer2.position(byteBuffer2.limit());
                                            byteBuffer2.limit(position);
                                            int limit = byteBuffer2.limit();
                                            socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint;
                                            socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer2;
                                            socks5Endpoint$tcpUnwrap$1.L$2 = function13;
                                            socks5Endpoint$tcpUnwrap$1.L$3 = function14;
                                            socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$2;
                                            socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$3;
                                            socks5Endpoint$tcpUnwrap$1.I$0 = i;
                                            socks5Endpoint$tcpUnwrap$1.I$1 = i4;
                                            socks5Endpoint$tcpUnwrap$1.I$2 = position;
                                            socks5Endpoint$tcpUnwrap$1.label = 8;
                                            if (socks5Endpoint$tcpUnwrap$2.invoke(limit, socks5Endpoint$tcpUnwrap$1) == coroutineSingletons) {
                                                return coroutineSingletons;
                                            }
                                            byteBuffer2.reset();
                                            return Unit.INSTANCE;
                                        }
                                        StringBuilder outline26 = GeneratedOutlineSupport.outline26("Buffer too small to contain the message: ", i4, " > ");
                                        outline26.append(byteBuffer2.capacity() - byteBuffer2.position());
                                        throw new IOException(outline26.toString());
                                    }
                                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("SOCKS5 server returned error ");
                                    outline25.append((int) byteBuffer3.get(3));
                                    throw new IOException(outline25.toString());
                                }
                                StringBuilder outline252 = GeneratedOutlineSupport.outline25("Unsupported SOCKS version ");
                                outline252.append((int) byteBuffer4.get(2));
                                throw new IOException(outline252.toString());
                            }
                            StringBuilder outline253 = GeneratedOutlineSupport.outline25("Unsupported authentication ");
                            outline253.append((int) byteBuffer4.get(1));
                            throw new IOException(outline253.toString());
                        }
                        StringBuilder outline254 = GeneratedOutlineSupport.outline25("Unsupported SOCKS version ");
                        outline254.append((int) byteBuffer4.get(0));
                        throw new IOException(outline254.toString());
                    case 1:
                        socks5Endpoint$tcpUnwrap$32 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        function17 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        byteBuffer4 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        socks5Endpoint4 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        socks5Endpoint$tcpUnwrap$23 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function16 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        obj = obj2;
                        if (((Number) obj).byteValue() != ((byte) 5)) {
                        }
                        break;
                    case 2:
                        socks5Endpoint$tcpUnwrap$32 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        socks5Endpoint$tcpUnwrap$22 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function17 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        function15 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        byteBuffer4 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        socks5Endpoint4 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        if (((Number) obj2).byteValue() != ((byte) 0)) {
                        }
                        break;
                    case 3:
                        socks5Endpoint$tcpUnwrap$32 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        socks5Endpoint$tcpUnwrap$22 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function17 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        function15 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        byteBuffer4 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        socks5Endpoint4 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        if (((Number) obj2).byteValue() != ((byte) 5)) {
                        }
                        break;
                    case 4:
                        socks5Endpoint$tcpUnwrap$32 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        socks5Endpoint$tcpUnwrap$22 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function17 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        function15 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        byteBuffer3 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        socks5Endpoint3 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        if (((Number) obj2).byteValue() != ((byte) 0)) {
                        }
                        break;
                    case 5:
                        socks5Endpoint$tcpUnwrap$32 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        socks5Endpoint$tcpUnwrap$22 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function17 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        function15 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        byteBuffer3 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        socks5Endpoint2 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        byteValue = ((Number) obj2).byteValue();
                        if (byteValue != ((byte) 1)) {
                        }
                        socks5Endpoint = socks5Endpoint2;
                        socks5Endpoint$tcpUnwrap$3 = socks5Endpoint$tcpUnwrap$32;
                        function14 = function17;
                        socks5Endpoint$tcpUnwrap$2 = socks5Endpoint$tcpUnwrap$22;
                        i = intValue + 8;
                        socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint;
                        socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer3;
                        socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                        socks5Endpoint$tcpUnwrap$1.L$3 = function14;
                        socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$2;
                        socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$3;
                        socks5Endpoint$tcpUnwrap$1.I$0 = i;
                        socks5Endpoint$tcpUnwrap$1.label = 7;
                        if (socks5Endpoint$tcpUnwrap$2.invoke(i + 2, socks5Endpoint$tcpUnwrap$1) == coroutineSingletons) {
                        }
                        break;
                    case 6:
                        i3 = socks5Endpoint$tcpUnwrap$1.I$0;
                        socks5Endpoint$tcpUnwrap$32 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        socks5Endpoint$tcpUnwrap$22 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function17 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        function15 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        byteBuffer3 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        socks5Endpoint2 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        intValue = ((Number) obj2).intValue() + i3;
                        socks5Endpoint = socks5Endpoint2;
                        socks5Endpoint$tcpUnwrap$3 = socks5Endpoint$tcpUnwrap$32;
                        function14 = function17;
                        socks5Endpoint$tcpUnwrap$2 = socks5Endpoint$tcpUnwrap$22;
                        i = intValue + 8;
                        socks5Endpoint$tcpUnwrap$1.L$0 = socks5Endpoint;
                        socks5Endpoint$tcpUnwrap$1.L$1 = byteBuffer3;
                        socks5Endpoint$tcpUnwrap$1.L$2 = function15;
                        socks5Endpoint$tcpUnwrap$1.L$3 = function14;
                        socks5Endpoint$tcpUnwrap$1.L$4 = socks5Endpoint$tcpUnwrap$2;
                        socks5Endpoint$tcpUnwrap$1.L$5 = socks5Endpoint$tcpUnwrap$3;
                        socks5Endpoint$tcpUnwrap$1.I$0 = i;
                        socks5Endpoint$tcpUnwrap$1.label = 7;
                        if (socks5Endpoint$tcpUnwrap$2.invoke(i + 2, socks5Endpoint$tcpUnwrap$1) == coroutineSingletons) {
                        }
                        break;
                    case 7:
                        int i5 = socks5Endpoint$tcpUnwrap$1.I$0;
                        socks5Endpoint$tcpUnwrap$3 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        socks5Endpoint$tcpUnwrap$2 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        function14 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        function13 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        socks5Endpoint = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        i = i5;
                        byteBuffer2 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        byteBuffer2.limit(byteBuffer2.position());
                        byteBuffer2.position(i);
                        int i42 = byteBuffer2.getShort() & 65535;
                        position = byteBuffer2.position() + i42;
                        if (position > byteBuffer2.capacity()) {
                        }
                        break;
                    case 8:
                        Socks5Endpoint$tcpUnwrap$3 socks5Endpoint$tcpUnwrap$34 = (Socks5Endpoint$tcpUnwrap$3) socks5Endpoint$tcpUnwrap$1.L$5;
                        Socks5Endpoint$tcpUnwrap$2 socks5Endpoint$tcpUnwrap$24 = (Socks5Endpoint$tcpUnwrap$2) socks5Endpoint$tcpUnwrap$1.L$4;
                        Function1 function18 = (Function1) socks5Endpoint$tcpUnwrap$1.L$3;
                        Function1 function19 = (Function1) socks5Endpoint$tcpUnwrap$1.L$2;
                        byteBuffer2 = (ByteBuffer) socks5Endpoint$tcpUnwrap$1.L$1;
                        Socks5Endpoint socks5Endpoint5 = (Socks5Endpoint) socks5Endpoint$tcpUnwrap$1.L$0;
                        ViewGroupUtilsApi14.throwOnFailure(obj2);
                        byteBuffer2.reset();
                        return Unit.INSTANCE;
                    default:
                        throw new IllegalStateException("call to 'resume' before 'invoke' with coroutine");
                }
            }
        }
        socks5Endpoint$tcpUnwrap$1 = new Socks5Endpoint$tcpUnwrap$1(this, continuation);
        Object obj22 = socks5Endpoint$tcpUnwrap$1.result;
        CoroutineSingletons coroutineSingletons2 = CoroutineSingletons.COROUTINE_SUSPENDED;
        int i32 = 1;
        switch (socks5Endpoint$tcpUnwrap$1.label) {
        }
    }

    public final ByteBuffer tcpWrap(ByteBuffer byteBuffer) {
        Intrinsics.checkParameterIsNotNull(byteBuffer, "message");
        if (byteBuffer.remaining() < 65536) {
            ByteBuffer allocateDirect = ByteBuffer.allocateDirect(byteBuffer.remaining() + this.dest.length + 8);
            byte b = (byte) 5;
            allocateDirect.put(b);
            allocateDirect.put((byte) 1);
            allocateDirect.put((byte) 0);
            allocateDirect.put(b);
            allocateDirect.put((byte) 1);
            allocateDirect.put((byte) 0);
            allocateDirect.put(this.dest);
            allocateDirect.putShort((short) byteBuffer.remaining());
            allocateDirect.put(byteBuffer);
            allocateDirect.flip();
            Intrinsics.checkExpressionValueIsNotNull(allocateDirect, "ByteBuffer.allocateDirec…         flip()\n        }");
            return allocateDirect;
        }
        throw new IllegalStateException("TCP message too large".toString());
    }

    public final void tryPosition(ByteBuffer byteBuffer, int i) {
        if (byteBuffer.limit() >= i) {
            byteBuffer.position(i);
            return;
        }
        throw new EOFException(byteBuffer.limit() + " < " + i);
    }

    public final void udpUnwrap(ByteBuffer byteBuffer) {
        Intrinsics.checkParameterIsNotNull(byteBuffer, "packet");
        tryPosition(byteBuffer, 3);
        byte b = byteBuffer.get();
        int i = 4;
        if (b != ((byte) 1)) {
            if (b == ((byte) 3)) {
                i = byteBuffer.get() + 1;
            } else if (b == ((byte) 4)) {
                i = 16;
            } else {
                throw new IOException(GeneratedOutlineSupport.outline11("Unsupported address type ", b));
            }
        }
        tryPosition(byteBuffer, i + 6);
        byteBuffer.mark();
    }
}
