package com.github.shadowsocks.net;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.github.shadowsocks.utils.UtilsKt;
import java.net.InetAddress;
import java.util.Comparator;
import java.util.List;
import java.util.Objects;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;

/* compiled from: Subnet.kt */
public final class Subnet implements Comparable<Subnet> {
    public static final Companion Companion = new Companion(null);
    public final InetAddress address;
    public final int prefixSize;

    /* compiled from: Subnet.kt */
    public final class Companion {
        public Companion(DefaultConstructorMarker defaultConstructorMarker) {
        }

        public static Subnet fromString$default(Companion companion, String str, int i, int i2) {
            if ((i2 & 2) != 0) {
                i = -1;
            }
            Intrinsics.checkParameterIsNotNull(str, "value");
            boolean z = false;
            List split$default = StringsKt__IndentKt.split$default((CharSequence) str, new char[]{'/'}, false, 2, 2);
            InetAddress parseNumericAddress = UtilsKt.parseNumericAddress((String) split$default.get(0));
            if (parseNumericAddress == null) {
                return null;
            }
            if (i < 0 || parseNumericAddress.getAddress().length == i) {
                z = true;
            }
            if (!z) {
                throw new IllegalStateException("Check failed.".toString());
            } else if (split$default.size() != 2) {
                return new Subnet(parseNumericAddress, parseNumericAddress.getAddress().length << 3);
            } else {
                try {
                    int parseInt = Integer.parseInt((String) split$default.get(1));
                    if (parseInt < 0) {
                        return null;
                    }
                    if (parseInt > (parseNumericAddress.getAddress().length << 3)) {
                        return null;
                    }
                    return new Subnet(parseNumericAddress, parseInt);
                } catch (NumberFormatException unused) {
                    return null;
                }
            }
        }
    }

    public Subnet(InetAddress inetAddress, int i) {
        Intrinsics.checkParameterIsNotNull(inetAddress, "address");
        this.address = inetAddress;
        this.prefixSize = i;
        if (!(i >= 0 && getAddressLength() >= i)) {
            StringBuilder outline26 = GeneratedOutlineSupport.outline26("prefixSize ", i, " not in 0..");
            outline26.append(getAddressLength());
            throw new IllegalArgumentException(outline26.toString().toString());
        }
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
    @Override // java.lang.Comparable
    public int compareTo(Subnet subnet) {
        Subnet subnet2 = subnet;
        Intrinsics.checkParameterIsNotNull(subnet2, "other");
        byte[] address2 = this.address.getAddress();
        byte[] address3 = subnet2.address.getAddress();
        int compare = Intrinsics.compare(address2.length, address3.length);
        if (compare != 0) {
            return compare;
        }
        Intrinsics.checkExpressionValueIsNotNull(address2, "addrThis");
        int length = address2.length;
        for (int i = 0; i < length; i++) {
            int compare2 = Intrinsics.compare(address2[i] & 255, address3[i] & 255);
            if (compare2 != 0) {
                return compare2;
            }
        }
        return Intrinsics.compare(this.prefixSize, subnet2.prefixSize);
    }

    public boolean equals(Object obj) {
        InetAddress inetAddress = null;
        if (!(obj instanceof Subnet)) {
            obj = null;
        }
        Subnet subnet = (Subnet) obj;
        InetAddress inetAddress2 = this.address;
        if (subnet != null) {
            inetAddress = subnet.address;
        }
        return Intrinsics.areEqual(inetAddress2, inetAddress) && this.prefixSize == subnet.prefixSize;
    }

    public final int getAddressLength() {
        return this.address.getAddress().length << 3;
    }

    public int hashCode() {
        return Objects.hash(this.address, Integer.valueOf(this.prefixSize));
    }

    public String toString() {
        if (this.prefixSize == getAddressLength()) {
            String hostAddress = this.address.getHostAddress();
            Intrinsics.checkExpressionValueIsNotNull(hostAddress, "address.hostAddress");
            return hostAddress;
        }
        return this.address.getHostAddress() + '/' + this.prefixSize;
    }

    /* compiled from: Subnet.kt */
    public final class Immutable {
        public static final Companion Companion = new Companion(null);
        public final byte[] a;
        public final int prefixSize;

        /* compiled from: Subnet.kt */
        public final class Companion implements Comparator<Immutable> {
            public Companion(DefaultConstructorMarker defaultConstructorMarker) {
            }

            /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, java.lang.Object] */
            @Override // java.util.Comparator
            public int compare(Immutable immutable, Immutable immutable2) {
                Immutable immutable3 = immutable;
                Immutable immutable4 = immutable2;
                Intrinsics.checkParameterIsNotNull(immutable3, "a");
                Intrinsics.checkParameterIsNotNull(immutable4, "b");
                byte[] bArr = immutable3.a;
                if (bArr.length == immutable4.a.length) {
                    int length = bArr.length;
                    for (int i = 0; i < length; i++) {
                        int compare = Intrinsics.compare(immutable3.a[i], immutable4.a[i]);
                        if (compare != 0) {
                            return compare;
                        }
                    }
                    return 0;
                }
                throw new IllegalStateException("Check failed.".toString());
            }
        }

        public Immutable(byte[] bArr, int i, int i2) {
            i = (i2 & 2) != 0 ? 0 : i;
            Intrinsics.checkParameterIsNotNull(bArr, "a");
            this.a = bArr;
            this.prefixSize = i;
        }

        public final boolean matches(byte[] bArr) {
            int i;
            int i2;
            Intrinsics.checkParameterIsNotNull(bArr, "b");
            if (this.a.length != bArr.length) {
                return false;
            }
            int i3 = 0;
            while (true) {
                i = i3 * 8;
                i2 = this.prefixSize;
                if (i < i2 && i + 8 <= i2) {
                    if (this.a[i3] != bArr[i3]) {
                        return false;
                    }
                    i3++;
                }
            }
            if (i == i2 || this.a[i3] == ((byte) (bArr[i3] & (-(1 << ((i + 8) - i2)))))) {
                return true;
            }
            return false;
        }

        public Immutable(byte[] bArr, int i) {
            Intrinsics.checkParameterIsNotNull(bArr, "a");
            this.a = bArr;
            this.prefixSize = i;
        }
    }
}
