package com.github.shadowsocks.plugin;

import android.annotation.SuppressLint;
import android.content.BroadcastReceiver;
import android.content.ContentResolver;
import android.content.Intent;
import android.content.pm.ComponentInfo;
import android.content.pm.PackageManager;
import android.content.pm.ProviderInfo;
import android.content.pm.ResolveInfo;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.system.Os;
import android.util.Log;
import androidx.appcompat.app.AppCompatDelegateImpl;
import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.github.shadowsocks.Core;
import com.github.shadowsocks.bg.BaseService$ExpectedException;
import com.github.shadowsocks.core.R$string;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.List;
import java.util.Objects;
import kotlin.Lazy;
import kotlin.Pair;
import kotlin.collections.ArraysKt___ArraysKt;
import kotlin.io.FilesKt__FileReadWriteKt;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.PropertyReference1Impl;
import kotlin.jvm.internal.Reflection;
import kotlin.reflect.KProperty;
import kotlin.text.StringsKt__IndentKt;

/* compiled from: PluginManager.kt */
public final class PluginManager {
    public static final /* synthetic */ KProperty[] $$delegatedProperties;
    public static final PluginManager INSTANCE = new PluginManager();
    public static PluginList cachedPlugins;
    public static BroadcastReceiver receiver;
    public static final Lazy trustedSignatures$delegate = ViewGroupUtilsApi14.lazy(PluginManager$trustedSignatures$2.INSTANCE);

    /* compiled from: PluginManager.kt */
    public final class PluginNotFoundException extends FileNotFoundException implements BaseService$ExpectedException {
        private final String plugin;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public PluginNotFoundException(String str) {
            super(str);
            Intrinsics.checkParameterIsNotNull(str, "plugin");
            this.plugin = str;
        }

        public String getLocalizedMessage() {
            String string = Core.INSTANCE.getApp().getString(R$string.plugin_unknown, new Object[]{this.plugin});
            Intrinsics.checkExpressionValueIsNotNull(string, "app.getString(com.github…g.plugin_unknown, plugin)");
            return string;
        }
    }

    static {
        PropertyReference1Impl propertyReference1Impl = new PropertyReference1Impl(Reflection.getOrCreateKotlinClass(PluginManager.class), "trustedSignatures", "getTrustedSignatures()Ljava/util/Set;");
        Objects.requireNonNull(Reflection.factory);
        $$delegatedProperties = new KProperty[]{propertyReference1Impl};
    }

    public final Pair<String, PluginOptions> initNative(PluginConfiguration pluginConfiguration) {
        Throwable th;
        PackageManager packageManager = Core.INSTANCE.getApp().getPackageManager();
        String str = pluginConfiguration.selected;
        List<ResolveInfo> queryIntentContentProviders = packageManager.queryIntentContentProviders(new Intent("com.github.shadowsocks.plugin.ACTION_NATIVE_PLUGIN", new Uri.Builder().scheme("plugin").authority("com.github.shadowsocks").path('/' + str).build()), 786560);
        if (queryIntentContentProviders.isEmpty()) {
            return null;
        }
        Intrinsics.checkExpressionValueIsNotNull(queryIntentContentProviders, "providers");
        ProviderInfo providerInfo = ((ResolveInfo) ArraysKt___ArraysKt.single(queryIntentContentProviders)).providerInfo;
        PluginOptions options$default = PluginConfiguration.getOptions$default(pluginConfiguration, null, new PluginManager$initNative$options$1(providerInfo), 1);
        try {
            Intrinsics.checkExpressionValueIsNotNull(providerInfo, "provider");
            String initNativeFaster = initNativeFaster(providerInfo);
            if (initNativeFaster != null) {
                return new Pair<>(initNativeFaster, options$default);
            }
            th = null;
            Uri.Builder builder = new Uri.Builder();
            builder.scheme("content");
            builder.authority(providerInfo.authority);
            Uri build = builder.build();
            try {
                ContentResolver contentResolver = Core.INSTANCE.getApp().getContentResolver();
                Intrinsics.checkExpressionValueIsNotNull(contentResolver, "app.contentResolver");
                Intrinsics.checkExpressionValueIsNotNull(build, "uri");
                String initNativeFast = initNativeFast(contentResolver, options$default, build);
                if (initNativeFast != null) {
                    return new Pair<>(initNativeFast, options$default);
                }
                return null;
            } catch (Throwable th2) {
                th2.addSuppressed(th);
                throw th2;
            }
        } catch (Throwable th3) {
            th = th3;
            Log.w("PluginManager", "Initializing native plugin faster mode failed");
        }
    }

    public final String initNativeFast(ContentResolver contentResolver, PluginOptions pluginOptions, Uri uri) {
        String string;
        Bundle call = contentResolver.call(uri, "shadowsocks:getExecutable", (String) null, AppCompatDelegateImpl.Api17Impl.bundleOf(new Pair("com.github.shadowsocks.plugin.EXTRA_OPTIONS", pluginOptions.getId())));
        if (call == null || (string = call.getString("com.github.shadowsocks.plugin.EXTRA_ENTRY")) == null) {
            return null;
        }
        if (new File(string).canExecute()) {
            return string;
        }
        throw new IllegalStateException("Check failed.".toString());
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x0085  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0087  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x008b  */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x00d8  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x00dd  */
    public final String initNativeFaster(ProviderInfo providerInfo) {
        int i;
        File file;
        char c;
        int indexOf$default;
        String loadString = loadString(providerInfo, "com.github.shadowsocks.plugin.executable_path");
        if (loadString == null) {
            return null;
        }
        File file2 = new File(providerInfo.applicationInfo.nativeLibraryDir);
        Intrinsics.checkNotNullParameter(file2, "$this$resolve");
        Intrinsics.checkNotNullParameter(loadString, "relative");
        File file3 = new File(loadString);
        Intrinsics.checkNotNullParameter(file2, "$this$resolve");
        Intrinsics.checkNotNullParameter(file3, "relative");
        Intrinsics.checkNotNullParameter(file3, "$this$isRooted");
        String path = file3.getPath();
        Intrinsics.checkNotNullExpressionValue(path, "path");
        int indexOf$default2 = StringsKt__IndentKt.indexOf$default((CharSequence) path, File.separatorChar, 0, false, 4);
        boolean z = true;
        if (indexOf$default2 == 0) {
            if (path.length() <= 1 || path.charAt(1) != (c = File.separatorChar) || (indexOf$default = StringsKt__IndentKt.indexOf$default((CharSequence) path, c, 2, false, 4)) < 0) {
                i = 1;
                if (!(i <= 0)) {
                    String file4 = file2.toString();
                    Intrinsics.checkNotNullExpressionValue(file4, "this.toString()");
                    if (file4.length() != 0) {
                        z = false;
                    }
                    if (z || StringsKt__IndentKt.endsWith$default((CharSequence) file4, File.separatorChar, false, 2)) {
                        file = new File(file4 + file3);
                    } else {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25(file4);
                        outline25.append(File.separatorChar);
                        outline25.append(file3);
                        file = new File(outline25.toString());
                    }
                    file3 = file;
                }
                if (!file3.canExecute()) {
                    return file3.getAbsolutePath();
                }
                throw new IllegalStateException("Check failed.".toString());
            }
            indexOf$default2 = StringsKt__IndentKt.indexOf$default((CharSequence) path, File.separatorChar, indexOf$default + 1, false, 4);
            if (indexOf$default2 < 0) {
                i = path.length();
                if (!(i <= 0)) {
                }
                if (!file3.canExecute()) {
                }
            }
        } else if (indexOf$default2 <= 0 || path.charAt(indexOf$default2 - 1) != ':') {
            i = (indexOf$default2 != -1 || !StringsKt__IndentKt.endsWith$default(path, ':', false, 2)) ? 0 : path.length();
            if (!(i <= 0)) {
            }
            if (!file3.canExecute()) {
            }
        }
        i = indexOf$default2 + 1;
        if (!(i <= 0)) {
        }
        if (!file3.canExecute()) {
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:40:0x00e8, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x00e9, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r12, r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00ed, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:47:0x00f1, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:0x00f2, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r9, r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x00f6, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x0116, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:63:0x0117, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r2, r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x011b, code lost:
        throw r0;
     */
    @SuppressLint({"Recycle"})
    public final String initNativeSlow(ContentResolver contentResolver, PluginOptions pluginOptions, Uri uri) {
        int i;
        PluginManager$initNativeSlow$1 pluginManager$initNativeSlow$1 = PluginManager$initNativeSlow$1.INSTANCE;
        File file = new File(Core.INSTANCE.getDeviceStorage().getNoBackupFilesDir(), "plugin");
        Cursor query = contentResolver.query(uri, new String[]{"path", "mode"}, null, null, null);
        if (query == null) {
            return null;
        }
        if (query.moveToFirst()) {
            FilesKt__FileReadWriteKt.deleteRecursively(file);
            if (file.mkdirs()) {
                String str = file.getAbsolutePath() + '/';
                boolean z = false;
                do {
                    String string = query.getString(0);
                    File file2 = new File(file, string);
                    String absolutePath = file2.getAbsolutePath();
                    Intrinsics.checkExpressionValueIsNotNull(absolutePath, "file.absolutePath");
                    if (StringsKt__IndentKt.startsWith$default(absolutePath, str, false, 2)) {
                        InputStream openInputStream = contentResolver.openInputStream(uri.buildUpon().path(string).build());
                        if (openInputStream != null) {
                            FileOutputStream fileOutputStream = new FileOutputStream(file2);
                            Intrinsics.checkExpressionValueIsNotNull(openInputStream, "inStream");
                            ViewGroupUtilsApi14.copyTo$default(openInputStream, fileOutputStream, 0, 2);
                            ViewGroupUtilsApi14.closeFinally(fileOutputStream, null);
                            ViewGroupUtilsApi14.closeFinally(openInputStream, null);
                            String absolutePath2 = file2.getAbsolutePath();
                            int type = query.getType(1);
                            if (type == 1) {
                                i = query.getInt(1);
                            } else if (type == 3) {
                                String string2 = query.getString(1);
                                Intrinsics.checkExpressionValueIsNotNull(string2, "cursor.getString(1)");
                                ViewGroupUtilsApi14.checkRadix(8);
                                i = Integer.parseInt(string2, 8);
                            } else {
                                throw new IllegalArgumentException("File mode should be of type int");
                            }
                            Os.chmod(absolutePath2, i);
                            if (Intrinsics.areEqual(string, pluginOptions.getId())) {
                                z = true;
                            }
                        } else {
                            Intrinsics.throwNpe();
                            throw null;
                        }
                    } else {
                        throw new IllegalStateException("Check failed.".toString());
                    }
                } while (query.moveToNext());
                ViewGroupUtilsApi14.closeFinally(query, null);
                if (z) {
                    return new File(file, pluginOptions.getId()).getAbsolutePath();
                }
                pluginManager$initNativeSlow$1.invoke();
                throw null;
            }
            throw new FileNotFoundException("Unable to create plugin directory");
        }
        pluginManager$initNativeSlow$1.invoke();
        throw null;
    }

    public final String loadString(ComponentInfo componentInfo, String str) {
        Intrinsics.checkParameterIsNotNull(componentInfo, "$this$loadString");
        Intrinsics.checkParameterIsNotNull(str, "key");
        Object obj = componentInfo.metaData.get(str);
        if (obj instanceof String) {
            return (String) obj;
        }
        if (obj instanceof Integer) {
            return Core.INSTANCE.getApp().getPackageManager().getResourcesForApplication(componentInfo.applicationInfo).getString(((Number) obj).intValue());
        }
        if (obj == null) {
            return null;
        }
        StringBuilder outline29 = GeneratedOutlineSupport.outline29("meta-data ", str, " has invalid type ");
        outline29.append(obj.getClass());
        throw new IllegalStateException(outline29.toString().toString());
    }
}
