package com.google.android.material.datepicker;

import android.content.Context;
import android.text.TextUtils;
import androidx.transition.ViewGroupUtilsApi14;
import com.google.android.material.R$string;
import com.google.android.material.internal.TextWatcherAdapter;
import com.google.android.material.textfield.TextInputLayout;
import java.text.DateFormat;
import java.text.ParseException;
import java.util.Date;

public abstract class DateFormatTextWatcher extends TextWatcherAdapter {
    public final CalendarConstraints constraints;
    public final DateFormat dateFormat;
    public final String outOfRange;
    public final Runnable setErrorCallback;
    public Runnable setRangeErrorCallback;
    public final TextInputLayout textInputLayout;

    public DateFormatTextWatcher(final String str, DateFormat dateFormat2, TextInputLayout textInputLayout2, CalendarConstraints calendarConstraints) {
        this.dateFormat = dateFormat2;
        this.textInputLayout = textInputLayout2;
        this.constraints = calendarConstraints;
        this.outOfRange = textInputLayout2.getContext().getString(R$string.mtrl_picker_out_of_range);
        this.setErrorCallback = new Runnable() {
            /* class com.google.android.material.datepicker.DateFormatTextWatcher.AnonymousClass1 */

            public void run() {
                DateFormatTextWatcher dateFormatTextWatcher = DateFormatTextWatcher.this;
                TextInputLayout textInputLayout = dateFormatTextWatcher.textInputLayout;
                DateFormat dateFormat = dateFormatTextWatcher.dateFormat;
                Context context = textInputLayout.getContext();
                String string = context.getString(R$string.mtrl_picker_invalid_format);
                String format = String.format(context.getString(R$string.mtrl_picker_invalid_format_use), str);
                String format2 = String.format(context.getString(R$string.mtrl_picker_invalid_format_example), dateFormat.format(new Date(UtcDates.getTodayCalendar().getTimeInMillis())));
                textInputLayout.setError(string + "\n" + format + "\n" + format2);
                DateFormatTextWatcher.this.onInvalidDate();
            }
        };
    }

    public abstract void onInvalidDate();

    /* JADX WARNING: Removed duplicated region for block: B:14:0x005a A[Catch:{ ParseException -> 0x0073 }] */
    @Override // com.google.android.material.internal.TextWatcherAdapter
    public void onTextChanged(CharSequence charSequence, int i, int i2, int i3) {
        this.textInputLayout.removeCallbacks(this.setErrorCallback);
        this.textInputLayout.removeCallbacks(this.setRangeErrorCallback);
        this.textInputLayout.setError(null);
        onValidDate(null);
        if (!TextUtils.isEmpty(charSequence)) {
            try {
                Date parse = this.dateFormat.parse(charSequence.toString());
                this.textInputLayout.setError(null);
                final long time = parse.getTime();
                if (this.constraints.validator.isValid(time)) {
                    CalendarConstraints calendarConstraints = this.constraints;
                    boolean z = true;
                    if (calendarConstraints.start.getDay(1) <= time) {
                        Month month = calendarConstraints.end;
                        if (time <= month.getDay(month.daysInMonth)) {
                            if (z) {
                                onValidDate(Long.valueOf(parse.getTime()));
                                return;
                            }
                        }
                    }
                    z = false;
                    if (z) {
                    }
                }
                AnonymousClass2 r7 = new Runnable() {
                    /* class com.google.android.material.datepicker.DateFormatTextWatcher.AnonymousClass2 */

                    public void run() {
                        DateFormatTextWatcher dateFormatTextWatcher = DateFormatTextWatcher.this;
                        dateFormatTextWatcher.textInputLayout.setError(String.format(dateFormatTextWatcher.outOfRange, ViewGroupUtilsApi14.getDateString(time)));
                        DateFormatTextWatcher.this.onInvalidDate();
                    }
                };
                this.setRangeErrorCallback = r7;
                this.textInputLayout.postDelayed(r7, 1000);
            } catch (ParseException unused) {
                this.textInputLayout.postDelayed(this.setErrorCallback, 1000);
            }
        }
    }

    public abstract void onValidDate(Long l);
}
