package com.google.protobuf;

import com.google.protobuf.Internal;
import java.lang.reflect.Field;
import java.nio.charset.Charset;
import java.util.Objects;

public final class FieldInfo implements Comparable<FieldInfo> {
    public final Field cachedSizeField;
    public final boolean enforceUtf8;
    public final Internal.EnumVerifier enumVerifier;
    public final Field field;
    public final int fieldNumber;
    public final Object mapDefaultEntry;
    public final Class<?> messageClass;
    public final OneofInfo oneof;
    public final Class<?> oneofStoredType;
    public final Field presenceField;
    public final int presenceMask;
    public final boolean required;
    public final FieldType type;

    public FieldInfo(Field field2, int i, FieldType fieldType, Class<?> cls, Field field3, int i2, boolean z, boolean z2, OneofInfo oneofInfo, Class<?> cls2, Object obj, Internal.EnumVerifier enumVerifier2, Field field4) {
        this.field = field2;
        this.type = fieldType;
        this.messageClass = cls;
        this.fieldNumber = i;
        this.presenceField = field3;
        this.presenceMask = i2;
        this.required = z;
        this.enforceUtf8 = z2;
        this.oneof = oneofInfo;
        this.oneofStoredType = cls2;
        this.mapDefaultEntry = obj;
        this.enumVerifier = enumVerifier2;
        this.cachedSizeField = field4;
    }

    public static void checkFieldNumber(int i) {
        if (i <= 0) {
            StringBuilder sb = new StringBuilder(41);
            sb.append("fieldNumber must be positive: ");
            sb.append(i);
            throw new IllegalArgumentException(sb.toString());
        }
    }

    public static FieldInfo forField(Field field2, int i, FieldType fieldType, boolean z) {
        checkFieldNumber(i);
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(field2, "field");
        Objects.requireNonNull(fieldType, "fieldType");
        if (fieldType != FieldType.MESSAGE_LIST && fieldType != FieldType.GROUP_LIST) {
            return new FieldInfo(field2, i, fieldType, null, null, 0, false, z, null, null, null, null, null);
        }
        throw new IllegalStateException("Shouldn't be called for repeated message fields.");
    }

    public static FieldInfo forMapField(Field field2, int i, Object obj, Internal.EnumVerifier enumVerifier2) {
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(obj, "mapDefaultEntry");
        checkFieldNumber(i);
        Objects.requireNonNull(field2, "field");
        return new FieldInfo(field2, i, FieldType.MAP, null, null, 0, false, true, null, null, obj, enumVerifier2, null);
    }

    public static FieldInfo forPackedField(Field field2, int i, FieldType fieldType, Field field3) {
        checkFieldNumber(i);
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(field2, "field");
        Objects.requireNonNull(fieldType, "fieldType");
        if (fieldType != FieldType.MESSAGE_LIST && fieldType != FieldType.GROUP_LIST) {
            return new FieldInfo(field2, i, fieldType, null, null, 0, false, false, null, null, null, null, field3);
        }
        throw new IllegalStateException("Shouldn't be called for repeated message fields.");
    }

    public static FieldInfo forRepeatedMessageField(Field field2, int i, FieldType fieldType, Class<?> cls) {
        checkFieldNumber(i);
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(field2, "field");
        Objects.requireNonNull(fieldType, "fieldType");
        Objects.requireNonNull(cls, "messageClass");
        return new FieldInfo(field2, i, fieldType, cls, null, 0, false, false, null, null, null, null, null);
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
    @Override // java.lang.Comparable
    public int compareTo(FieldInfo fieldInfo) {
        return this.fieldNumber - fieldInfo.fieldNumber;
    }
}
