package com.google.protobuf;

import com.google.protobuf.Internal;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public abstract class ListFieldSchema {
    public static final ListFieldSchema FULL_INSTANCE = new ListFieldSchemaFull(null);
    public static final ListFieldSchema LITE_INSTANCE = new ListFieldSchemaLite(null);

    public final class ListFieldSchemaFull extends ListFieldSchema {
        public static final Class<?> UNMODIFIABLE_LIST_CLASS = Collections.unmodifiableList(Collections.emptyList()).getClass();

        public ListFieldSchemaFull(AnonymousClass1 r1) {
            super(null);
        }

        @Override // com.google.protobuf.ListFieldSchema
        public void makeImmutableListAt(Object obj, long j) {
            Object obj2;
            List list = (List) UnsafeUtil.getObject(obj, j);
            if (list instanceof LazyStringList) {
                obj2 = ((LazyStringList) list).getUnmodifiableView();
            } else if (!UNMODIFIABLE_LIST_CLASS.isAssignableFrom(list.getClass())) {
                if (!(list instanceof PrimitiveNonBoxingCollection) || !(list instanceof Internal.ProtobufList)) {
                    obj2 = Collections.unmodifiableList(list);
                } else {
                    AbstractProtobufList abstractProtobufList = (AbstractProtobufList) ((Internal.ProtobufList) list);
                    if (abstractProtobufList.isMutable) {
                        abstractProtobufList.isMutable = false;
                        return;
                    }
                    return;
                }
            } else {
                return;
            }
            UnsafeUtil.MEMORY_ACCESSOR.putObject(obj, j, obj2);
        }

        /* JADX DEBUG: Multi-variable search result rejected for r1v11, resolved type: java.util.ArrayList */
        /* JADX WARN: Multi-variable type inference failed */
        @Override // com.google.protobuf.ListFieldSchema
        public <L> List<L> mutableListAt(Object obj, long j) {
            LazyStringArrayList lazyStringArrayList;
            List<L> list;
            List<L> list2 = (List) UnsafeUtil.getObject(obj, j);
            if (list2.isEmpty()) {
                if (list2 instanceof LazyStringList) {
                    list = new LazyStringArrayList(10);
                } else if (!(list2 instanceof PrimitiveNonBoxingCollection) || !(list2 instanceof Internal.ProtobufList)) {
                    list = new ArrayList<>(10);
                } else {
                    list = ((Internal.ProtobufList) list2).mutableCopyWithCapacity(10);
                }
                UnsafeUtil.MEMORY_ACCESSOR.putObject(obj, j, list);
                return list;
            }
            if (UNMODIFIABLE_LIST_CLASS.isAssignableFrom(list2.getClass())) {
                ArrayList arrayList = new ArrayList(list2.size() + 10);
                arrayList.addAll(list2);
                UnsafeUtil.MEMORY_ACCESSOR.putObject(obj, j, arrayList);
                lazyStringArrayList = arrayList;
            } else if (list2 instanceof UnmodifiableLazyStringList) {
                LazyStringArrayList lazyStringArrayList2 = new LazyStringArrayList(list2.size() + 10);
                lazyStringArrayList2.addAll(lazyStringArrayList2.size(), (UnmodifiableLazyStringList) list2);
                UnsafeUtil.MEMORY_ACCESSOR.putObject(obj, j, lazyStringArrayList2);
                lazyStringArrayList = lazyStringArrayList2;
            } else if (!(list2 instanceof PrimitiveNonBoxingCollection) || !(list2 instanceof Internal.ProtobufList)) {
                return list2;
            } else {
                Internal.ProtobufList protobufList = (Internal.ProtobufList) list2;
                if (((AbstractProtobufList) protobufList).isMutable) {
                    return list2;
                }
                Internal.ProtobufList mutableCopyWithCapacity = protobufList.mutableCopyWithCapacity(list2.size() + 10);
                UnsafeUtil.MEMORY_ACCESSOR.putObject(obj, j, mutableCopyWithCapacity);
                return mutableCopyWithCapacity;
            }
            return lazyStringArrayList;
        }
    }

    public final class ListFieldSchemaLite extends ListFieldSchema {
        public ListFieldSchemaLite(AnonymousClass1 r1) {
            super(null);
        }

        @Override // com.google.protobuf.ListFieldSchema
        public void makeImmutableListAt(Object obj, long j) {
            ((AbstractProtobufList) ((Internal.ProtobufList) UnsafeUtil.getObject(obj, j))).isMutable = false;
        }

        @Override // com.google.protobuf.ListFieldSchema
        public <L> List<L> mutableListAt(Object obj, long j) {
            Internal.ProtobufList protobufList = (Internal.ProtobufList) UnsafeUtil.getObject(obj, j);
            if (((AbstractProtobufList) protobufList).isMutable) {
                return protobufList;
            }
            int size = protobufList.size();
            Internal.ProtobufList mutableCopyWithCapacity = protobufList.mutableCopyWithCapacity(size == 0 ? 10 : size * 2);
            UnsafeUtil.MEMORY_ACCESSOR.putObject(obj, j, mutableCopyWithCapacity);
            return mutableCopyWithCapacity;
        }
    }

    public ListFieldSchema(AnonymousClass1 r1) {
    }

    public abstract void makeImmutableListAt(Object obj, long j);

    public abstract <L> List<L> mutableListAt(Object obj, long j);
}
