package com.google.protobuf;

import com.google.protobuf.AbstractMessage;
import com.google.protobuf.AbstractMessage.Builder;
import com.google.protobuf.MessageOrBuilder;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;

public class RepeatedFieldBuilderV3<MType extends AbstractMessage, BType extends AbstractMessage.Builder, IType extends MessageOrBuilder> implements AbstractMessage.BuilderParent {
    public boolean isClean;
    public boolean isMessagesListMutable;
    public List<MType> messages;
    public AbstractMessage.BuilderParent parent;

    public RepeatedFieldBuilderV3(List<MType> list, boolean z, AbstractMessage.BuilderParent builderParent, boolean z2) {
        this.messages = list;
        this.isMessagesListMutable = z;
        this.parent = builderParent;
        this.isClean = z2;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: com.google.protobuf.RepeatedFieldBuilderV3<MType extends com.google.protobuf.AbstractMessage, BType extends com.google.protobuf.AbstractMessage$Builder, IType extends com.google.protobuf.MessageOrBuilder> */
    /* JADX WARN: Multi-variable type inference failed */
    public RepeatedFieldBuilderV3<MType, BType, IType> addAllMessages(Iterable<? extends MType> iterable) {
        Iterator<? extends MType> it = iterable.iterator();
        while (it.hasNext()) {
            Charset charset = Internal.UTF_8;
            Objects.requireNonNull((AbstractMessage) it.next());
        }
        int i = -1;
        if (iterable instanceof Collection) {
            Collection collection = (Collection) iterable;
            if (collection.isEmpty()) {
                return this;
            }
            i = collection.size();
        }
        ensureMutableMessageList();
        if (i >= 0) {
            List<MType> list = this.messages;
            if (list instanceof ArrayList) {
                ((ArrayList) list).ensureCapacity(list.size() + i);
            }
        }
        Iterator<? extends MType> it2 = iterable.iterator();
        while (it2.hasNext()) {
            addMessage((AbstractMessage) it2.next());
        }
        onChanged();
        return this;
    }

    public RepeatedFieldBuilderV3<MType, BType, IType> addMessage(MType mtype) {
        Charset charset = Internal.UTF_8;
        Objects.requireNonNull(mtype);
        ensureMutableMessageList();
        this.messages.add(mtype);
        onChanged();
        return this;
    }

    public List<MType> build() {
        this.isClean = true;
        boolean z = this.isMessagesListMutable;
        if (!z) {
            return this.messages;
        }
        if (z) {
            ensureMutableMessageList();
            for (int i = 0; i < this.messages.size(); i++) {
                List<MType> list = this.messages;
                list.set(i, list.get(i));
            }
            List<MType> unmodifiableList = Collections.unmodifiableList(this.messages);
            this.messages = unmodifiableList;
            this.isMessagesListMutable = false;
            return unmodifiableList;
        } else if (this.messages.size() <= 0) {
            return this.messages;
        } else {
            this.messages.get(0);
            throw null;
        }
    }

    public final void ensureMutableMessageList() {
        if (!this.isMessagesListMutable) {
            this.messages = new ArrayList(this.messages);
            this.isMessagesListMutable = true;
        }
    }

    public int getCount() {
        return this.messages.size();
    }

    public boolean isEmpty() {
        return this.messages.isEmpty();
    }

    @Override // com.google.protobuf.AbstractMessage.BuilderParent
    public void markDirty() {
        onChanged();
    }

    public final void onChanged() {
        AbstractMessage.BuilderParent builderParent;
        if (this.isClean && (builderParent = this.parent) != null) {
            builderParent.markDirty();
            this.isClean = false;
        }
    }
}
