package com.google.protobuf;

import androidx.transition.ViewGroupUtilsApi14;
import com.faster.cheetah.sdk.shadowsocks.tcpip.TCPHeader;
import com.google.protobuf.Descriptors;
import com.google.protobuf.DynamicMessage;
import com.google.protobuf.TypeRegistry;
import com.google.protobuf.UnknownFieldSet;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.logging.Logger;
import net.xfkefu.sdk.retrofit.Retrofit2;

public abstract class TextFormat {
    public static final Logger logger = Logger.getLogger(TextFormat.class.getName());

    public class InvalidEscapeSequenceException extends IOException {
        private static final long serialVersionUID = -8164033650142593304L;

        public InvalidEscapeSequenceException(String str) {
            super(str);
        }
    }

    public final class Printer {
        public static final Printer DEFAULT = new Printer(true, TypeRegistry.EmptyTypeRegistryHolder.EMPTY);
        public final TypeRegistry typeRegistry;

        public class MapEntryAdapter implements Comparable<MapEntryAdapter> {
            public Object entry;
            public final Descriptors.FieldDescriptor.JavaType fieldType;

            public MapEntryAdapter(Object obj, Descriptors.FieldDescriptor fieldDescriptor) {
                this.entry = obj;
                this.fieldType = fieldDescriptor.getMessageType().getFields().get(0).getJavaType();
            }

            /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
            @Override // java.lang.Comparable
            public int compareTo(MapEntryAdapter mapEntryAdapter) {
                TextFormat.logger.info("Invalid key for map field.");
                return -1;
            }
        }

        static {
            int i = TypeRegistry.$r8$clinit;
        }

        public Printer(boolean z, TypeRegistry typeRegistry2) {
            this.typeRegistry = typeRegistry2;
        }

        public static void printUnknownField(int i, int i2, List<?> list, TextGenerator textGenerator) {
            for (Object obj : list) {
                textGenerator.print(String.valueOf(i));
                textGenerator.print(": ");
                int i3 = i2 & 7;
                if (i3 == 0) {
                    textGenerator.print(TextFormat.unsignedToString(((Long) obj).longValue()));
                } else if (i3 == 1) {
                    textGenerator.print(String.format(null, "0x%016x", (Long) obj));
                } else if (i3 == 2) {
                    try {
                        ByteString byteString = (ByteString) obj;
                        UnknownFieldSet.Builder newBuilder = UnknownFieldSet.newBuilder();
                        try {
                            CodedInputStream newCodedInput = byteString.newCodedInput();
                            newBuilder.mergeFrom(newCodedInput);
                            newCodedInput.checkLastTagWas(0);
                            UnknownFieldSet build = newBuilder.build();
                            textGenerator.print("{");
                            textGenerator.eol();
                            textGenerator.indent();
                            printUnknownFields(build, textGenerator);
                            textGenerator.outdent();
                            textGenerator.print("}");
                        } catch (InvalidProtocolBufferException e) {
                            throw e;
                        } catch (IOException e2) {
                            throw new RuntimeException("Reading from a ByteString threw an IOException (should never happen).", e2);
                        }
                    } catch (InvalidProtocolBufferException unused) {
                        textGenerator.print("\"");
                        Logger logger = TextFormat.logger;
                        textGenerator.print(ViewGroupUtilsApi14.escapeBytes((ByteString) obj));
                        textGenerator.print("\"");
                    }
                } else if (i3 == 3) {
                    printUnknownFields((UnknownFieldSet) obj, textGenerator);
                } else if (i3 == 5) {
                    textGenerator.print(String.format(null, "0x%08x", (Integer) obj));
                } else {
                    StringBuilder sb = new StringBuilder(20);
                    sb.append("Bad tag: ");
                    sb.append(i2);
                    throw new IllegalArgumentException(sb.toString());
                }
                textGenerator.eol();
            }
        }

        public static void printUnknownFields(UnknownFieldSet unknownFieldSet, TextGenerator textGenerator) {
            for (Map.Entry<Integer, UnknownFieldSet.Field> entry : unknownFieldSet.fields.entrySet()) {
                int intValue = entry.getKey().intValue();
                UnknownFieldSet.Field value = entry.getValue();
                printUnknownField(intValue, 0, value.varint, textGenerator);
                printUnknownField(intValue, 5, value.fixed32, textGenerator);
                printUnknownField(intValue, 1, value.fixed64, textGenerator);
                printUnknownField(intValue, 2, value.lengthDelimited, textGenerator);
                for (UnknownFieldSet unknownFieldSet2 : value.group) {
                    textGenerator.print(entry.getKey().toString());
                    textGenerator.print(" {");
                    textGenerator.eol();
                    textGenerator.indent();
                    printUnknownFields(unknownFieldSet2, textGenerator);
                    textGenerator.outdent();
                    textGenerator.print("}");
                    textGenerator.eol();
                }
            }
        }

        /* JADX WARNING: Removed duplicated region for block: B:21:0x007a A[RETURN] */
        public final void print(MessageOrBuilder messageOrBuilder, TextGenerator textGenerator) {
            if (messageOrBuilder.getDescriptorForType().fullName.equals("google.protobuf.Any")) {
                Descriptors.Descriptor descriptorForType = messageOrBuilder.getDescriptorForType();
                boolean z = true;
                Descriptors.FieldDescriptor findFieldByNumber = descriptorForType.findFieldByNumber(1);
                Descriptors.FieldDescriptor findFieldByNumber2 = descriptorForType.findFieldByNumber(2);
                if (findFieldByNumber != null && findFieldByNumber.type == Descriptors.FieldDescriptor.Type.STRING && findFieldByNumber2 != null && findFieldByNumber2.type == Descriptors.FieldDescriptor.Type.BYTES) {
                    String str = (String) messageOrBuilder.getField(findFieldByNumber);
                    if (!str.isEmpty()) {
                        Object field = messageOrBuilder.getField(findFieldByNumber2);
                        try {
                            Descriptors.Descriptor descriptorForTypeUrl = this.typeRegistry.getDescriptorForTypeUrl(str);
                            if (descriptorForTypeUrl != null) {
                                DynamicMessage.Builder newBuilderForType = DynamicMessage.getDefaultInstance(descriptorForTypeUrl).newBuilderForType();
                                newBuilderForType.mergeFrom((ByteString) field);
                                textGenerator.print("[");
                                textGenerator.print(str);
                                textGenerator.print("] {");
                                textGenerator.eol();
                                textGenerator.indent();
                                print(newBuilderForType, textGenerator);
                                textGenerator.outdent();
                                textGenerator.print("}");
                                textGenerator.eol();
                                if (z) {
                                    return;
                                }
                            }
                        } catch (InvalidProtocolBufferException unused) {
                        }
                    }
                }
                z = false;
                if (z) {
                }
            }
            for (Map.Entry<Descriptors.FieldDescriptor, Object> entry : messageOrBuilder.getAllFields().entrySet()) {
                Descriptors.FieldDescriptor key = entry.getKey();
                Object value = entry.getValue();
                if (key.isMapField()) {
                    ArrayList arrayList = new ArrayList();
                    for (Object obj : (List) value) {
                        arrayList.add(new MapEntryAdapter(obj, key));
                    }
                    Collections.sort(arrayList);
                    Iterator it = arrayList.iterator();
                    while (it.hasNext()) {
                        printSingleField(key, ((MapEntryAdapter) it.next()).entry, textGenerator);
                    }
                } else if (key.isRepeated()) {
                    for (Object obj2 : (List) value) {
                        printSingleField(key, obj2, textGenerator);
                    }
                } else {
                    printSingleField(key, value, textGenerator);
                }
            }
            printUnknownFields(messageOrBuilder.getUnknownFields(), textGenerator);
        }

        public final void printSingleField(Descriptors.FieldDescriptor fieldDescriptor, Object obj, TextGenerator textGenerator) {
            String str;
            if (fieldDescriptor.isExtension()) {
                textGenerator.print("[");
                if (fieldDescriptor.containingType.getOptions().getMessageSetWireFormat() && fieldDescriptor.type == Descriptors.FieldDescriptor.Type.MESSAGE && fieldDescriptor.isOptional()) {
                    if (!fieldDescriptor.isExtension()) {
                        throw new UnsupportedOperationException(String.format("This field is not an extension. (%s)", fieldDescriptor.fullName));
                    } else if (fieldDescriptor.extensionScope == fieldDescriptor.getMessageType()) {
                        textGenerator.print(fieldDescriptor.getMessageType().fullName);
                        textGenerator.print("]");
                    }
                }
                textGenerator.print(fieldDescriptor.fullName);
                textGenerator.print("]");
            } else if (fieldDescriptor.type == Descriptors.FieldDescriptor.Type.GROUP) {
                textGenerator.print(fieldDescriptor.getMessageType().getName());
            } else {
                textGenerator.print(fieldDescriptor.getName());
            }
            Descriptors.FieldDescriptor.JavaType javaType = fieldDescriptor.getJavaType();
            Descriptors.FieldDescriptor.JavaType javaType2 = Descriptors.FieldDescriptor.JavaType.MESSAGE;
            if (javaType == javaType2) {
                textGenerator.print(" {");
                textGenerator.eol();
                textGenerator.indent();
            } else {
                textGenerator.print(": ");
            }
            switch (fieldDescriptor.type.ordinal()) {
                case 0:
                    textGenerator.print(((Double) obj).toString());
                    break;
                case 1:
                    textGenerator.print(((Float) obj).toString());
                    break;
                case 2:
                case 15:
                case 17:
                    textGenerator.print(((Long) obj).toString());
                    break;
                case 3:
                case 5:
                    textGenerator.print(TextFormat.unsignedToString(((Long) obj).longValue()));
                    break;
                case 4:
                case 14:
                case 16:
                    textGenerator.print(((Integer) obj).toString());
                    break;
                case 6:
                case 12:
                    int intValue = ((Integer) obj).intValue();
                    Logger logger = TextFormat.logger;
                    if (intValue >= 0) {
                        str = Integer.toString(intValue);
                    } else {
                        str = Long.toString(((long) intValue) & 4294967295L);
                    }
                    textGenerator.print(str);
                    break;
                case 7:
                    textGenerator.print(((Boolean) obj).toString());
                    break;
                case 8:
                    textGenerator.print("\"");
                    textGenerator.print(ViewGroupUtilsApi14.escapeBytes(ByteString.copyFromUtf8((String) obj)));
                    textGenerator.print("\"");
                    break;
                case 9:
                case 10:
                    print((Message) obj, textGenerator);
                    break;
                case 11:
                    textGenerator.print("\"");
                    if (obj instanceof ByteString) {
                        Logger logger2 = TextFormat.logger;
                        textGenerator.print(ViewGroupUtilsApi14.escapeBytes((ByteString) obj));
                    } else {
                        Logger logger3 = TextFormat.logger;
                        textGenerator.print(ViewGroupUtilsApi14.escapeBytes(new TextFormatEscaper$2((byte[]) obj)));
                    }
                    textGenerator.print("\"");
                    break;
                case 13:
                    textGenerator.print(((Descriptors.EnumValueDescriptor) obj).proto.getName());
                    break;
            }
            if (fieldDescriptor.getJavaType() == javaType2) {
                textGenerator.outdent();
                textGenerator.print("}");
            }
            textGenerator.eol();
        }

        public String printToString(MessageOrBuilder messageOrBuilder) {
            try {
                StringBuilder sb = new StringBuilder();
                Logger logger = TextFormat.logger;
                print(messageOrBuilder, new TextGenerator(sb, false, null));
                return sb.toString();
            } catch (IOException e) {
                throw new IllegalStateException(e);
            }
        }
    }

    public final class TextGenerator {
        public boolean atStartOfLine = false;
        public final StringBuilder indent = new StringBuilder();
        public final Appendable output;

        public TextGenerator(Appendable appendable, boolean z, AnonymousClass1 r3) {
            this.output = appendable;
        }

        public void eol() {
            this.output.append("\n");
            this.atStartOfLine = true;
        }

        public void indent() {
            this.indent.append("  ");
        }

        public void outdent() {
            int length = this.indent.length();
            if (length != 0) {
                this.indent.setLength(length - 2);
                return;
            }
            throw new IllegalArgumentException(" Outdent() without matching Indent().");
        }

        public void print(CharSequence charSequence) {
            if (this.atStartOfLine) {
                this.atStartOfLine = false;
                this.output.append(this.indent);
            }
            this.output.append(charSequence);
        }
    }

    static {
        int i = TypeRegistry.$r8$clinit;
        TypeRegistry typeRegistry = TypeRegistry.EmptyTypeRegistryHolder.EMPTY;
    }

    public static int digitValue(byte b) {
        if (48 <= b && b <= 57) {
            return b - 48;
        }
        return ((97 > b || b > 122) ? b - 65 : b - 97) + 10;
    }

    public static boolean isHex(byte b) {
        return (48 <= b && b <= 57) || (97 <= b && b <= 102) || (65 <= b && b <= 70);
    }

    public static boolean isOctal(byte b) {
        return 48 <= b && b <= 55;
    }

    public static long parseInteger(String str, boolean z, boolean z2) {
        int i = 0;
        boolean z3 = true;
        if (!str.startsWith("-", 0)) {
            z3 = false;
        } else if (!z) {
            throw new NumberFormatException(str.length() != 0 ? "Number must be positive: ".concat(str) : new String("Number must be positive: "));
        } else {
            i = 1;
        }
        int i2 = 10;
        if (str.startsWith("0x", i)) {
            i += 2;
            i2 = 16;
        } else if (str.startsWith(Retrofit2.RESP_CODE_SUCCESS, i)) {
            i2 = 8;
        }
        String substring = str.substring(i);
        if (substring.length() < 16) {
            long parseLong = Long.parseLong(substring, i2);
            if (z3) {
                parseLong = -parseLong;
            }
            if (z2) {
                return parseLong;
            }
            if (z) {
                if (parseLong <= 2147483647L && parseLong >= -2147483648L) {
                    return parseLong;
                }
                throw new NumberFormatException(str.length() != 0 ? "Number out of range for 32-bit signed integer: ".concat(str) : new String("Number out of range for 32-bit signed integer: "));
            } else if (parseLong < 4294967296L && parseLong >= 0) {
                return parseLong;
            } else {
                throw new NumberFormatException(str.length() != 0 ? "Number out of range for 32-bit unsigned integer: ".concat(str) : new String("Number out of range for 32-bit unsigned integer: "));
            }
        } else {
            BigInteger bigInteger = new BigInteger(substring, i2);
            if (z3) {
                bigInteger = bigInteger.negate();
            }
            if (!z2) {
                if (z) {
                    if (bigInteger.bitLength() > 31) {
                        throw new NumberFormatException(str.length() != 0 ? "Number out of range for 32-bit signed integer: ".concat(str) : new String("Number out of range for 32-bit signed integer: "));
                    }
                } else if (bigInteger.bitLength() > 32) {
                    throw new NumberFormatException(str.length() != 0 ? "Number out of range for 32-bit unsigned integer: ".concat(str) : new String("Number out of range for 32-bit unsigned integer: "));
                }
            } else if (z) {
                if (bigInteger.bitLength() > 63) {
                    throw new NumberFormatException(str.length() != 0 ? "Number out of range for 64-bit signed integer: ".concat(str) : new String("Number out of range for 64-bit signed integer: "));
                }
            } else if (bigInteger.bitLength() > 64) {
                throw new NumberFormatException(str.length() != 0 ? "Number out of range for 64-bit unsigned integer: ".concat(str) : new String("Number out of range for 64-bit unsigned integer: "));
            }
            return bigInteger.longValue();
        }
    }

    public static ByteString unescapeBytes(CharSequence charSequence) {
        int i;
        int i2;
        ByteString copyFromUtf8 = ByteString.copyFromUtf8(charSequence.toString());
        int size = copyFromUtf8.size();
        byte[] bArr = new byte[size];
        int i3 = 0;
        int i4 = 0;
        while (i3 < copyFromUtf8.size()) {
            byte byteAt = copyFromUtf8.byteAt(i3);
            if (byteAt == 92) {
                i3++;
                if (i3 < copyFromUtf8.size()) {
                    byte byteAt2 = copyFromUtf8.byteAt(i3);
                    if (isOctal(byteAt2)) {
                        int digitValue = digitValue(byteAt2);
                        int i5 = i3 + 1;
                        if (i5 < copyFromUtf8.size() && isOctal(copyFromUtf8.byteAt(i5))) {
                            digitValue = (digitValue * 8) + digitValue(copyFromUtf8.byteAt(i5));
                            i3 = i5;
                        }
                        int i6 = i3 + 1;
                        if (i6 < copyFromUtf8.size() && isOctal(copyFromUtf8.byteAt(i6))) {
                            digitValue = (digitValue * 8) + digitValue(copyFromUtf8.byteAt(i6));
                            i3 = i6;
                        }
                        i = i4 + 1;
                        bArr[i4] = (byte) digitValue;
                    } else {
                        if (byteAt2 == 34) {
                            i2 = i4 + 1;
                            bArr[i4] = 34;
                        } else if (byteAt2 == 39) {
                            i2 = i4 + 1;
                            bArr[i4] = 39;
                        } else if (byteAt2 == 92) {
                            i2 = i4 + 1;
                            bArr[i4] = 92;
                        } else if (byteAt2 == 102) {
                            i2 = i4 + 1;
                            bArr[i4] = TCPHeader.offset_lenres;
                        } else if (byteAt2 == 110) {
                            i2 = i4 + 1;
                            bArr[i4] = 10;
                        } else if (byteAt2 == 114) {
                            i2 = i4 + 1;
                            bArr[i4] = 13;
                        } else if (byteAt2 == 116) {
                            i2 = i4 + 1;
                            bArr[i4] = 9;
                        } else if (byteAt2 == 118) {
                            i2 = i4 + 1;
                            bArr[i4] = 11;
                        } else if (byteAt2 == 120) {
                            i3++;
                            if (i3 >= copyFromUtf8.size() || !isHex(copyFromUtf8.byteAt(i3))) {
                                throw new InvalidEscapeSequenceException("Invalid escape sequence: '\\x' with no digits");
                            }
                            int digitValue2 = digitValue(copyFromUtf8.byteAt(i3));
                            int i7 = i3 + 1;
                            if (i7 < copyFromUtf8.size() && isHex(copyFromUtf8.byteAt(i7))) {
                                digitValue2 = (digitValue2 * 16) + digitValue(copyFromUtf8.byteAt(i7));
                                i3 = i7;
                            }
                            i = i4 + 1;
                            bArr[i4] = (byte) digitValue2;
                        } else if (byteAt2 == 97) {
                            i2 = i4 + 1;
                            bArr[i4] = 7;
                        } else if (byteAt2 == 98) {
                            i2 = i4 + 1;
                            bArr[i4] = 8;
                        } else {
                            StringBuilder sb = new StringBuilder(29);
                            sb.append("Invalid escape sequence: '\\");
                            sb.append((char) byteAt2);
                            sb.append('\'');
                            throw new InvalidEscapeSequenceException(sb.toString());
                        }
                        i4 = i2;
                        i3++;
                    }
                } else {
                    throw new InvalidEscapeSequenceException("Invalid escape sequence: '\\' at end of string.");
                }
            } else {
                i = i4 + 1;
                bArr[i4] = byteAt;
            }
            i4 = i;
            i3++;
        }
        if (size == i4) {
            return ByteString.wrap(bArr);
        }
        return ByteString.copyFrom(bArr, 0, i4);
    }

    public static String unsignedToString(long j) {
        if (j >= 0) {
            return Long.toString(j);
        }
        return BigInteger.valueOf(j & Long.MAX_VALUE).setBit(63).toString();
    }
}
