package com.google.zxing.aztec;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.Writer;
import com.google.zxing.aztec.encoder.Encoder;
import com.google.zxing.aztec.encoder.HighLevelEncoder;
import com.google.zxing.aztec.encoder.State;
import com.google.zxing.aztec.encoder.Token;
import com.google.zxing.common.BitArray;
import com.google.zxing.common.BitMatrix;
import java.nio.charset.Charset;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.LinkedList;
import java.util.Map;
import java.util.Objects;

public final class AztecWriter implements Writer {
    public static final Charset DEFAULT_CHARSET = Charset.forName("ISO-8859-1");

    /* JADX WARNING: Removed duplicated region for block: B:14:0x004d  */
    /* JADX WARNING: Removed duplicated region for block: B:230:0x0457  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x009b  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x00ee  */
    @Override // com.google.zxing.Writer
    public BitMatrix encode(String str, BarcodeFormat barcodeFormat, int i, int i2, Map<EncodeHintType, ?> map) {
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        boolean z;
        int i8;
        BitArray bitArray;
        BitArray bitArray2;
        int i9;
        int i10;
        Charset charset = DEFAULT_CHARSET;
        int i11 = 33;
        if (map != null) {
            EncodeHintType encodeHintType = EncodeHintType.CHARACTER_SET;
            if (map.containsKey(encodeHintType)) {
                charset = Charset.forName(map.get(encodeHintType).toString());
            }
            EncodeHintType encodeHintType2 = EncodeHintType.ERROR_CORRECTION;
            if (map.containsKey(encodeHintType2)) {
                i11 = Integer.parseInt(map.get(encodeHintType2).toString());
            }
            EncodeHintType encodeHintType3 = EncodeHintType.AZTEC_LAYERS;
            if (map.containsKey(encodeHintType3)) {
                i3 = Integer.parseInt(map.get(encodeHintType3).toString());
                if (barcodeFormat != BarcodeFormat.AZTEC) {
                    HighLevelEncoder highLevelEncoder = new HighLevelEncoder(str.getBytes(charset));
                    Collection<State> singletonList = Collections.singletonList(State.INITIAL_STATE);
                    int i12 = 0;
                    while (true) {
                        byte[] bArr = highLevelEncoder.text;
                        i4 = 32;
                        int i13 = 4;
                        int i14 = 2;
                        i5 = 1;
                        if (i12 >= bArr.length) {
                            break;
                        }
                        int i15 = i12 + 1;
                        byte b = i15 < bArr.length ? bArr[i15] : 0;
                        byte b2 = bArr[i12];
                        if (b2 != 13) {
                            if (b2 != 44) {
                                if (b2 != 46) {
                                    if (b2 == 58 && b == 32) {
                                        i10 = 5;
                                        if (i10 > 0) {
                                            LinkedList linkedList = new LinkedList();
                                            for (State state : singletonList) {
                                                State endBinaryShift = state.endBinaryShift(i12);
                                                linkedList.add(endBinaryShift.latchAndAppend(4, i10));
                                                if (state.mode != 4) {
                                                    linkedList.add(endBinaryShift.shiftAndAppend(4, i10));
                                                }
                                                if (i10 == 3 || i10 == 4) {
                                                    linkedList.add(endBinaryShift.latchAndAppend(2, 16 - i10).latchAndAppend(2, 1));
                                                }
                                                if (state.binaryShiftByteCount > 0) {
                                                    linkedList.add(state.addBinaryShiftChar(i12).addBinaryShiftChar(i15));
                                                }
                                            }
                                            singletonList = HighLevelEncoder.simplifyStates(linkedList);
                                            i12 = i15;
                                        } else {
                                            LinkedList linkedList2 = new LinkedList();
                                            for (State state2 : singletonList) {
                                                char c = (char) (highLevelEncoder.text[i12] & 255);
                                                boolean z2 = HighLevelEncoder.CHAR_MAP[state2.mode][c] > 0;
                                                int i16 = 0;
                                                State state3 = null;
                                                while (i16 <= i13) {
                                                    int i17 = HighLevelEncoder.CHAR_MAP[i16][c];
                                                    if (i17 > 0) {
                                                        if (state3 == null) {
                                                            state3 = state2.endBinaryShift(i12);
                                                        }
                                                        if (!z2 || i16 == state2.mode || i16 == i14) {
                                                            linkedList2.add(state3.latchAndAppend(i16, i17));
                                                        }
                                                        if (!z2 && HighLevelEncoder.SHIFT_TABLE[state2.mode][i16] >= 0) {
                                                            linkedList2.add(state3.shiftAndAppend(i16, i17));
                                                        }
                                                    }
                                                    i16++;
                                                    i13 = 4;
                                                    i14 = 2;
                                                }
                                                if (state2.binaryShiftByteCount > 0 || HighLevelEncoder.CHAR_MAP[state2.mode][c] == 0) {
                                                    linkedList2.add(state2.addBinaryShiftChar(i12));
                                                }
                                                i13 = 4;
                                                i14 = 2;
                                            }
                                            singletonList = HighLevelEncoder.simplifyStates(linkedList2);
                                        }
                                        i12++;
                                    }
                                } else if (b == 32) {
                                    i10 = 3;
                                    if (i10 > 0) {
                                    }
                                    i12++;
                                }
                            } else if (b == 32) {
                                i10 = 4;
                                if (i10 > 0) {
                                }
                                i12++;
                            }
                        } else if (b == 10) {
                            i10 = 2;
                            if (i10 > 0) {
                            }
                            i12++;
                        }
                        i10 = 0;
                        if (i10 > 0) {
                        }
                        i12++;
                    }
                    State state4 = (State) Collections.min(singletonList, new Comparator<State>(highLevelEncoder) {
                        /* class com.google.zxing.aztec.encoder.HighLevelEncoder.AnonymousClass1 */

                        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, java.lang.Object] */
                        @Override // java.util.Comparator
                        public int compare(State state, State state2) {
                            return state.bitCount - state2.bitCount;
                        }
                    });
                    byte[] bArr2 = highLevelEncoder.text;
                    Objects.requireNonNull(state4);
                    LinkedList<Token> linkedList3 = new LinkedList();
                    for (Token token = state4.endBinaryShift(bArr2.length).token; token != null; token = token.previous) {
                        linkedList3.addFirst(token);
                    }
                    BitArray bitArray3 = new BitArray();
                    for (Token token2 : linkedList3) {
                        token2.appendTo(bitArray3, bArr2);
                    }
                    int i18 = bitArray3.size;
                    int i19 = 11;
                    int outline2 = GeneratedOutlineSupport.outline2(i11, i18, 100, 11);
                    int i20 = i18 + outline2;
                    if (i3 != 0) {
                        z = i3 < 0;
                        i6 = Math.abs(i3);
                        if (z) {
                            i4 = 4;
                        }
                        if (i6 <= i4) {
                            i8 = ((z ? 88 : 112) + (i6 << 4)) * i6;
                            i7 = Encoder.WORD_SIZE[i6];
                            int i21 = i8 - (i8 % i7);
                            bitArray = Encoder.stuffBits(bitArray3, i7);
                            int i22 = bitArray.size;
                            if (outline2 + i22 > i21) {
                                throw new IllegalArgumentException("Data to large for user specified layer");
                            } else if (z && i22 > (i7 << 6)) {
                                throw new IllegalArgumentException("Data to large for user specified layer");
                            }
                        } else {
                            throw new IllegalArgumentException(String.format("Illegal value %s for layers", Integer.valueOf(i3)));
                        }
                    } else {
                        int i23 = 0;
                        BitArray bitArray4 = null;
                        int i24 = 0;
                        while (i23 <= i4) {
                            boolean z3 = i23 <= 3;
                            int i25 = z3 ? i23 + 1 : i23;
                            int i26 = ((z3 ? 88 : 112) + (i25 << 4)) * i25;
                            if (i20 <= i26) {
                                int[] iArr = Encoder.WORD_SIZE;
                                if (i24 != iArr[i25]) {
                                    int i27 = iArr[i25];
                                    i24 = i27;
                                    bitArray4 = Encoder.stuffBits(bitArray3, i27);
                                }
                                int i28 = i26 - (i26 % i24);
                                if ((!z3 || bitArray4.size <= (i24 << 6)) && bitArray4.size + outline2 <= i28) {
                                    bitArray = bitArray4;
                                    i7 = i24;
                                    z = z3;
                                    i6 = i25;
                                    i8 = i26;
                                }
                            }
                            i23++;
                            i5 = 1;
                            i4 = 32;
                        }
                        throw new IllegalArgumentException("Data too large for an Aztec code");
                    }
                    BitArray generateCheckWords = Encoder.generateCheckWords(bitArray, i8, i7);
                    int i29 = bitArray.size / i7;
                    BitArray bitArray5 = new BitArray();
                    if (z) {
                        bitArray5.appendBits(i6 - 1, 2);
                        bitArray5.appendBits(i29 - 1, 6);
                        bitArray2 = Encoder.generateCheckWords(bitArray5, 28, 4);
                    } else {
                        bitArray5.appendBits(i6 - 1, 5);
                        bitArray5.appendBits(i29 - 1, 11);
                        bitArray2 = Encoder.generateCheckWords(bitArray5, 40, 4);
                    }
                    if (!z) {
                        i19 = 14;
                    }
                    int i30 = i19 + (i6 << 2);
                    int[] iArr2 = new int[i30];
                    if (z) {
                        for (int i31 = 0; i31 < i30; i31++) {
                            iArr2[i31] = i31;
                        }
                        i9 = i30;
                    } else {
                        int i32 = i30 / 2;
                        i9 = (((i32 - 1) / 15) * 2) + i30 + 1;
                        int i33 = i9 / 2;
                        for (int i34 = 0; i34 < i32; i34++) {
                            int i35 = (i34 / 15) + i34;
                            iArr2[(i32 - i34) - i5] = (i33 - i35) - 1;
                            iArr2[i32 + i34] = i35 + i33 + i5;
                        }
                    }
                    BitMatrix bitMatrix = new BitMatrix(i9, i9);
                    int i36 = 0;
                    for (int i37 = 0; i37 < i6; i37++) {
                        int i38 = ((i6 - i37) << 2) + (z ? 9 : 12);
                        for (int i39 = 0; i39 < i38; i39++) {
                            int i40 = i39 << 1;
                            for (int i41 = 0; i41 < 2; i41++) {
                                if (generateCheckWords.get(i36 + i40 + i41)) {
                                    int i42 = i37 << 1;
                                    bitMatrix.set(iArr2[i42 + i41], iArr2[i42 + i39]);
                                }
                                if (generateCheckWords.get((i38 << 1) + i36 + i40 + i41)) {
                                    int i43 = i37 << 1;
                                    bitMatrix.set(iArr2[i43 + i39], iArr2[((i30 - 1) - i43) - i41]);
                                }
                                if (generateCheckWords.get((i38 << 2) + i36 + i40 + i41)) {
                                    int i44 = (i30 - 1) - (i37 << 1);
                                    bitMatrix.set(iArr2[i44 - i41], iArr2[i44 - i39]);
                                }
                                if (generateCheckWords.get((i38 * 6) + i36 + i40 + i41)) {
                                    int i45 = i37 << 1;
                                    bitMatrix.set(iArr2[((i30 - 1) - i45) - i39], iArr2[i45 + i41]);
                                }
                            }
                        }
                        i36 += i38 << 3;
                    }
                    int i46 = i9 / 2;
                    int i47 = 0;
                    if (z) {
                        while (i47 < 7) {
                            int i48 = (i46 - 3) + i47;
                            if (bitArray2.get(i47)) {
                                bitMatrix.set(i48, i46 - 5);
                            }
                            if (bitArray2.get(i47 + 7)) {
                                bitMatrix.set(i46 + 5, i48);
                            }
                            if (bitArray2.get(20 - i47)) {
                                bitMatrix.set(i48, i46 + 5);
                            }
                            if (bitArray2.get(27 - i47)) {
                                bitMatrix.set(i46 - 5, i48);
                            }
                            i47++;
                        }
                    } else {
                        while (i47 < 10) {
                            int i49 = (i47 / 5) + (i46 - 5) + i47;
                            if (bitArray2.get(i47)) {
                                bitMatrix.set(i49, i46 - 7);
                            }
                            if (bitArray2.get(i47 + 10)) {
                                bitMatrix.set(i46 + 7, i49);
                            }
                            if (bitArray2.get(29 - i47)) {
                                bitMatrix.set(i49, i46 + 7);
                            }
                            if (bitArray2.get(39 - i47)) {
                                bitMatrix.set(i46 - 7, i49);
                            }
                            i47++;
                        }
                    }
                    if (z) {
                        Encoder.drawBullsEye(bitMatrix, i46, 5);
                    } else {
                        Encoder.drawBullsEye(bitMatrix, i46, 7);
                        int i50 = 0;
                        int i51 = 0;
                        while (i50 < (i30 / 2) - 1) {
                            for (int i52 = i46 & 1; i52 < i9; i52 += 2) {
                                int i53 = i46 - i51;
                                bitMatrix.set(i53, i52);
                                int i54 = i46 + i51;
                                bitMatrix.set(i54, i52);
                                bitMatrix.set(i52, i53);
                                bitMatrix.set(i52, i54);
                            }
                            i50 += 15;
                            i51 += 16;
                        }
                    }
                    int i55 = bitMatrix.width;
                    int i56 = bitMatrix.height;
                    int max = Math.max(i, i55);
                    int max2 = Math.max(i2, i56);
                    int min = Math.min(max / i55, max2 / i56);
                    int i57 = (max - (i55 * min)) / 2;
                    int i58 = (max2 - (i56 * min)) / 2;
                    BitMatrix bitMatrix2 = new BitMatrix(max, max2);
                    int i59 = 0;
                    while (i59 < i56) {
                        int i60 = 0;
                        int i61 = i57;
                        while (i60 < i55) {
                            if (bitMatrix.get(i60, i59)) {
                                bitMatrix2.setRegion(i61, i58, min, min);
                            }
                            i60++;
                            i61 += min;
                        }
                        i59++;
                        i58 += min;
                    }
                    return bitMatrix2;
                }
                throw new IllegalArgumentException("Can only encode AZTEC, but got " + barcodeFormat);
            }
        }
        i3 = 0;
        if (barcodeFormat != BarcodeFormat.AZTEC) {
        }
    }
}
