package com.google.zxing.oned;

import com.google.zxing.BarcodeFormat;
import com.google.zxing.DecodeHintType;
import com.google.zxing.FormatException;
import com.google.zxing.NotFoundException;
import com.google.zxing.Result;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.Map;

public final class ITFReader extends OneDReader {
    public static final int[] DEFAULT_ALLOWED_LENGTHS = {6, 8, 10, 12, 14};
    public static final int[] END_PATTERN_REVERSED = {1, 1, 3};
    public static final int[][] PATTERNS = {new int[]{1, 1, 3, 3, 1}, new int[]{3, 1, 1, 1, 3}, new int[]{1, 3, 1, 1, 3}, new int[]{3, 3, 1, 1, 1}, new int[]{1, 1, 3, 1, 3}, new int[]{3, 1, 3, 1, 1}, new int[]{1, 3, 3, 1, 1}, new int[]{1, 1, 1, 3, 3}, new int[]{3, 1, 1, 3, 1}, new int[]{1, 3, 1, 3, 1}};
    public static final int[] START_PATTERN = {1, 1, 1, 1};
    public int narrowLineWidth = -1;

    public static int decodeDigit(int[] iArr) {
        int length = PATTERNS.length;
        float f = 0.38f;
        int i = -1;
        for (int i2 = 0; i2 < length; i2++) {
            float patternMatchVariance = OneDReader.patternMatchVariance(iArr, PATTERNS[i2], 0.78f);
            if (patternMatchVariance < f) {
                i = i2;
                f = patternMatchVariance;
            }
        }
        if (i >= 0) {
            return i;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    public static int[] findGuardPattern(BitArray bitArray, int i, int[] iArr) {
        int length = iArr.length;
        int[] iArr2 = new int[length];
        int i2 = bitArray.size;
        int i3 = i;
        boolean z = false;
        int i4 = 0;
        while (i < i2) {
            if (bitArray.get(i) ^ z) {
                iArr2[i4] = iArr2[i4] + 1;
            } else {
                int i5 = length - 1;
                if (i4 != i5) {
                    i4++;
                } else if (OneDReader.patternMatchVariance(iArr2, iArr, 0.78f) < 0.38f) {
                    return new int[]{i3, i};
                } else {
                    i3 += iArr2[0] + iArr2[1];
                    int i6 = length - 2;
                    System.arraycopy(iArr2, 2, iArr2, 0, i6);
                    iArr2[i6] = 0;
                    iArr2[i5] = 0;
                    i4--;
                }
                iArr2[i4] = 1;
                z = !z;
            }
            i++;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    /* JADX INFO: finally extract failed */
    @Override // com.google.zxing.oned.OneDReader
    public Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map) {
        boolean z;
        int i2 = bitArray.size;
        int nextSet = bitArray.getNextSet(0);
        if (nextSet != i2) {
            int[] findGuardPattern = findGuardPattern(bitArray, nextSet, START_PATTERN);
            this.narrowLineWidth = (findGuardPattern[1] - findGuardPattern[0]) / 4;
            validateQuietZone(bitArray, findGuardPattern[0]);
            bitArray.reverse();
            try {
                int i3 = bitArray.size;
                int nextSet2 = bitArray.getNextSet(0);
                if (nextSet2 != i3) {
                    int[] findGuardPattern2 = findGuardPattern(bitArray, nextSet2, END_PATTERN_REVERSED);
                    validateQuietZone(bitArray, findGuardPattern2[0]);
                    int i4 = findGuardPattern2[0];
                    int i5 = bitArray.size;
                    findGuardPattern2[0] = i5 - findGuardPattern2[1];
                    findGuardPattern2[1] = i5 - i4;
                    bitArray.reverse();
                    StringBuilder sb = new StringBuilder(20);
                    int i6 = findGuardPattern[1];
                    int i7 = findGuardPattern2[0];
                    int[] iArr = new int[10];
                    int[] iArr2 = new int[5];
                    int[] iArr3 = new int[5];
                    while (i6 < i7) {
                        OneDReader.recordPattern(bitArray, i6, iArr);
                        for (int i8 = 0; i8 < 5; i8++) {
                            int i9 = i8 * 2;
                            iArr2[i8] = iArr[i9];
                            iArr3[i8] = iArr[i9 + 1];
                        }
                        sb.append((char) (decodeDigit(iArr2) + 48));
                        sb.append((char) (decodeDigit(iArr3) + 48));
                        for (int i10 = 0; i10 < 10; i10++) {
                            i6 += iArr[i10];
                        }
                    }
                    String sb2 = sb.toString();
                    int[] iArr4 = map != null ? (int[]) map.get(DecodeHintType.ALLOWED_LENGTHS) : null;
                    if (iArr4 == null) {
                        iArr4 = DEFAULT_ALLOWED_LENGTHS;
                    }
                    int length = sb2.length();
                    int length2 = iArr4.length;
                    int i11 = 0;
                    int i12 = 0;
                    while (true) {
                        if (i11 >= length2) {
                            z = false;
                            break;
                        }
                        int i13 = iArr4[i11];
                        if (length == i13) {
                            z = true;
                            break;
                        }
                        if (i13 > i12) {
                            i12 = i13;
                        }
                        i11++;
                    }
                    if (!z && length > i12) {
                        z = true;
                    }
                    if (z) {
                        float f = (float) i;
                        return new Result(sb2, null, new ResultPoint[]{new ResultPoint((float) findGuardPattern[1], f), new ResultPoint((float) findGuardPattern2[0], f)}, BarcodeFormat.ITF);
                    }
                    throw FormatException.getFormatInstance();
                }
                throw NotFoundException.getNotFoundInstance();
            } catch (Throwable th) {
                bitArray.reverse();
                throw th;
            }
        } else {
            throw NotFoundException.getNotFoundInstance();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0019 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:11:0x001a  */
    public final void validateQuietZone(BitArray bitArray, int i) {
        int i2 = this.narrowLineWidth * 10;
        if (i2 >= i) {
            i2 = i;
        }
        while (true) {
            i--;
            if (i2 > 0 && i >= 0 && !bitArray.get(i)) {
                i2--;
            } else if (i2 == 0) {
                throw NotFoundException.getNotFoundInstance();
            } else {
                return;
            }
        }
        if (i2 == 0) {
        }
    }
}
