package com.google.zxing.oned;

import com.google.zxing.BinaryBitmap;
import com.google.zxing.DecodeHintType;
import com.google.zxing.LuminanceSource;
import com.google.zxing.NotFoundException;
import com.google.zxing.Reader;
import com.google.zxing.ReaderException;
import com.google.zxing.Result;
import com.google.zxing.ResultMetadataType;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitArray;
import java.util.Arrays;
import java.util.EnumMap;
import java.util.Map;
import java.util.Objects;

public abstract class OneDReader implements Reader {
    public static float patternMatchVariance(int[] iArr, int[] iArr2, float f) {
        int length = iArr.length;
        int i = 0;
        int i2 = 0;
        for (int i3 = 0; i3 < length; i3++) {
            i += iArr[i3];
            i2 += iArr2[i3];
        }
        if (i < i2) {
            return Float.POSITIVE_INFINITY;
        }
        float f2 = (float) i;
        float f3 = f2 / ((float) i2);
        float f4 = f * f3;
        float f5 = 0.0f;
        for (int i4 = 0; i4 < length; i4++) {
            int i5 = iArr[i4];
            float f6 = ((float) iArr2[i4]) * f3;
            float f7 = (float) i5;
            float f8 = f7 > f6 ? f7 - f6 : f6 - f7;
            if (f8 > f4) {
                return Float.POSITIVE_INFINITY;
            }
            f5 += f8;
        }
        return f5 / f2;
    }

    public static void recordPattern(BitArray bitArray, int i, int[] iArr) {
        int length = iArr.length;
        int i2 = 0;
        Arrays.fill(iArr, 0, length, 0);
        int i3 = bitArray.size;
        if (i < i3) {
            boolean z = !bitArray.get(i);
            while (i < i3) {
                if (!(bitArray.get(i) ^ z)) {
                    i2++;
                    if (i2 == length) {
                        break;
                    }
                    iArr[i2] = 1;
                    z = !z;
                } else {
                    iArr[i2] = iArr[i2] + 1;
                }
                i++;
            }
            if (i2 == length) {
                return;
            }
            if (i2 != length - 1 || i != i3) {
                throw NotFoundException.getNotFoundInstance();
            }
            return;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    public static void recordPatternInReverse(BitArray bitArray, int i, int[] iArr) {
        int length = iArr.length;
        boolean z = bitArray.get(i);
        while (i > 0 && length >= 0) {
            i--;
            if (bitArray.get(i) != z) {
                length--;
                z = !z;
            }
        }
        if (length < 0) {
            recordPattern(bitArray, i + 1, iArr);
            return;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    @Override // com.google.zxing.Reader
    public Result decode(BinaryBitmap binaryBitmap, Map<DecodeHintType, ?> map) {
        try {
            return doDecode(binaryBitmap, map);
        } catch (NotFoundException e) {
            if (map != null && map.containsKey(DecodeHintType.TRY_HARDER)) {
                Objects.requireNonNull(binaryBitmap.binarizer.source);
            }
            throw e;
        }
    }

    public abstract Result decodeRow(int i, BitArray bitArray, Map<DecodeHintType, ?> map);

    /* JADX WARNING: Removed duplicated region for block: B:39:0x007d A[Catch:{ ReaderException -> 0x00ba }] */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x00b9 A[SYNTHETIC] */
    public final Result doDecode(BinaryBitmap binaryBitmap, Map<DecodeHintType, ?> map) {
        OneDReader oneDReader;
        int i;
        Map<DecodeHintType, ?> map2;
        BinaryBitmap binaryBitmap2 = binaryBitmap;
        EnumMap enumMap = map;
        LuminanceSource luminanceSource = binaryBitmap2.binarizer.source;
        int i2 = luminanceSource.width;
        int i3 = luminanceSource.height;
        BitArray bitArray = new BitArray(i2);
        int i4 = i3 >> 1;
        int i5 = 1;
        boolean z = enumMap != null && enumMap.containsKey(DecodeHintType.TRY_HARDER);
        int max = Math.max(1, i3 >> (z ? 8 : 5));
        int i6 = z ? i3 : 15;
        int i7 = 0;
        while (i7 < i6) {
            int i8 = i7 + 1;
            int i9 = i8 / 2;
            if (!((i7 & 1) == 0)) {
                i9 = -i9;
            }
            int i10 = (i9 * max) + i4;
            if (i10 < 0 || i10 >= i3) {
                break;
            }
            try {
                bitArray = binaryBitmap2.getBlackRow(i10, bitArray);
                int i11 = 0;
                while (i11 < 2) {
                    if (i11 == i5) {
                        bitArray.reverse();
                        if (enumMap != null) {
                            DecodeHintType decodeHintType = DecodeHintType.NEED_RESULT_POINT_CALLBACK;
                            if (enumMap.containsKey(decodeHintType)) {
                                EnumMap enumMap2 = new EnumMap(DecodeHintType.class);
                                enumMap2.putAll(enumMap);
                                enumMap2.remove(decodeHintType);
                                oneDReader = this;
                                enumMap = enumMap2;
                                Result decodeRow = oneDReader.decodeRow(i10, bitArray, enumMap);
                                if (i11 != i5) {
                                    decodeRow.putMetadata(ResultMetadataType.ORIENTATION, 180);
                                    ResultPoint[] resultPointArr = decodeRow.resultPoints;
                                    if (resultPointArr != null) {
                                        float f = (float) i2;
                                        map2 = enumMap;
                                        try {
                                            i = i3;
                                            try {
                                                resultPointArr[0] = new ResultPoint((f - resultPointArr[0].x) - 1.0f, resultPointArr[0].y);
                                                try {
                                                    resultPointArr[1] = new ResultPoint((f - resultPointArr[1].x) - 1.0f, resultPointArr[1].y);
                                                } catch (ReaderException unused) {
                                                    continue;
                                                }
                                            } catch (ReaderException unused2) {
                                                i11++;
                                                enumMap = map2;
                                                i3 = i;
                                                i5 = 1;
                                            }
                                        } catch (ReaderException unused3) {
                                            i = i3;
                                            i11++;
                                            enumMap = map2;
                                            i3 = i;
                                            i5 = 1;
                                        }
                                    }
                                }
                                return decodeRow;
                            }
                        }
                    }
                    oneDReader = this;
                    try {
                        Result decodeRow2 = oneDReader.decodeRow(i10, bitArray, enumMap);
                        if (i11 != i5) {
                        }
                        return decodeRow2;
                    } catch (ReaderException unused4) {
                        map2 = enumMap;
                        i = i3;
                        i11++;
                        enumMap = map2;
                        i3 = i;
                        i5 = 1;
                    }
                }
                continue;
            } catch (NotFoundException unused5) {
            }
            binaryBitmap2 = binaryBitmap;
            i7 = i8;
            i3 = i3;
            i5 = 1;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    @Override // com.google.zxing.Reader
    public void reset() {
    }
}
