package com.google.zxing.pdf417;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.Writer;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.common.CharacterSetECI;
import com.google.zxing.pdf417.encoder.BarcodeMatrix;
import com.google.zxing.pdf417.encoder.Compaction;
import com.google.zxing.pdf417.encoder.Dimensions;
import com.google.zxing.pdf417.encoder.PDF417;
import com.google.zxing.pdf417.encoder.PDF417ErrorCorrection;
import com.google.zxing.pdf417.encoder.PDF417HighLevelEncoder;
import java.lang.reflect.Array;
import java.nio.charset.Charset;
import java.nio.charset.CharsetEncoder;
import java.util.Map;

public final class PDF417Writer implements Writer {
    public static BitMatrix bitMatrixFrombitArray(byte[][] bArr, int i) {
        int i2 = i * 2;
        BitMatrix bitMatrix = new BitMatrix(bArr[0].length + i2, bArr.length + i2);
        int length = bitMatrix.bits.length;
        for (int i3 = 0; i3 < length; i3++) {
            bitMatrix.bits[i3] = 0;
        }
        int i4 = (bitMatrix.height - i) - 1;
        int i5 = 0;
        while (i5 < bArr.length) {
            for (int i6 = 0; i6 < bArr[0].length; i6++) {
                if (bArr[i5][i6] == 1) {
                    bitMatrix.set(i6 + i, i4);
                }
            }
            i5++;
            i4--;
        }
        return bitMatrix;
    }

    public static byte[][] rotateArray(byte[][] bArr) {
        int length = bArr[0].length;
        int[] iArr = new int[2];
        iArr[1] = bArr.length;
        iArr[0] = length;
        byte[][] bArr2 = (byte[][]) Array.newInstance(byte.class, iArr);
        for (int i = 0; i < bArr.length; i++) {
            int length2 = (bArr.length - i) - 1;
            for (int i2 = 0; i2 < bArr[0].length; i2++) {
                bArr2[i2][length2] = bArr[i][i2];
            }
        }
        return bArr2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:197:0x03d2 A[LOOP:13: B:196:0x03d0->B:197:0x03d2, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:200:0x03ed  */
    /* JADX WARNING: Removed duplicated region for block: B:201:0x03f6  */
    @Override // com.google.zxing.Writer
    public BitMatrix encode(String str, BarcodeFormat barcodeFormat, int i, int i2, Map<EncodeHintType, ?> map) {
        int i3;
        int i4;
        boolean z;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        char c;
        boolean z2;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        CharacterSetECI characterSetECIByName;
        if (barcodeFormat == BarcodeFormat.PDF_417) {
            Compaction compaction = Compaction.AUTO;
            Charset charset = null;
            if (map != null) {
                EncodeHintType encodeHintType = EncodeHintType.PDF417_COMPACT;
                z = map.containsKey(encodeHintType) ? Boolean.valueOf(map.get(encodeHintType).toString()).booleanValue() : false;
                EncodeHintType encodeHintType2 = EncodeHintType.PDF417_COMPACTION;
                if (map.containsKey(encodeHintType2)) {
                    compaction = Compaction.valueOf(map.get(encodeHintType2).toString());
                }
                EncodeHintType encodeHintType3 = EncodeHintType.PDF417_DIMENSIONS;
                if (!map.containsKey(encodeHintType3)) {
                    EncodeHintType encodeHintType4 = EncodeHintType.MARGIN;
                    i4 = map.containsKey(encodeHintType4) ? Integer.parseInt(map.get(encodeHintType4).toString()) : 30;
                    EncodeHintType encodeHintType5 = EncodeHintType.ERROR_CORRECTION;
                    i3 = map.containsKey(encodeHintType5) ? Integer.parseInt(map.get(encodeHintType5).toString()) : 2;
                    EncodeHintType encodeHintType6 = EncodeHintType.CHARACTER_SET;
                    if (map.containsKey(encodeHintType6)) {
                        charset = Charset.forName(map.get(encodeHintType6).toString());
                    }
                } else {
                    Dimensions dimensions = (Dimensions) map.get(encodeHintType3);
                    throw null;
                }
            } else {
                z = false;
                i4 = 30;
                i3 = 2;
            }
            int errorCorrectionCodewordCount = PDF417ErrorCorrection.getErrorCorrectionCodewordCount(i3);
            byte[] bArr = PDF417HighLevelEncoder.TEXT_MIXED_RAW;
            StringBuilder sb = new StringBuilder(str.length());
            if (charset == null) {
                charset = PDF417HighLevelEncoder.DEFAULT_ENCODING;
            } else if (!PDF417HighLevelEncoder.DEFAULT_ENCODING.equals(charset) && (characterSetECIByName = CharacterSetECI.getCharacterSetECIByName(charset.name())) != null) {
                int value = characterSetECIByName.getValue();
                if (value >= 0 && value < 900) {
                    sb.append((char) 927);
                    sb.append((char) value);
                } else if (value < 810900) {
                    sb.append((char) 926);
                    sb.append((char) ((value / 900) - 1));
                    sb.append((char) (value % 900));
                } else if (value < 811800) {
                    sb.append((char) 925);
                    sb.append((char) (810900 - value));
                } else {
                    throw new WriterException(GeneratedOutlineSupport.outline10("ECI number not in valid range from 0..811799, but was ", value));
                }
            }
            int length = str.length();
            if (compaction == Compaction.TEXT) {
                PDF417HighLevelEncoder.encodeText(str, 0, length, sb, 0);
            } else if (compaction != Compaction.BYTE) {
                char c2 = 902;
                if (compaction != Compaction.NUMERIC) {
                    int i17 = 0;
                    int i18 = 0;
                    loop0:
                    while (true) {
                        int i19 = 0;
                        while (i18 < length) {
                            int length2 = str.length();
                            if (i18 < length2) {
                                char charAt = str.charAt(i18);
                                int i20 = 0;
                                i5 = i19;
                                int i21 = i18;
                                while (PDF417HighLevelEncoder.isDigit(charAt) && i21 < length2) {
                                    i20++;
                                    i21++;
                                    if (i21 < length2) {
                                        charAt = str.charAt(i21);
                                    }
                                }
                                i6 = i20;
                            } else {
                                i5 = i19;
                                i6 = 0;
                            }
                            int i22 = 13;
                            if (i6 >= 13) {
                                sb.append(c2);
                                PDF417HighLevelEncoder.encodeNumeric(str, i18, i6, sb);
                                i18 += i6;
                                i17 = 2;
                            } else {
                                int length3 = str.length();
                                int i23 = i18;
                                while (true) {
                                    if (i23 >= length3) {
                                        i7 = i4;
                                        break;
                                    }
                                    char charAt2 = str.charAt(i23);
                                    i7 = i4;
                                    int i24 = 0;
                                    while (i24 < i22 && PDF417HighLevelEncoder.isDigit(charAt2) && i23 < length3) {
                                        i24++;
                                        i23++;
                                        if (i23 < length3) {
                                            charAt2 = str.charAt(i23);
                                        }
                                    }
                                    if (i24 >= i22) {
                                        i8 = (i23 - i18) - i24;
                                        break;
                                    }
                                    if (i24 <= 0) {
                                        char charAt3 = str.charAt(i23);
                                        if (!(charAt3 == '\t' || charAt3 == '\n' || charAt3 == '\r' || (charAt3 >= ' ' && charAt3 <= '~'))) {
                                            break;
                                        }
                                        i23++;
                                    }
                                    i22 = 13;
                                    i4 = i7;
                                }
                                i8 = i23 - i18;
                                if (i8 >= 5 || i6 == length) {
                                    i9 = length;
                                    if (i17 != 0) {
                                        sb.append((char) 900);
                                        i17 = 0;
                                        i10 = 0;
                                    } else {
                                        i10 = i5;
                                    }
                                    int encodeText = PDF417HighLevelEncoder.encodeText(str, i18, i8, sb, i10);
                                    i18 += i8;
                                    i19 = encodeText;
                                } else {
                                    CharsetEncoder newEncoder = charset.newEncoder();
                                    int length4 = str.length();
                                    int i25 = i18;
                                    while (true) {
                                        if (i25 >= length4) {
                                            i9 = length;
                                            break;
                                        }
                                        char charAt4 = str.charAt(i25);
                                        i9 = length;
                                        int i26 = 0;
                                        for (int i27 = 13; i26 < i27 && PDF417HighLevelEncoder.isDigit(charAt4); i27 = 13) {
                                            i26++;
                                            int i28 = i25 + i26;
                                            if (i28 >= length4) {
                                                break;
                                            }
                                            charAt4 = str.charAt(i28);
                                        }
                                        if (i26 >= 13) {
                                            break;
                                        }
                                        char charAt5 = str.charAt(i25);
                                        if (newEncoder.canEncode(charAt5)) {
                                            i25++;
                                            length = i9;
                                        } else {
                                            throw new WriterException("Non-encodable character detected: " + charAt5 + " (Unicode: " + ((int) charAt5) + ')');
                                        }
                                    }
                                    int i29 = i25 - i18;
                                    if (i29 == 0) {
                                        i29 = 1;
                                    }
                                    int i30 = i29 + i18;
                                    byte[] bytes = str.substring(i18, i30).getBytes(charset);
                                    if (bytes.length == 1 && i17 == 0) {
                                        PDF417HighLevelEncoder.encodeBinary(bytes, 0, 1, 0, sb);
                                        i19 = i5;
                                    } else {
                                        PDF417HighLevelEncoder.encodeBinary(bytes, 0, bytes.length, i17, sb);
                                        i17 = 1;
                                        i19 = 0;
                                    }
                                    i18 = i30;
                                }
                                c2 = 902;
                                length = i9;
                                i4 = i7;
                            }
                        }
                        break loop0;
                    }
                } else {
                    sb.append((char) 902);
                    PDF417HighLevelEncoder.encodeNumeric(str, 0, length, sb);
                }
            } else {
                byte[] bytes2 = str.getBytes(charset);
                PDF417HighLevelEncoder.encodeBinary(bytes2, 0, bytes2.length, 1, sb);
            }
            String sb2 = sb.toString();
            int length5 = sb2.length();
            int[] iArr = null;
            float f = 0.0f;
            for (int i31 = 2; i31 <= 30; i31++) {
                int i32 = length5 + 1 + errorCorrectionCodewordCount;
                int i33 = (i32 / i31) + 1;
                if (i31 * i33 >= i32 + i31) {
                    i33--;
                }
                if (i33 < 2) {
                    break;
                }
                if (i33 <= 30) {
                    float f2 = (((float) ((i31 * 17) + 69)) * 0.357f) / (((float) i33) * 2.0f);
                    if (iArr == null || Math.abs(f2 - 3.0f) <= Math.abs(f - 3.0f)) {
                        iArr = new int[]{i31, i33};
                        f = f2;
                    }
                }
            }
            if (iArr == null) {
                int i34 = length5 + 1 + errorCorrectionCodewordCount;
                i11 = 1;
                int i35 = (i34 / 2) + 1;
                if (i35 * 2 >= i34 + 2) {
                    i35--;
                }
                if (i35 < 2) {
                    c = 0;
                    iArr = new int[]{2, 2};
                } else {
                    c = 0;
                }
            } else {
                c = 0;
                i11 = 1;
            }
            if (iArr != null) {
                int i36 = iArr[c];
                int i37 = iArr[i11];
                int i38 = (i36 * i37) - errorCorrectionCodewordCount;
                int i39 = i38 > length5 + 1 ? (i38 - length5) - 1 : 0;
                if (errorCorrectionCodewordCount + length5 + i11 <= 929) {
                    int i40 = length5 + i39 + i11;
                    StringBuilder sb3 = new StringBuilder(i40);
                    sb3.append((char) i40);
                    sb3.append(sb2);
                    for (int i41 = 0; i41 < i39; i41++) {
                        sb3.append((char) 900);
                    }
                    String sb4 = sb3.toString();
                    int errorCorrectionCodewordCount2 = PDF417ErrorCorrection.getErrorCorrectionCodewordCount(i3);
                    char[] cArr = new char[errorCorrectionCodewordCount2];
                    int length6 = sb4.length();
                    for (int i42 = 0; i42 < length6; i42++) {
                        int i43 = errorCorrectionCodewordCount2 - 1;
                        int charAt6 = (sb4.charAt(i42) + cArr[i43]) % 929;
                        while (i43 > 0) {
                            int i44 = i43 - 1;
                            cArr[i43] = (char) ((cArr[i44] + (929 - ((PDF417ErrorCorrection.EC_COEFFICIENTS[i3][i43] * charAt6) % 929))) % 929);
                            i43 = i44;
                        }
                        cArr[0] = (char) ((929 - ((charAt6 * PDF417ErrorCorrection.EC_COEFFICIENTS[i3][0]) % 929)) % 929);
                    }
                    StringBuilder sb5 = new StringBuilder(errorCorrectionCodewordCount2);
                    while (true) {
                        errorCorrectionCodewordCount2--;
                        if (errorCorrectionCodewordCount2 < 0) {
                            break;
                        }
                        if (cArr[errorCorrectionCodewordCount2] != 0) {
                            cArr[errorCorrectionCodewordCount2] = (char) (929 - cArr[errorCorrectionCodewordCount2]);
                        }
                        sb5.append(cArr[errorCorrectionCodewordCount2]);
                    }
                    String sb6 = sb5.toString();
                    BarcodeMatrix barcodeMatrix = new BarcodeMatrix(i37, i36);
                    String outline18 = GeneratedOutlineSupport.outline18(sb4, sb6);
                    int i45 = 0;
                    for (int i46 = 0; i46 < i37; i46++) {
                        int i47 = i46 % 3;
                        barcodeMatrix.currentRow++;
                        PDF417.encodeChar(130728, 17, barcodeMatrix.getCurrentRow());
                        if (i47 == 0) {
                            i16 = (i46 / 3) * 30;
                            i13 = ((i37 - 1) / 3) + i16;
                            i15 = i36 - 1;
                        } else if (i47 == 1) {
                            i16 = (i46 / 3) * 30;
                            int i48 = i37 - 1;
                            i13 = (i3 * 3) + i16 + (i48 % 3);
                            i15 = i48 / 3;
                        } else {
                            int i49 = (i46 / 3) * 30;
                            i13 = (i36 - 1) + i49;
                            i12 = (i3 * 3) + i49 + ((i37 - 1) % 3);
                            PDF417.encodeChar(PDF417.CODEWORD_TABLE[i47][i13], 17, barcodeMatrix.getCurrentRow());
                            for (i14 = 0; i14 < i36; i14++) {
                                PDF417.encodeChar(PDF417.CODEWORD_TABLE[i47][outline18.charAt(i45)], 17, barcodeMatrix.getCurrentRow());
                                i45++;
                            }
                            if (!z) {
                                PDF417.encodeChar(260649, 1, barcodeMatrix.getCurrentRow());
                            } else {
                                PDF417.encodeChar(PDF417.CODEWORD_TABLE[i47][i12], 17, barcodeMatrix.getCurrentRow());
                                PDF417.encodeChar(260649, 18, barcodeMatrix.getCurrentRow());
                            }
                        }
                        i12 = i15 + i16;
                        PDF417.encodeChar(PDF417.CODEWORD_TABLE[i47][i13], 17, barcodeMatrix.getCurrentRow());
                        while (i14 < i36) {
                        }
                        if (!z) {
                        }
                    }
                    byte[][] scaledMatrix = barcodeMatrix.getScaledMatrix(1, 4);
                    if ((i2 > i) ^ (scaledMatrix[0].length < scaledMatrix.length)) {
                        scaledMatrix = rotateArray(scaledMatrix);
                        z2 = true;
                    } else {
                        z2 = false;
                    }
                    int length7 = i / scaledMatrix[0].length;
                    int length8 = i2 / scaledMatrix.length;
                    if (length7 >= length8) {
                        length7 = length8;
                    }
                    if (length7 <= 1) {
                        return bitMatrixFrombitArray(scaledMatrix, i4);
                    }
                    byte[][] scaledMatrix2 = barcodeMatrix.getScaledMatrix(length7, length7 << 2);
                    if (z2) {
                        scaledMatrix2 = rotateArray(scaledMatrix2);
                    }
                    return bitMatrixFrombitArray(scaledMatrix2, i4);
                }
                throw new WriterException("Encoded message contains too many code words, message too big (" + str.length() + " bytes)");
            }
            throw new WriterException("Unable to fit message in columns");
        }
        throw new IllegalArgumentException("Can only encode PDF_417, but got " + barcodeFormat);
    }
}
