package com.google.zxing.pdf417.decoder;

import androidx.transition.ViewGroupUtilsApi14;
import com.google.zxing.ChecksumException;
import com.google.zxing.FormatException;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.common.CharacterSetECI;
import com.google.zxing.common.DecoderResult;
import com.google.zxing.pdf417.PDF417Common;
import com.google.zxing.pdf417.PDF417ResultMetadata;
import com.google.zxing.pdf417.decoder.ec.ErrorCorrection;
import com.google.zxing.pdf417.decoder.ec.ModulusGF;
import com.google.zxing.pdf417.decoder.ec.ModulusPoly;
import java.io.ByteArrayOutputStream;
import java.nio.charset.Charset;
import java.util.Arrays;
import java.util.Objects;

public abstract class PDF417ScanningDecoder {
    public static final ErrorCorrection errorCorrection = new ErrorCorrection();

    /* JADX WARNING: Removed duplicated region for block: B:75:0x00f2  */
    public static BoundingBox adjustBoundingBox(DetectionResultRowIndicatorColumn detectionResultRowIndicatorColumn) {
        int[] iArr;
        ResultPoint resultPoint;
        ResultPoint resultPoint2;
        ResultPoint resultPoint3;
        ResultPoint resultPoint4;
        ResultPoint resultPoint5;
        ResultPoint resultPoint6;
        int i;
        if (detectionResultRowIndicatorColumn == null) {
            return null;
        }
        BarcodeMetadata barcodeMetadata = detectionResultRowIndicatorColumn.getBarcodeMetadata();
        int i2 = 0;
        if (barcodeMetadata == null) {
            iArr = null;
        } else {
            BoundingBox boundingBox = detectionResultRowIndicatorColumn.boundingBox;
            boolean z = detectionResultRowIndicatorColumn.isLeft;
            if (z) {
                resultPoint5 = boundingBox.topLeft;
            } else {
                resultPoint5 = boundingBox.topRight;
            }
            if (z) {
                resultPoint6 = boundingBox.bottomLeft;
            } else {
                resultPoint6 = boundingBox.bottomRight;
            }
            int imageRowToCodewordIndex = detectionResultRowIndicatorColumn.imageRowToCodewordIndex((int) resultPoint6.y);
            Codeword[] codewordArr = detectionResultRowIndicatorColumn.codewords;
            int i3 = -1;
            int i4 = 0;
            int i5 = 1;
            for (int imageRowToCodewordIndex2 = detectionResultRowIndicatorColumn.imageRowToCodewordIndex((int) resultPoint5.y); imageRowToCodewordIndex2 < imageRowToCodewordIndex; imageRowToCodewordIndex2++) {
                if (codewordArr[imageRowToCodewordIndex2] != null) {
                    Codeword codeword = codewordArr[imageRowToCodewordIndex2];
                    codeword.setRowNumberAsRowIndicatorColumn();
                    int i6 = codeword.rowNumber;
                    int i7 = i6 - i3;
                    if (i7 == 0) {
                        i4++;
                    } else {
                        if (i7 == 1) {
                            i5 = Math.max(i5, i4);
                            i3 = codeword.rowNumber;
                        } else if (i6 >= barcodeMetadata.rowCount) {
                            codewordArr[imageRowToCodewordIndex2] = null;
                        } else {
                            i3 = i6;
                        }
                        i4 = 1;
                    }
                }
            }
            int i8 = barcodeMetadata.rowCount;
            iArr = new int[i8];
            Codeword[] codewordArr2 = detectionResultRowIndicatorColumn.codewords;
            for (Codeword codeword2 : codewordArr2) {
                if (codeword2 != null && (i = codeword2.rowNumber) < i8) {
                    iArr[i] = iArr[i] + 1;
                }
            }
        }
        if (iArr == null) {
            return null;
        }
        int i9 = -1;
        for (int i10 : iArr) {
            i9 = Math.max(i9, i10);
        }
        int i11 = 0;
        for (int i12 : iArr) {
            i11 += i9 - i12;
            if (i12 > 0) {
                break;
            }
        }
        Codeword[] codewordArr3 = detectionResultRowIndicatorColumn.codewords;
        int i13 = 0;
        while (i11 > 0 && codewordArr3[i13] == null) {
            i11--;
            i13++;
        }
        int i14 = 0;
        for (int length = iArr.length - 1; length >= 0; length--) {
            i14 += i9 - iArr[length];
            if (iArr[length] > 0) {
                break;
            }
        }
        int length2 = codewordArr3.length - 1;
        while (i14 > 0 && codewordArr3[length2] == null) {
            i14--;
            length2--;
        }
        BoundingBox boundingBox2 = detectionResultRowIndicatorColumn.boundingBox;
        boolean z2 = detectionResultRowIndicatorColumn.isLeft;
        ResultPoint resultPoint7 = boundingBox2.topLeft;
        ResultPoint resultPoint8 = boundingBox2.bottomLeft;
        ResultPoint resultPoint9 = boundingBox2.topRight;
        ResultPoint resultPoint10 = boundingBox2.bottomRight;
        if (i11 > 0) {
            ResultPoint resultPoint11 = z2 ? resultPoint7 : resultPoint9;
            int i15 = ((int) resultPoint11.y) - i11;
            if (i15 >= 0) {
                i2 = i15;
            }
            ResultPoint resultPoint12 = new ResultPoint(resultPoint11.x, (float) i2);
            if (z2) {
                resultPoint7 = resultPoint12;
            } else {
                resultPoint2 = resultPoint7;
                resultPoint = resultPoint12;
                if (i14 > 0) {
                    ResultPoint resultPoint13 = z2 ? resultPoint8 : resultPoint10;
                    int i16 = ((int) resultPoint13.y) + i14;
                    int i17 = boundingBox2.image.height;
                    if (i16 >= i17) {
                        i16 = i17 - 1;
                    }
                    ResultPoint resultPoint14 = new ResultPoint(resultPoint13.x, (float) i16);
                    if (z2) {
                        resultPoint8 = resultPoint14;
                    } else {
                        resultPoint3 = resultPoint14;
                        resultPoint4 = resultPoint8;
                        boundingBox2.calculateMinMaxValues();
                        return new BoundingBox(boundingBox2.image, resultPoint2, resultPoint4, resultPoint, resultPoint3);
                    }
                }
                resultPoint4 = resultPoint8;
                resultPoint3 = resultPoint10;
                boundingBox2.calculateMinMaxValues();
                return new BoundingBox(boundingBox2.image, resultPoint2, resultPoint4, resultPoint, resultPoint3);
            }
        }
        resultPoint2 = resultPoint7;
        resultPoint = resultPoint9;
        if (i14 > 0) {
        }
        resultPoint4 = resultPoint8;
        resultPoint3 = resultPoint10;
        boundingBox2.calculateMinMaxValues();
        return new BoundingBox(boundingBox2.image, resultPoint2, resultPoint4, resultPoint, resultPoint3);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Removed duplicated region for block: B:122:0x02ab  */
    /* JADX WARNING: Removed duplicated region for block: B:250:0x04a0  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0182  */
    public static DecoderResult decodeCodewords(int[] iArr, int i, int[] iArr2) {
        PDF417ResultMetadata pDF417ResultMetadata;
        int i2;
        PDF417ResultMetadata pDF417ResultMetadata2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        ModulusPoly modulusPoly;
        if (iArr.length != 0) {
            int i8 = 1 << (i + 1);
            if ((iArr2 == null || iArr2.length <= (i8 / 2) + 3) && i8 >= 0 && i8 <= 512) {
                ErrorCorrection errorCorrection2 = errorCorrection;
                ModulusPoly modulusPoly2 = new ModulusPoly(errorCorrection2.field, iArr);
                int[] iArr3 = new int[i8];
                boolean z = false;
                for (int i9 = i8; i9 > 0; i9--) {
                    int evaluateAt = modulusPoly2.evaluateAt(errorCorrection2.field.expTable[i9]);
                    iArr3[i8 - i9] = evaluateAt;
                    if (evaluateAt != 0) {
                        z = true;
                    }
                }
                if (z) {
                    ModulusPoly modulusPoly3 = errorCorrection2.field.one;
                    if (iArr2 != null) {
                        for (int i10 : iArr2) {
                            ModulusGF modulusGF = errorCorrection2.field;
                            modulusPoly3 = modulusPoly3.multiply(new ModulusPoly(modulusGF, new int[]{modulusGF.subtract(0, modulusGF.expTable[(iArr.length - 1) - i10]), 1}));
                        }
                    }
                    ModulusPoly modulusPoly4 = new ModulusPoly(errorCorrection2.field, iArr3);
                    ModulusPoly buildMonomial = errorCorrection2.field.buildMonomial(i8, 1);
                    if (buildMonomial.getDegree() >= modulusPoly4.getDegree()) {
                        modulusPoly4 = buildMonomial;
                        buildMonomial = modulusPoly4;
                    }
                    ModulusGF modulusGF2 = errorCorrection2.field;
                    ModulusPoly modulusPoly5 = modulusGF2.zero;
                    ModulusPoly modulusPoly6 = modulusGF2.one;
                    while (true) {
                        modulusPoly4 = buildMonomial;
                        buildMonomial = modulusPoly4;
                        if (modulusPoly4.getDegree() < i8 / 2) {
                            int coefficient = modulusPoly6.getCoefficient(0);
                            if (coefficient != 0) {
                                int inverse = errorCorrection2.field.inverse(coefficient);
                                ModulusPoly[] modulusPolyArr = {modulusPoly6.multiply(inverse), modulusPoly4.multiply(inverse)};
                                ModulusPoly modulusPoly7 = modulusPolyArr[0];
                                ModulusPoly modulusPoly8 = modulusPolyArr[1];
                                int degree = modulusPoly7.getDegree();
                                int[] iArr4 = new int[degree];
                                int i11 = 1;
                                int i12 = 0;
                                while (true) {
                                    Objects.requireNonNull(errorCorrection2.field);
                                    if (i11 < 929 && i12 < degree) {
                                        if (modulusPoly7.evaluateAt(i11) == 0) {
                                            iArr4[i12] = errorCorrection2.field.inverse(i11);
                                            i12++;
                                        }
                                        i11++;
                                    } else if (i12 != degree) {
                                        int degree2 = modulusPoly7.getDegree();
                                        int[] iArr5 = new int[degree2];
                                        for (int i13 = 1; i13 <= degree2; i13++) {
                                            iArr5[degree2 - i13] = errorCorrection2.field.multiply(i13, modulusPoly7.getCoefficient(i13));
                                        }
                                        ModulusPoly modulusPoly9 = new ModulusPoly(errorCorrection2.field, iArr5);
                                        int[] iArr6 = new int[degree];
                                        for (int i14 = 0; i14 < degree; i14++) {
                                            int inverse2 = errorCorrection2.field.inverse(iArr4[i14]);
                                            iArr6[i14] = errorCorrection2.field.multiply(errorCorrection2.field.subtract(0, modulusPoly8.evaluateAt(inverse2)), errorCorrection2.field.inverse(modulusPoly9.evaluateAt(inverse2)));
                                        }
                                        for (int i15 = 0; i15 < degree; i15++) {
                                            int length = iArr.length - 1;
                                            ModulusGF modulusGF3 = errorCorrection2.field;
                                            int i16 = iArr4[i15];
                                            Objects.requireNonNull(modulusGF3);
                                            if (i16 != 0) {
                                                int i17 = length - modulusGF3.logTable[i16];
                                                if (i17 >= 0) {
                                                    iArr[i17] = errorCorrection2.field.subtract(iArr[i17], iArr6[i15]);
                                                } else {
                                                    throw ChecksumException.getChecksumInstance();
                                                }
                                            } else {
                                                throw new IllegalArgumentException();
                                            }
                                        }
                                    } else {
                                        throw ChecksumException.getChecksumInstance();
                                    }
                                }
                                if (i12 != degree) {
                                }
                            } else {
                                throw ChecksumException.getChecksumInstance();
                            }
                        } else if (!modulusPoly4.isZero()) {
                            ModulusPoly modulusPoly10 = errorCorrection2.field.zero;
                            int inverse3 = errorCorrection2.field.inverse(modulusPoly4.getCoefficient(modulusPoly4.getDegree()));
                            while (buildMonomial.getDegree() >= modulusPoly4.getDegree() && !buildMonomial.isZero()) {
                                int degree3 = buildMonomial.getDegree() - modulusPoly4.getDegree();
                                int multiply = errorCorrection2.field.multiply(buildMonomial.getCoefficient(buildMonomial.getDegree()), inverse3);
                                modulusPoly10 = modulusPoly10.add(errorCorrection2.field.buildMonomial(degree3, multiply));
                                if (degree3 >= 0) {
                                    if (multiply == 0) {
                                        modulusPoly = modulusPoly4.field.zero;
                                    } else {
                                        int length2 = modulusPoly4.coefficients.length;
                                        int[] iArr7 = new int[(degree3 + length2)];
                                        for (int i18 = 0; i18 < length2; i18++) {
                                            iArr7[i18] = modulusPoly4.field.multiply(modulusPoly4.coefficients[i18], multiply);
                                        }
                                        modulusPoly = new ModulusPoly(modulusPoly4.field, iArr7);
                                    }
                                    buildMonomial = buildMonomial.subtract(modulusPoly);
                                } else {
                                    throw new IllegalArgumentException();
                                }
                            }
                            modulusPoly5 = modulusPoly6;
                            modulusPoly6 = modulusPoly10.multiply(modulusPoly6).subtract(modulusPoly5).negative();
                        } else {
                            throw ChecksumException.getChecksumInstance();
                        }
                    }
                }
                if (iArr.length >= 4) {
                    int i19 = iArr[0];
                    if (i19 <= iArr.length) {
                        if (i19 == 0) {
                            if (i8 < iArr.length) {
                                iArr[0] = iArr.length - i8;
                            } else {
                                throw FormatException.getFormatInstance();
                            }
                        }
                        String valueOf = String.valueOf(i);
                        char[] cArr = DecodedBitStreamParser.PUNCT_CHARS;
                        StringBuilder sb = new StringBuilder(iArr.length << 1);
                        Charset charset = DecodedBitStreamParser.DEFAULT_ENCODING;
                        int i20 = iArr[1];
                        PDF417ResultMetadata pDF417ResultMetadata3 = new PDF417ResultMetadata();
                        int i21 = 2;
                        while (i21 < iArr[0]) {
                            if (i20 != 913) {
                                int i22 = 924;
                                int i23 = 900;
                                int i24 = 928;
                                switch (i20) {
                                    case 900:
                                        i2 = DecodedBitStreamParser.textCompaction(iArr, i21, sb);
                                        pDF417ResultMetadata = pDF417ResultMetadata3;
                                        break;
                                    case 901:
                                        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                                        if (i20 == 901) {
                                            int[] iArr8 = new int[6];
                                            int i25 = i21 + 1;
                                            int i26 = iArr[i21];
                                            int i27 = i25;
                                            boolean z2 = false;
                                            while (true) {
                                                i3 = i26;
                                                long j = 0;
                                                boolean z3 = z2;
                                                i4 = i27;
                                                i5 = 0;
                                                while (i4 < iArr[0] && !z3) {
                                                    int i28 = i5 + 1;
                                                    iArr8[i5] = i3;
                                                    j = (j * 900) + ((long) i3);
                                                    int i29 = i4 + 1;
                                                    i3 = iArr[i4];
                                                    if (i3 == i23 || i3 == 901 || i3 == 902 || i3 == i22 || i3 == 928 || i3 == 923 || i3 == 922) {
                                                        i4 = i29 - 1;
                                                        z3 = true;
                                                    } else if (i28 % 5 != 0 || i28 <= 0) {
                                                        i4 = i29;
                                                    } else {
                                                        int i30 = 0;
                                                        while (i30 < 6) {
                                                            byteArrayOutputStream.write((byte) ((int) (j >> ((5 - i30) * 8))));
                                                            i30++;
                                                            i22 = 924;
                                                            i23 = 900;
                                                        }
                                                        i27 = i29;
                                                        i26 = i3;
                                                        z2 = z3;
                                                    }
                                                    i5 = i28;
                                                    i22 = 924;
                                                    i23 = 900;
                                                }
                                            }
                                            if (i4 != iArr[0] || i3 >= 900) {
                                                i6 = i5;
                                            } else {
                                                i6 = i5 + 1;
                                                iArr8[i5] = i3;
                                            }
                                            for (int i31 = 0; i31 < i6; i31++) {
                                                byteArrayOutputStream.write((byte) iArr8[i31]);
                                            }
                                            i21 = i4;
                                        } else if (i20 == 924) {
                                            long j2 = 0;
                                            int i32 = 0;
                                            boolean z4 = false;
                                            for (char c = 0; i21 < iArr[c] && !z4; c = 0) {
                                                int i33 = i21 + 1;
                                                int i34 = iArr[i21];
                                                if (i34 < 900) {
                                                    i32++;
                                                    pDF417ResultMetadata2 = pDF417ResultMetadata3;
                                                    j2 = (j2 * 900) + ((long) i34);
                                                    i21 = i33;
                                                } else {
                                                    pDF417ResultMetadata2 = pDF417ResultMetadata3;
                                                    if (i34 != 900 && i34 != 901) {
                                                        if (i34 != 902 && i34 != 924 && i34 != 928 && i34 != 923) {
                                                            if (i34 != 922) {
                                                                i21 = i33;
                                                            }
                                                        }
                                                    }
                                                    i21 = i33 - 1;
                                                    z4 = true;
                                                }
                                                if (i32 % 5 == 0 && i32 > 0) {
                                                    for (int i35 = 0; i35 < 6; i35++) {
                                                        byteArrayOutputStream.write((byte) ((int) (j2 >> ((5 - i35) * 8))));
                                                    }
                                                    j2 = 0;
                                                    i32 = 0;
                                                }
                                                pDF417ResultMetadata3 = pDF417ResultMetadata2;
                                            }
                                        }
                                        pDF417ResultMetadata = pDF417ResultMetadata3;
                                        sb.append(new String(byteArrayOutputStream.toByteArray(), charset));
                                        i2 = i21;
                                        break;
                                    case 902:
                                        int[] iArr9 = new int[15];
                                        boolean z5 = false;
                                        int i36 = 0;
                                        for (char c2 = 0; i21 < iArr[c2] && !z5; c2 = 0) {
                                            int i37 = i21 + 1;
                                            int i38 = iArr[i21];
                                            if (i37 == iArr[c2]) {
                                                z5 = true;
                                            }
                                            if (i38 < 900) {
                                                iArr9[i36] = i38;
                                                i36++;
                                            } else if (i38 == 900 || i38 == 901 || i38 == 924 || i38 == i24 || i38 == 923 || i38 == 922) {
                                                i37--;
                                                i7 = i36;
                                                z5 = true;
                                                if ((i7 % 15 == 0 || i38 == 902 || z5) && i7 > 0) {
                                                    sb.append(DecodedBitStreamParser.decodeBase900toBase10(iArr9, i7));
                                                    i7 = 0;
                                                }
                                                i21 = i37;
                                                i36 = i7;
                                                i24 = 928;
                                            }
                                            i7 = i36;
                                            sb.append(DecodedBitStreamParser.decodeBase900toBase10(iArr9, i7));
                                            i7 = 0;
                                            i21 = i37;
                                            i36 = i7;
                                            i24 = 928;
                                        }
                                        pDF417ResultMetadata = pDF417ResultMetadata3;
                                        i2 = i21;
                                        break;
                                    default:
                                        switch (i20) {
                                            case 922:
                                            case 923:
                                                throw FormatException.getFormatInstance();
                                            case 924:
                                                break;
                                            case 925:
                                                i2 = i21 + 1;
                                                pDF417ResultMetadata = pDF417ResultMetadata3;
                                                break;
                                            case 926:
                                                i2 = i21 + 2;
                                                pDF417ResultMetadata = pDF417ResultMetadata3;
                                                break;
                                            case 927:
                                                i2 = i21 + 1;
                                                charset = Charset.forName(CharacterSetECI.getCharacterSetECIByValue(iArr[i21]).name());
                                                pDF417ResultMetadata = pDF417ResultMetadata3;
                                                break;
                                            case 928:
                                                if (i21 + 2 <= iArr[0]) {
                                                    int[] iArr10 = new int[2];
                                                    int i39 = 0;
                                                    while (i39 < 2) {
                                                        iArr10[i39] = iArr[i21];
                                                        i39++;
                                                        i21++;
                                                    }
                                                    Integer.parseInt(DecodedBitStreamParser.decodeBase900toBase10(iArr10, 2));
                                                    StringBuilder sb2 = new StringBuilder();
                                                    i21 = DecodedBitStreamParser.textCompaction(iArr, i21, sb2);
                                                    sb2.toString();
                                                    if (iArr[i21] == 923) {
                                                        i21++;
                                                        int[] iArr11 = new int[(iArr[0] - i21)];
                                                        boolean z6 = false;
                                                        int i40 = 0;
                                                        for (char c3 = 0; i21 < iArr[c3] && !z6; c3 = 0) {
                                                            int i41 = i21 + 1;
                                                            int i42 = iArr[i21];
                                                            if (i42 < 900) {
                                                                iArr11[i40] = i42;
                                                                i21 = i41;
                                                                i40++;
                                                            } else if (i42 == 922) {
                                                                i21 = i41 + 1;
                                                                z6 = true;
                                                            } else {
                                                                throw FormatException.getFormatInstance();
                                                            }
                                                        }
                                                        Arrays.copyOf(iArr11, i40);
                                                    } else if (iArr[i21] == 922) {
                                                        i21++;
                                                    }
                                                    pDF417ResultMetadata = pDF417ResultMetadata3;
                                                    i2 = i21;
                                                    break;
                                                } else {
                                                    throw FormatException.getFormatInstance();
                                                }
                                            default:
                                                pDF417ResultMetadata = pDF417ResultMetadata3;
                                                i2 = DecodedBitStreamParser.textCompaction(iArr, i21 - 1, sb);
                                                break;
                                        }
                                }
                            } else {
                                pDF417ResultMetadata = pDF417ResultMetadata3;
                                i2 = i21 + 1;
                                sb.append((char) iArr[i21]);
                            }
                            if (i2 < iArr.length) {
                                i21 = i2 + 1;
                                i20 = iArr[i2];
                                pDF417ResultMetadata3 = pDF417ResultMetadata;
                            } else {
                                throw FormatException.getFormatInstance();
                            }
                        }
                        if (sb.length() != 0) {
                            DecoderResult decoderResult = new DecoderResult(null, sb.toString(), null, valueOf);
                            decoderResult.other = pDF417ResultMetadata3;
                            int length3 = iArr2.length;
                            return decoderResult;
                        }
                        throw FormatException.getFormatInstance();
                    }
                    throw FormatException.getFormatInstance();
                }
                throw FormatException.getFormatInstance();
            }
            throw ChecksumException.getChecksumInstance();
        }
        throw FormatException.getFormatInstance();
    }

    public static Codeword detectCodeword(BitMatrix bitMatrix, int i, int i2, boolean z, int i3, int i4, int i5, int i6) {
        int i7;
        int i8 = i;
        int i9 = z ? -1 : 1;
        boolean z2 = z;
        int i10 = i3;
        int i11 = 0;
        loop0:
        while (true) {
            if (i11 >= 2) {
                break;
            }
            while (true) {
                if (z2) {
                    if (i10 < i8) {
                        continue;
                        break;
                    }
                } else if (i10 >= i2) {
                    continue;
                    break;
                }
                if (z2 != bitMatrix.get(i10, i4)) {
                    continue;
                    break;
                } else if (Math.abs(i3 - i10) > 2) {
                    i10 = i3;
                    break loop0;
                } else {
                    i10 += i9;
                }
            }
            i9 = -i9;
            z2 = !z2;
            i11++;
        }
        int[] iArr = new int[8];
        int i12 = z ? 1 : -1;
        boolean z3 = z;
        int i13 = i10;
        int i14 = 0;
        while (true) {
            if (z) {
                if (i13 >= i2) {
                    break;
                }
            } else if (i13 < i8) {
                break;
            }
            if (i14 >= 8) {
                break;
            } else if (bitMatrix.get(i13, i4) == z3) {
                iArr[i14] = iArr[i14] + 1;
                i13 += i12;
            } else {
                i14++;
                z3 = !z3;
            }
        }
        if (i14 != 8) {
            if (z) {
                i8 = i2;
            }
            if (!(i13 == i8 && i14 == 7)) {
                iArr = null;
            }
        }
        if (iArr == null) {
            return null;
        }
        int sum = ViewGroupUtilsApi14.sum(iArr);
        if (z) {
            i7 = i10 + sum;
        } else {
            for (int i15 = 0; i15 < iArr.length / 2; i15++) {
                int i16 = iArr[i15];
                iArr[i15] = iArr[(iArr.length - 1) - i15];
                iArr[(iArr.length - 1) - i15] = i16;
            }
            i10 -= sum;
            i7 = i10;
        }
        if (!(i5 + -2 <= sum && sum <= i6 + 2)) {
            return null;
        }
        float[][] fArr = PDF417CodewordDecoder.RATIOS_TABLE;
        float sum2 = (float) ViewGroupUtilsApi14.sum(iArr);
        int[] iArr2 = new int[8];
        int i17 = 0;
        int i18 = 0;
        for (int i19 = 0; i19 < 17; i19++) {
            if (((float) (iArr[i17] + i18)) <= ((((float) i19) * sum2) / 17.0f) + (sum2 / 34.0f)) {
                i18 += iArr[i17];
                i17++;
            }
            iArr2[i17] = iArr2[i17] + 1;
        }
        long j = 0;
        for (int i20 = 0; i20 < 8; i20++) {
            for (int i21 = 0; i21 < iArr2[i20]; i21++) {
                j = (j << 1) | ((long) (i20 % 2 == 0 ? 1 : 0));
            }
        }
        int i22 = (int) j;
        if (PDF417Common.getCodeword(i22) == -1) {
            i22 = -1;
        }
        if (i22 == -1) {
            int sum3 = ViewGroupUtilsApi14.sum(iArr);
            float[] fArr2 = new float[8];
            for (int i23 = 0; i23 < 8; i23++) {
                fArr2[i23] = ((float) iArr[i23]) / ((float) sum3);
            }
            float f = Float.MAX_VALUE;
            int i24 = -1;
            int i25 = 0;
            while (true) {
                float[][] fArr3 = PDF417CodewordDecoder.RATIOS_TABLE;
                if (i25 >= fArr3.length) {
                    break;
                }
                float f2 = 0.0f;
                float[] fArr4 = fArr3[i25];
                for (int i26 = 0; i26 < 8; i26++) {
                    float f3 = fArr4[i26] - fArr2[i26];
                    f2 += f3 * f3;
                    if (f2 >= f) {
                        break;
                    }
                }
                if (f2 < f) {
                    i24 = PDF417Common.SYMBOL_TABLE[i25];
                    f = f2;
                }
                i25++;
            }
            i22 = i24;
        }
        int codeword = PDF417Common.getCodeword(i22);
        if (codeword == -1) {
            return null;
        }
        int[] iArr3 = new int[8];
        int i27 = i22;
        int i28 = 7;
        int i29 = 0;
        while (true) {
            int i30 = i27 & 1;
            if (i30 != i29) {
                i28--;
                if (i28 < 0) {
                    return new Codeword(i10, i7, ((((iArr3[0] - iArr3[2]) + iArr3[4]) - iArr3[6]) + 9) % 9, codeword);
                }
                i29 = i30;
            }
            iArr3[i28] = iArr3[i28] + 1;
            i27 >>= 1;
        }
    }

    public static DetectionResultRowIndicatorColumn getRowIndicatorColumn(BitMatrix bitMatrix, BoundingBox boundingBox, ResultPoint resultPoint, boolean z, int i, int i2) {
        int i3;
        DetectionResultRowIndicatorColumn detectionResultRowIndicatorColumn = new DetectionResultRowIndicatorColumn(boundingBox, z);
        int i4 = 0;
        while (i4 < 2) {
            int i5 = i4 == 0 ? 1 : -1;
            int i6 = (int) resultPoint.x;
            int i7 = (int) resultPoint.y;
            while (i7 <= boundingBox.maxY && i7 >= boundingBox.minY) {
                Codeword detectCodeword = detectCodeword(bitMatrix, 0, bitMatrix.width, z, i6, i7, i, i2);
                if (detectCodeword != null) {
                    detectionResultRowIndicatorColumn.codewords[i7 - detectionResultRowIndicatorColumn.boundingBox.minY] = detectCodeword;
                    if (z) {
                        i3 = detectCodeword.startX;
                    } else {
                        i3 = detectCodeword.endX;
                    }
                    i6 = i3;
                }
                i7 += i5;
            }
            i4++;
        }
        return detectionResultRowIndicatorColumn;
    }

    public static boolean isValidBarcodeColumn(DetectionResult detectionResult, int i) {
        return i >= 0 && i <= detectionResult.barcodeColumnCount + 1;
    }
}
