package com.google.zxing.qrcode;

import androidx.transition.ViewGroupUtilsApi14;
import com.google.zxing.BarcodeFormat;
import com.google.zxing.EncodeHintType;
import com.google.zxing.Writer;
import com.google.zxing.WriterException;
import com.google.zxing.common.BitArray;
import com.google.zxing.common.BitMatrix;
import com.google.zxing.common.CharacterSetECI;
import com.google.zxing.common.reedsolomon.GenericGF;
import com.google.zxing.common.reedsolomon.ReedSolomonEncoder;
import com.google.zxing.qrcode.decoder.ErrorCorrectionLevel;
import com.google.zxing.qrcode.decoder.Mode;
import com.google.zxing.qrcode.decoder.Version;
import com.google.zxing.qrcode.encoder.BlockPair;
import com.google.zxing.qrcode.encoder.ByteMatrix;
import com.google.zxing.qrcode.encoder.Encoder;
import com.google.zxing.qrcode.encoder.MatrixUtil;
import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import org.xbill.DNS.KEYRecord;

public final class QRCodeWriter implements Writer {
    /* JADX WARNING: Removed duplicated region for block: B:123:0x01c4  */
    /* JADX WARNING: Removed duplicated region for block: B:133:0x020a  */
    /* JADX WARNING: Removed duplicated region for block: B:142:0x0268  */
    /* JADX WARNING: Removed duplicated region for block: B:143:0x026d  */
    /* JADX WARNING: Removed duplicated region for block: B:146:0x027a  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x004b  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0066 A[SYNTHETIC, Splitter:B:23:0x0066] */
    /* JADX WARNING: Removed duplicated region for block: B:327:0x0637  */
    /* JADX WARNING: Removed duplicated region for block: B:340:0x00b7 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:345:0x014a A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x009c  */
    /* JADX WARNING: Removed duplicated region for block: B:70:0x00fe  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x013a A[LOOP:2: B:77:0x010b->B:92:0x013a, LOOP_END] */
    @Override // com.google.zxing.Writer
    public BitMatrix encode(String str, BarcodeFormat barcodeFormat, int i, int i2, Map<EncodeHintType, ?> map) {
        int i3;
        String str2;
        Mode mode;
        BitArray bitArray;
        BitArray bitArray2;
        int ordinal;
        Version version;
        int sizeInBytes;
        int i4;
        BitArray bitArray3;
        int i5;
        char c;
        int i6;
        int i7;
        CharacterSetECI characterSetECIByName;
        int i8;
        boolean z;
        if (str.isEmpty()) {
            throw new IllegalArgumentException("Found empty contents");
        } else if (barcodeFormat != BarcodeFormat.QR_CODE) {
            throw new IllegalArgumentException("Can only encode QR_CODE, but got " + barcodeFormat);
        } else if (i < 0 || i2 < 0) {
            throw new IllegalArgumentException("Requested dimensions are too small: " + i + 'x' + i2);
        } else {
            ErrorCorrectionLevel errorCorrectionLevel = ErrorCorrectionLevel.L;
            if (map != null) {
                EncodeHintType encodeHintType = EncodeHintType.ERROR_CORRECTION;
                if (map.containsKey(encodeHintType)) {
                    errorCorrectionLevel = ErrorCorrectionLevel.valueOf(map.get(encodeHintType).toString());
                }
                EncodeHintType encodeHintType2 = EncodeHintType.MARGIN;
                if (map.containsKey(encodeHintType2)) {
                    i3 = Integer.parseInt(map.get(encodeHintType2).toString());
                    if (map != null) {
                        EncodeHintType encodeHintType3 = EncodeHintType.CHARACTER_SET;
                        if (map.containsKey(encodeHintType3)) {
                            str2 = map.get(encodeHintType3).toString();
                            if ("Shift_JIS".equals(str2)) {
                                try {
                                    byte[] bytes = str.getBytes("Shift_JIS");
                                    int length = bytes.length;
                                    if (length % 2 == 0) {
                                        int i9 = 0;
                                        while (true) {
                                            if (i9 >= length) {
                                                z = true;
                                                break;
                                            }
                                            int i10 = bytes[i9] & 255;
                                            if ((i10 < 129 || i10 > 159) && (i10 < 224 || i10 > 235)) {
                                                break;
                                            }
                                            i9 += 2;
                                        }
                                    }
                                } catch (UnsupportedEncodingException unused) {
                                }
                                z = false;
                                if (z) {
                                    mode = Mode.KANJI;
                                    bitArray = new BitArray();
                                    if (mode == Mode.BYTE && !"ISO-8859-1".equals(str2) && (characterSetECIByName = CharacterSetECI.getCharacterSetECIByName(str2)) != null) {
                                        bitArray.appendBits(Mode.ECI.getBits(), 4);
                                        bitArray.appendBits(characterSetECIByName.getValue(), 8);
                                    }
                                    bitArray.appendBits(mode.getBits(), 4);
                                    bitArray2 = new BitArray();
                                    ordinal = mode.ordinal();
                                    if (ordinal != 1) {
                                        int length2 = str.length();
                                        int i11 = 0;
                                        while (i11 < length2) {
                                            int charAt = str.charAt(i11) - '0';
                                            int i12 = i11 + 2;
                                            if (i12 < length2) {
                                                bitArray2.appendBits(((str.charAt(i11 + 1) - '0') * 10) + (charAt * 100) + (str.charAt(i12) - '0'), 10);
                                                i11 += 3;
                                            } else {
                                                i11++;
                                                if (i11 < length2) {
                                                    bitArray2.appendBits((charAt * 10) + (str.charAt(i11) - '0'), 7);
                                                    i11 = i12;
                                                } else {
                                                    bitArray2.appendBits(charAt, 4);
                                                }
                                            }
                                        }
                                    } else if (ordinal == 2) {
                                        int length3 = str.length();
                                        int i13 = 0;
                                        while (i13 < length3) {
                                            int alphanumericCode = Encoder.getAlphanumericCode(str.charAt(i13));
                                            if (alphanumericCode != -1) {
                                                int i14 = i13 + 1;
                                                if (i14 < length3) {
                                                    int alphanumericCode2 = Encoder.getAlphanumericCode(str.charAt(i14));
                                                    if (alphanumericCode2 != -1) {
                                                        bitArray2.appendBits((alphanumericCode * 45) + alphanumericCode2, 11);
                                                        i13 += 2;
                                                    } else {
                                                        throw new WriterException();
                                                    }
                                                } else {
                                                    bitArray2.appendBits(alphanumericCode, 6);
                                                    i13 = i14;
                                                }
                                            } else {
                                                throw new WriterException();
                                            }
                                        }
                                    } else if (ordinal == 4) {
                                        try {
                                            for (byte b : str.getBytes(str2)) {
                                                bitArray2.appendBits(b, 8);
                                            }
                                        } catch (UnsupportedEncodingException e) {
                                            throw new WriterException(e);
                                        }
                                    } else if (ordinal == 6) {
                                        try {
                                            byte[] bytes2 = str.getBytes("Shift_JIS");
                                            int length4 = bytes2.length;
                                            for (int i15 = 0; i15 < length4; i15 += 2) {
                                                int i16 = ((bytes2[i15] & 255) << 8) | (bytes2[i15 + 1] & 255);
                                                if (i16 >= 33088 && i16 <= 40956) {
                                                    i7 = 33088;
                                                } else if (i16 < 57408 || i16 > 60351) {
                                                    i6 = -1;
                                                    if (i6 == -1) {
                                                        bitArray2.appendBits(((i6 >> 8) * 192) + (i6 & KEYRecord.PROTOCOL_ANY), 13);
                                                    } else {
                                                        throw new WriterException("Invalid byte sequence");
                                                    }
                                                } else {
                                                    i7 = 49472;
                                                }
                                                i6 = i16 - i7;
                                                if (i6 == -1) {
                                                }
                                            }
                                        } catch (UnsupportedEncodingException e2) {
                                            throw new WriterException(e2);
                                        }
                                    } else {
                                        throw new WriterException("Invalid mode: " + mode);
                                    }
                                    if (map != null) {
                                        EncodeHintType encodeHintType4 = EncodeHintType.QR_VERSION;
                                        if (map.containsKey(encodeHintType4)) {
                                            version = Version.getVersionForNumber(Integer.parseInt(map.get(encodeHintType4).toString()));
                                            if (!Encoder.willFit(mode.getCharacterCountBits(version) + bitArray.size + bitArray2.size, version, errorCorrectionLevel)) {
                                                throw new WriterException("Data too big for requested version");
                                            }
                                            BitArray bitArray4 = new BitArray();
                                            bitArray4.appendBitArray(bitArray);
                                            sizeInBytes = mode == Mode.BYTE ? bitArray2.getSizeInBytes() : str.length();
                                            int characterCountBits = mode.getCharacterCountBits(version);
                                            i4 = 1 << characterCountBits;
                                            if (sizeInBytes < i4) {
                                                bitArray4.appendBits(sizeInBytes, characterCountBits);
                                                bitArray4.appendBitArray(bitArray2);
                                                Version.ECBlocks eCBlocks = version.ecBlocks[errorCorrectionLevel.ordinal()];
                                                int numBlocks = version.totalCodewords - (eCBlocks.getNumBlocks() * eCBlocks.ecCodewordsPerBlock);
                                                int i17 = numBlocks << 3;
                                                if (bitArray4.size <= i17) {
                                                    for (int i18 = 0; i18 < 4 && bitArray4.size < i17; i18++) {
                                                        bitArray4.appendBit(false);
                                                    }
                                                    boolean z2 = false;
                                                    int i19 = bitArray4.size & 7;
                                                    if (i19 > 0) {
                                                        int i20 = 8;
                                                        while (i19 < i20) {
                                                            bitArray4.appendBit(z2);
                                                            i19++;
                                                            i20 = 8;
                                                            z2 = false;
                                                        }
                                                    }
                                                    int sizeInBytes2 = numBlocks - bitArray4.getSizeInBytes();
                                                    for (int i21 = 0; i21 < sizeInBytes2; i21++) {
                                                        bitArray4.appendBits((i21 & 1) == 0 ? 236 : 17, 8);
                                                    }
                                                    if (bitArray4.size == i17) {
                                                        int i22 = version.totalCodewords;
                                                        int numBlocks2 = eCBlocks.getNumBlocks();
                                                        if (bitArray4.getSizeInBytes() == numBlocks) {
                                                            ArrayList arrayList = new ArrayList(numBlocks2);
                                                            int i23 = 0;
                                                            int i24 = 0;
                                                            int i25 = 0;
                                                            int i26 = 0;
                                                            while (i24 < numBlocks2) {
                                                                int[] iArr = new int[1];
                                                                int[] iArr2 = new int[1];
                                                                if (i24 < numBlocks2) {
                                                                    int i27 = i22 % numBlocks2;
                                                                    int i28 = numBlocks2 - i27;
                                                                    int i29 = i22 / numBlocks2;
                                                                    int i30 = numBlocks / numBlocks2;
                                                                    int i31 = i30 + 1;
                                                                    int i32 = i29 - i30;
                                                                    int i33 = (i29 + 1) - i31;
                                                                    if (i32 != i33) {
                                                                        throw new WriterException("EC bytes mismatch");
                                                                    } else if (numBlocks2 != i28 + i27) {
                                                                        throw new WriterException("RS blocks mismatch");
                                                                    } else if (i22 == ((i31 + i33) * i27) + ((i30 + i32) * i28)) {
                                                                        if (i24 < i28) {
                                                                            c = 0;
                                                                            iArr[0] = i30;
                                                                            iArr2[0] = i32;
                                                                        } else {
                                                                            c = 0;
                                                                            iArr[0] = i31;
                                                                            iArr2[0] = i33;
                                                                        }
                                                                        int i34 = iArr[c];
                                                                        byte[] bArr = new byte[i34];
                                                                        int i35 = i23 << 3;
                                                                        int i36 = 0;
                                                                        while (i36 < i34) {
                                                                            int i37 = i35;
                                                                            int i38 = 0;
                                                                            int i39 = 0;
                                                                            for (int i40 = 8; i38 < i40; i40 = 8) {
                                                                                if (bitArray4.get(i37)) {
                                                                                    i39 = (1 << (7 - i38)) | i39;
                                                                                }
                                                                                i37++;
                                                                                i38++;
                                                                            }
                                                                            bArr[i36 + 0] = (byte) i39;
                                                                            i36++;
                                                                            i35 = i37;
                                                                            i22 = i22;
                                                                            numBlocks2 = numBlocks2;
                                                                        }
                                                                        int i41 = iArr2[0];
                                                                        int[] iArr3 = new int[(i34 + i41)];
                                                                        for (int i42 = 0; i42 < i34; i42++) {
                                                                            iArr3[i42] = bArr[i42] & 255;
                                                                        }
                                                                        new ReedSolomonEncoder(GenericGF.QR_CODE_FIELD_256).encode(iArr3, i41);
                                                                        byte[] bArr2 = new byte[i41];
                                                                        for (int i43 = 0; i43 < i41; i43++) {
                                                                            bArr2[i43] = (byte) iArr3[i34 + i43];
                                                                        }
                                                                        arrayList.add(new BlockPair(bArr, bArr2));
                                                                        i25 = Math.max(i25, i34);
                                                                        i26 = Math.max(i26, i41);
                                                                        i23 += iArr[0];
                                                                        i24++;
                                                                        numBlocks2 = numBlocks2;
                                                                        errorCorrectionLevel = errorCorrectionLevel;
                                                                        version = version;
                                                                        i22 = i22;
                                                                        i3 = i3;
                                                                    } else {
                                                                        throw new WriterException("Total bytes mismatch");
                                                                    }
                                                                } else {
                                                                    throw new WriterException("Block ID too large");
                                                                }
                                                            }
                                                            ErrorCorrectionLevel errorCorrectionLevel2 = errorCorrectionLevel;
                                                            Version version2 = version;
                                                            if (numBlocks == i23) {
                                                                BitArray bitArray5 = new BitArray();
                                                                for (int i44 = 0; i44 < i25; i44++) {
                                                                    Iterator it = arrayList.iterator();
                                                                    while (it.hasNext()) {
                                                                        byte[] bArr3 = ((BlockPair) it.next()).dataBytes;
                                                                        if (i44 < bArr3.length) {
                                                                            bitArray5.appendBits(bArr3[i44], 8);
                                                                        }
                                                                    }
                                                                }
                                                                for (int i45 = 0; i45 < i26; i45++) {
                                                                    Iterator it2 = arrayList.iterator();
                                                                    while (it2.hasNext()) {
                                                                        byte[] bArr4 = ((BlockPair) it2.next()).errorCorrectionBytes;
                                                                        if (i45 < bArr4.length) {
                                                                            bitArray5.appendBits(bArr4[i45], 8);
                                                                        }
                                                                    }
                                                                }
                                                                if (i22 == bitArray5.getSizeInBytes()) {
                                                                    int dimensionForVersion = version2.getDimensionForVersion();
                                                                    ByteMatrix byteMatrix = new ByteMatrix(dimensionForVersion, dimensionForVersion);
                                                                    int i46 = Integer.MAX_VALUE;
                                                                    int i47 = 0;
                                                                    int i48 = -1;
                                                                    for (int i49 = 8; i47 < i49; i49 = 8) {
                                                                        MatrixUtil.buildMatrix(bitArray5, errorCorrectionLevel2, version2, i47, byteMatrix);
                                                                        int applyMaskPenaltyRule1Internal = ViewGroupUtilsApi14.applyMaskPenaltyRule1Internal(byteMatrix, false) + ViewGroupUtilsApi14.applyMaskPenaltyRule1Internal(byteMatrix, true);
                                                                        byte[][] bArr5 = byteMatrix.bytes;
                                                                        int i50 = byteMatrix.width;
                                                                        int i51 = byteMatrix.height;
                                                                        int i52 = 0;
                                                                        for (int i53 = 0; i53 < i51 - 1; i53++) {
                                                                            int i54 = 0;
                                                                            while (i54 < i50 - 1) {
                                                                                byte b2 = bArr5[i53][i54];
                                                                                int i55 = i54 + 1;
                                                                                if (b2 == bArr5[i53][i55]) {
                                                                                    int i56 = i53 + 1;
                                                                                    if (b2 == bArr5[i56][i54] && b2 == bArr5[i56][i55]) {
                                                                                        i52++;
                                                                                    }
                                                                                }
                                                                                i54 = i55;
                                                                            }
                                                                        }
                                                                        int i57 = (i52 * 3) + applyMaskPenaltyRule1Internal;
                                                                        byte[][] bArr6 = byteMatrix.bytes;
                                                                        int i58 = byteMatrix.width;
                                                                        int i59 = byteMatrix.height;
                                                                        int i60 = 0;
                                                                        for (int i61 = 0; i61 < i59; i61++) {
                                                                            int i62 = 0;
                                                                            while (i62 < i58) {
                                                                                byte[] bArr7 = bArr6[i61];
                                                                                int i63 = i62 + 6;
                                                                                if (i63 < i58) {
                                                                                    i5 = i58;
                                                                                    bitArray3 = bitArray5;
                                                                                    if (bArr7[i62] == 1 && bArr7[i62 + 1] == 0 && bArr7[i62 + 2] == 1 && bArr7[i62 + 3] == 1 && bArr7[i62 + 4] == 1 && bArr7[i62 + 5] == 0 && bArr7[i63] == 1 && (ViewGroupUtilsApi14.isWhiteHorizontal(bArr7, i62 - 4, i62) || ViewGroupUtilsApi14.isWhiteHorizontal(bArr7, i62 + 7, i62 + 11))) {
                                                                                        i60++;
                                                                                    }
                                                                                } else {
                                                                                    bitArray3 = bitArray5;
                                                                                    i5 = i58;
                                                                                }
                                                                                int i64 = i61 + 6;
                                                                                if (i64 < i59 && bArr6[i61][i62] == 1 && bArr6[i61 + 1][i62] == 0 && bArr6[i61 + 2][i62] == 1 && bArr6[i61 + 3][i62] == 1 && bArr6[i61 + 4][i62] == 1 && bArr6[i61 + 5][i62] == 0 && bArr6[i64][i62] == 1 && (ViewGroupUtilsApi14.isWhiteVertical(bArr6, i62, i61 - 4, i61) || ViewGroupUtilsApi14.isWhiteVertical(bArr6, i62, i61 + 7, i61 + 11))) {
                                                                                    i60++;
                                                                                }
                                                                                i62++;
                                                                                bitArray5 = bitArray3;
                                                                                i58 = i5;
                                                                            }
                                                                        }
                                                                        int i65 = (i60 * 40) + i57;
                                                                        byte[][] bArr8 = byteMatrix.bytes;
                                                                        int i66 = byteMatrix.width;
                                                                        int i67 = byteMatrix.height;
                                                                        int i68 = 0;
                                                                        for (int i69 = 0; i69 < i67; i69++) {
                                                                            byte[] bArr9 = bArr8[i69];
                                                                            for (int i70 = 0; i70 < i66; i70++) {
                                                                                if (bArr9[i70] == 1) {
                                                                                    i68++;
                                                                                }
                                                                            }
                                                                        }
                                                                        int i71 = byteMatrix.height * byteMatrix.width;
                                                                        int abs = (((Math.abs((i68 << 1) - i71) * 10) / i71) * 10) + i65;
                                                                        if (abs < i46) {
                                                                            i46 = abs;
                                                                            i48 = i47;
                                                                        }
                                                                        i47++;
                                                                        bitArray5 = bitArray5;
                                                                        errorCorrectionLevel2 = errorCorrectionLevel2;
                                                                        version2 = version2;
                                                                    }
                                                                    MatrixUtil.buildMatrix(bitArray5, errorCorrectionLevel2, version2, i48, byteMatrix);
                                                                    int i72 = byteMatrix.width;
                                                                    int i73 = byteMatrix.height;
                                                                    int i74 = i3 << 1;
                                                                    int i75 = i72 + i74;
                                                                    int i76 = i74 + i73;
                                                                    int max = Math.max(i, i75);
                                                                    int max2 = Math.max(i2, i76);
                                                                    int min = Math.min(max / i75, max2 / i76);
                                                                    int i77 = (max - (i72 * min)) / 2;
                                                                    int i78 = (max2 - (i73 * min)) / 2;
                                                                    BitMatrix bitMatrix = new BitMatrix(max, max2);
                                                                    int i79 = 0;
                                                                    while (i79 < i73) {
                                                                        int i80 = i77;
                                                                        int i81 = 0;
                                                                        while (i81 < i72) {
                                                                            if (byteMatrix.get(i81, i79) == 1) {
                                                                                bitMatrix.setRegion(i80, i78, min, min);
                                                                            }
                                                                            i81++;
                                                                            i80 += min;
                                                                        }
                                                                        i79++;
                                                                        i78 += min;
                                                                    }
                                                                    return bitMatrix;
                                                                }
                                                                throw new WriterException("Interleaving error: " + i22 + " and " + bitArray5.getSizeInBytes() + " differ.");
                                                            }
                                                            throw new WriterException("Data bytes does not match offset");
                                                        }
                                                        throw new WriterException("Number of bits and data bytes does not match");
                                                    }
                                                    throw new WriterException("Bits size does not equal capacity");
                                                }
                                                throw new WriterException("data bits cannot fit in the QR Code" + bitArray4.size + " > " + i17);
                                            }
                                            throw new WriterException(sizeInBytes + " is bigger than " + (i4 - 1));
                                        }
                                    }
                                    version = Encoder.chooseVersion(mode.getCharacterCountBits(Encoder.chooseVersion(mode.getCharacterCountBits(Version.getVersionForNumber(1)) + bitArray.size + bitArray2.size, errorCorrectionLevel)) + bitArray.size + bitArray2.size, errorCorrectionLevel);
                                    BitArray bitArray42 = new BitArray();
                                    bitArray42.appendBitArray(bitArray);
                                    if (mode == Mode.BYTE) {
                                    }
                                    int characterCountBits2 = mode.getCharacterCountBits(version);
                                    i4 = 1 << characterCountBits2;
                                    if (sizeInBytes < i4) {
                                    }
                                }
                            }
                            i8 = 0;
                            boolean z3 = false;
                            boolean z4 = false;
                            while (true) {
                                if (i8 < str.length()) {
                                    char charAt2 = str.charAt(i8);
                                    if (charAt2 < '0' || charAt2 > '9') {
                                        if (Encoder.getAlphanumericCode(charAt2) == -1) {
                                            mode = Mode.BYTE;
                                            break;
                                        }
                                        z3 = true;
                                    } else {
                                        z4 = true;
                                    }
                                    i8++;
                                } else if (z3) {
                                    mode = Mode.ALPHANUMERIC;
                                } else if (z4) {
                                    mode = Mode.NUMERIC;
                                } else {
                                    mode = Mode.BYTE;
                                }
                            }
                            bitArray = new BitArray();
                            bitArray.appendBits(Mode.ECI.getBits(), 4);
                            bitArray.appendBits(characterSetECIByName.getValue(), 8);
                            bitArray.appendBits(mode.getBits(), 4);
                            bitArray2 = new BitArray();
                            ordinal = mode.ordinal();
                            if (ordinal != 1) {
                            }
                            if (map != null) {
                            }
                            version = Encoder.chooseVersion(mode.getCharacterCountBits(Encoder.chooseVersion(mode.getCharacterCountBits(Version.getVersionForNumber(1)) + bitArray.size + bitArray2.size, errorCorrectionLevel)) + bitArray.size + bitArray2.size, errorCorrectionLevel);
                            BitArray bitArray422 = new BitArray();
                            bitArray422.appendBitArray(bitArray);
                            if (mode == Mode.BYTE) {
                            }
                            int characterCountBits22 = mode.getCharacterCountBits(version);
                            i4 = 1 << characterCountBits22;
                            if (sizeInBytes < i4) {
                            }
                        }
                    }
                    str2 = "ISO-8859-1";
                    if ("Shift_JIS".equals(str2)) {
                    }
                    i8 = 0;
                    boolean z32 = false;
                    boolean z42 = false;
                    while (true) {
                        if (i8 < str.length()) {
                        }
                        i8++;
                    }
                    bitArray = new BitArray();
                    bitArray.appendBits(Mode.ECI.getBits(), 4);
                    bitArray.appendBits(characterSetECIByName.getValue(), 8);
                    bitArray.appendBits(mode.getBits(), 4);
                    bitArray2 = new BitArray();
                    ordinal = mode.ordinal();
                    if (ordinal != 1) {
                    }
                    if (map != null) {
                    }
                    version = Encoder.chooseVersion(mode.getCharacterCountBits(Encoder.chooseVersion(mode.getCharacterCountBits(Version.getVersionForNumber(1)) + bitArray.size + bitArray2.size, errorCorrectionLevel)) + bitArray.size + bitArray2.size, errorCorrectionLevel);
                    BitArray bitArray4222 = new BitArray();
                    bitArray4222.appendBitArray(bitArray);
                    if (mode == Mode.BYTE) {
                    }
                    int characterCountBits222 = mode.getCharacterCountBits(version);
                    i4 = 1 << characterCountBits222;
                    if (sizeInBytes < i4) {
                    }
                }
            }
            i3 = 4;
            if (map != null) {
            }
            str2 = "ISO-8859-1";
            if ("Shift_JIS".equals(str2)) {
            }
            i8 = 0;
            boolean z322 = false;
            boolean z422 = false;
            while (true) {
                if (i8 < str.length()) {
                }
                i8++;
            }
            bitArray = new BitArray();
            bitArray.appendBits(Mode.ECI.getBits(), 4);
            bitArray.appendBits(characterSetECIByName.getValue(), 8);
            bitArray.appendBits(mode.getBits(), 4);
            bitArray2 = new BitArray();
            ordinal = mode.ordinal();
            if (ordinal != 1) {
            }
            if (map != null) {
            }
            version = Encoder.chooseVersion(mode.getCharacterCountBits(Encoder.chooseVersion(mode.getCharacterCountBits(Version.getVersionForNumber(1)) + bitArray.size + bitArray2.size, errorCorrectionLevel)) + bitArray.size + bitArray2.size, errorCorrectionLevel);
            BitArray bitArray42222 = new BitArray();
            bitArray42222.appendBitArray(bitArray);
            if (mode == Mode.BYTE) {
            }
            int characterCountBits2222 = mode.getCharacterCountBits(version);
            i4 = 1 << characterCountBits2222;
            if (sizeInBytes < i4) {
            }
        }
    }
}
