package com.google.zxing.qrcode.detector;

import com.google.zxing.common.BitMatrix;
import com.yzq.zxinglibrary.view.ViewfinderResultPointCallback;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;

public class FinderPatternFinder {
    public final int[] crossCheckStateCount = new int[5];
    public boolean hasSkipped;
    public final BitMatrix image;
    public final List<FinderPattern> possibleCenters = new ArrayList();
    public final ViewfinderResultPointCallback resultPointCallback;

    public final class CenterComparator implements Serializable, Comparator<FinderPattern> {
        private final float average;

        public CenterComparator(float f, AnonymousClass1 r2) {
            this.average = f;
        }

        public int compare(FinderPattern finderPattern, FinderPattern finderPattern2) {
            int i = finderPattern2.count;
            int i2 = finderPattern.count;
            if (i != i2) {
                return i - i2;
            }
            float abs = Math.abs(finderPattern2.estimatedModuleSize - this.average);
            float abs2 = Math.abs(finderPattern.estimatedModuleSize - this.average);
            if (abs < abs2) {
                return 1;
            }
            return abs == abs2 ? 0 : -1;
        }
    }

    public final class FurthestFromAverageComparator implements Serializable, Comparator<FinderPattern> {
        private final float average;

        public FurthestFromAverageComparator(float f, AnonymousClass1 r2) {
            this.average = f;
        }

        public int compare(FinderPattern finderPattern, FinderPattern finderPattern2) {
            float abs = Math.abs(finderPattern2.estimatedModuleSize - this.average);
            float abs2 = Math.abs(finderPattern.estimatedModuleSize - this.average);
            if (abs < abs2) {
                return -1;
            }
            return abs == abs2 ? 0 : 1;
        }
    }

    public FinderPatternFinder(BitMatrix bitMatrix, ViewfinderResultPointCallback viewfinderResultPointCallback) {
        this.image = bitMatrix;
        this.resultPointCallback = viewfinderResultPointCallback;
    }

    public static float centerFromEnd(int[] iArr, int i) {
        return ((float) ((i - iArr[4]) - iArr[3])) - (((float) iArr[2]) / 2.0f);
    }

    public static boolean foundPatternCross(int[] iArr) {
        int i = 0;
        for (int i2 = 0; i2 < 5; i2++) {
            int i3 = iArr[i2];
            if (i3 == 0) {
                return false;
            }
            i += i3;
        }
        if (i < 7) {
            return false;
        }
        float f = ((float) i) / 7.0f;
        float f2 = f / 2.0f;
        if (Math.abs(f - ((float) iArr[0])) >= f2 || Math.abs(f - ((float) iArr[1])) >= f2 || Math.abs((f * 3.0f) - ((float) iArr[2])) >= 3.0f * f2 || Math.abs(f - ((float) iArr[3])) >= f2 || Math.abs(f - ((float) iArr[4])) >= f2) {
            return false;
        }
        return true;
    }

    public final int[] getCrossCheckStateCount() {
        int[] iArr = this.crossCheckStateCount;
        iArr[0] = 0;
        iArr[1] = 0;
        iArr[2] = 0;
        iArr[3] = 0;
        iArr[4] = 0;
        return iArr;
    }

    /* JADX WARNING: Removed duplicated region for block: B:109:0x01b7  */
    /* JADX WARNING: Removed duplicated region for block: B:165:0x027d  */
    /* JADX WARNING: Removed duplicated region for block: B:197:0x032a A[LOOP:18: B:183:0x02c5->B:197:0x032a, LOOP_END] */
    /* JADX WARNING: Removed duplicated region for block: B:255:0x0296 A[ADDED_TO_REGION, EDGE_INSN: B:255:0x0296->B:172:0x0296 ?: BREAK  , SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:258:0x0306 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:260:? A[ORIG_RETURN, RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:261:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:262:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00ea  */
    public final boolean handlePossibleCenter(int[] iArr, int i, int i2, boolean z) {
        float f;
        float f2;
        boolean z2;
        boolean z3;
        boolean z4;
        int i3;
        int i4;
        char c;
        int i5;
        int i6;
        int i7;
        char c2;
        int i8 = iArr[0] + iArr[1] + iArr[2] + iArr[3] + iArr[4];
        int centerFromEnd = (int) centerFromEnd(iArr, i2);
        int i9 = iArr[2];
        BitMatrix bitMatrix = this.image;
        int i10 = bitMatrix.height;
        int[] crossCheckStateCount2 = getCrossCheckStateCount();
        int i11 = i;
        while (i11 >= 0 && bitMatrix.get(centerFromEnd, i11)) {
            crossCheckStateCount2[2] = crossCheckStateCount2[2] + 1;
            i11--;
        }
        if (i11 >= 0) {
            while (i11 >= 0 && !bitMatrix.get(centerFromEnd, i11) && crossCheckStateCount2[1] <= i9) {
                crossCheckStateCount2[1] = crossCheckStateCount2[1] + 1;
                i11--;
            }
            if (i11 >= 0 && crossCheckStateCount2[1] <= i9) {
                while (i11 >= 0 && bitMatrix.get(centerFromEnd, i11) && crossCheckStateCount2[0] <= i9) {
                    crossCheckStateCount2[0] = crossCheckStateCount2[0] + 1;
                    i11--;
                }
                if (crossCheckStateCount2[0] <= i9) {
                    int i12 = i + 1;
                    while (i12 < i10 && bitMatrix.get(centerFromEnd, i12)) {
                        crossCheckStateCount2[2] = crossCheckStateCount2[2] + 1;
                        i12++;
                    }
                    if (i12 != i10) {
                        while (i12 < i10 && !bitMatrix.get(centerFromEnd, i12) && crossCheckStateCount2[3] < i9) {
                            crossCheckStateCount2[3] = crossCheckStateCount2[3] + 1;
                            i12++;
                        }
                        if (i12 != i10 && crossCheckStateCount2[3] < i9) {
                            while (i12 < i10 && bitMatrix.get(centerFromEnd, i12) && crossCheckStateCount2[4] < i9) {
                                crossCheckStateCount2[4] = crossCheckStateCount2[4] + 1;
                                i12++;
                            }
                            if (crossCheckStateCount2[4] < i9 && Math.abs(((((crossCheckStateCount2[0] + crossCheckStateCount2[1]) + crossCheckStateCount2[2]) + crossCheckStateCount2[3]) + crossCheckStateCount2[4]) - i8) * 5 < i8 * 2 && foundPatternCross(crossCheckStateCount2)) {
                                f = centerFromEnd(crossCheckStateCount2, i12);
                                if (!Float.isNaN(f)) {
                                    return false;
                                }
                                int i13 = (int) f;
                                int i14 = iArr[2];
                                BitMatrix bitMatrix2 = this.image;
                                int i15 = bitMatrix2.width;
                                int[] crossCheckStateCount3 = getCrossCheckStateCount();
                                int i16 = centerFromEnd;
                                while (i16 >= 0 && bitMatrix2.get(i16, i13)) {
                                    crossCheckStateCount3[2] = crossCheckStateCount3[2] + 1;
                                    i16--;
                                }
                                if (i16 >= 0) {
                                    while (i16 >= 0 && !bitMatrix2.get(i16, i13) && crossCheckStateCount3[1] <= i14) {
                                        crossCheckStateCount3[1] = crossCheckStateCount3[1] + 1;
                                        i16--;
                                    }
                                    if (i16 >= 0 && crossCheckStateCount3[1] <= i14) {
                                        while (i16 >= 0 && bitMatrix2.get(i16, i13) && crossCheckStateCount3[0] <= i14) {
                                            crossCheckStateCount3[0] = crossCheckStateCount3[0] + 1;
                                            i16--;
                                        }
                                        if (crossCheckStateCount3[0] <= i14) {
                                            int i17 = centerFromEnd + 1;
                                            while (i17 < i15 && bitMatrix2.get(i17, i13)) {
                                                crossCheckStateCount3[2] = crossCheckStateCount3[2] + 1;
                                                i17++;
                                            }
                                            if (i17 != i15) {
                                                while (i17 < i15 && !bitMatrix2.get(i17, i13) && crossCheckStateCount3[3] < i14) {
                                                    crossCheckStateCount3[3] = crossCheckStateCount3[3] + 1;
                                                    i17++;
                                                }
                                                if (i17 != i15 && crossCheckStateCount3[3] < i14) {
                                                    while (true) {
                                                        if (i17 < i15 && bitMatrix2.get(i17, i13)) {
                                                            c2 = 4;
                                                            if (crossCheckStateCount3[4] >= i14) {
                                                                break;
                                                            }
                                                            crossCheckStateCount3[4] = crossCheckStateCount3[4] + 1;
                                                            i17++;
                                                        } else {
                                                            c2 = 4;
                                                        }
                                                    }
                                                    if (crossCheckStateCount3[c2] < i14 && Math.abs(((((crossCheckStateCount3[0] + crossCheckStateCount3[1]) + crossCheckStateCount3[2]) + crossCheckStateCount3[3]) + crossCheckStateCount3[c2]) - i8) * 5 < i8 && foundPatternCross(crossCheckStateCount3)) {
                                                        f2 = centerFromEnd(crossCheckStateCount3, i17);
                                                        if (!Float.isNaN(f2)) {
                                                            return false;
                                                        }
                                                        if (z) {
                                                            int i18 = (int) f2;
                                                            int i19 = iArr[2];
                                                            int[] crossCheckStateCount4 = getCrossCheckStateCount();
                                                            int i20 = 0;
                                                            while (i13 >= i20 && i18 >= i20 && this.image.get(i18 - i20, i13 - i20)) {
                                                                crossCheckStateCount4[2] = crossCheckStateCount4[2] + 1;
                                                                i20++;
                                                            }
                                                            if (i13 >= i20 && i18 >= i20) {
                                                                while (i13 >= i20 && i18 >= i20 && !this.image.get(i18 - i20, i13 - i20) && crossCheckStateCount4[1] <= i19) {
                                                                    crossCheckStateCount4[1] = crossCheckStateCount4[1] + 1;
                                                                    i20++;
                                                                }
                                                                if (i13 >= i20 && i18 >= i20 && crossCheckStateCount4[1] <= i19) {
                                                                    while (i13 >= i20 && i18 >= i20 && this.image.get(i18 - i20, i13 - i20) && crossCheckStateCount4[0] <= i19) {
                                                                        crossCheckStateCount4[0] = crossCheckStateCount4[0] + 1;
                                                                        i20++;
                                                                    }
                                                                    if (crossCheckStateCount4[0] <= i19) {
                                                                        BitMatrix bitMatrix3 = this.image;
                                                                        int i21 = bitMatrix3.height;
                                                                        int i22 = bitMatrix3.width;
                                                                        int i23 = 1;
                                                                        while (true) {
                                                                            int i24 = i13 + i23;
                                                                            if (i24 < i21 && (i7 = i18 + i23) < i22 && this.image.get(i7, i24)) {
                                                                                crossCheckStateCount4[2] = crossCheckStateCount4[2] + 1;
                                                                                i23++;
                                                                            } else if (i24 < i21 && i18 + i23 < i22) {
                                                                                while (true) {
                                                                                    i3 = i13 + i23;
                                                                                    if (i3 < i21 && (i6 = i18 + i23) < i22 && !this.image.get(i6, i3) && crossCheckStateCount4[3] < i19) {
                                                                                        crossCheckStateCount4[3] = crossCheckStateCount4[3] + 1;
                                                                                        i23++;
                                                                                    } else if (i3 < i21 && i18 + i23 < i22 && crossCheckStateCount4[3] < i19) {
                                                                                        while (true) {
                                                                                            i4 = i13 + i23;
                                                                                            if (i4 >= i21 && (i5 = i18 + i23) < i22 && this.image.get(i5, i4)) {
                                                                                                c = 4;
                                                                                                if (crossCheckStateCount4[4] >= i19) {
                                                                                                    break;
                                                                                                }
                                                                                                crossCheckStateCount4[4] = crossCheckStateCount4[4] + 1;
                                                                                                i23++;
                                                                                            } else {
                                                                                                c = 4;
                                                                                            }
                                                                                        }
                                                                                        c = 4;
                                                                                        if (crossCheckStateCount4[c] < i19 && Math.abs(((((crossCheckStateCount4[0] + crossCheckStateCount4[1]) + crossCheckStateCount4[2]) + crossCheckStateCount4[3]) + crossCheckStateCount4[c]) - i8) < i8 * 2 && foundPatternCross(crossCheckStateCount4)) {
                                                                                            z4 = true;
                                                                                            if (!z4) {
                                                                                                return false;
                                                                                            }
                                                                                        }
                                                                                    }
                                                                                }
                                                                                while (true) {
                                                                                    i4 = i13 + i23;
                                                                                    if (i4 >= i21) {
                                                                                        break;
                                                                                    }
                                                                                    break;
                                                                                    crossCheckStateCount4[4] = crossCheckStateCount4[4] + 1;
                                                                                    i23++;
                                                                                }
                                                                                c = 4;
                                                                                z4 = true;
                                                                                if (!z4) {
                                                                                }
                                                                            }
                                                                        }
                                                                        while (true) {
                                                                            i3 = i13 + i23;
                                                                            if (i3 < i21) {
                                                                                break;
                                                                            }
                                                                            break;
                                                                            crossCheckStateCount4[3] = crossCheckStateCount4[3] + 1;
                                                                            i23++;
                                                                        }
                                                                        while (true) {
                                                                            i4 = i13 + i23;
                                                                            if (i4 >= i21) {
                                                                            }
                                                                            crossCheckStateCount4[4] = crossCheckStateCount4[4] + 1;
                                                                            i23++;
                                                                        }
                                                                        c = 4;
                                                                        z4 = true;
                                                                        if (!z4) {
                                                                        }
                                                                    }
                                                                }
                                                            }
                                                            z4 = false;
                                                            if (!z4) {
                                                            }
                                                        }
                                                        float f3 = ((float) i8) / 7.0f;
                                                        int i25 = 0;
                                                        while (true) {
                                                            if (i25 >= this.possibleCenters.size()) {
                                                                z2 = false;
                                                                break;
                                                            }
                                                            FinderPattern finderPattern = this.possibleCenters.get(i25);
                                                            if (Math.abs(f - finderPattern.y) <= f3 && Math.abs(f2 - finderPattern.x) <= f3) {
                                                                float abs = Math.abs(f3 - finderPattern.estimatedModuleSize);
                                                                if (abs <= 1.0f || abs <= finderPattern.estimatedModuleSize) {
                                                                    z3 = true;
                                                                    if (!z3) {
                                                                        List<FinderPattern> list = this.possibleCenters;
                                                                        int i26 = finderPattern.count;
                                                                        int i27 = i26 + 1;
                                                                        float f4 = (float) i26;
                                                                        float f5 = (float) i27;
                                                                        list.set(i25, new FinderPattern(((finderPattern.x * f4) + f2) / f5, ((finderPattern.y * f4) + f) / f5, ((f4 * finderPattern.estimatedModuleSize) + f3) / f5, i27));
                                                                        z2 = true;
                                                                        break;
                                                                    }
                                                                    i25++;
                                                                }
                                                            }
                                                            z3 = false;
                                                            if (!z3) {
                                                            }
                                                        }
                                                        if (!z2) {
                                                            FinderPattern finderPattern2 = new FinderPattern(f2, f, f3);
                                                            this.possibleCenters.add(finderPattern2);
                                                            ViewfinderResultPointCallback viewfinderResultPointCallback = this.resultPointCallback;
                                                            if (viewfinderResultPointCallback != null) {
                                                                viewfinderResultPointCallback.foundPossibleResultPoint(finderPattern2);
                                                            }
                                                        }
                                                        return true;
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                                f2 = Float.NaN;
                                if (!Float.isNaN(f2)) {
                                }
                            }
                        }
                    }
                }
            }
        }
        f = Float.NaN;
        if (!Float.isNaN(f)) {
        }
    }

    public final boolean haveMultiplyConfirmedCenters() {
        int size = this.possibleCenters.size();
        float f = 0.0f;
        int i = 0;
        float f2 = 0.0f;
        for (FinderPattern finderPattern : this.possibleCenters) {
            if (finderPattern.count >= 2) {
                i++;
                f2 += finderPattern.estimatedModuleSize;
            }
        }
        if (i < 3) {
            return false;
        }
        float f3 = f2 / ((float) size);
        for (FinderPattern finderPattern2 : this.possibleCenters) {
            f += Math.abs(finderPattern2.estimatedModuleSize - f3);
        }
        if (f <= f2 * 0.05f) {
            return true;
        }
        return false;
    }
}
