package io.netty.bootstrap;

import io.netty.bootstrap.AbstractBootstrap;
import io.netty.channel.Channel;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelPromise;
import io.netty.channel.EventLoopGroup;
import io.netty.resolver.AddressResolver;
import io.netty.resolver.AddressResolverGroup;
import io.netty.resolver.DefaultAddressResolverGroup;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.FutureListener;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.SocketAddress;

public class Bootstrap extends AbstractBootstrap<Bootstrap, Channel> {
    private static final AddressResolverGroup<?> DEFAULT_RESOLVER = DefaultAddressResolverGroup.INSTANCE;
    private static final InternalLogger logger = InternalLoggerFactory.getInstance(Bootstrap.class);
    private final BootstrapConfig config = new BootstrapConfig(this);
    private volatile SocketAddress remoteAddress;
    private volatile AddressResolverGroup<SocketAddress> resolver = DEFAULT_RESOLVER;

    /* JADX DEBUG: Type inference failed for r0v1. Raw type applied. Possible types: io.netty.resolver.AddressResolverGroup<?>, io.netty.resolver.AddressResolverGroup<java.net.SocketAddress> */
    public Bootstrap() {
    }

    /* access modifiers changed from: private */
    public static void doConnect(final SocketAddress socketAddress, final SocketAddress socketAddress2, final ChannelPromise channelPromise) {
        final Channel channel = channelPromise.channel();
        channel.eventLoop().execute(new Runnable() {
            /* class io.netty.bootstrap.Bootstrap.AnonymousClass3 */

            public void run() {
                SocketAddress socketAddress = socketAddress2;
                if (socketAddress == null) {
                    channel.connect(socketAddress, channelPromise);
                } else {
                    channel.connect(socketAddress, socketAddress, channelPromise);
                }
                channelPromise.addListener((GenericFutureListener<? extends Future<? super Void>>) ChannelFutureListener.CLOSE_ON_FAILURE);
            }
        });
    }

    private ChannelFuture doResolveAndConnect(final SocketAddress socketAddress, final SocketAddress socketAddress2) {
        ChannelFuture initAndRegister = initAndRegister();
        final Channel channel = initAndRegister.channel();
        if (!initAndRegister.isDone()) {
            final AbstractBootstrap.PendingRegistrationPromise pendingRegistrationPromise = new AbstractBootstrap.PendingRegistrationPromise(channel);
            initAndRegister.addListener((GenericFutureListener<? extends Future<? super Void>>) new ChannelFutureListener() {
                /* class io.netty.bootstrap.Bootstrap.AnonymousClass1 */

                public void operationComplete(ChannelFuture channelFuture) {
                    Throwable cause = channelFuture.cause();
                    if (cause != null) {
                        pendingRegistrationPromise.setFailure(cause);
                        return;
                    }
                    pendingRegistrationPromise.registered();
                    Bootstrap.this.doResolveAndConnect0(channel, socketAddress, socketAddress2, pendingRegistrationPromise);
                }
            });
            return pendingRegistrationPromise;
        } else if (!initAndRegister.isSuccess()) {
            return initAndRegister;
        } else {
            return doResolveAndConnect0(channel, socketAddress, socketAddress2, channel.newPromise());
        }
    }

    /* JADX WARN: Type inference failed for: r3v2, types: [io.netty.channel.ChannelPromise, io.netty.channel.ChannelFuture] */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Unknown variable types count: 1 */
    private ChannelFuture doResolveAndConnect0(final Channel channel, SocketAddress socketAddress, final SocketAddress socketAddress2, final ChannelPromise channelPromise) {
        try {
            try {
                AddressResolver<SocketAddress> resolver2 = this.resolver.getResolver(channel.eventLoop());
                if (!resolver2.isSupported(socketAddress) || resolver2.isResolved(socketAddress)) {
                    doConnect(socketAddress, socketAddress2, channelPromise);
                    return channelPromise;
                }
                Future<SocketAddress> resolve = resolver2.resolve(socketAddress);
                if (resolve.isDone()) {
                    Throwable cause = resolve.cause();
                    if (cause != null) {
                        channel.close();
                        channelPromise.setFailure(cause);
                    } else {
                        doConnect(resolve.getNow(), socketAddress2, channelPromise);
                    }
                    return channelPromise;
                }
                resolve.addListener(new FutureListener<SocketAddress>() {
                    /* class io.netty.bootstrap.Bootstrap.AnonymousClass2 */

                    @Override // io.netty.util.concurrent.GenericFutureListener
                    public void operationComplete(Future<SocketAddress> future) {
                        if (future.cause() != null) {
                            channel.close();
                            channelPromise.setFailure(future.cause());
                            return;
                        }
                        Bootstrap.doConnect(future.getNow(), socketAddress2, channelPromise);
                    }
                });
                return channelPromise;
            } catch (Throwable th) {
                channel.close();
                return channelPromise.setFailure(th);
            }
        } catch (Throwable th2) {
            channelPromise.tryFailure(th2);
        }
    }

    public ChannelFuture connect() {
        validate();
        SocketAddress socketAddress = this.remoteAddress;
        if (socketAddress != null) {
            return doResolveAndConnect(socketAddress, this.config.localAddress());
        }
        throw new IllegalStateException("remoteAddress not set");
    }

    @Override // io.netty.bootstrap.AbstractBootstrap
    public void init(Channel channel) {
        channel.pipeline().addLast(this.config.handler());
        AbstractBootstrap.setChannelOptions(channel, newOptionsArray(), logger);
        AbstractBootstrap.setAttributes(channel, newAttributesArray());
    }

    public Bootstrap remoteAddress(SocketAddress socketAddress) {
        this.remoteAddress = socketAddress;
        return this;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:0:0x0000 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r1v0, types: [io.netty.resolver.AddressResolverGroup<?>] */
    /* JADX WARN: Type inference failed for: r1v1, types: [io.netty.resolver.AddressResolverGroup<java.net.SocketAddress>] */
    /* JADX WARN: Type inference failed for: r1v2, types: [io.netty.resolver.AddressResolverGroup<?>] */
    public Bootstrap resolver(AddressResolverGroup<?> addressResolverGroup) {
        if (addressResolverGroup == 0) {
            addressResolverGroup = DEFAULT_RESOLVER;
        }
        this.resolver = addressResolverGroup;
        return this;
    }

    /* Return type fixed from 'io.netty.bootstrap.BootstrapConfig' to match base method */
    @Override // io.netty.bootstrap.AbstractBootstrap
    public final AbstractBootstrapConfig<Bootstrap, Channel> config() {
        return this.config;
    }

    public Bootstrap remoteAddress(String str, int i) {
        this.remoteAddress = InetSocketAddress.createUnresolved(str, i);
        return this;
    }

    public final AddressResolverGroup<?> resolver() {
        return this.resolver;
    }

    @Override // io.netty.bootstrap.AbstractBootstrap
    public Bootstrap validate() {
        super.validate();
        if (this.config.handler() != null) {
            return this;
        }
        throw new IllegalStateException("handler not set");
    }

    @Override // io.netty.bootstrap.AbstractBootstrap, io.netty.bootstrap.AbstractBootstrap, java.lang.Object
    public Bootstrap clone() {
        return new Bootstrap(this);
    }

    public Bootstrap remoteAddress(InetAddress inetAddress, int i) {
        this.remoteAddress = new InetSocketAddress(inetAddress, i);
        return this;
    }

    /* JADX DEBUG: Type inference failed for r0v1. Raw type applied. Possible types: io.netty.resolver.AddressResolverGroup<?>, io.netty.resolver.AddressResolverGroup<java.net.SocketAddress> */
    private Bootstrap(Bootstrap bootstrap) {
        super(bootstrap);
        this.resolver = bootstrap.resolver;
        this.remoteAddress = bootstrap.remoteAddress;
    }

    public Bootstrap clone(EventLoopGroup eventLoopGroup) {
        Bootstrap bootstrap = new Bootstrap(this);
        bootstrap.group = eventLoopGroup;
        return bootstrap;
    }

    public final SocketAddress remoteAddress() {
        return this.remoteAddress;
    }

    public ChannelFuture connect(String str, int i) {
        return connect(InetSocketAddress.createUnresolved(str, i));
    }

    public ChannelFuture connect(InetAddress inetAddress, int i) {
        return connect(new InetSocketAddress(inetAddress, i));
    }

    public ChannelFuture connect(SocketAddress socketAddress) {
        ObjectUtil.checkNotNull(socketAddress, "remoteAddress");
        validate();
        return doResolveAndConnect(socketAddress, this.config.localAddress());
    }

    public ChannelFuture connect(SocketAddress socketAddress, SocketAddress socketAddress2) {
        ObjectUtil.checkNotNull(socketAddress, "remoteAddress");
        validate();
        return doResolveAndConnect(socketAddress, socketAddress2);
    }
}
