package io.netty.channel;

import io.netty.channel.ChannelFlushPromiseNotifier;
import io.netty.util.concurrent.DefaultProgressivePromise;
import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.ProgressivePromise;

public class DefaultChannelProgressivePromise extends DefaultProgressivePromise<Void> implements ChannelProgressivePromise, ChannelFlushPromiseNotifier.FlushCheckpoint {
    private final Channel channel;
    private long checkpoint;

    public DefaultChannelProgressivePromise(Channel channel2) {
        this.channel = channel2;
    }

    @Override // io.netty.channel.ChannelFuture, io.netty.channel.ChannelPromise
    public Channel channel() {
        return this.channel;
    }

    @Override // io.netty.util.concurrent.DefaultPromise
    public void checkDeadLock() {
        if (channel().isRegistered()) {
            super.checkDeadLock();
        }
    }

    @Override // io.netty.util.concurrent.DefaultPromise
    public EventExecutor executor() {
        EventExecutor executor = super.executor();
        return executor == null ? channel().eventLoop() : executor;
    }

    @Override // io.netty.channel.ChannelFlushPromiseNotifier.FlushCheckpoint
    public long flushCheckpoint() {
        return this.checkpoint;
    }

    @Override // io.netty.channel.ChannelFuture
    public boolean isVoid() {
        return false;
    }

    @Override // io.netty.channel.ChannelFlushPromiseNotifier.FlushCheckpoint
    public ChannelProgressivePromise promise() {
        return this;
    }

    @Override // io.netty.channel.ChannelPromise
    public boolean trySuccess() {
        return trySuccess(null);
    }

    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.channel.ChannelPromise
    public ChannelProgressivePromise unvoid() {
        return this;
    }

    @Override // io.netty.channel.ChannelFlushPromiseNotifier.FlushCheckpoint
    public void flushCheckpoint(long j) {
        this.checkpoint = j;
    }

    /* Return type fixed from 'io.netty.channel.ChannelProgressivePromise' to match base method */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.ProgressivePromise
    public ProgressivePromise<Void> setProgress(long j, long j2) {
        super.setProgress(j, j2);
        return this;
    }

    public DefaultChannelProgressivePromise(Channel channel2, EventExecutor eventExecutor) {
        super(eventExecutor);
        this.channel = channel2;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise
    public ProgressivePromise<Void> setFailure(Throwable th) {
        super.setFailure(th);
        return this;
    }

    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.channel.ChannelPromise
    public ChannelProgressivePromise setSuccess() {
        return setSuccess((Void) null);
    }

    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.channel.ChannelPromise
    public ChannelProgressivePromise setSuccess(Void r1) {
        super.setSuccess((Object) r1);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> addListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        super.addListener((GenericFutureListener) genericFutureListener);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> addListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        super.addListeners((GenericFutureListener[]) genericFutureListenerArr);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> await() {
        super.await();
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> awaitUninterruptibly() {
        super.awaitUninterruptibly();
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> removeListener(GenericFutureListener<? extends Future<? super Void>> genericFutureListener) {
        super.removeListener((GenericFutureListener) genericFutureListener);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> removeListeners(GenericFutureListener<? extends Future<? super Void>>... genericFutureListenerArr) {
        super.removeListeners((GenericFutureListener[]) genericFutureListenerArr);
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> sync() {
        super.sync();
        return this;
    }

    /* JADX WARN: Due to multiple override return type can be incorrect, original value: io.netty.channel.ChannelProgressivePromise */
    @Override // io.netty.channel.ChannelProgressivePromise, io.netty.util.concurrent.Promise, io.netty.util.concurrent.ProgressiveFuture, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.util.concurrent.DefaultProgressivePromise, io.netty.channel.ChannelFuture, io.netty.util.concurrent.DefaultPromise, io.netty.util.concurrent.DefaultPromise, io.netty.channel.ChannelProgressiveFuture, io.netty.channel.ChannelPromise, io.netty.util.concurrent.ProgressivePromise, io.netty.util.concurrent.Future
    public ProgressivePromise<Void> syncUninterruptibly() {
        super.syncUninterruptibly();
        return this;
    }
}
