package io.netty.handler.codec.compression;

import com.android.tools.r8.GeneratedOutlineSupport;
import org.xbill.DNS.CERTRecord;
import org.xbill.DNS.KEYRecord;

public final class Bzip2DivSufSort {
    private static final int BUCKET_A_SIZE = 256;
    private static final int BUCKET_B_SIZE = 65536;
    private static final int INSERTIONSORT_THRESHOLD = 8;
    private static final int[] LOG_2_TABLE = {-1, 0, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7};
    private static final int SS_BLOCKSIZE = 1024;
    private static final int STACK_SIZE = 64;
    private final int[] SA;
    private final byte[] T;
    private final int n;

    public static class PartitionResult {
        public final int first;
        public final int last;

        public PartitionResult(int i, int i2) {
            this.first = i;
            this.last = i2;
        }
    }

    public static class StackEntry {
        public final int a;
        public final int b;
        public final int c;
        public final int d;

        public StackEntry(int i, int i2, int i3, int i4) {
            this.a = i;
            this.b = i2;
            this.c = i3;
            this.d = i4;
        }
    }

    public static class TRBudget {
        public int budget;
        public int chance;

        public TRBudget(int i, int i2) {
            this.budget = i;
            this.chance = i2;
        }

        public boolean update(int i, int i2) {
            int i3 = this.budget - i2;
            this.budget = i3;
            if (i3 <= 0) {
                int i4 = this.chance - 1;
                this.chance = i4;
                if (i4 == 0) {
                    return false;
                }
                this.budget = i3 + i;
            }
            return true;
        }
    }

    public Bzip2DivSufSort(byte[] bArr, int[] iArr, int i) {
        this.T = bArr;
        this.SA = iArr;
        this.n = i;
    }

    private static int BUCKET_B(int i, int i2) {
        return i | (i2 << 8);
    }

    private static int BUCKET_BSTAR(int i, int i2) {
        return (i << 8) | i2;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: byte[] */
    /* JADX DEBUG: Multi-variable search result rejected for r4v5, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r14v5, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r9v0, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r10v1, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r10v4, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r11v0, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r9v6, resolved type: byte */
    /* JADX WARN: Multi-variable type inference failed */
    private int constructBWT(int[] iArr, int[] iArr2) {
        byte[] bArr = this.T;
        int[] iArr3 = this.SA;
        int i = this.n;
        int i2 = CERTRecord.OID;
        int i3 = 0;
        int i4 = 0;
        while (i2 >= 0) {
            int i5 = i2 + 1;
            int i6 = iArr2[BUCKET_BSTAR(i2, i5)];
            int i7 = 0;
            int i8 = -1;
            for (int i9 = iArr[i5]; i6 <= i9; i9--) {
                int i10 = iArr3[i9];
                if (i10 >= 0) {
                    int i11 = i10 - 1;
                    if (i11 < 0) {
                        i11 = i - 1;
                    }
                    int i12 = bArr[i11] & KEYRecord.PROTOCOL_ANY;
                    if (i12 <= i2) {
                        iArr3[i9] = ~i10;
                        if (i11 > 0 && (bArr[i11 - 1] & KEYRecord.PROTOCOL_ANY) > i12) {
                            i11 = ~i11;
                        }
                        if (i8 == i12) {
                            i7--;
                            iArr3[i7] = i11;
                        } else {
                            if (i8 >= 0) {
                                iArr2[BUCKET_B(i8, i2)] = i7;
                            }
                            i7 = iArr2[BUCKET_B(i12, i2)] - 1;
                            iArr3[i7] = i11;
                            i8 = i12;
                        }
                    }
                } else {
                    iArr3[i9] = ~i10;
                }
            }
            i2--;
            i3 = i7;
            i4 = i8;
        }
        int i13 = -1;
        for (int i14 = 0; i14 < i; i14++) {
            int i15 = iArr3[i14];
            if (i15 >= 0) {
                int i16 = i15 - 1;
                if (i16 < 0) {
                    i16 = i - 1;
                }
                int i17 = bArr[i16] & KEYRecord.PROTOCOL_ANY;
                if (i17 >= (bArr[i16 + 1] & KEYRecord.PROTOCOL_ANY)) {
                    if (i16 > 0 && (bArr[i16 - 1] & KEYRecord.PROTOCOL_ANY) < i17) {
                        i16 = ~i16;
                    }
                    if (i17 == i4) {
                        i3++;
                        iArr3[i3] = i16;
                    } else {
                        if (i4 != -1) {
                            iArr[i4] = i3;
                        }
                        i3 = iArr[i17] + 1;
                        iArr3[i3] = i16;
                        i4 = i17;
                    }
                }
            } else {
                i15 = ~i15;
            }
            if (i15 == 0) {
                iArr3[i14] = bArr[i - 1];
                i13 = i14;
            } else {
                iArr3[i14] = bArr[i15 - 1];
            }
        }
        return i13;
    }

    private static int getIDX(int i) {
        return i >= 0 ? i : ~i;
    }

    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:106:0x01be  */
    /* JADX WARNING: Removed duplicated region for block: B:135:0x0132 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:141:0x0119 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x0104  */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x0114  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x0122  */
    /* JADX WARNING: Removed duplicated region for block: B:73:0x0134  */
    private void lsIntroSort(int r21, int r22, int r23, int r24, int r25) {
        /*
        // Method dump skipped, instructions count: 462
        */
        throw new UnsupportedOperationException("Method not decompiled: io.netty.handler.codec.compression.Bzip2DivSufSort.lsIntroSort(int, int, int, int, int):void");
    }

    private void lsSort(int i, int i2, int i3) {
        int i4;
        int[] iArr = this.SA;
        int i5 = i3 + i;
        while (true) {
            int i6 = 0;
            if ((-i2) < iArr[0]) {
                int i7 = 0;
                int i8 = 0;
                do {
                    int i9 = iArr[i8];
                    if (i9 < 0) {
                        i8 -= i9;
                        i7 += i9;
                        continue;
                    } else {
                        if (i7 != 0) {
                            iArr[i8 + i7] = i7;
                            i4 = 0;
                        } else {
                            i4 = i7;
                        }
                        int i10 = iArr[i9 + i] + 1;
                        lsIntroSort(i, i5, i + i2, i8, i10);
                        i7 = i4;
                        i8 = i10;
                        continue;
                    }
                } while (i8 < i2);
                if (i7 != 0) {
                    iArr[i8 + i7] = i7;
                }
                int i11 = i5 - i;
                if (i2 < i11) {
                    do {
                        int i12 = iArr[i6];
                        if (i12 < 0) {
                            i6 -= i12;
                            continue;
                        } else {
                            int i13 = iArr[i12 + i] + 1;
                            while (i6 < i13) {
                                iArr[iArr[i6] + i] = i6;
                                i6++;
                            }
                            i6 = i13;
                            continue;
                        }
                    } while (i6 < i2);
                    return;
                }
                i5 += i11;
            } else {
                return;
            }
        }
    }

    private void lsUpdateGroup(int i, int i2, int i3) {
        int[] iArr = this.SA;
        while (i2 < i3) {
            if (iArr[i2] >= 0) {
                int i4 = i2;
                do {
                    iArr[iArr[i4] + i] = i4;
                    i4++;
                    if (i4 >= i3) {
                        break;
                    }
                } while (iArr[i4] >= 0);
                iArr[i2] = i2 - i4;
                if (i3 > i4) {
                    i2 = i4;
                } else {
                    return;
                }
            }
            int i5 = i2;
            do {
                iArr[i5] = ~iArr[i5];
                i5++;
            } while (iArr[i5] < 0);
            do {
                iArr[iArr[i2] + i] = i5;
                i2++;
            } while (i2 <= i5);
            i2 = i5 + 1;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0029, code lost:
        r16 = true;
     */
    private int sortTypeBstar(int[] iArr, int[] iArr2) {
        boolean z;
        int i;
        int i2;
        int i3;
        int[] iArr3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        byte[] bArr = this.T;
        int[] iArr4 = this.SA;
        int i13 = this.n;
        int[] iArr5 = new int[256];
        int i14 = 1;
        while (true) {
            if (i14 >= i13) {
                break;
            }
            int i15 = i14 - 1;
            if (bArr[i15] == bArr[i14]) {
                i14++;
            } else if ((bArr[i15] & 255) > (bArr[i14] & 255)) {
                z = false;
            }
        }
        int i16 = i13 - 1;
        int i17 = bArr[i16] & 255;
        int i18 = bArr[0] & 255;
        if (i17 < i18 || (bArr[i16] == bArr[0] && z)) {
            if (!z) {
                int BUCKET_BSTAR = BUCKET_BSTAR(i17, i18);
                iArr2[BUCKET_BSTAR] = iArr2[BUCKET_BSTAR] + 1;
                i2 = i13 - 1;
                iArr4[i2] = i16;
            } else {
                int BUCKET_B = BUCKET_B(i17, i18);
                iArr2[BUCKET_B] = iArr2[BUCKET_B] + 1;
                i2 = i13;
            }
            i = i16 - 1;
            while (i >= 0) {
                int i19 = bArr[i] & 255;
                int i20 = bArr[i + 1] & 255;
                if (i19 > i20) {
                    break;
                }
                int BUCKET_B2 = BUCKET_B(i19, i20);
                iArr2[BUCKET_B2] = iArr2[BUCKET_B2] + 1;
                i--;
            }
        } else {
            i2 = i13;
            i = i16;
        }
        while (i >= 0) {
            do {
                int i21 = bArr[i] & 255;
                iArr[i21] = iArr[i21] + 1;
                i--;
                if (i < 0) {
                    break;
                }
            } while ((bArr[i] & 255) >= (bArr[i + 1] & 255));
            if (i >= 0) {
                int BUCKET_BSTAR2 = BUCKET_BSTAR(bArr[i] & 255, bArr[i + 1] & 255);
                iArr2[BUCKET_BSTAR2] = iArr2[BUCKET_BSTAR2] + 1;
                i2--;
                iArr4[i2] = i;
                while (true) {
                    i--;
                    if (i < 0 || (i11 = bArr[i] & 255) > (i12 = bArr[i + 1] & 255)) {
                        break;
                    }
                    int BUCKET_B3 = BUCKET_B(i11, i12);
                    iArr2[BUCKET_B3] = iArr2[BUCKET_B3] + 1;
                }
            }
        }
        int i22 = i13 - i2;
        if (i22 == 0) {
            for (int i23 = 0; i23 < i13; i23++) {
                iArr4[i23] = i23;
            }
            return 0;
        }
        int i24 = 0;
        int i25 = -1;
        int i26 = 0;
        while (i24 < 256) {
            int i27 = iArr[i24] + i25;
            iArr[i24] = i25 + i26;
            int i28 = i27 + iArr2[BUCKET_B(i24, i24)];
            int i29 = i24 + 1;
            for (int i30 = i29; i30 < 256; i30++) {
                i26 += iArr2[BUCKET_BSTAR(i24, i30)];
                iArr2[(i24 << 8) | i30] = i26;
                i28 += iArr2[BUCKET_B(i24, i30)];
            }
            i24 = i29;
            i25 = i28;
        }
        int i31 = i13 - i22;
        for (int i32 = i22 - 2; i32 >= 0; i32--) {
            int i33 = iArr4[i31 + i32];
            int BUCKET_BSTAR3 = BUCKET_BSTAR(bArr[i33] & 255, bArr[i33 + 1] & 255);
            int i34 = iArr2[BUCKET_BSTAR3] - 1;
            iArr2[BUCKET_BSTAR3] = i34;
            iArr4[i34] = i32;
        }
        int i35 = iArr4[(i31 + i22) - 1];
        int BUCKET_BSTAR4 = BUCKET_BSTAR(bArr[i35] & 255, bArr[i35 + 1] & 255);
        int i36 = iArr2[BUCKET_BSTAR4] - 1;
        iArr2[BUCKET_BSTAR4] = i36;
        int i37 = i22 - 1;
        iArr4[i36] = i37;
        int i38 = i13 - (i22 * 2);
        if (i38 <= 256) {
            iArr3 = iArr5;
            i4 = 256;
            i3 = 0;
        } else {
            i4 = i38;
            i3 = i22;
            iArr3 = iArr4;
        }
        int i39 = i22;
        int i40 = KEYRecord.PROTOCOL_ANY;
        while (i39 > 0) {
            int i41 = i39;
            int i42 = KEYRecord.PROTOCOL_ANY;
            while (i40 < i42) {
                int i43 = iArr2[BUCKET_BSTAR(i40, i42)];
                if (1 < i41 - i43) {
                    i9 = i42;
                    i8 = i40;
                    i7 = i37;
                    i10 = i22;
                    subStringSort(i31, i43, i41, iArr3, i3, i4, 2, iArr4[i43] == i37, i13);
                } else {
                    i9 = i42;
                    i8 = i40;
                    i7 = i37;
                    i10 = i22;
                }
                i42 = i9 - 1;
                i22 = i10;
                i41 = i43;
                i40 = i8;
                i37 = i7;
            }
            i40--;
            i39 = i41;
        }
        while (i37 >= 0) {
            if (iArr4[i37] >= 0) {
                int i44 = i37;
                do {
                    iArr4[i22 + iArr4[i44]] = i44;
                    i44--;
                    if (i44 < 0) {
                        break;
                    }
                } while (iArr4[i44] >= 0);
                iArr4[i44 + 1] = i44 - i37;
                if (i44 <= 0) {
                    break;
                }
                i37 = i44;
            }
            int i45 = i37;
            do {
                int i46 = ~iArr4[i45];
                iArr4[i45] = i46;
                iArr4[i22 + i46] = i37;
                i45--;
            } while (iArr4[i45] < 0);
            iArr4[i22 + iArr4[i45]] = i37;
            i37 = i45 - 1;
        }
        trSort(i22, i22, 1);
        if ((bArr[i16] & 255) < (bArr[0] & 255) || (bArr[i16] == bArr[0] && z)) {
            if (!z) {
                i5 = i22 - 1;
                iArr4[iArr4[i22 + i5]] = i16;
            } else {
                i5 = i22;
            }
            i6 = i16 - 1;
            while (i6 >= 0 && (bArr[i6] & 255) <= (bArr[i6 + 1] & 255)) {
                i6--;
            }
        } else {
            i5 = i22;
            i6 = i16;
        }
        while (i6 >= 0) {
            do {
                i6--;
                if (i6 < 0) {
                    break;
                }
            } while ((bArr[i6] & 255) >= (bArr[i6 + 1] & 255));
            if (i6 >= 0) {
                i5--;
                iArr4[iArr4[i22 + i5]] = i6;
                do {
                    i6--;
                    if (i6 < 0) {
                        break;
                    }
                } while ((bArr[i6] & 255) <= (bArr[i6 + 1] & 255));
            }
        }
        int i47 = i37;
        for (int i48 = KEYRecord.PROTOCOL_ANY; i48 >= 0; i48--) {
            for (int i49 = KEYRecord.PROTOCOL_ANY; i48 < i49; i49--) {
                int i50 = i16 - iArr2[BUCKET_B(i48, i49)];
                iArr2[BUCKET_B(i48, i49)] = i16 + 1;
                int i51 = iArr2[BUCKET_BSTAR(i48, i49)];
                i16 = i50;
                while (i51 <= i47) {
                    iArr4[i16] = iArr4[i47];
                    i16--;
                    i47--;
                }
            }
            int i52 = i16 - iArr2[BUCKET_B(i48, i48)];
            iArr2[BUCKET_B(i48, i48)] = i16 + 1;
            if (i48 < 255) {
                iArr2[BUCKET_BSTAR(i48, i48 + 1)] = i52 + 1;
            }
            i16 = iArr[i48];
        }
        return i22;
    }

    private static void ssBlockSwap(int[] iArr, int i, int[] iArr2, int i2, int i3) {
        while (i3 > 0) {
            swapElements(iArr, i, iArr2, i2);
            i3--;
            i++;
            i2++;
        }
    }

    private int ssCompare(int i, int i2, int i3) {
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i4 = iArr[i + 1] + 2;
        int i5 = iArr[i2 + 1] + 2;
        int i6 = iArr[i] + i3;
        int i7 = i3 + iArr[i2];
        while (i6 < i4 && i7 < i5 && bArr[i6] == bArr[i7]) {
            i6++;
            i7++;
        }
        if (i6 >= i4) {
            return i7 < i5 ? -1 : 0;
        }
        if (i7 < i5) {
            return (bArr[i6] & 255) - (bArr[i7] & 255);
        }
        return 1;
    }

    private int ssCompareLast(int i, int i2, int i3, int i4, int i5) {
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i6 = iArr[i2] + i4;
        int i7 = i4 + iArr[i3];
        int i8 = iArr[i3 + 1] + 2;
        while (i6 < i5 && i7 < i8 && bArr[i6] == bArr[i7]) {
            i6++;
            i7++;
        }
        if (i6 < i5) {
            if (i7 < i8) {
                return (bArr[i6] & 255) - (bArr[i7] & 255);
            }
            return 1;
        } else if (i7 == i8) {
            return 1;
        } else {
            int i9 = i6 % i5;
            int i10 = iArr[i] + 2;
            while (i9 < i10 && i7 < i8 && bArr[i9] == bArr[i7]) {
                i9++;
                i7++;
            }
            if (i9 >= i10) {
                return i7 < i8 ? -1 : 0;
            }
            if (i7 < i8) {
                return (bArr[i9] & 255) - (bArr[i7] & 255);
            }
            return 1;
        }
    }

    private void ssFixdown(int i, int i2, int i3, int i4, int i5) {
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i6 = iArr[i3 + i4];
        int i7 = bArr[iArr[i2 + i6] + i] & 255;
        while (true) {
            int i8 = (i4 * 2) + 1;
            if (i8 >= i5) {
                break;
            }
            int i9 = i8 + 1;
            int i10 = bArr[iArr[iArr[i3 + i8] + i2] + i] & 255;
            int i11 = bArr[iArr[iArr[i3 + i9] + i2] + i] & 255;
            if (i10 < i11) {
                i8 = i9;
                i10 = i11;
            }
            if (i10 <= i7) {
                break;
            }
            iArr[i4 + i3] = iArr[i3 + i8];
            i4 = i8;
        }
        iArr[i3 + i4] = i6;
    }

    private void ssHeapSort(int i, int i2, int i3, int i4) {
        int i5;
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i6 = i4 % 2;
        if (i6 == 0) {
            int i7 = i4 - 1;
            int i8 = (i7 / 2) + i3;
            int i9 = i3 + i7;
            if ((bArr[iArr[iArr[i8] + i2] + i] & 255) < (bArr[iArr[iArr[i9] + i2] + i] & 255)) {
                swapElements(iArr, i9, iArr, i8);
            }
            i5 = i7;
        } else {
            i5 = i4;
        }
        for (int i10 = (i5 / 2) - 1; i10 >= 0; i10--) {
            ssFixdown(i, i2, i3, i10, i5);
        }
        if (i6 == 0) {
            swapElements(iArr, i3, iArr, i3 + i5);
            ssFixdown(i, i2, i3, 0, i5);
        }
        for (int i11 = i5 - 1; i11 > 0; i11--) {
            int i12 = iArr[i3];
            int i13 = i3 + i11;
            iArr[i3] = iArr[i13];
            ssFixdown(i, i2, i3, 0, i11);
            iArr[i13] = i12;
        }
    }

    private void ssInsertionSort(int i, int i2, int i3, int i4) {
        int ssCompare;
        int[] iArr = this.SA;
        for (int i5 = i3 - 2; i2 <= i5; i5--) {
            int i6 = iArr[i5];
            int i7 = i5 + 1;
            do {
                ssCompare = ssCompare(i + i6, iArr[i7] + i, i4);
                if (ssCompare <= 0) {
                    break;
                }
                do {
                    iArr[i7 - 1] = iArr[i7];
                    i7++;
                    if (i7 >= i3) {
                        break;
                    }
                } while (iArr[i7] < 0);
                continue;
            } while (i3 > i7);
            if (ssCompare == 0) {
                iArr[i7] = ~iArr[i7];
            }
            iArr[i7 - 1] = i6;
        }
    }

    private static int ssLog(int i) {
        return (65280 & i) != 0 ? LOG_2_TABLE[(i >> 8) & KEYRecord.PROTOCOL_ANY] + 8 : LOG_2_TABLE[i & KEYRecord.PROTOCOL_ANY];
    }

    private int ssMedian3(int i, int i2, int i3, int i4, int i5) {
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i6 = bArr[iArr[iArr[i3] + i2] + i] & 255;
        int i7 = bArr[iArr[iArr[i4] + i2] + i] & 255;
        int i8 = bArr[i + iArr[i2 + iArr[i5]]] & 255;
        if (i6 <= i7) {
            i4 = i3;
            i3 = i4;
            i7 = i6;
            i6 = i7;
        }
        if (i6 > i8) {
            return i7 > i8 ? i4 : i5;
        }
        return i3;
    }

    private int ssMedian5(int i, int i2, int i3, int i4, int i5, int i6, int i7) {
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i17 = bArr[iArr[iArr[i3] + i2] + i] & 255;
        int i18 = bArr[iArr[iArr[i4] + i2] + i] & 255;
        int i19 = bArr[iArr[iArr[i5] + i2] + i] & 255;
        int i20 = bArr[iArr[iArr[i6] + i2] + i] & 255;
        int i21 = bArr[iArr[iArr[i7] + i2] + i] & 255;
        if (i18 > i19) {
            i10 = i5;
            i8 = i18;
            i9 = i4;
        } else {
            i10 = i4;
            i8 = i19;
            i19 = i18;
            i9 = i5;
        }
        if (i20 > i21) {
            i12 = i21;
            i11 = i20;
            i14 = i6;
            i13 = i7;
        } else {
            i11 = i21;
            i12 = i20;
            i13 = i6;
            i14 = i7;
        }
        if (i19 > i12) {
            i9 = i14;
            i14 = i9;
            i11 = i8;
            i8 = i11;
        } else {
            i10 = i13;
            i19 = i12;
        }
        if (i17 > i8) {
            i15 = i17;
            i16 = i3;
        } else {
            i15 = i8;
            i8 = i17;
            i16 = i9;
            i9 = i3;
        }
        if (i8 > i19) {
            i10 = i9;
            i19 = i8;
        } else {
            i14 = i16;
            i11 = i15;
        }
        return i11 > i19 ? i10 : i14;
    }

    private void ssMerge(int i, int i2, int i3, int i4, int[] iArr, int i5, int i6, int i7) {
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        int[] iArr2 = this.SA;
        StackEntry[] stackEntryArr = new StackEntry[64];
        int i13 = i2;
        int i14 = i3;
        int i15 = i4;
        int i16 = 0;
        int i17 = 0;
        while (true) {
            int i18 = i15 - i14;
            if (i18 <= i6) {
                if (i13 >= i14 || i14 >= i15) {
                    i12 = i15;
                } else {
                    i12 = i15;
                    ssMergeBackward(i, iArr, i5, i13, i14, i15, i7);
                }
                if ((i16 & 1) != 0) {
                    ssMergeCheckEqual(i, i7, i13);
                }
                if ((i16 & 2) != 0) {
                    ssMergeCheckEqual(i, i7, i12);
                }
                if (i17 != 0) {
                    i17--;
                    StackEntry stackEntry = stackEntryArr[i17];
                    i13 = stackEntry.a;
                    i14 = stackEntry.b;
                    i15 = stackEntry.c;
                    i8 = stackEntry.d;
                } else {
                    return;
                }
            } else {
                int i19 = i14 - i13;
                if (i19 <= i6) {
                    if (i13 < i14) {
                        ssMergeForward(i, iArr, i5, i13, i14, i15, i7);
                    }
                    if ((i16 & 1) != 0) {
                        ssMergeCheckEqual(i, i7, i13);
                    }
                    if ((i16 & 2) != 0) {
                        ssMergeCheckEqual(i, i7, i15);
                    }
                    if (i17 != 0) {
                        i17--;
                        StackEntry stackEntry2 = stackEntryArr[i17];
                        i13 = stackEntry2.a;
                        i14 = stackEntry2.b;
                        i15 = stackEntry2.c;
                        i8 = stackEntry2.d;
                    } else {
                        return;
                    }
                } else {
                    int min = Math.min(i19, i18);
                    int i20 = min >> 1;
                    int i21 = 0;
                    while (min > 0) {
                        if (ssCompare(getIDX(iArr2[i14 + i21 + i20]) + i, getIDX(iArr2[((i14 - i21) - i20) - 1]) + i, i7) < 0) {
                            i21 += i20 + 1;
                            i20 -= (min & 1) ^ 1;
                        }
                        min = i20;
                        i20 = min >> 1;
                    }
                    if (i21 > 0) {
                        int i22 = i14 - i21;
                        ssBlockSwap(iArr2, i22, iArr2, i14, i21);
                        int i23 = i14 + i21;
                        if (i23 < i15) {
                            if (iArr2[i23] < 0) {
                                i11 = i14;
                                while (iArr2[i11 - 1] < 0) {
                                    i11--;
                                }
                                iArr2[i23] = ~iArr2[i23];
                            } else {
                                i11 = i14;
                            }
                            i9 = i14;
                            while (iArr2[i9] < 0) {
                                i9++;
                            }
                            i15 = i11;
                            i10 = 1;
                        } else {
                            i9 = i14;
                            i15 = i9;
                            i10 = 0;
                        }
                        if (i15 - i13 <= i15 - i9) {
                            stackEntryArr[i17] = new StackEntry(i9, i23, i15, (i10 & 1) | (i16 & 2));
                            i16 &= 1;
                            i14 = i22;
                            i17++;
                        } else {
                            if (i15 == i14 && i14 == i9) {
                                i10 <<= 1;
                            }
                            stackEntryArr[i17] = new StackEntry(i13, i22, i15, (i16 & 1) | (i10 & 2));
                            i16 = (i16 & 2) | (i10 & 1);
                            i14 = i23;
                            i17++;
                            i13 = i9;
                            i15 = i15;
                        }
                    } else {
                        if ((i16 & 1) != 0) {
                            ssMergeCheckEqual(i, i7, i13);
                        }
                        ssMergeCheckEqual(i, i7, i14);
                        if ((i16 & 2) != 0) {
                            ssMergeCheckEqual(i, i7, i15);
                        }
                        if (i17 != 0) {
                            i17--;
                            StackEntry stackEntry3 = stackEntryArr[i17];
                            i13 = stackEntry3.a;
                            i14 = stackEntry3.b;
                            i15 = stackEntry3.c;
                            i8 = stackEntry3.d;
                        } else {
                            return;
                        }
                    }
                }
            }
            i16 = i8;
        }
    }

    private void ssMergeBackward(int i, int[] iArr, int i2, int i3, int i4, int i5, int i6) {
        boolean z;
        int i7;
        int i8;
        int i9;
        boolean z2;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        int i17;
        int i18;
        int i19;
        int i20;
        int[] iArr2 = this.SA;
        int i21 = i5 - i4;
        ssBlockSwap(iArr, i2, iArr2, i4, i21);
        int i22 = (i2 + i21) - 1;
        if (iArr[i22] < 0) {
            i7 = i + (~iArr[i22]);
            z = true;
        } else {
            i7 = i + iArr[i22];
            z = false;
        }
        int i23 = i4 - 1;
        if (iArr2[i23] < 0) {
            z |= true;
            i8 = ~iArr2[i23];
        } else {
            i8 = iArr2[i23];
        }
        int i24 = i + i8;
        int i25 = i5 - 1;
        int i26 = iArr2[i25];
        while (true) {
            int ssCompare = ssCompare(i7, i24, i6);
            if (ssCompare > 0) {
                if (z && true) {
                    while (true) {
                        i19 = i25 - 1;
                        iArr2[i25] = iArr[i22];
                        i20 = i22 - 1;
                        iArr[i22] = iArr2[i19];
                        if (iArr[i20] >= 0) {
                            break;
                        }
                        i22 = i20;
                        i25 = i19;
                    }
                    z = !z;
                    i22 = i20;
                    i25 = i19;
                }
                int i27 = i25 - 1;
                iArr2[i25] = iArr[i22];
                if (i22 <= i2) {
                    iArr[i22] = i26;
                    return;
                }
                int i28 = i22 - 1;
                iArr[i22] = iArr2[i27];
                if (iArr[i28] < 0) {
                    z |= true;
                    i18 = ~iArr[i28];
                } else {
                    i18 = iArr[i28];
                }
                int i29 = i + i18;
                i22 = i28;
                i25 = i27;
                i7 = i29;
            } else if (ssCompare < 0) {
                if (z && true) {
                    while (true) {
                        i16 = i25 - 1;
                        iArr2[i25] = iArr2[i23];
                        i17 = i23 - 1;
                        iArr2[i23] = iArr2[i16];
                        if (iArr2[i17] >= 0) {
                            break;
                        }
                        i23 = i17;
                        i25 = i16;
                    }
                    z ^= true;
                    i23 = i17;
                    i25 = i16;
                }
                int i30 = i25 - 1;
                iArr2[i25] = iArr2[i23];
                int i31 = i23 - 1;
                iArr2[i23] = iArr2[i30];
                if (i31 < i3) {
                    while (i2 < i22) {
                        int i32 = i30 - 1;
                        iArr2[i30] = iArr[i22];
                        iArr[i22] = iArr2[i32];
                        i30 = i32;
                        i22--;
                    }
                    iArr2[i30] = iArr[i22];
                    iArr[i22] = i26;
                    return;
                }
                if (iArr2[i31] < 0) {
                    z |= true;
                    i15 = ~iArr2[i31];
                } else {
                    i15 = iArr2[i31];
                }
                i24 = i + i15;
                i23 = i31;
                i25 = i30;
            } else {
                if (z && true) {
                    while (true) {
                        i13 = i25 - 1;
                        iArr2[i25] = iArr[i22];
                        i14 = i22 - 1;
                        iArr[i22] = iArr2[i13];
                        if (iArr[i14] >= 0) {
                            break;
                        }
                        i22 = i14;
                        i25 = i13;
                    }
                    z = !z;
                    i22 = i14;
                    i25 = i13;
                }
                int i33 = i25 - 1;
                iArr2[i25] = ~iArr[i22];
                if (i22 <= i2) {
                    iArr[i22] = i26;
                    return;
                }
                int i34 = i22 - 1;
                iArr[i22] = iArr2[i33];
                if (z && true) {
                    while (true) {
                        i11 = i33 - 1;
                        iArr2[i33] = iArr2[i23];
                        i12 = i23 - 1;
                        iArr2[i23] = iArr2[i11];
                        if (iArr2[i12] >= 0) {
                            break;
                        }
                        i23 = i12;
                        i33 = i11;
                    }
                    z ^= true;
                    i23 = i12;
                    i33 = i11;
                }
                int i35 = i33 - 1;
                iArr2[i33] = iArr2[i23];
                int i36 = i23 - 1;
                iArr2[i23] = iArr2[i35];
                if (i36 < i3) {
                    while (i2 < i34) {
                        int i37 = i35 - 1;
                        iArr2[i35] = iArr[i34];
                        iArr[i34] = iArr2[i37];
                        i35 = i37;
                        i34--;
                    }
                    iArr2[i35] = iArr[i34];
                    iArr[i34] = i26;
                    return;
                }
                if (iArr[i34] < 0) {
                    z2 = z | true;
                    i9 = i + (~iArr[i34]);
                } else {
                    i9 = i + iArr[i34];
                    z2 = z;
                }
                if (iArr2[i36] < 0) {
                    z2 |= true;
                    i10 = ~iArr2[i36];
                } else {
                    i10 = iArr2[i36];
                }
                i24 = i + i10;
                z = z2;
                i23 = i36;
                i7 = i9;
                i22 = i34;
                i25 = i35;
            }
        }
    }

    private void ssMergeCheckEqual(int i, int i2, int i3) {
        int[] iArr = this.SA;
        if (iArr[i3] >= 0 && ssCompare(getIDX(iArr[i3 - 1]) + i, i + iArr[i3], i2) == 0) {
            iArr[i3] = ~iArr[i3];
        }
    }

    private void ssMergeForward(int i, int[] iArr, int i2, int i3, int i4, int i5, int i6) {
        int i7;
        int[] iArr2 = this.SA;
        int i8 = i4 - i3;
        int i9 = (i2 + i8) - 1;
        ssBlockSwap(iArr, i2, iArr2, i3, i8);
        int i10 = iArr2[i3];
        while (true) {
            int ssCompare = ssCompare(iArr[i2] + i, iArr2[i4] + i, i6);
            if (ssCompare < 0) {
                while (true) {
                    i7 = i3 + 1;
                    iArr2[i3] = iArr[i2];
                    if (i9 <= i2) {
                        iArr[i2] = i10;
                        return;
                    }
                    int i11 = i2 + 1;
                    iArr[i2] = iArr2[i7];
                    if (iArr[i11] >= 0) {
                        i2 = i11;
                        break;
                    } else {
                        i2 = i11;
                        i3 = i7;
                    }
                }
            } else if (ssCompare > 0) {
                while (true) {
                    i7 = i3 + 1;
                    iArr2[i3] = iArr2[i4];
                    int i12 = i4 + 1;
                    iArr2[i4] = iArr2[i7];
                    if (i5 <= i12) {
                        while (i2 < i9) {
                            int i13 = i7 + 1;
                            iArr2[i7] = iArr[i2];
                            iArr[i2] = iArr2[i13];
                            i7 = i13;
                            i2++;
                        }
                        iArr2[i7] = iArr[i2];
                        iArr[i2] = i10;
                        return;
                    } else if (iArr2[i12] >= 0) {
                        i4 = i12;
                        break;
                    } else {
                        i4 = i12;
                        i3 = i7;
                    }
                }
            } else {
                iArr2[i4] = ~iArr2[i4];
                while (true) {
                    int i14 = i3 + 1;
                    iArr2[i3] = iArr[i2];
                    if (i9 <= i2) {
                        iArr[i2] = i10;
                        return;
                    }
                    int i15 = i2 + 1;
                    iArr[i2] = iArr2[i14];
                    if (iArr[i15] >= 0) {
                        while (true) {
                            int i16 = i14 + 1;
                            iArr2[i14] = iArr2[i4];
                            int i17 = i4 + 1;
                            iArr2[i4] = iArr2[i16];
                            if (i5 <= i17) {
                                while (i15 < i9) {
                                    int i18 = i16 + 1;
                                    iArr2[i16] = iArr[i15];
                                    iArr[i15] = iArr2[i18];
                                    i15++;
                                    i16 = i18;
                                }
                                iArr2[i16] = iArr[i15];
                                iArr[i15] = i10;
                                return;
                            } else if (iArr2[i17] >= 0) {
                                i4 = i17;
                                i3 = i16;
                                i2 = i15;
                                break;
                            } else {
                                i4 = i17;
                                i14 = i16;
                            }
                        }
                    } else {
                        i2 = i15;
                        i3 = i14;
                    }
                }
            }
            i3 = i7;
        }
    }

    private void ssMultiKeyIntroSort(int i, int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        Bzip2DivSufSort bzip2DivSufSort = this;
        int[] iArr = bzip2DivSufSort.SA;
        byte[] bArr = bzip2DivSufSort.T;
        StackEntry[] stackEntryArr = new StackEntry[64];
        int i10 = -1;
        int i11 = i3;
        int i12 = i4;
        int ssLog = ssLog(i3 - i2);
        int i13 = 0;
        int i14 = 0;
        int i15 = i2;
        while (true) {
            int i16 = i11 - i15;
            if (i16 <= 8) {
                if (1 < i16) {
                    bzip2DivSufSort.ssInsertionSort(i, i15, i11, i12);
                }
                if (i13 != 0) {
                    i13--;
                    StackEntry stackEntry = stackEntryArr[i13];
                    int i17 = stackEntry.a;
                    int i18 = stackEntry.b;
                    int i19 = stackEntry.c;
                    ssLog = stackEntry.d;
                    i15 = i17;
                    i11 = i18;
                    i12 = i19;
                } else {
                    return;
                }
            } else {
                int i20 = ssLog - 1;
                if (ssLog == 0) {
                    bzip2DivSufSort.ssHeapSort(i12, i, i15, i16);
                }
                if (i20 < 0) {
                    int i21 = bArr[iArr[iArr[i15] + i] + i12] & 255;
                    int i22 = i15;
                    i15++;
                    while (i15 < i11) {
                        i14 = bArr[iArr[iArr[i15] + i] + i12] & 255;
                        if (i14 != i21) {
                            if (1 < i15 - i22) {
                                break;
                            }
                            i22 = i15;
                            i21 = i14;
                        }
                        i15++;
                    }
                    if ((bArr[(iArr[iArr[i22] + i] + i12) - 1] & 255) < i21) {
                        i22 = bzip2DivSufSort.ssSubstringPartition(i, i22, i15, i12);
                    }
                    int i23 = i15 - i22;
                    int i24 = i11 - i15;
                    if (i23 <= i24) {
                        if (1 < i23) {
                            stackEntryArr[i13] = new StackEntry(i15, i11, i12, i10);
                            i12++;
                            i9 = ssLog(i23);
                            i13++;
                            i11 = i15;
                            i15 = i22;
                            ssLog = i9;
                        }
                    } else if (1 < i24) {
                        stackEntryArr[i13] = new StackEntry(i22, i15, i12 + 1, ssLog(i23));
                        i13++;
                    } else {
                        i12++;
                        i9 = ssLog(i23);
                        i11 = i15;
                        i15 = i22;
                        ssLog = i9;
                    }
                    ssLog = -1;
                } else {
                    int ssPivot = bzip2DivSufSort.ssPivot(i12, i, i15, i11);
                    int i25 = bArr[iArr[iArr[ssPivot] + i] + i12] & 255;
                    swapElements(iArr, i15, iArr, ssPivot);
                    int i26 = i15 + 1;
                    while (i26 < i11) {
                        i14 = bArr[iArr[iArr[i26] + i] + i12] & 255;
                        if (i14 != i25) {
                            break;
                        }
                        i26++;
                    }
                    if (i26 < i11 && i14 < i25) {
                        i5 = i14;
                        i6 = i26;
                        while (true) {
                            i26++;
                            if (i26 >= i11 || (i5 = bArr[iArr[iArr[i26] + i] + i12] & 255) > i25) {
                                break;
                            } else if (i5 == i25) {
                                swapElements(iArr, i26, iArr, i6);
                                i6++;
                            }
                        }
                    } else {
                        i5 = i14;
                        i6 = i26;
                    }
                    int i27 = i11 - 1;
                    while (i26 < i27) {
                        i5 = bArr[iArr[iArr[i27] + i] + i12] & 255;
                        if (i5 != i25) {
                            break;
                        }
                        i27--;
                    }
                    if (i26 < i27 && i5 > i25) {
                        int i28 = i5;
                        int i29 = i27;
                        while (true) {
                            i27 += i10;
                            if (i26 >= i27) {
                                i7 = i29;
                                i5 = i28;
                                break;
                            }
                            int i30 = bArr[i12 + iArr[i + iArr[i27]]] & 255;
                            if (i30 < i25) {
                                i5 = i30;
                                i7 = i29;
                                break;
                            }
                            if (i30 == i25) {
                                swapElements(iArr, i27, iArr, i29);
                                i29--;
                            }
                            i28 = i30;
                            i10 = -1;
                        }
                    } else {
                        i7 = i27;
                    }
                    while (i26 < i27) {
                        swapElements(iArr, i26, iArr, i27);
                        while (true) {
                            i26++;
                            if (i26 < i27 && (i5 = bArr[iArr[iArr[i26] + i] + i12] & 255) <= i25) {
                                if (i5 == i25) {
                                    swapElements(iArr, i26, iArr, i6);
                                    i6++;
                                }
                            }
                        }
                        while (true) {
                            i27--;
                            if (i26 < i27 && (i5 = bArr[iArr[iArr[i27] + i] + i12] & 255) >= i25) {
                                if (i5 == i25) {
                                    swapElements(iArr, i27, iArr, i7);
                                    i7--;
                                }
                            }
                        }
                    }
                    if (i6 <= i7) {
                        int i31 = i26 - 1;
                        int i32 = i6 - i15;
                        int i33 = i26 - i6;
                        if (i32 > i33) {
                            i32 = i33;
                        }
                        int i34 = i15;
                        int i35 = i26 - i32;
                        while (i32 > 0) {
                            swapElements(iArr, i34, iArr, i35);
                            i32--;
                            i34++;
                            i35++;
                        }
                        int i36 = i7 - i31;
                        int i37 = (i11 - i7) - 1;
                        if (i36 <= i37) {
                            i37 = i36;
                        }
                        int i38 = i11 - i37;
                        int i39 = i26;
                        while (i37 > 0) {
                            swapElements(iArr, i39, iArr, i38);
                            i37--;
                            i39++;
                            i38++;
                        }
                        int i40 = i15 + i33;
                        int i41 = i11 - i36;
                        int ssSubstringPartition = i25 <= (bArr[(iArr[iArr[i40] + i] + i12) + -1] & 255) ? i40 : bzip2DivSufSort.ssSubstringPartition(i, i40, i41, i12);
                        int i42 = i40 - i15;
                        int i43 = i11 - i41;
                        if (i42 <= i43) {
                            int i44 = i41 - ssSubstringPartition;
                            if (i43 <= i44) {
                                int i45 = i13 + 1;
                                stackEntryArr[i13] = new StackEntry(ssSubstringPartition, i41, i12 + 1, ssLog(i44));
                                i13 = i45 + 1;
                                i8 = i20;
                                stackEntryArr[i45] = new StackEntry(i41, i11, i12, i8);
                            } else {
                                i8 = i20;
                                if (i42 <= i44) {
                                    int i46 = i13 + 1;
                                    stackEntryArr[i13] = new StackEntry(i41, i11, i12, i8);
                                    i13 = i46 + 1;
                                    stackEntryArr[i46] = new StackEntry(ssSubstringPartition, i41, i12 + 1, ssLog(i44));
                                } else {
                                    int i47 = i13 + 1;
                                    stackEntryArr[i13] = new StackEntry(i41, i11, i12, i8);
                                    i13 = i47 + 1;
                                    stackEntryArr[i47] = new StackEntry(i15, i40, i12, i8);
                                    i12++;
                                    i11 = i41;
                                    i10 = -1;
                                    ssLog = ssLog(i44);
                                    i15 = ssSubstringPartition;
                                    i14 = i5;
                                }
                            }
                            i14 = i5;
                            i11 = i40;
                            ssLog = i8;
                        } else {
                            int i48 = i41 - ssSubstringPartition;
                            if (i42 <= i48) {
                                int i49 = i13 + 1;
                                stackEntryArr[i13] = new StackEntry(ssSubstringPartition, i41, i12 + 1, ssLog(i48));
                                i13 = i49 + 1;
                                stackEntryArr[i49] = new StackEntry(i15, i40, i12, i20);
                            } else if (i43 <= i48) {
                                int i50 = i13 + 1;
                                stackEntryArr[i13] = new StackEntry(i15, i40, i12, i20);
                                i13 = i50 + 1;
                                stackEntryArr[i50] = new StackEntry(ssSubstringPartition, i41, i12 + 1, ssLog(i48));
                            } else {
                                int i51 = i13 + 1;
                                stackEntryArr[i13] = new StackEntry(i15, i40, i12, i20);
                                i13 = i51 + 1;
                                stackEntryArr[i51] = new StackEntry(i41, i11, i12, i20);
                                i12++;
                                i10 = -1;
                                i11 = i41;
                                i15 = ssSubstringPartition;
                                i14 = i5;
                                ssLog = ssLog(i48);
                                bzip2DivSufSort = this;
                            }
                            i10 = -1;
                            bzip2DivSufSort = this;
                            i14 = i5;
                            i15 = i41;
                            ssLog = i20;
                        }
                    } else {
                        int i52 = i20 + 1;
                        if ((bArr[(iArr[iArr[i15] + i] + i12) - 1] & 255) < i25) {
                            bzip2DivSufSort = this;
                            i15 = bzip2DivSufSort.ssSubstringPartition(i, i15, i11, i12);
                            ssLog = ssLog(i11 - i15);
                        } else {
                            bzip2DivSufSort = this;
                            ssLog = i52;
                        }
                        i12++;
                        i14 = i5;
                    }
                    i10 = -1;
                }
            }
        }
    }

    private int ssPivot(int i, int i2, int i3, int i4) {
        int i5 = i4 - i3;
        int i6 = (i5 / 2) + i3;
        if (i5 > 512) {
            int i7 = i5 >> 3;
            int i8 = i7 << 1;
            int i9 = i4 - 1;
            return ssMedian3(i, i2, ssMedian3(i, i2, i3, i3 + i7, i3 + i8), ssMedian3(i, i2, i6 - i7, i6, i6 + i7), ssMedian3(i, i2, i9 - i8, i9 - i7, i9));
        } else if (i5 <= 32) {
            return ssMedian3(i, i2, i3, i6, i4 - 1);
        } else {
            int i10 = i5 >> 2;
            int i11 = i4 - 1;
            return ssMedian5(i, i2, i3, i3 + i10, i6, i11 - i10, i11);
        }
    }

    private int ssSubstringPartition(int i, int i2, int i3, int i4) {
        int[] iArr = this.SA;
        int i5 = i2 - 1;
        while (true) {
            i5++;
            if (i5 >= i3 || iArr[iArr[i5] + i] + i4 < iArr[iArr[i5] + i + 1] + 1) {
                do {
                    i3--;
                    if (i5 >= i3) {
                        break;
                    }
                } while (iArr[iArr[i3] + i] + i4 < iArr[iArr[i3] + i + 1] + 1);
                if (i3 <= i5) {
                    break;
                }
                int i6 = ~iArr[i3];
                iArr[i3] = iArr[i5];
                iArr[i5] = i6;
            } else {
                iArr[i5] = ~iArr[i5];
            }
        }
        if (i2 < i5) {
            iArr[i2] = ~iArr[i2];
        }
        return i5;
    }

    private void subStringSort(int i, int i2, int i3, int[] iArr, int i4, int i5, int i6, boolean z, int i7) {
        int i8;
        int[] iArr2;
        int i9;
        int[] iArr3 = this.SA;
        int i10 = z ? i2 + 1 : i2;
        int i11 = i10;
        int i12 = 0;
        while (true) {
            int i13 = i11 + 1024;
            if (i13 >= i3) {
                break;
            }
            ssMultiKeyIntroSort(i, i11, i13, i6);
            int i14 = i3 - i13;
            if (i14 <= i5) {
                iArr2 = iArr;
                i8 = i4;
                i9 = i5;
            } else {
                i9 = i14;
                i8 = i13;
                iArr2 = iArr3;
            }
            int i15 = i11;
            int i16 = i12;
            int i17 = 1024;
            while ((i16 & 1) != 0) {
                int i18 = i15 - i17;
                ssMerge(i, i18, i15, i15 + i17, iArr2, i8, i9, i6);
                i17 <<= 1;
                i16 >>>= 1;
                i15 = i18;
                i13 = i13;
            }
            i12++;
            i11 = i13;
        }
        ssMultiKeyIntroSort(i, i11, i3, i6);
        int i19 = i11;
        int i20 = 1024;
        for (int i21 = i12; i21 != 0; i21 >>= 1) {
            if ((i21 & 1) != 0) {
                int i22 = i19 - i20;
                ssMerge(i, i22, i19, i3, iArr, i4, i5, i6);
                i19 = i22;
            }
            i20 <<= 1;
        }
        if (z) {
            int i23 = iArr3[i10 - 1];
            int i24 = 1;
            while (i10 < i3 && (iArr3[i10] < 0 || (i24 = ssCompareLast(i, i + i23, i + iArr3[i10], i6, i7)) > 0)) {
                iArr3[i10 - 1] = iArr3[i10];
                i10++;
            }
            if (i24 == 0) {
                iArr3[i10] = ~iArr3[i10];
            }
            iArr3[i10 - 1] = i23;
        }
    }

    private static void swapElements(int[] iArr, int i, int[] iArr2, int i2) {
        int i3 = iArr[i];
        iArr[i] = iArr2[i2];
        iArr2[i2] = i3;
    }

    private void trCopy(int i, int i2, int i3, int i4, int i5, int i6, int i7) {
        int[] iArr = this.SA;
        int i8 = i5 - 1;
        int i9 = i4 - 1;
        while (i3 <= i9) {
            int i10 = iArr[i3] - i7;
            if (i10 < 0) {
                i10 += i2 - i;
            }
            int i11 = i + i10;
            if (iArr[i11] == i8) {
                i9++;
                iArr[i9] = i10;
                iArr[i11] = i9;
            }
            i3++;
        }
        int i12 = i6 - 1;
        int i13 = i9 + 1;
        while (i13 < i5) {
            int i14 = iArr[i12] - i7;
            if (i14 < 0) {
                i14 += i2 - i;
            }
            int i15 = i + i14;
            if (iArr[i15] == i8) {
                i5--;
                iArr[i5] = i14;
                iArr[i15] = i5;
            }
            i12--;
        }
    }

    private void trFixdown(int i, int i2, int i3, int i4, int i5, int i6) {
        int[] iArr = this.SA;
        int i7 = iArr[i4 + i5];
        int trGetC = trGetC(i, i2, i3, i7);
        while (true) {
            int i8 = (i5 * 2) + 1;
            if (i8 >= i6) {
                break;
            }
            int i9 = i8 + 1;
            int trGetC2 = trGetC(i, i2, i3, iArr[i4 + i8]);
            int trGetC3 = trGetC(i, i2, i3, iArr[i4 + i9]);
            if (trGetC2 < trGetC3) {
                i8 = i9;
                trGetC2 = trGetC3;
            }
            if (trGetC2 <= trGetC) {
                break;
            }
            iArr[i5 + i4] = iArr[i4 + i8];
            i5 = i8;
        }
        iArr[i4 + i5] = i7;
    }

    private int trGetC(int i, int i2, int i3, int i4) {
        int i5 = i2 + i4;
        return i5 < i3 ? this.SA[i5] : this.SA[(((i2 - i) + i4) % (i3 - i)) + i];
    }

    private void trHeapSort(int i, int i2, int i3, int i4, int i5) {
        int i6;
        int[] iArr = this.SA;
        int i7 = i5 % 2;
        if (i7 == 0) {
            int i8 = i5 - 1;
            int i9 = (i8 / 2) + i4;
            int i10 = i4 + i8;
            if (trGetC(i, i2, i3, iArr[i9]) < trGetC(i, i2, i3, iArr[i10])) {
                swapElements(iArr, i10, iArr, i9);
            }
            i6 = i8;
        } else {
            i6 = i5;
        }
        for (int i11 = (i6 / 2) - 1; i11 >= 0; i11--) {
            trFixdown(i, i2, i3, i4, i11, i6);
        }
        if (i7 == 0) {
            swapElements(iArr, i4, iArr, i4 + i6);
            trFixdown(i, i2, i3, i4, 0, i6);
        }
        for (int i12 = i6 - 1; i12 > 0; i12--) {
            int i13 = iArr[i4];
            int i14 = i4 + i12;
            iArr[i4] = iArr[i14];
            trFixdown(i, i2, i3, i4, 0, i12);
            iArr[i14] = i13;
        }
    }

    private void trInsertionSort(int i, int i2, int i3, int i4, int i5) {
        int trGetC;
        int[] iArr = this.SA;
        for (int i6 = i4 + 1; i6 < i5; i6++) {
            int i7 = iArr[i6];
            int i8 = i6 - 1;
            do {
                trGetC = trGetC(i, i2, i3, i7) - trGetC(i, i2, i3, iArr[i8]);
                if (trGetC >= 0) {
                    break;
                }
                do {
                    iArr[i8 + 1] = iArr[i8];
                    i8--;
                    if (i4 > i8) {
                        break;
                    }
                } while (iArr[i8] < 0);
                continue;
            } while (i8 >= i4);
            if (trGetC == 0) {
                iArr[i8] = ~iArr[i8];
            }
            iArr[i8 + 1] = i7;
        }
    }

    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:134:0x02c9  */
    /* JADX WARNING: Removed duplicated region for block: B:140:0x02da  */
    /* JADX WARNING: Removed duplicated region for block: B:145:0x02e8  */
    /* JADX WARNING: Removed duplicated region for block: B:150:0x02fa  */
    /* JADX WARNING: Removed duplicated region for block: B:233:0x04e2  */
    /* JADX WARNING: Removed duplicated region for block: B:286:0x02f8 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:292:0x02df A[SYNTHETIC] */
    private void trIntroSort(int r22, int r23, int r24, int r25, int r26, io.netty.handler.codec.compression.Bzip2DivSufSort.TRBudget r27, int r28) {
        /*
        // Method dump skipped, instructions count: 1300
        */
        throw new UnsupportedOperationException("Method not decompiled: io.netty.handler.codec.compression.Bzip2DivSufSort.trIntroSort(int, int, int, int, int, io.netty.handler.codec.compression.Bzip2DivSufSort$TRBudget, int):void");
    }

    private static int trLog(int i) {
        return (-65536 & i) != 0 ? (-16777216 & i) != 0 ? LOG_2_TABLE[(i >> 24) & KEYRecord.PROTOCOL_ANY] + 24 : LOG_2_TABLE[(i >> 16) & 271] : (65280 & i) != 0 ? LOG_2_TABLE[(i >> 8) & KEYRecord.PROTOCOL_ANY] + 8 : LOG_2_TABLE[i & KEYRecord.PROTOCOL_ANY];
    }

    private int trMedian3(int i, int i2, int i3, int i4, int i5, int i6) {
        int[] iArr = this.SA;
        int trGetC = trGetC(i, i2, i3, iArr[i4]);
        int trGetC2 = trGetC(i, i2, i3, iArr[i5]);
        int trGetC3 = trGetC(i, i2, i3, iArr[i6]);
        if (trGetC <= trGetC2) {
            i5 = i4;
            i4 = i5;
            trGetC2 = trGetC;
            trGetC = trGetC2;
        }
        if (trGetC > trGetC3) {
            return trGetC2 > trGetC3 ? i5 : i6;
        }
        return i4;
    }

    private int trMedian5(int i, int i2, int i3, int i4, int i5, int i6, int i7, int i8) {
        int[] iArr = this.SA;
        int trGetC = trGetC(i, i2, i3, iArr[i4]);
        int trGetC2 = trGetC(i, i2, i3, iArr[i5]);
        int trGetC3 = trGetC(i, i2, i3, iArr[i6]);
        int trGetC4 = trGetC(i, i2, i3, iArr[i7]);
        int trGetC5 = trGetC(i, i2, i3, iArr[i8]);
        if (trGetC2 > trGetC3) {
            i6 = i5;
            i5 = i6;
            trGetC3 = trGetC2;
            trGetC2 = trGetC3;
        }
        if (trGetC4 > trGetC5) {
            trGetC4 = trGetC5;
            trGetC5 = trGetC4;
        } else {
            i8 = i7;
            i7 = i8;
        }
        if (trGetC2 > trGetC4) {
            trGetC3 = trGetC5;
            trGetC5 = trGetC3;
            i7 = i6;
            i6 = i7;
        } else {
            i5 = i8;
            trGetC2 = trGetC4;
        }
        if (trGetC > trGetC3) {
            i6 = i4;
            i4 = i6;
            trGetC3 = trGetC;
            trGetC = trGetC3;
        }
        if (trGetC > trGetC2) {
            i5 = i4;
            trGetC2 = trGetC;
        } else {
            i7 = i6;
            trGetC5 = trGetC3;
        }
        return trGetC5 > trGetC2 ? i5 : i7;
    }

    private PartitionResult trPartition(int i, int i2, int i3, int i4, int i5, int i6) {
        int i7;
        int i8;
        int trGetC;
        int trGetC2;
        int trGetC3;
        int[] iArr = this.SA;
        int i9 = 0;
        int i10 = i4;
        while (i10 < i5) {
            i9 = trGetC(i, i2, i3, iArr[i10]);
            if (i9 != i6) {
                break;
            }
            i10++;
        }
        if (i10 < i5 && i9 < i6) {
            i7 = i10;
            while (true) {
                i10++;
                if (i10 >= i5 || (i9 = trGetC(i, i2, i3, iArr[i10])) > i6) {
                    break;
                } else if (i9 == i6) {
                    swapElements(iArr, i10, iArr, i7);
                    i7++;
                }
            }
        } else {
            i7 = i10;
        }
        int i11 = i5 - 1;
        while (i10 < i11) {
            i9 = trGetC(i, i2, i3, iArr[i11]);
            if (i9 != i6) {
                break;
            }
            i11--;
        }
        if (i10 < i11 && i9 > i6) {
            i8 = i11;
            while (true) {
                i11--;
                if (i10 >= i11 || (trGetC3 = trGetC(i, i2, i3, iArr[i11])) < i6) {
                    break;
                } else if (trGetC3 == i6) {
                    swapElements(iArr, i11, iArr, i8);
                    i8--;
                }
            }
        } else {
            i8 = i11;
        }
        while (i10 < i11) {
            swapElements(iArr, i10, iArr, i11);
            while (true) {
                i10++;
                if (i10 < i11 && (trGetC2 = trGetC(i, i2, i3, iArr[i10])) <= i6) {
                    if (trGetC2 == i6) {
                        swapElements(iArr, i10, iArr, i7);
                        i7++;
                    }
                }
            }
            while (true) {
                i11--;
                if (i10 < i11 && (trGetC = trGetC(i, i2, i3, iArr[i11])) >= i6) {
                    if (trGetC == i6) {
                        swapElements(iArr, i11, iArr, i8);
                        i8--;
                    }
                }
            }
        }
        if (i7 <= i8) {
            int i12 = i10 - 1;
            int i13 = i7 - i4;
            int i14 = i10 - i7;
            if (i13 > i14) {
                i13 = i14;
            }
            int i15 = i10 - i13;
            int i16 = i4;
            while (i13 > 0) {
                swapElements(iArr, i16, iArr, i15);
                i13--;
                i16++;
                i15++;
            }
            int i17 = i8 - i12;
            int i18 = (i5 - i8) - 1;
            if (i17 <= i18) {
                i18 = i17;
            }
            int i19 = i5 - i18;
            while (i18 > 0) {
                swapElements(iArr, i10, iArr, i19);
                i18--;
                i10++;
                i19++;
            }
            i4 += i14;
            i5 -= i17;
        }
        return new PartitionResult(i4, i5);
    }

    private int trPivot(int i, int i2, int i3, int i4, int i5) {
        int i6 = i5 - i4;
        int i7 = (i6 / 2) + i4;
        if (i6 > 512) {
            int i8 = i6 >> 3;
            int i9 = i8 << 1;
            int i10 = i5 - 1;
            return trMedian3(i, i2, i3, trMedian3(i, i2, i3, i4, i4 + i8, i4 + i9), trMedian3(i, i2, i3, i7 - i8, i7, i7 + i8), trMedian3(i, i2, i3, i10 - i9, i10 - i8, i10));
        } else if (i6 <= 32) {
            return trMedian3(i, i2, i3, i4, i7, i5 - 1);
        } else {
            int i11 = i6 >> 2;
            int i12 = i5 - 1;
            return trMedian5(i, i2, i3, i4, i4 + i11, i7, i12 - i11, i12);
        }
    }

    private void trSort(int i, int i2, int i3) {
        int[] iArr = this.SA;
        if ((-i2) < iArr[0]) {
            TRBudget tRBudget = new TRBudget(i2, GeneratedOutlineSupport.outline2(trLog(i2), 2, 3, 1));
            int i4 = 0;
            do {
                int i5 = iArr[i4];
                if (i5 < 0) {
                    i4 -= i5;
                    continue;
                } else {
                    int i6 = iArr[i + i5] + 1;
                    if (1 < i6 - i4) {
                        trIntroSort(i, i + i3, i + i2, i4, i6, tRBudget, i2);
                        if (tRBudget.chance == 0) {
                            if (i4 > 0) {
                                iArr[0] = -i4;
                            }
                            lsSort(i, i2, i3);
                            return;
                        }
                    }
                    i4 = i6;
                    continue;
                }
            } while (i4 < i2);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: int[] */
    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: byte[] */
    /* JADX DEBUG: Multi-variable search result rejected for r1v1, resolved type: byte */
    /* JADX WARN: Multi-variable type inference failed */
    public int bwt() {
        int[] iArr = this.SA;
        byte[] bArr = this.T;
        int i = this.n;
        int[] iArr2 = new int[256];
        int[] iArr3 = new int[65536];
        if (i == 0) {
            return 0;
        }
        if (i == 1) {
            iArr[0] = bArr[0];
            return 0;
        } else if (sortTypeBstar(iArr2, iArr3) > 0) {
            return constructBWT(iArr2, iArr3);
        } else {
            return 0;
        }
    }
}
