package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.MessageToByteEncoder;
import java.util.zip.Adler32;
import java.util.zip.Checksum;

public class FastLzFrameEncoder extends MessageToByteEncoder<ByteBuf> {
    private final ByteBufChecksum checksum;
    private final int level;

    public FastLzFrameEncoder() {
        this(0, null);
    }

    public FastLzFrameEncoder(int i) {
        this(i, null);
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x008a  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x008c A[SYNTHETIC] */
    public void encode(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, ByteBuf byteBuf2) {
        int i;
        int i2;
        ByteBufChecksum byteBufChecksum = this.checksum;
        while (byteBuf.isReadable()) {
            int readerIndex = byteBuf.readerIndex();
            int min = Math.min(byteBuf.readableBytes(), (int) FastLz.MAX_CHUNK_LENGTH);
            int writerIndex = byteBuf2.writerIndex();
            byteBuf2.setMedium(writerIndex, FastLz.MAGIC_NUMBER);
            int i3 = writerIndex + 4;
            int i4 = 0;
            int i5 = i3 + (byteBufChecksum != null ? 4 : 0);
            if (min < 32) {
                int i6 = i5 + 2;
                byteBuf2.ensureWritable(i6 + min);
                if (byteBufChecksum != null) {
                    byteBufChecksum.reset();
                    byteBufChecksum.update(byteBuf, readerIndex, min);
                    byteBuf2.setInt(i3, (int) byteBufChecksum.getValue());
                }
                byteBuf2.setBytes(i6, byteBuf, readerIndex, min);
            } else {
                if (byteBufChecksum != null) {
                    byteBufChecksum.reset();
                    byteBufChecksum.update(byteBuf, readerIndex, min);
                    byteBuf2.setInt(i3, (int) byteBufChecksum.getValue());
                }
                int i7 = i5 + 4;
                byteBuf2.ensureWritable(FastLz.calculateOutputBufferLength(min) + i7);
                i = FastLz.compress(byteBuf, byteBuf.readerIndex(), min, byteBuf2, i7, this.level);
                if (i < min) {
                    i2 = 1;
                    byteBuf2.setShort(i5, i);
                    i5 += 2;
                    byteBuf2.setShort(i5, min);
                    int i8 = writerIndex + 3;
                    if (byteBufChecksum == null) {
                        i4 = 16;
                    }
                    byteBuf2.setByte(i8, i2 | i4);
                    byteBuf2.writerIndex(i5 + 2 + i);
                    byteBuf.skipBytes(min);
                } else {
                    byteBuf2.setBytes(i5 + 2, byteBuf, readerIndex, min);
                }
            }
            i = min;
            i2 = 0;
            byteBuf2.setShort(i5, min);
            int i82 = writerIndex + 3;
            if (byteBufChecksum == null) {
            }
            byteBuf2.setByte(i82, i2 | i4);
            byteBuf2.writerIndex(i5 + 2 + i);
            byteBuf.skipBytes(min);
        }
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public FastLzFrameEncoder(boolean z) {
        this(0, z ? new Adler32() : null);
    }

    public FastLzFrameEncoder(int i, Checksum checksum2) {
        ByteBufChecksum byteBufChecksum;
        if (i == 0 || i == 1 || i == 2) {
            this.level = i;
            if (checksum2 == null) {
                byteBufChecksum = null;
            } else {
                byteBufChecksum = ByteBufChecksum.wrapChecksum(checksum2);
            }
            this.checksum = byteBufChecksum;
            return;
        }
        throw new IllegalArgumentException(String.format("level: %d (expected: %d or %d or %d)", Integer.valueOf(i), 0, 1, 2));
    }
}
