package io.netty.handler.codec.compression;

import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelFuture;
import io.netty.channel.ChannelFutureListener;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelPromise;
import io.netty.util.concurrent.EventExecutor;
import io.netty.util.concurrent.Future;
import io.netty.util.concurrent.GenericFutureListener;
import io.netty.util.concurrent.PromiseNotifier;
import io.netty.util.internal.ObjectUtil;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.SuppressJava6Requirement;
import java.util.concurrent.TimeUnit;
import java.util.zip.CRC32;
import java.util.zip.Deflater;

public class JdkZlibEncoder extends ZlibEncoder {
    private static final byte[] gzipHeader = {31, -117, 8, 0, 0, 0, 0, 0, 0, 0};
    private final CRC32 crc;
    private volatile ChannelHandlerContext ctx;
    private final Deflater deflater;
    private volatile boolean finished;
    private final ZlibWrapper wrapper;
    private boolean writeHeader;

    /* renamed from: io.netty.handler.codec.compression.JdkZlibEncoder$4  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass4 {
        public static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$ZlibWrapper;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        static {
            ZlibWrapper.values();
            int[] iArr = new int[4];
            $SwitchMap$io$netty$handler$codec$compression$ZlibWrapper = iArr;
            iArr[ZlibWrapper.GZIP.ordinal()] = 1;
            try {
                $SwitchMap$io$netty$handler$codec$compression$ZlibWrapper[ZlibWrapper.ZLIB.ordinal()] = 2;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public JdkZlibEncoder() {
        this(6);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ChannelHandlerContext ctx() {
        ChannelHandlerContext channelHandlerContext = this.ctx;
        if (channelHandlerContext != null) {
            return channelHandlerContext;
        }
        throw new IllegalStateException("not added to a pipeline");
    }

    @SuppressJava6Requirement(reason = "Usage guarded by java version check")
    private void deflate(ByteBuf byteBuf) {
        int deflate;
        if (PlatformDependent.javaVersion() < 7) {
            deflateJdk6(byteBuf);
        }
        do {
            int writerIndex = byteBuf.writerIndex();
            deflate = this.deflater.deflate(byteBuf.array(), byteBuf.arrayOffset() + writerIndex, byteBuf.writableBytes(), 2);
            byteBuf.writerIndex(writerIndex + deflate);
        } while (deflate > 0);
    }

    private void deflateJdk6(ByteBuf byteBuf) {
        int deflate;
        do {
            int writerIndex = byteBuf.writerIndex();
            deflate = this.deflater.deflate(byteBuf.array(), byteBuf.arrayOffset() + writerIndex, byteBuf.writableBytes());
            byteBuf.writerIndex(writerIndex + deflate);
        } while (deflate > 0);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private ChannelFuture finishEncode(ChannelHandlerContext channelHandlerContext, ChannelPromise channelPromise) {
        if (this.finished) {
            channelPromise.setSuccess();
            return channelPromise;
        }
        this.finished = true;
        ByteBuf heapBuffer = channelHandlerContext.alloc().heapBuffer();
        if (this.writeHeader && this.wrapper == ZlibWrapper.GZIP) {
            this.writeHeader = false;
            heapBuffer.writeBytes(gzipHeader);
        }
        this.deflater.finish();
        while (!this.deflater.finished()) {
            deflate(heapBuffer);
            if (!heapBuffer.isWritable()) {
                channelHandlerContext.write(heapBuffer);
                heapBuffer = channelHandlerContext.alloc().heapBuffer();
            }
        }
        if (this.wrapper == ZlibWrapper.GZIP) {
            int value = (int) this.crc.getValue();
            int totalIn = this.deflater.getTotalIn();
            heapBuffer.writeByte(value);
            heapBuffer.writeByte(value >>> 8);
            heapBuffer.writeByte(value >>> 16);
            heapBuffer.writeByte(value >>> 24);
            heapBuffer.writeByte(totalIn);
            heapBuffer.writeByte(totalIn >>> 8);
            heapBuffer.writeByte(totalIn >>> 16);
            heapBuffer.writeByte(totalIn >>> 24);
        }
        this.deflater.end();
        return channelHandlerContext.writeAndFlush(heapBuffer, channelPromise);
    }

    @Override // io.netty.handler.codec.compression.ZlibEncoder
    public ChannelFuture close() {
        return close(ctx().newPromise());
    }

    @Override // io.netty.channel.ChannelHandlerAdapter, io.netty.channel.ChannelHandler
    public void handlerAdded(ChannelHandlerContext channelHandlerContext) {
        this.ctx = channelHandlerContext;
    }

    @Override // io.netty.handler.codec.compression.ZlibEncoder
    public boolean isClosed() {
        return this.finished;
    }

    public JdkZlibEncoder(int i) {
        this(ZlibWrapper.ZLIB, i);
    }

    public final ByteBuf allocateBuffer(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, boolean z) {
        int ceil = ((int) Math.ceil(((double) byteBuf.readableBytes()) * 1.001d)) + 12;
        if (this.writeHeader) {
            int ordinal = this.wrapper.ordinal();
            if (ordinal == 0) {
                ceil += 2;
            } else if (ordinal == 1) {
                ceil += gzipHeader.length;
            }
        }
        return channelHandlerContext.alloc().heapBuffer(ceil);
    }

    @Override // io.netty.handler.codec.compression.ZlibEncoder
    public ChannelFuture close(final ChannelPromise channelPromise) {
        ChannelHandlerContext ctx2 = ctx();
        EventExecutor executor = ctx2.executor();
        if (executor.inEventLoop()) {
            return finishEncode(ctx2, channelPromise);
        }
        final ChannelPromise newPromise = ctx2.newPromise();
        executor.execute(new Runnable() {
            /* class io.netty.handler.codec.compression.JdkZlibEncoder.AnonymousClass1 */

            public void run() {
                JdkZlibEncoder jdkZlibEncoder = JdkZlibEncoder.this;
                PromiseNotifier.cascade(jdkZlibEncoder.finishEncode(jdkZlibEncoder.ctx(), newPromise), channelPromise);
            }
        });
        return newPromise;
    }

    public void encode(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, ByteBuf byteBuf2) {
        byte[] bArr;
        int i;
        if (this.finished) {
            byteBuf2.writeBytes(byteBuf);
            return;
        }
        int readableBytes = byteBuf.readableBytes();
        if (readableBytes != 0) {
            ByteBuf byteBuf3 = null;
            try {
                if (byteBuf.hasArray()) {
                    bArr = byteBuf.array();
                    i = byteBuf.arrayOffset() + byteBuf.readerIndex();
                    byteBuf.skipBytes(readableBytes);
                } else {
                    byteBuf3 = channelHandlerContext.alloc().heapBuffer(readableBytes, readableBytes);
                    byteBuf.readBytes(byteBuf3, readableBytes);
                    bArr = byteBuf3.array();
                    i = byteBuf3.readerIndex() + byteBuf3.arrayOffset();
                }
                if (this.writeHeader) {
                    this.writeHeader = false;
                    if (this.wrapper == ZlibWrapper.GZIP) {
                        byteBuf2.writeBytes(gzipHeader);
                    }
                }
                if (this.wrapper == ZlibWrapper.GZIP) {
                    this.crc.update(bArr, i, readableBytes);
                }
                this.deflater.setInput(bArr, i, readableBytes);
                while (true) {
                    deflate(byteBuf2);
                    if (this.deflater.needsInput()) {
                        break;
                    } else if (!byteBuf2.isWritable()) {
                        byteBuf2.ensureWritable(byteBuf2.writerIndex());
                    }
                }
            } finally {
                if (byteBuf3 != null) {
                    byteBuf3.release();
                }
            }
        }
    }

    public JdkZlibEncoder(ZlibWrapper zlibWrapper) {
        this(zlibWrapper, 6);
    }

    public JdkZlibEncoder(ZlibWrapper zlibWrapper, int i) {
        this.crc = new CRC32();
        boolean z = true;
        this.writeHeader = true;
        if (i < 0 || i > 9) {
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline12("compressionLevel: ", i, " (expected: 0-9)"));
        }
        ObjectUtil.checkNotNull(zlibWrapper, "wrapper");
        ZlibWrapper zlibWrapper2 = ZlibWrapper.ZLIB_OR_NONE;
        if (zlibWrapper != zlibWrapper2) {
            this.wrapper = zlibWrapper;
            this.deflater = new Deflater(i, zlibWrapper == ZlibWrapper.ZLIB ? false : z);
            return;
        }
        throw new IllegalArgumentException("wrapper '" + zlibWrapper2 + "' is not allowed for compression.");
    }

    @Override // io.netty.channel.ChannelOutboundHandlerAdapter, io.netty.channel.ChannelOutboundHandler
    public void close(final ChannelHandlerContext channelHandlerContext, final ChannelPromise channelPromise) {
        ChannelFuture finishEncode = finishEncode(channelHandlerContext, channelHandlerContext.newPromise());
        finishEncode.addListener((GenericFutureListener<? extends Future<? super Void>>) new ChannelFutureListener() {
            /* class io.netty.handler.codec.compression.JdkZlibEncoder.AnonymousClass2 */

            public void operationComplete(ChannelFuture channelFuture) {
                channelHandlerContext.close(channelPromise);
            }
        });
        if (!finishEncode.isDone()) {
            channelHandlerContext.executor().schedule((Runnable) new Runnable() {
                /* class io.netty.handler.codec.compression.JdkZlibEncoder.AnonymousClass3 */

                public void run() {
                    channelHandlerContext.close(channelPromise);
                }
            }, 10L, TimeUnit.SECONDS);
        }
    }

    public JdkZlibEncoder(byte[] bArr) {
        this(6, bArr);
    }

    public JdkZlibEncoder(int i, byte[] bArr) {
        this.crc = new CRC32();
        this.writeHeader = true;
        if (i < 0 || i > 9) {
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline12("compressionLevel: ", i, " (expected: 0-9)"));
        }
        ObjectUtil.checkNotNull(bArr, "dictionary");
        this.wrapper = ZlibWrapper.ZLIB;
        Deflater deflater2 = new Deflater(i);
        this.deflater = deflater2;
        deflater2.setDictionary(bArr);
    }
}
