package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import io.netty.util.internal.ObjectUtil;
import java.util.List;
import java.util.zip.Checksum;
import net.jpountz.lz4.LZ4Exception;
import net.jpountz.lz4.LZ4Factory;
import net.jpountz.lz4.LZ4FastDecompressor;

public class Lz4FrameDecoder extends ByteToMessageDecoder {
    private int blockType;
    private ByteBufChecksum checksum;
    private int compressedLength;
    private int currentChecksum;
    private State currentState;
    private int decompressedLength;
    private LZ4FastDecompressor decompressor;

    /* renamed from: io.netty.handler.codec.compression.Lz4FrameDecoder$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State;

        /* JADX WARNING: Can't wrap try/catch for region: R(10:0|1|2|3|4|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0027 */
        static {
            State.values();
            int[] iArr = new int[4];
            $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State = iArr;
            iArr[State.INIT_BLOCK.ordinal()] = 1;
            $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[State.DECOMPRESS_DATA.ordinal()] = 2;
            $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[State.FINISHED.ordinal()] = 3;
            $SwitchMap$io$netty$handler$codec$compression$Lz4FrameDecoder$State[State.CORRUPTED.ordinal()] = 4;
        }
    }

    public enum State {
        INIT_BLOCK,
        DECOMPRESS_DATA,
        FINISHED,
        CORRUPTED
    }

    public Lz4FrameDecoder() {
        this(false);
    }

    /* JADX WARNING: Removed duplicated region for block: B:66:0x0137  */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    public void decode(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, List<Object> list) {
        ByteBuf byteBuf2;
        Throwable th;
        LZ4Exception e;
        try {
            int ordinal = this.currentState.ordinal();
            ByteBuf byteBuf3 = null;
            if (ordinal != 0) {
                if (ordinal != 1) {
                    if (ordinal != 2) {
                        if (ordinal != 3) {
                            throw new IllegalStateException();
                        }
                    }
                    byteBuf.skipBytes(byteBuf.readableBytes());
                    return;
                }
            } else if (byteBuf.readableBytes() >= 21) {
                if (byteBuf.readLong() == Lz4Constants.MAGIC_NUMBER) {
                    byte readByte = byteBuf.readByte();
                    int i = (readByte & 15) + 10;
                    int i2 = readByte & 240;
                    int reverseBytes = Integer.reverseBytes(byteBuf.readInt());
                    if (reverseBytes < 0 || reverseBytes > 33554432) {
                        throw new DecompressionException(String.format("invalid compressedLength: %d (expected: 0-%d)", Integer.valueOf(reverseBytes), 33554432));
                    }
                    int reverseBytes2 = Integer.reverseBytes(byteBuf.readInt());
                    int i3 = 1 << i;
                    if (reverseBytes2 < 0 || reverseBytes2 > i3) {
                        throw new DecompressionException(String.format("invalid decompressedLength: %d (expected: 0-%d)", Integer.valueOf(reverseBytes2), Integer.valueOf(i3)));
                    }
                    if ((reverseBytes2 != 0 || reverseBytes == 0) && (reverseBytes2 == 0 || reverseBytes != 0)) {
                        if (i2 == 16) {
                            if (reverseBytes2 == reverseBytes) {
                            }
                        }
                        int reverseBytes3 = Integer.reverseBytes(byteBuf.readInt());
                        if (reverseBytes2 != 0 || reverseBytes != 0) {
                            this.blockType = i2;
                            this.compressedLength = reverseBytes;
                            this.decompressedLength = reverseBytes2;
                            this.currentChecksum = reverseBytes3;
                            this.currentState = State.DECOMPRESS_DATA;
                        } else if (reverseBytes3 == 0) {
                            this.currentState = State.FINISHED;
                            this.decompressor = null;
                            this.checksum = null;
                            return;
                        } else {
                            throw new DecompressionException("stream corrupted: checksum error");
                        }
                    }
                    throw new DecompressionException(String.format("stream corrupted: compressedLength(%d) and decompressedLength(%d) mismatch", Integer.valueOf(reverseBytes), Integer.valueOf(reverseBytes2)));
                }
                throw new DecompressionException("unexpected block identifier");
            } else {
                return;
            }
            int i4 = this.blockType;
            int i5 = this.compressedLength;
            int i6 = this.decompressedLength;
            int i7 = this.currentChecksum;
            if (byteBuf.readableBytes() >= i5) {
                ByteBufChecksum byteBufChecksum = this.checksum;
                if (i4 == 16) {
                    byteBuf2 = byteBuf.retainedSlice(byteBuf.readerIndex(), i6);
                } else if (i4 == 32) {
                    try {
                        byteBuf2 = channelHandlerContext.alloc().buffer(i6, i6);
                        try {
                            this.decompressor.decompress(CompressionUtil.safeNioBuffer(byteBuf), byteBuf2.internalNioBuffer(byteBuf2.writerIndex(), i6));
                            byteBuf2.writerIndex(byteBuf2.writerIndex() + i6);
                        } catch (LZ4Exception e2) {
                            e = e2;
                            byteBuf3 = byteBuf2;
                        } catch (Throwable th2) {
                            th = th2;
                            byteBuf3 = byteBuf2;
                            if (byteBuf3 != null) {
                            }
                            throw th;
                        }
                    } catch (LZ4Exception e3) {
                        e = e3;
                        try {
                            throw new DecompressionException((Throwable) e);
                        } catch (Throwable th3) {
                            th = th3;
                            if (byteBuf3 != null) {
                                byteBuf3.release();
                            }
                            throw th;
                        }
                    }
                } else {
                    throw new DecompressionException(String.format("unexpected blockType: %d (expected: %d or %d)", Integer.valueOf(i4), 16, 32));
                }
                byteBuf.skipBytes(i5);
                if (byteBufChecksum != null) {
                    CompressionUtil.checkChecksum(byteBufChecksum, byteBuf2, i7);
                }
                list.add(byteBuf2);
                this.currentState = State.INIT_BLOCK;
            }
        } catch (Exception e4) {
            this.currentState = State.CORRUPTED;
            throw e4;
        }
    }

    public boolean isClosed() {
        return this.currentState == State.FINISHED;
    }

    public Lz4FrameDecoder(boolean z) {
        this(LZ4Factory.fastestInstance(), z);
    }

    /* JADX INFO: this call moved to the top of the method (can break code semantics) */
    public Lz4FrameDecoder(LZ4Factory lZ4Factory, boolean z) {
        this(lZ4Factory, z ? new Lz4XXHash32(Lz4Constants.DEFAULT_SEED) : null);
    }

    public Lz4FrameDecoder(LZ4Factory lZ4Factory, Checksum checksum2) {
        ByteBufChecksum byteBufChecksum;
        this.currentState = State.INIT_BLOCK;
        this.decompressor = ((LZ4Factory) ObjectUtil.checkNotNull(lZ4Factory, "factory")).fastDecompressor();
        if (checksum2 == null) {
            byteBufChecksum = null;
        } else {
            byteBufChecksum = ByteBufChecksum.wrapChecksum(checksum2);
        }
        this.checksum = byteBufChecksum;
    }
}
