package io.netty.handler.codec.compression;

import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.ByteToMessageDecoder;
import java.util.List;

public class SnappyFrameDecoder extends ByteToMessageDecoder {
    private static final int MAX_COMPRESSED_CHUNK_SIZE = 16777215;
    private static final int MAX_DECOMPRESSED_DATA_SIZE = 65536;
    private static final int MAX_UNCOMPRESSED_DATA_SIZE = 65540;
    private static final int SNAPPY_IDENTIFIER_LEN = 6;
    private boolean corrupted;
    private int numBytesToSkip;
    private final Snappy snappy;
    private boolean started;
    private final boolean validateChecksums;

    /* renamed from: io.netty.handler.codec.compression.SnappyFrameDecoder$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType;

        /* JADX WARNING: Can't wrap try/catch for region: R(12:0|1|2|3|4|5|6|7|8|9|10|12) */
        /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0027 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:9:0x0032 */
        static {
            ChunkType.values();
            int[] iArr = new int[5];
            $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType = iArr;
            iArr[ChunkType.STREAM_IDENTIFIER.ordinal()] = 1;
            $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.RESERVED_SKIPPABLE.ordinal()] = 2;
            $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.RESERVED_UNSKIPPABLE.ordinal()] = 3;
            $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.UNCOMPRESSED_DATA.ordinal()] = 4;
            $SwitchMap$io$netty$handler$codec$compression$SnappyFrameDecoder$ChunkType[ChunkType.COMPRESSED_DATA.ordinal()] = 5;
        }
    }

    public enum ChunkType {
        STREAM_IDENTIFIER,
        COMPRESSED_DATA,
        UNCOMPRESSED_DATA,
        RESERVED_UNSKIPPABLE,
        RESERVED_SKIPPABLE
    }

    public SnappyFrameDecoder() {
        this(false);
    }

    private static void checkByte(byte b, byte b2) {
        if (b != b2) {
            throw new DecompressionException("Unexpected stream identifier contents. Mismatched snappy protocol version?");
        }
    }

    private static ChunkType mapChunkType(byte b) {
        if (b == 0) {
            return ChunkType.COMPRESSED_DATA;
        }
        if (b == 1) {
            return ChunkType.UNCOMPRESSED_DATA;
        }
        if (b == -1) {
            return ChunkType.STREAM_IDENTIFIER;
        }
        if ((b & 128) == 128) {
            return ChunkType.RESERVED_SKIPPABLE;
        }
        return ChunkType.RESERVED_UNSKIPPABLE;
    }

    /* JADX INFO: finally extract failed */
    @Override // io.netty.handler.codec.ByteToMessageDecoder
    public void decode(ChannelHandlerContext channelHandlerContext, ByteBuf byteBuf, List<Object> list) {
        if (this.corrupted) {
            byteBuf.skipBytes(byteBuf.readableBytes());
            return;
        }
        int i = this.numBytesToSkip;
        if (i != 0) {
            int min = Math.min(i, byteBuf.readableBytes());
            byteBuf.skipBytes(min);
            this.numBytesToSkip -= min;
            return;
        }
        try {
            int readerIndex = byteBuf.readerIndex();
            int readableBytes = byteBuf.readableBytes();
            if (readableBytes >= 4) {
                short unsignedByte = byteBuf.getUnsignedByte(readerIndex);
                ChunkType mapChunkType = mapChunkType((byte) unsignedByte);
                int unsignedMediumLE = byteBuf.getUnsignedMediumLE(readerIndex + 1);
                int ordinal = mapChunkType.ordinal();
                if (ordinal != 0) {
                    if (ordinal != 1) {
                        if (ordinal != 2) {
                            if (ordinal == 3) {
                                throw new DecompressionException("Found reserved unskippable chunk type: 0x" + Integer.toHexString(unsignedByte));
                            } else if (ordinal == 4) {
                                if (this.started) {
                                    byteBuf.skipBytes(4);
                                    int min2 = Math.min(unsignedMediumLE, byteBuf.readableBytes());
                                    byteBuf.skipBytes(min2);
                                    if (min2 != unsignedMediumLE) {
                                        this.numBytesToSkip = unsignedMediumLE - min2;
                                        return;
                                    }
                                    return;
                                }
                                throw new DecompressionException("Received RESERVED_SKIPPABLE tag before STREAM_IDENTIFIER");
                            }
                        } else if (!this.started) {
                            throw new DecompressionException("Received UNCOMPRESSED_DATA tag before STREAM_IDENTIFIER");
                        } else if (unsignedMediumLE > MAX_UNCOMPRESSED_DATA_SIZE) {
                            throw new DecompressionException("Received UNCOMPRESSED_DATA larger than 65540 bytes");
                        } else if (readableBytes >= unsignedMediumLE + 4) {
                            byteBuf.skipBytes(4);
                            if (this.validateChecksums) {
                                Snappy.validateChecksum(byteBuf.readIntLE(), byteBuf, byteBuf.readerIndex(), unsignedMediumLE - 4);
                            } else {
                                byteBuf.skipBytes(4);
                            }
                            list.add(byteBuf.readRetainedSlice(unsignedMediumLE - 4));
                        }
                    } else if (!this.started) {
                        throw new DecompressionException("Received COMPRESSED_DATA tag before STREAM_IDENTIFIER");
                    } else if (unsignedMediumLE > MAX_COMPRESSED_CHUNK_SIZE) {
                        throw new DecompressionException("Received COMPRESSED_DATA that contains chunk that exceeds 16777215 bytes");
                    } else if (readableBytes >= unsignedMediumLE + 4) {
                        byteBuf.skipBytes(4);
                        int readIntLE = byteBuf.readIntLE();
                        int preamble = this.snappy.getPreamble(byteBuf);
                        if (preamble <= 65536) {
                            ByteBuf buffer = channelHandlerContext.alloc().buffer(preamble, 65536);
                            try {
                                if (this.validateChecksums) {
                                    int writerIndex = byteBuf.writerIndex();
                                    try {
                                        byteBuf.writerIndex((byteBuf.readerIndex() + unsignedMediumLE) - 4);
                                        this.snappy.decode(byteBuf, buffer);
                                        byteBuf.writerIndex(writerIndex);
                                        Snappy.validateChecksum(readIntLE, buffer, 0, buffer.writerIndex());
                                    } catch (Throwable th) {
                                        byteBuf.writerIndex(writerIndex);
                                        throw th;
                                    }
                                } else {
                                    this.snappy.decode(byteBuf.readSlice(unsignedMediumLE - 4), buffer);
                                }
                                list.add(buffer);
                                this.snappy.reset();
                            } catch (Throwable th2) {
                                if (buffer != null) {
                                    buffer.release();
                                }
                                throw th2;
                            }
                        } else {
                            throw new DecompressionException("Received COMPRESSED_DATA that contains uncompressed data that exceeds 65536 bytes");
                        }
                    }
                } else if (unsignedMediumLE != 6) {
                    throw new DecompressionException("Unexpected length of stream identifier: " + unsignedMediumLE);
                } else if (readableBytes >= 10) {
                    byteBuf.skipBytes(4);
                    int readerIndex2 = byteBuf.readerIndex();
                    byteBuf.skipBytes(6);
                    int i2 = readerIndex2 + 1;
                    checkByte(byteBuf.getByte(readerIndex2), (byte) 115);
                    int i3 = i2 + 1;
                    checkByte(byteBuf.getByte(i2), (byte) 78);
                    int i4 = i3 + 1;
                    checkByte(byteBuf.getByte(i3), (byte) 97);
                    int i5 = i4 + 1;
                    checkByte(byteBuf.getByte(i4), (byte) 80);
                    checkByte(byteBuf.getByte(i5), (byte) 112);
                    checkByte(byteBuf.getByte(i5 + 1), (byte) 89);
                    this.started = true;
                }
            }
        } catch (Exception e) {
            this.corrupted = true;
            throw e;
        }
    }

    public SnappyFrameDecoder(boolean z) {
        this.snappy = new Snappy();
        this.validateChecksums = z;
    }
}
