package io.netty.resolver;

import io.netty.util.CharsetUtil;
import io.netty.util.internal.PlatformDependent;
import java.net.InetAddress;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Map;

public final class DefaultHostsFileEntriesResolver implements HostsFileEntriesResolver {
    private final Map<String, List<InetAddress>> inet4Entries;
    private final Map<String, List<InetAddress>> inet6Entries;

    /* renamed from: io.netty.resolver.DefaultHostsFileEntriesResolver$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$io$netty$resolver$ResolvedAddressTypes;

        /* JADX WARNING: Can't wrap try/catch for region: R(10:0|1|2|3|4|5|6|7|8|10) */
        /* JADX WARNING: Code restructure failed: missing block: B:11:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:7:0x0027 */
        static {
            ResolvedAddressTypes.values();
            int[] iArr = new int[4];
            $SwitchMap$io$netty$resolver$ResolvedAddressTypes = iArr;
            iArr[ResolvedAddressTypes.IPV4_ONLY.ordinal()] = 1;
            $SwitchMap$io$netty$resolver$ResolvedAddressTypes[ResolvedAddressTypes.IPV6_ONLY.ordinal()] = 2;
            $SwitchMap$io$netty$resolver$ResolvedAddressTypes[ResolvedAddressTypes.IPV4_PREFERRED.ordinal()] = 3;
            $SwitchMap$io$netty$resolver$ResolvedAddressTypes[ResolvedAddressTypes.IPV6_PREFERRED.ordinal()] = 4;
        }
    }

    public DefaultHostsFileEntriesResolver() {
        this(parseEntries());
    }

    private static List<InetAddress> allAddresses(List<InetAddress> list, List<InetAddress> list2) {
        ArrayList arrayList = new ArrayList(list.size() + (list2 == null ? 0 : list2.size()));
        arrayList.addAll(list);
        if (list2 != null) {
            arrayList.addAll(list2);
        }
        return arrayList;
    }

    private static InetAddress firstAddress(List<InetAddress> list) {
        if (list == null || list.isEmpty()) {
            return null;
        }
        return list.get(0);
    }

    private static HostsFileEntriesProvider parseEntries() {
        if (!PlatformDependent.isWindows()) {
            return HostsFileEntriesProvider.parser().parseSilently();
        }
        return HostsFileEntriesProvider.parser().parseSilently(Charset.defaultCharset(), CharsetUtil.UTF_16, CharsetUtil.UTF_8);
    }

    @Override // io.netty.resolver.HostsFileEntriesResolver
    public InetAddress address(String str, ResolvedAddressTypes resolvedAddressTypes) {
        String normalize = normalize(str);
        int ordinal = resolvedAddressTypes.ordinal();
        if (ordinal == 0) {
            return firstAddress(this.inet4Entries.get(normalize));
        }
        if (ordinal == 1) {
            return firstAddress(this.inet6Entries.get(normalize));
        }
        if (ordinal == 2) {
            InetAddress firstAddress = firstAddress(this.inet4Entries.get(normalize));
            return firstAddress != null ? firstAddress : firstAddress(this.inet6Entries.get(normalize));
        } else if (ordinal == 3) {
            InetAddress firstAddress2 = firstAddress(this.inet6Entries.get(normalize));
            return firstAddress2 != null ? firstAddress2 : firstAddress(this.inet4Entries.get(normalize));
        } else {
            throw new IllegalArgumentException("Unknown ResolvedAddressTypes " + resolvedAddressTypes);
        }
    }

    public List<InetAddress> addresses(String str, ResolvedAddressTypes resolvedAddressTypes) {
        String normalize = normalize(str);
        int ordinal = resolvedAddressTypes.ordinal();
        if (ordinal == 0) {
            return this.inet4Entries.get(normalize);
        }
        if (ordinal == 1) {
            return this.inet6Entries.get(normalize);
        }
        if (ordinal == 2) {
            List<InetAddress> list = this.inet4Entries.get(normalize);
            if (list != null) {
                return allAddresses(list, this.inet6Entries.get(normalize));
            }
            return this.inet6Entries.get(normalize);
        } else if (ordinal == 3) {
            List<InetAddress> list2 = this.inet6Entries.get(normalize);
            if (list2 != null) {
                return allAddresses(list2, this.inet4Entries.get(normalize));
            }
            return this.inet4Entries.get(normalize);
        } else {
            throw new IllegalArgumentException("Unknown ResolvedAddressTypes " + resolvedAddressTypes);
        }
    }

    public String normalize(String str) {
        return str.toLowerCase(Locale.ENGLISH);
    }

    public DefaultHostsFileEntriesResolver(HostsFileEntriesProvider hostsFileEntriesProvider) {
        this.inet4Entries = hostsFileEntriesProvider.ipv4Entries();
        this.inet6Entries = hostsFileEntriesProvider.ipv6Entries();
    }
}
