package io.netty.util;

import com.allpayx.sdk.constants.AllPayConst;
import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.NetUtilInitializations;
import io.netty.util.internal.PlatformDependent;
import io.netty.util.internal.StringUtil;
import io.netty.util.internal.SystemPropertyUtil;
import io.netty.util.internal.logging.InternalLogger;
import io.netty.util.internal.logging.InternalLoggerFactory;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.InputStreamReader;
import java.net.Inet4Address;
import java.net.Inet6Address;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.NetworkInterface;
import java.net.UnknownHostException;
import java.security.AccessController;
import java.security.PrivilegedAction;
import org.xbill.DNS.KEYRecord;

public final class NetUtil {
    private static final int IPV4_MAX_CHAR_BETWEEN_SEPARATOR = 3;
    private static final boolean IPV4_PREFERRED;
    private static final int IPV4_SEPARATORS = 3;
    private static final boolean IPV6_ADDRESSES_PREFERRED;
    private static final int IPV6_BYTE_COUNT = 16;
    private static final int IPV6_MAX_CHAR_BETWEEN_SEPARATOR = 4;
    private static final int IPV6_MAX_CHAR_COUNT = 39;
    private static final int IPV6_MAX_SEPARATORS = 8;
    private static final int IPV6_MIN_SEPARATORS = 2;
    private static final int IPV6_WORD_COUNT = 8;
    public static final InetAddress LOCALHOST;
    public static final Inet4Address LOCALHOST4;
    public static final Inet6Address LOCALHOST6;
    public static final NetworkInterface LOOPBACK_IF;
    public static final int SOMAXCONN = ((Integer) AccessController.doPrivileged(new PrivilegedAction<Integer>() {
        /* class io.netty.util.NetUtil.AnonymousClass1 */

        /* JADX WARNING: Removed duplicated region for block: B:35:0x008f A[Catch:{ all -> 0x00af }] */
        /* JADX WARNING: Removed duplicated region for block: B:37:0x00a7  */
        /* JADX WARNING: Removed duplicated region for block: B:44:0x00b3 A[SYNTHETIC, Splitter:B:44:0x00b3] */
        @Override // java.security.PrivilegedAction
        public Integer run() {
            Throwable th;
            BufferedReader bufferedReader;
            Exception e;
            Integer num;
            int i = PlatformDependent.isWindows() ? AllPayConst.VTPAY_PAY_RESULT_CODE : 128;
            File file = new File("/proc/sys/net/core/somaxconn");
            BufferedReader bufferedReader2 = null;
            try {
                if (file.exists()) {
                    bufferedReader = new BufferedReader(new FileReader(file));
                    try {
                        i = Integer.parseInt(bufferedReader.readLine());
                        if (NetUtil.logger.isDebugEnabled()) {
                            NetUtil.logger.debug("{}: {}", file, Integer.valueOf(i));
                        }
                        bufferedReader2 = bufferedReader;
                    } catch (Exception e2) {
                        e = e2;
                        try {
                            if (NetUtil.logger.isDebugEnabled()) {
                            }
                            if (bufferedReader != null) {
                            }
                            return Integer.valueOf(i);
                        } catch (Throwable th2) {
                            th = th2;
                            bufferedReader2 = bufferedReader;
                            if (bufferedReader2 != null) {
                            }
                            throw th;
                        }
                    }
                } else {
                    if (SystemPropertyUtil.getBoolean("io.netty.net.somaxconn.trySysctl", false)) {
                        num = NetUtil.sysctlGetInt("kern.ipc.somaxconn");
                        if (num == null) {
                            num = NetUtil.sysctlGetInt("kern.ipc.soacceptqueue");
                            if (num != null) {
                                i = num.intValue();
                            }
                        } else {
                            i = num.intValue();
                        }
                    } else {
                        num = null;
                    }
                    if (num == null) {
                        NetUtil.logger.debug("Failed to get SOMAXCONN from sysctl and file {}. Default: {}", file, Integer.valueOf(i));
                    }
                }
                if (bufferedReader2 != null) {
                    try {
                        bufferedReader2.close();
                    } catch (Exception unused) {
                    }
                }
            } catch (Exception e3) {
                bufferedReader = null;
                e = e3;
                if (NetUtil.logger.isDebugEnabled()) {
                    NetUtil.logger.debug("Failed to get SOMAXCONN from sysctl and file {}. Default: {}", file, Integer.valueOf(i), e);
                }
                if (bufferedReader != null) {
                    bufferedReader.close();
                }
                return Integer.valueOf(i);
            } catch (Throwable th3) {
                th = th3;
                if (bufferedReader2 != null) {
                    try {
                        bufferedReader2.close();
                    } catch (Exception unused2) {
                    }
                }
                throw th;
            }
            return Integer.valueOf(i);
        }
    })).intValue();
    private static final InternalLogger logger;

    static {
        boolean z = SystemPropertyUtil.getBoolean("java.net.preferIPv4Stack", false);
        IPV4_PREFERRED = z;
        boolean z2 = SystemPropertyUtil.getBoolean("java.net.preferIPv6Addresses", false);
        IPV6_ADDRESSES_PREFERRED = z2;
        InternalLogger instance = InternalLoggerFactory.getInstance(NetUtil.class);
        logger = instance;
        instance.debug("-Djava.net.preferIPv4Stack: {}", Boolean.valueOf(z));
        instance.debug("-Djava.net.preferIPv6Addresses: {}", Boolean.valueOf(z2));
        Inet4Address createLocalhost4 = NetUtilInitializations.createLocalhost4();
        LOCALHOST4 = createLocalhost4;
        Inet6Address createLocalhost6 = NetUtilInitializations.createLocalhost6();
        LOCALHOST6 = createLocalhost6;
        NetUtilInitializations.NetworkIfaceAndInetAddress determineLoopback = NetUtilInitializations.determineLoopback(createLocalhost4, createLocalhost6);
        LOOPBACK_IF = determineLoopback.iface();
        LOCALHOST = determineLoopback.address();
    }

    private NetUtil() {
    }

    public static String bytesToIpAddress(byte[] bArr) {
        return bytesToIpAddress(bArr, 0, bArr.length);
    }

    public static byte[] createByteArrayFromIpAddressString(String str) {
        if (isValidIpV4Address(str)) {
            return validIpV4ToBytes(str);
        }
        if (!isValidIpV6Address(str)) {
            return null;
        }
        if (str.charAt(0) == '[') {
            str = str.substring(1, str.length() - 1);
        }
        int indexOf = str.indexOf(37);
        if (indexOf >= 0) {
            str = str.substring(0, indexOf);
        }
        return getIPv6ByName(str, true);
    }

    private static int decimalDigit(String str, int i) {
        return str.charAt(i) - '0';
    }

    public static Inet6Address getByName(CharSequence charSequence) {
        return getByName(charSequence, true);
    }

    public static String getHostname(InetSocketAddress inetSocketAddress) {
        return PlatformDependent.javaVersion() >= 7 ? inetSocketAddress.getHostString() : inetSocketAddress.getHostName();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:107:0x0186, code lost:
        if (r19.charAt(0) == ':') goto L_0x018c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:116:0x0199, code lost:
        if (r7 <= 2) goto L_0x019b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:94:0x0168, code lost:
        if ((r6 - r9) <= 3) goto L_0x016c;
     */
    private static byte[] getIPv6ByName(CharSequence charSequence, boolean z) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        byte[] bArr = new byte[16];
        int length = charSequence.length();
        int i7 = 0;
        int i8 = 0;
        int i9 = 0;
        int i10 = -1;
        int i11 = 0;
        int i12 = 0;
        int i13 = 0;
        int i14 = 0;
        boolean z2 = false;
        while (i7 < length) {
            char charAt = charSequence.charAt(i7);
            if (charAt == '.') {
                i9++;
                int i15 = i7 - i10;
                if (i15 <= 3 && i10 >= 0 && i9 <= 3 && ((i11 <= 0 || i12 + i13 >= 12) && i7 + 1 < length && i12 < 16 && (i9 != 1 || (z && ((i12 == 0 || isValidIPv4Mapped(bArr, i12, i8, i13)) && ((i15 != 3 || (isValidNumericChar(charSequence.charAt(i7 - 1)) && isValidNumericChar(charSequence.charAt(i7 - 2)) && isValidNumericChar(charSequence.charAt(i7 - 3)))) && ((i15 != 2 || (isValidNumericChar(charSequence.charAt(i7 - 1)) && isValidNumericChar(charSequence.charAt(i7 - 2)))) && (i15 != 1 || isValidNumericChar(charSequence.charAt(i7 - 1)))))))))) {
                    int i16 = i14 << ((3 - i15) << 2);
                    int i17 = (((i16 >> 4) & 15) * 10) + ((i16 & 15) * 100) + ((i16 >> 8) & 15);
                    if (i17 >= 0 && i17 <= 255) {
                        bArr[i12] = (byte) i17;
                        i12++;
                    }
                }
                return null;
            } else if (charAt == ':') {
                i11++;
                int i18 = i7 - i10;
                if (i18 > 4 || i9 > 0 || i11 > 8 || (i6 = i12 + 1) >= 16) {
                    return null;
                }
                int i19 = i14 << ((4 - i18) << 2);
                if (i13 > 0) {
                    i13 -= 2;
                }
                bArr[i12] = (byte) (((i19 & 15) << 4) | ((i19 >> 4) & 15));
                i12 = i6 + 1;
                bArr[i6] = (byte) ((((i19 >> 8) & 15) << 4) | ((i19 >> 12) & 15));
                int i20 = i7 + 1;
                if (i20 < length && charSequence.charAt(i20) == ':') {
                    int i21 = i20 + 1;
                    if (i8 != 0 || (i21 < length && charSequence.charAt(i21) == ':')) {
                        return null;
                    }
                    i11++;
                    z2 = i11 == 2 && i19 == 0;
                    i13 = (16 - i12) - 2;
                    i8 = i12;
                    i7 = i20;
                }
            } else if (!isValidHexChar(charAt) || (i9 > 0 && !isValidNumericChar(charAt))) {
                return null;
            } else {
                if (i10 < 0) {
                    i10 = i7;
                } else if (i7 - i10 > 4) {
                    return null;
                }
                i14 += StringUtil.decodeHexNibble(charAt) << ((i7 - i10) << 2);
                i5 = 1;
                i7 += i5;
            }
            i5 = 1;
            i10 = -1;
            i14 = 0;
            i7 += i5;
        }
        boolean z3 = i8 > 0;
        if (i9 > 0) {
            int i22 = i10 > 0 ? 3 : 3;
            if (i9 == i22 && i12 < 16) {
                if (i11 == 0) {
                    i13 = 12;
                } else if (i11 >= 2) {
                    if (z3 || i11 != 6) {
                        i4 = 0;
                        if (z3 && i11 < 8) {
                            if (charSequence.charAt(i4) == ':') {
                            }
                        }
                    } else {
                        i4 = 0;
                    }
                    i13 -= 2;
                }
                int i23 = i14 << ((3 - (i7 - i10)) << 2);
                int i24 = (((i23 >> 4) & 15) * 10) + ((i23 & 15) * 100) + ((i23 >> 8) & 15);
                if (i24 >= 0 && i24 <= 255) {
                    i = i12 + 1;
                    bArr[i12] = (byte) i24;
                }
            }
            return null;
        }
        int i25 = length - 1;
        if ((i10 > 0 && i7 - i10 > 4) || i11 < 2 || ((!z3 && (i11 + 1 != 8 || charSequence.charAt(0) == ':' || charSequence.charAt(i25) == ':')) || ((z3 && (i11 > 8 || (i11 == 8 && ((i8 <= 2 && charSequence.charAt(0) != ':') || (i8 >= 14 && charSequence.charAt(i25) != ':'))))) || (i2 = i12 + 1) >= 16 || ((i10 < 0 && charSequence.charAt(i25 - 1) != ':') || (i8 > 2 && charSequence.charAt(0) == ':'))))) {
            return null;
        }
        if (i10 >= 0) {
            int i26 = i7 - i10;
            i3 = 4;
            if (i26 <= 4) {
                i14 <<= (4 - i26) << 2;
            }
        } else {
            i3 = 4;
        }
        bArr[i12] = (byte) (((i14 >> 4) & 15) | ((i14 & 15) << i3));
        i = i2 + 1;
        bArr[i2] = (byte) ((((i14 >> 8) & 15) << 4) | ((i14 >> 12) & 15));
        int i27 = i + i13;
        if (!z2 && i27 < 16) {
            for (int i28 = 0; i28 < i13; i28++) {
                int i29 = i28 + i8;
                int i30 = i29 + i13;
                if (i30 >= 16) {
                    break;
                }
                bArr[i30] = bArr[i29];
                bArr[i29] = 0;
            }
        } else {
            if (i27 >= 16) {
                i8++;
            }
            while (i < 16) {
                int i31 = 15;
                while (i31 >= i8) {
                    bArr[i31] = bArr[i31 - 1];
                    i31--;
                }
                bArr[i31] = 0;
                i8++;
                i++;
            }
        }
        if (i9 > 0) {
            bArr[11] = -1;
            bArr[10] = -1;
        }
        return bArr;
    }

    private static boolean inRangeEndExclusive(int i, int i2, int i3) {
        return i >= i2 && i < i3;
    }

    public static String intToIpAddress(int i) {
        StringBuilder sb = new StringBuilder(15);
        sb.append((i >> 24) & KEYRecord.PROTOCOL_ANY);
        sb.append('.');
        sb.append((i >> 16) & KEYRecord.PROTOCOL_ANY);
        sb.append('.');
        sb.append((i >> 8) & KEYRecord.PROTOCOL_ANY);
        sb.append('.');
        sb.append(i & KEYRecord.PROTOCOL_ANY);
        return sb.toString();
    }

    public static int ipv4AddressToInt(Inet4Address inet4Address) {
        byte[] address = inet4Address.getAddress();
        return (address[3] & 255) | ((address[0] & 255) << 24) | ((address[1] & 255) << 16) | ((address[2] & 255) << 8);
    }

    private static byte ipv4WordToByte(String str, int i, int i2) {
        int decimalDigit = decimalDigit(str, i);
        int i3 = i + 1;
        if (i3 == i2) {
            return (byte) decimalDigit;
        }
        int decimalDigit2 = (decimalDigit * 10) + decimalDigit(str, i3);
        int i4 = i3 + 1;
        if (i4 == i2) {
            return (byte) decimalDigit2;
        }
        return (byte) ((decimalDigit2 * 10) + decimalDigit(str, i4));
    }

    public static boolean isIpV4StackPreferred() {
        return IPV4_PREFERRED;
    }

    public static boolean isIpV6AddressesPreferred() {
        return IPV6_ADDRESSES_PREFERRED;
    }

    private static boolean isValidHexChar(char c) {
        return (c >= '0' && c <= '9') || (c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f');
    }

    private static boolean isValidIPv4Mapped(byte[] bArr, int i, int i2, int i3) {
        boolean z = i3 + i2 >= 14;
        if (i > 12 || i < 2 || ((z && i2 >= 12) || !isValidIPv4MappedSeparators(bArr[i - 1], bArr[i - 2], z) || !PlatformDependent.isZero(bArr, 0, i - 3))) {
            return false;
        }
        return true;
    }

    private static boolean isValidIPv4MappedChar(char c) {
        return c == 'f' || c == 'F';
    }

    private static boolean isValidIPv4MappedSeparators(byte b, byte b2, boolean z) {
        return b == b2 && (b == 0 || (!z && b2 == -1));
    }

    public static boolean isValidIpV4Address(CharSequence charSequence) {
        return isValidIpV4Address(charSequence, 0, charSequence.length());
    }

    private static boolean isValidIpV4Address0(CharSequence charSequence, int i, int i2) {
        int indexOf;
        int i3;
        int indexOf2;
        int i4;
        int indexOf3;
        int i5 = i2 - i;
        if (i5 > 15 || i5 < 7 || (indexOf = AsciiString.indexOf(charSequence, '.', i + 1)) <= 0 || !isValidIpV4Word(charSequence, i, indexOf) || (indexOf2 = AsciiString.indexOf(charSequence, '.', (i3 = indexOf + 2))) <= 0 || !isValidIpV4Word(charSequence, i3 - 1, indexOf2) || (indexOf3 = AsciiString.indexOf(charSequence, '.', (i4 = indexOf2 + 2))) <= 0 || !isValidIpV4Word(charSequence, i4 - 1, indexOf3) || !isValidIpV4Word(charSequence, indexOf3 + 1, i2)) {
            return false;
        }
        return true;
    }

    private static boolean isValidIpV4Word(CharSequence charSequence, int i, int i2) {
        char charAt;
        char charAt2;
        int i3 = i2 - i;
        if (i3 < 1 || i3 > 3 || (charAt = charSequence.charAt(i)) < '0') {
            return false;
        }
        if (i3 == 3) {
            char charAt3 = charSequence.charAt(i + 1);
            if (charAt3 < '0' || (charAt2 = charSequence.charAt(i + 2)) < '0') {
                return false;
            }
            if (charAt > '1' || charAt3 > '9' || charAt2 > '9') {
                if (charAt != '2' || charAt3 > '5') {
                    return false;
                }
                if (charAt2 <= '5' || (charAt3 < '5' && charAt2 <= '9')) {
                    return true;
                }
                return false;
            }
            return true;
        } else if (charAt > '9') {
            return false;
        } else {
            if (i3 == 1 || isValidNumericChar(charSequence.charAt(i + 1))) {
                return true;
            }
            return false;
        }
    }

    public static boolean isValidIpV6Address(String str) {
        return isValidIpV6Address((CharSequence) str);
    }

    private static boolean isValidNumericChar(char c) {
        return c >= '0' && c <= '9';
    }

    private static StringBuilder newSocketAddressStringBuilder(String str, String str2, boolean z) {
        int length = str.length();
        if (z) {
            StringBuilder sb = new StringBuilder(str2.length() + length + 1);
            sb.append(str);
            return sb;
        }
        StringBuilder sb2 = new StringBuilder(str2.length() + length + 3);
        if (length > 1 && str.charAt(0) == '[' && str.charAt(length - 1) == ']') {
            sb2.append(str);
            return sb2;
        }
        sb2.append('[');
        sb2.append(str);
        sb2.append(']');
        return sb2;
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: private */
    public static Integer sysctlGetInt(String str) {
        Process start = new ProcessBuilder("sysctl", str).start();
        try {
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(start.getInputStream()));
            try {
                String readLine = bufferedReader.readLine();
                if (readLine != null && readLine.startsWith(str)) {
                    for (int length = readLine.length() - 1; length > str.length(); length--) {
                        if (!Character.isDigit(readLine.charAt(length))) {
                            Integer valueOf = Integer.valueOf(readLine.substring(length + 1));
                            bufferedReader.close();
                            start.destroy();
                            return valueOf;
                        }
                    }
                }
                bufferedReader.close();
                start.destroy();
                return null;
            } catch (Throwable th) {
                bufferedReader.close();
                throw th;
            }
        } catch (Throwable th2) {
            if (start != null) {
                start.destroy();
            }
            throw th2;
        }
    }

    public static String toAddressString(InetAddress inetAddress) {
        return toAddressString(inetAddress, false);
    }

    public static String toSocketAddressString(InetSocketAddress inetSocketAddress) {
        StringBuilder sb;
        String valueOf = String.valueOf(inetSocketAddress.getPort());
        if (inetSocketAddress.isUnresolved()) {
            String hostname = getHostname(inetSocketAddress);
            sb = newSocketAddressStringBuilder(hostname, valueOf, !isValidIpV6Address(hostname));
        } else {
            InetAddress address = inetSocketAddress.getAddress();
            sb = newSocketAddressStringBuilder(toAddressString(address), valueOf, address instanceof Inet4Address);
        }
        sb.append(':');
        sb.append(valueOf);
        return sb.toString();
    }

    public static byte[] validIpV4ToBytes(String str) {
        int indexOf = str.indexOf(46, 1);
        int i = indexOf + 1;
        int indexOf2 = str.indexOf(46, indexOf + 2);
        int indexOf3 = str.indexOf(46, indexOf2 + 2);
        return new byte[]{ipv4WordToByte(str, 0, indexOf), ipv4WordToByte(str, i, indexOf2), ipv4WordToByte(str, indexOf2 + 1, indexOf3), ipv4WordToByte(str, indexOf3 + 1, str.length())};
    }

    public static String bytesToIpAddress(byte[] bArr, int i, int i2) {
        if (i2 == 4) {
            StringBuilder sb = new StringBuilder(15);
            sb.append(bArr[i] & 255);
            sb.append('.');
            sb.append(bArr[i + 1] & 255);
            sb.append('.');
            sb.append(bArr[i + 2] & 255);
            sb.append('.');
            sb.append(bArr[i + 3] & 255);
            return sb.toString();
        } else if (i2 == 16) {
            return toAddressString(bArr, i, false);
        } else {
            throw new IllegalArgumentException(GeneratedOutlineSupport.outline12("length: ", i2, " (expected: 4 or 16)"));
        }
    }

    public static Inet6Address getByName(CharSequence charSequence, boolean z) {
        byte[] iPv6ByName = getIPv6ByName(charSequence, z);
        if (iPv6ByName == null) {
            return null;
        }
        try {
            return Inet6Address.getByAddress((String) null, iPv6ByName, -1);
        } catch (UnknownHostException e) {
            throw new RuntimeException(e);
        }
    }

    public static boolean isValidIpV4Address(String str) {
        return isValidIpV4Address(str, 0, str.length());
    }

    public static boolean isValidIpV6Address(CharSequence charSequence) {
        int i;
        int i2;
        int length = charSequence.length();
        int i3 = 2;
        if (length < 2) {
            return false;
        }
        char charAt = charSequence.charAt(0);
        if (charAt == '[') {
            length--;
            if (charSequence.charAt(length) != ']') {
                return false;
            }
            charAt = charSequence.charAt(1);
            i = 1;
        } else {
            i = 0;
        }
        if (charAt != ':') {
            i3 = 0;
            i2 = -1;
        } else if (charSequence.charAt(i + 1) != ':') {
            return false;
        } else {
            i += 2;
            i2 = i;
        }
        int i4 = i;
        int i5 = 0;
        while (true) {
            if (i4 >= length) {
                break;
            }
            char charAt2 = charSequence.charAt(i4);
            if (!isValidHexChar(charAt2)) {
                if (charAt2 == '%') {
                    length = i4;
                    break;
                } else if (charAt2 != '.') {
                    if (charAt2 != ':' || i3 > 7) {
                        return false;
                    }
                    int i6 = i4 - 1;
                    if (charSequence.charAt(i6) != ':') {
                        i5 = 0;
                    } else if (i2 >= 0) {
                        return false;
                    } else {
                        i2 = i6;
                    }
                    i3++;
                } else if ((i2 < 0 && i3 != 6) || ((i3 == 7 && i2 >= i) || i3 > 7)) {
                    return false;
                } else {
                    int i7 = i4 - i5;
                    int i8 = i7 - 2;
                    if (isValidIPv4MappedChar(charSequence.charAt(i8))) {
                        if (!isValidIPv4MappedChar(charSequence.charAt(i8 - 1)) || !isValidIPv4MappedChar(charSequence.charAt(i8 - 2)) || !isValidIPv4MappedChar(charSequence.charAt(i8 - 3))) {
                            return false;
                        }
                        i8 -= 5;
                    }
                    while (i8 >= i) {
                        char charAt3 = charSequence.charAt(i8);
                        if (charAt3 != '0' && charAt3 != ':') {
                            return false;
                        }
                        i8--;
                    }
                    int indexOf = AsciiString.indexOf(charSequence, '%', i7 + 7);
                    if (indexOf >= 0) {
                        length = indexOf;
                    }
                    return isValidIpV4Address(charSequence, i7, length);
                }
            } else if (i5 >= 4) {
                return false;
            } else {
                i5++;
            }
            i4++;
        }
        if (i2 >= 0) {
            if (i2 + 2 != length) {
                if (i5 <= 0) {
                    return false;
                }
                if (i3 < 8 || i2 <= i) {
                    return true;
                }
                return false;
            }
            return true;
        } else if (i3 != 7 || i5 <= 0) {
            return false;
        } else {
            return true;
        }
    }

    public static String toAddressString(InetAddress inetAddress, boolean z) {
        if (inetAddress instanceof Inet4Address) {
            return inetAddress.getHostAddress();
        }
        if (inetAddress instanceof Inet6Address) {
            return toAddressString(inetAddress.getAddress(), 0, z);
        }
        throw new IllegalArgumentException("Unhandled type: " + inetAddress);
    }

    private static boolean isValidIpV4Address(CharSequence charSequence, int i, int i2) {
        if (charSequence instanceof String) {
            return isValidIpV4Address((String) charSequence, i, i2);
        }
        if (charSequence instanceof AsciiString) {
            return isValidIpV4Address((AsciiString) charSequence, i, i2);
        }
        return isValidIpV4Address0(charSequence, i, i2);
    }

    private static boolean isValidIpV4Address(String str, int i, int i2) {
        int indexOf;
        int i3;
        int indexOf2;
        int i4;
        int indexOf3;
        int i5 = i2 - i;
        if (i5 > 15 || i5 < 7 || (indexOf = str.indexOf(46, i + 1)) <= 0 || !isValidIpV4Word(str, i, indexOf) || (indexOf2 = str.indexOf(46, (i3 = indexOf + 2))) <= 0 || !isValidIpV4Word(str, i3 - 1, indexOf2) || (indexOf3 = str.indexOf(46, (i4 = indexOf2 + 2))) <= 0 || !isValidIpV4Word(str, i4 - 1, indexOf3) || !isValidIpV4Word(str, indexOf3 + 1, i2)) {
            return false;
        }
        return true;
    }

    private static String toAddressString(byte[] bArr, int i, boolean z) {
        int i2;
        int i3;
        int[] iArr = new int[8];
        int i4 = i + 8;
        while (true) {
            i2 = 1;
            if (i >= i4) {
                break;
            }
            int i5 = i << 1;
            iArr[i] = (bArr[i5 + 1] & 255) | ((bArr[i5] & 255) << 8);
            i++;
        }
        int i6 = -1;
        boolean z2 = false;
        int i7 = 0;
        int i8 = -1;
        int i9 = 0;
        int i10 = -1;
        while (i7 < 8) {
            if (iArr[i7] == 0) {
                if (i8 < 0) {
                    i8 = i7;
                }
            } else if (i8 >= 0) {
                int i11 = i7 - i8;
                if (i11 > i9) {
                    i9 = i11;
                } else {
                    i8 = i10;
                }
                i10 = i8;
                i8 = -1;
            }
            i7++;
        }
        if (i8 < 0 || (i3 = i7 - i8) <= i9) {
            i8 = i10;
        } else {
            i9 = i3;
        }
        if (i9 == 1) {
            i9 = 0;
        } else {
            i6 = i8;
        }
        int i12 = i9 + i6;
        StringBuilder sb = new StringBuilder(39);
        if (i12 < 0) {
            sb.append(Integer.toHexString(iArr[0]));
            while (i2 < 8) {
                sb.append(':');
                sb.append(Integer.toHexString(iArr[i2]));
                i2++;
            }
        } else {
            if (inRangeEndExclusive(0, i6, i12)) {
                sb.append("::");
                if (z && i12 == 5 && iArr[5] == 65535) {
                    z2 = true;
                }
            } else {
                sb.append(Integer.toHexString(iArr[0]));
            }
            while (i2 < 8) {
                if (!inRangeEndExclusive(i2, i6, i12)) {
                    if (!inRangeEndExclusive(i2 - 1, i6, i12)) {
                        if (!z2 || i2 == 6) {
                            sb.append(':');
                        } else {
                            sb.append('.');
                        }
                    }
                    if (!z2 || i2 <= 5) {
                        sb.append(Integer.toHexString(iArr[i2]));
                    } else {
                        sb.append(iArr[i2] >> 8);
                        sb.append('.');
                        sb.append(iArr[i2] & KEYRecord.PROTOCOL_ANY);
                    }
                } else if (!inRangeEndExclusive(i2 - 1, i6, i12)) {
                    sb.append("::");
                }
                i2++;
            }
        }
        return sb.toString();
    }

    public static String toSocketAddressString(String str, int i) {
        String valueOf = String.valueOf(i);
        StringBuilder newSocketAddressStringBuilder = newSocketAddressStringBuilder(str, valueOf, !isValidIpV6Address(str));
        newSocketAddressStringBuilder.append(':');
        newSocketAddressStringBuilder.append(valueOf);
        return newSocketAddressStringBuilder.toString();
    }

    private static boolean isValidIpV4Address(AsciiString asciiString, int i, int i2) {
        int indexOf;
        int i3;
        int indexOf2;
        int i4;
        int indexOf3;
        int i5 = i2 - i;
        if (i5 > 15 || i5 < 7 || (indexOf = asciiString.indexOf('.', i + 1)) <= 0 || !isValidIpV4Word(asciiString, i, indexOf) || (indexOf2 = asciiString.indexOf('.', (i3 = indexOf + 2))) <= 0 || !isValidIpV4Word(asciiString, i3 - 1, indexOf2) || (indexOf3 = asciiString.indexOf('.', (i4 = indexOf2 + 2))) <= 0 || !isValidIpV4Word(asciiString, i4 - 1, indexOf3) || !isValidIpV4Word(asciiString, indexOf3 + 1, i2)) {
            return false;
        }
        return true;
    }
}
