package kotlinx.coroutines;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.Objects;
import java.util.concurrent.CancellationException;
import java.util.concurrent.atomic.AtomicIntegerFieldUpdater;
import java.util.concurrent.atomic.AtomicReferenceFieldUpdater;
import kotlin.Result;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.CoroutineContext;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.coroutines.jvm.internal.CoroutineStackFrame;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.StackTraceRecoveryKt;
import kotlinx.coroutines.internal.Symbol;

/* compiled from: CancellableContinuationImpl.kt */
public class CancellableContinuationImpl<T> extends DispatchedTask<T> implements CancellableContinuation<T>, CoroutineStackFrame {
    public static final AtomicIntegerFieldUpdater _decision$FU = AtomicIntegerFieldUpdater.newUpdater(CancellableContinuationImpl.class, "_decision");
    public static final AtomicReferenceFieldUpdater _state$FU = AtomicReferenceFieldUpdater.newUpdater(CancellableContinuationImpl.class, Object.class, "_state");
    public volatile int _decision = 0;
    public volatile Object _parentHandle = null;
    public volatile Object _state = Active.INSTANCE;
    public final CoroutineContext context;
    public final Continuation<T> delegate;

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: kotlin.coroutines.Continuation<? super T> */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public CancellableContinuationImpl(Continuation<? super T> continuation, int i) {
        super(i);
        Intrinsics.checkParameterIsNotNull(continuation, "delegate");
        this.delegate = continuation;
        this.context = continuation.getContext();
    }

    public boolean cancel(Throwable th) {
        Object obj;
        boolean z;
        do {
            obj = this._state;
            if (!(obj instanceof NotCompleted)) {
                return false;
            }
            z = obj instanceof CancelHandler;
        } while (!_state$FU.compareAndSet(this, obj, new CancelledContinuation(this, th, z)));
        if (z) {
            try {
                ((CancelHandler) obj).invoke(th);
            } catch (Throwable th2) {
                CoroutineContext coroutineContext = this.context;
                ViewGroupUtilsApi14.handleCoroutineException(coroutineContext, new CompletionHandlerException("Exception in cancellation handler for " + this, th2));
            }
        }
        detachChildIfNonResuable();
        dispatchResume(0);
        return true;
    }

    @Override // kotlinx.coroutines.DispatchedTask
    public void cancelResult$kotlinx_coroutines_core(Object obj, Throwable th) {
        Intrinsics.checkParameterIsNotNull(th, "cause");
    }

    public void completeResume(Object obj) {
        Intrinsics.checkParameterIsNotNull(obj, "token");
        boolean z = DebugKt.DEBUG;
        dispatchResume(this.resumeMode);
    }

    public final void detachChild$kotlinx_coroutines_core() {
        DisposableHandle disposableHandle = (DisposableHandle) this._parentHandle;
        if (disposableHandle != null) {
            disposableHandle.dispose();
        }
        this._parentHandle = NonDisposableHandle.INSTANCE;
    }

    public final void detachChildIfNonResuable() {
        if (!isReusable()) {
            detachChild$kotlinx_coroutines_core();
        }
    }

    public final void dispatchResume(int i) {
        boolean z;
        boolean z2;
        while (true) {
            int i2 = this._decision;
            z = false;
            if (i2 == 0) {
                if (_decision$FU.compareAndSet(this, 0, 2)) {
                    z2 = true;
                    break;
                }
            } else if (i2 == 1) {
                z2 = false;
            } else {
                throw new IllegalStateException("Already resumed".toString());
            }
        }
        if (!z2) {
            Intrinsics.checkParameterIsNotNull(this, "$this$dispatch");
            Continuation<T> delegate$kotlinx_coroutines_core = getDelegate$kotlinx_coroutines_core();
            if (i == 0 || i == 1) {
                z = true;
            }
            if (!z || !(delegate$kotlinx_coroutines_core instanceof DispatchedContinuation) || ViewGroupUtilsApi14.isCancellableMode(i) != ViewGroupUtilsApi14.isCancellableMode(this.resumeMode)) {
                ViewGroupUtilsApi14.resume(this, delegate$kotlinx_coroutines_core, i);
                return;
            }
            CoroutineDispatcher coroutineDispatcher = ((DispatchedContinuation) delegate$kotlinx_coroutines_core).dispatcher;
            CoroutineContext context2 = delegate$kotlinx_coroutines_core.getContext();
            if (coroutineDispatcher.isDispatchNeeded(context2)) {
                coroutineDispatcher.dispatch(context2, this);
                return;
            }
            ThreadLocalEventLoop threadLocalEventLoop = ThreadLocalEventLoop.INSTANCE;
            EventLoopImplPlatform eventLoop$kotlinx_coroutines_core = ThreadLocalEventLoop.getEventLoop$kotlinx_coroutines_core();
            if (eventLoop$kotlinx_coroutines_core.isUnconfinedLoopActive()) {
                eventLoop$kotlinx_coroutines_core.dispatchUnconfined(this);
                return;
            }
            eventLoop$kotlinx_coroutines_core.incrementUseCount(true);
            try {
                ViewGroupUtilsApi14.resume(this, getDelegate$kotlinx_coroutines_core(), 2);
                do {
                } while (eventLoop$kotlinx_coroutines_core.processUnconfinedEvent());
            } catch (Throwable th) {
                eventLoop$kotlinx_coroutines_core.decrementUseCount(true);
                throw th;
            }
            eventLoop$kotlinx_coroutines_core.decrementUseCount(true);
        }
    }

    @Override // kotlin.coroutines.jvm.internal.CoroutineStackFrame
    public CoroutineStackFrame getCallerFrame() {
        Continuation<T> continuation = this.delegate;
        if (!(continuation instanceof CoroutineStackFrame)) {
            continuation = null;
        }
        return (CoroutineStackFrame) continuation;
    }

    @Override // kotlin.coroutines.Continuation
    public CoroutineContext getContext() {
        return this.context;
    }

    public Throwable getContinuationCancellationCause(Job job) {
        Intrinsics.checkParameterIsNotNull(job, "parent");
        return job.getCancellationException();
    }

    @Override // kotlinx.coroutines.DispatchedTask
    public final Continuation<T> getDelegate$kotlinx_coroutines_core() {
        return this.delegate;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v3, resolved type: java.util.concurrent.atomic.AtomicReferenceFieldUpdater */
    /* JADX DEBUG: Multi-variable search result rejected for r3v5, resolved type: java.util.concurrent.atomic.AtomicReferenceFieldUpdater */
    /* JADX WARN: Multi-variable type inference failed */
    public final Object getResult() {
        boolean z;
        Job job;
        Job job2;
        boolean z2 = !(this._state instanceof NotCompleted);
        if (this.resumeMode == 0) {
            Continuation<T> continuation = this.delegate;
            Throwable th = null;
            if (!(continuation instanceof DispatchedContinuation)) {
                continuation = null;
            }
            DispatchedContinuation dispatchedContinuation = (DispatchedContinuation) continuation;
            if (dispatchedContinuation != null) {
                Intrinsics.checkParameterIsNotNull(this, "continuation");
                while (true) {
                    Object obj = dispatchedContinuation._reusableCancellableContinuation;
                    Symbol symbol = DispatchedContinuationKt.REUSABLE_CLAIMED;
                    if (obj == symbol) {
                        if (DispatchedContinuation._reusableCancellableContinuation$FU.compareAndSet(dispatchedContinuation, symbol, this)) {
                            break;
                        }
                    } else if (obj != null) {
                        if (!(obj instanceof Throwable)) {
                            throw new IllegalStateException(GeneratedOutlineSupport.outline17("Inconsistent state ", obj).toString());
                        } else if (DispatchedContinuation._reusableCancellableContinuation$FU.compareAndSet(dispatchedContinuation, obj, null)) {
                            th = (Throwable) obj;
                        } else {
                            throw new IllegalArgumentException("Failed requirement.".toString());
                        }
                    }
                }
                if (th != null) {
                    if (!z2) {
                        cancel(th);
                    }
                    z2 = true;
                }
            }
        }
        if (!z2 && ((DisposableHandle) this._parentHandle) == null && (job2 = (Job) this.delegate.getContext().get(Job.Key)) != null) {
            job2.start();
            DisposableHandle invokeOnCompletion$default = ViewGroupUtilsApi14.invokeOnCompletion$default(job2, true, false, new ChildContinuation(job2, this), 2, null);
            this._parentHandle = invokeOnCompletion$default;
            if ((!(this._state instanceof NotCompleted)) && !isReusable()) {
                invokeOnCompletion$default.dispose();
                this._parentHandle = NonDisposableHandle.INSTANCE;
            }
        }
        while (true) {
            int i = this._decision;
            z = false;
            if (i == 0) {
                if (_decision$FU.compareAndSet(this, 0, 1)) {
                    z = true;
                    break;
                }
            } else if (i != 2) {
                throw new IllegalStateException("Already suspended".toString());
            }
        }
        if (z) {
            return CoroutineSingletons.COROUTINE_SUSPENDED;
        }
        Object obj2 = this._state;
        if (obj2 instanceof CompletedExceptionally) {
            throw StackTraceRecoveryKt.recoverStackTrace(((CompletedExceptionally) obj2).cause, this);
        } else if (this.resumeMode != 1 || (job = (Job) this.context.get(Job.Key)) == null || job.isActive()) {
            return obj2 instanceof CompletedIdempotentResult ? ((CompletedIdempotentResult) obj2).result : obj2;
        } else {
            CancellationException cancellationException = job.getCancellationException();
            Intrinsics.checkParameterIsNotNull(cancellationException, "cause");
            throw StackTraceRecoveryKt.recoverStackTrace(cancellationException, this);
        }
    }

    @Override // kotlin.coroutines.jvm.internal.CoroutineStackFrame
    public StackTraceElement getStackTraceElement() {
        return null;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // kotlinx.coroutines.DispatchedTask
    public <T> T getSuccessfulResult$kotlinx_coroutines_core(Object obj) {
        return obj instanceof CompletedIdempotentResult ? (T) ((CompletedIdempotentResult) obj).result : obj;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v1, resolved type: java.util.concurrent.atomic.AtomicIntegerFieldUpdater */
    /* JADX WARN: Multi-variable type inference failed */
    public void invokeOnCancellation(Function1<? super Throwable, Unit> function1) {
        Object obj;
        Intrinsics.checkParameterIsNotNull(function1, "handler");
        Throwable th = null;
        Object obj2 = null;
        do {
            obj = this._state;
            if (obj instanceof Active) {
                if (obj2 == null) {
                    obj2 = function1 instanceof CancelHandler ? (CancelHandler) function1 : new InvokeOnCancel(function1);
                }
            } else if (obj instanceof CancelHandler) {
                multipleHandlersError(function1, obj);
                throw null;
            } else if (obj instanceof CancelledContinuation) {
                CancelledContinuation cancelledContinuation = (CancelledContinuation) obj;
                Objects.requireNonNull(cancelledContinuation);
                if (CompletedExceptionally._handled$FU.compareAndSet(cancelledContinuation, 0, 1)) {
                    try {
                        if (!(obj instanceof CompletedExceptionally)) {
                            obj = null;
                        }
                        CompletedExceptionally completedExceptionally = (CompletedExceptionally) obj;
                        if (completedExceptionally != null) {
                            th = completedExceptionally.cause;
                        }
                        function1.invoke(th);
                        return;
                    } catch (Throwable th2) {
                        ViewGroupUtilsApi14.handleCoroutineException(this.context, new CompletionHandlerException("Exception in cancellation handler for " + this, th2));
                        return;
                    }
                } else {
                    multipleHandlersError(function1, obj);
                    throw null;
                }
            } else {
                return;
            }
        } while (!_state$FU.compareAndSet(this, obj, obj2));
    }

    public final boolean isReusable() {
        Continuation<T> continuation = this.delegate;
        if (continuation instanceof DispatchedContinuation) {
            if (((DispatchedContinuation) continuation)._reusableCancellableContinuation != null) {
                return true;
            }
        }
        return false;
    }

    public final void multipleHandlersError(Function1<? super Throwable, Unit> function1, Object obj) {
        throw new IllegalStateException(("It's prohibited to register multiple handlers, tried to register " + function1 + ", already has " + obj).toString());
    }

    public String nameString() {
        return "CancellableContinuation";
    }

    /* JADX DEBUG: Multi-variable search result rejected for r5v4, resolved type: java.util.concurrent.atomic.AtomicIntegerFieldUpdater */
    /* JADX WARN: Multi-variable type inference failed */
    public final CancelledContinuation resumeImpl(Object obj, int i) {
        Object obj2;
        do {
            obj2 = this._state;
            if (!(obj2 instanceof NotCompleted)) {
                if (obj2 instanceof CancelledContinuation) {
                    CancelledContinuation cancelledContinuation = (CancelledContinuation) obj2;
                    Objects.requireNonNull(cancelledContinuation);
                    if (CancelledContinuation._resumed$FU.compareAndSet(cancelledContinuation, 0, 1)) {
                        return cancelledContinuation;
                    }
                }
                throw new IllegalStateException(GeneratedOutlineSupport.outline17("Already resumed, but proposed with update ", obj).toString());
            }
        } while (!_state$FU.compareAndSet(this, obj2, obj));
        detachChildIfNonResuable();
        dispatchResume(i);
        return null;
    }

    public void resumeUndispatched(CoroutineDispatcher coroutineDispatcher, T t) {
        Intrinsics.checkParameterIsNotNull(coroutineDispatcher, "$this$resumeUndispatched");
        Continuation<T> continuation = this.delegate;
        CoroutineDispatcher coroutineDispatcher2 = null;
        if (!(continuation instanceof DispatchedContinuation)) {
            continuation = null;
        }
        DispatchedContinuation dispatchedContinuation = (DispatchedContinuation) continuation;
        if (dispatchedContinuation != null) {
            coroutineDispatcher2 = dispatchedContinuation.dispatcher;
        }
        resumeImpl(t, coroutineDispatcher2 == coroutineDispatcher ? 2 : this.resumeMode);
    }

    @Override // kotlin.coroutines.Continuation
    public void resumeWith(Object obj) {
        Intrinsics.checkParameterIsNotNull(this, "caller");
        Throwable r0 = Result.m136exceptionOrNullimpl(obj);
        if (r0 != null) {
            obj = new CompletedExceptionally(StackTraceRecoveryKt.recoverStackTrace(r0, this), false, 2);
        }
        resumeImpl(obj, this.resumeMode);
    }

    @Override // kotlinx.coroutines.DispatchedTask
    public Object takeState$kotlinx_coroutines_core() {
        return this._state;
    }

    public String toString() {
        return nameString() + '(' + ViewGroupUtilsApi14.toDebugString(this.delegate) + "){" + this._state + "}@" + ViewGroupUtilsApi14.getHexAddress(this);
    }

    public Object tryResume(T t, Object obj) {
        Object obj2;
        CompletedIdempotentResult completedIdempotentResult;
        do {
            obj2 = this._state;
            if (obj2 instanceof NotCompleted) {
                if (obj == null) {
                    completedIdempotentResult = t;
                } else {
                    completedIdempotentResult = new CompletedIdempotentResult(obj, t);
                }
            } else if (!(obj2 instanceof CompletedIdempotentResult) || ((CompletedIdempotentResult) obj2).idempotentResume != obj) {
                return null;
            } else {
                boolean z = DebugKt.DEBUG;
                return CancellableContinuationImplKt.RESUME_TOKEN;
            }
        } while (!_state$FU.compareAndSet(this, obj2, completedIdempotentResult));
        detachChildIfNonResuable();
        return CancellableContinuationImplKt.RESUME_TOKEN;
    }
}
