package kotlinx.coroutines;

import androidx.transition.ViewGroupUtilsApi14;
import java.util.concurrent.CancellationException;
import kotlin.Result;
import kotlin.TypeCastException;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.CoroutineContext;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.StackTraceRecoveryKt;
import kotlinx.coroutines.internal.ThreadContextKt;
import kotlinx.coroutines.scheduling.Task;
import kotlinx.coroutines.scheduling.TaskContext;

/* compiled from: DispatchedTask.kt */
public abstract class DispatchedTask<T> extends Task {
    public int resumeMode;

    public DispatchedTask(int i) {
        this.resumeMode = i;
    }

    public void cancelResult$kotlinx_coroutines_core(Object obj, Throwable th) {
        Intrinsics.checkParameterIsNotNull(th, "cause");
    }

    public abstract Continuation<T> getDelegate$kotlinx_coroutines_core();

    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    public <T> T getSuccessfulResult$kotlinx_coroutines_core(Object obj) {
        return obj;
    }

    public final void handleFatalException$kotlinx_coroutines_core(Throwable th, Throwable th2) {
        if (th != null || th2 != null) {
            if (!(th == null || th2 == null)) {
                ViewGroupUtilsApi14.addSuppressed(th, th2);
            }
            if (th == null) {
                th = th2;
            }
            String str = "Fatal exception in coroutines machinery for " + this + ". " + "Please read KDoc to 'handleFatalException' method and report this incident to maintainers";
            if (th != null) {
                ViewGroupUtilsApi14.handleCoroutineException(getDelegate$kotlinx_coroutines_core().getContext(), new CoroutinesInternalError(str, th));
                return;
            }
            Intrinsics.throwNpe();
            throw null;
        }
    }

    public final void run() {
        Object obj;
        Object obj2;
        TaskContext taskContext = this.taskContext;
        try {
            Continuation<T> delegate$kotlinx_coroutines_core = getDelegate$kotlinx_coroutines_core();
            if (delegate$kotlinx_coroutines_core != null) {
                DispatchedContinuation dispatchedContinuation = (DispatchedContinuation) delegate$kotlinx_coroutines_core;
                Continuation<T> continuation = dispatchedContinuation.continuation;
                CoroutineContext context = continuation.getContext();
                Object takeState$kotlinx_coroutines_core = takeState$kotlinx_coroutines_core();
                Object updateThreadContext = ThreadContextKt.updateThreadContext(context, dispatchedContinuation.countOrElement);
                try {
                    CompletedExceptionally completedExceptionally = (CompletedExceptionally) (!(takeState$kotlinx_coroutines_core instanceof CompletedExceptionally) ? null : takeState$kotlinx_coroutines_core);
                    Throwable th = completedExceptionally != null ? completedExceptionally.cause : null;
                    Job job = ViewGroupUtilsApi14.isCancellableMode(this.resumeMode) ? (Job) context.get(Job.Key) : null;
                    if (th == null && job != null && !job.isActive()) {
                        CancellationException cancellationException = job.getCancellationException();
                        cancelResult$kotlinx_coroutines_core(takeState$kotlinx_coroutines_core, cancellationException);
                        continuation.resumeWith(Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(StackTraceRecoveryKt.recoverStackTrace(cancellationException, continuation))));
                    } else if (th != null) {
                        continuation.resumeWith(Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(th)));
                    } else {
                        continuation.resumeWith(Result.m133constructorimpl(getSuccessfulResult$kotlinx_coroutines_core(takeState$kotlinx_coroutines_core)));
                    }
                    Unit unit = Unit.INSTANCE;
                    try {
                        taskContext.afterTask();
                        obj2 = Result.m133constructorimpl(unit);
                    } catch (Throwable th2) {
                        obj2 = Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(th2));
                    }
                    handleFatalException$kotlinx_coroutines_core(null, Result.m136exceptionOrNullimpl(obj2));
                    return;
                } finally {
                    ThreadContextKt.restoreThreadContext(context, updateThreadContext);
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.DispatchedContinuation<T>");
            }
        } catch (Throwable th3) {
            obj = Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(th3));
        }
        handleFatalException$kotlinx_coroutines_core(th, Result.m136exceptionOrNullimpl(obj));
    }

    public abstract Object takeState$kotlinx_coroutines_core();
}
