package kotlinx.coroutines;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.concurrent.atomic.AtomicReferenceFieldUpdater;
import java.util.concurrent.locks.LockSupport;
import kotlin.Unit;
import kotlin.coroutines.CoroutineContext;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.ArrayQueue;
import kotlinx.coroutines.internal.LockFreeTaskQueueCore;
import kotlinx.coroutines.internal.Symbol;
import kotlinx.coroutines.internal.ThreadSafeHeap;

/* compiled from: EventLoop.common.kt */
public abstract class EventLoopImplBase extends EventLoopImplPlatform implements Delay {
    public static final AtomicReferenceFieldUpdater _delayed$FU = AtomicReferenceFieldUpdater.newUpdater(EventLoopImplBase.class, Object.class, "_delayed");
    public static final AtomicReferenceFieldUpdater _queue$FU = AtomicReferenceFieldUpdater.newUpdater(EventLoopImplBase.class, Object.class, "_queue");
    public volatile Object _delayed = null;
    public volatile int _isCompleted = 0;
    public volatile Object _queue = null;

    /* compiled from: EventLoop.common.kt */
    public final class DelayedResumeTask extends DelayedTask {
        public final CancellableContinuation<Unit> cont;
        public final /* synthetic */ EventLoopImplBase this$0;

        /* JADX DEBUG: Multi-variable search result rejected for r5v0, resolved type: kotlinx.coroutines.CancellableContinuation<? super kotlin.Unit> */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public DelayedResumeTask(EventLoopImplBase eventLoopImplBase, long j, CancellableContinuation<? super Unit> cancellableContinuation) {
            super(j);
            Intrinsics.checkParameterIsNotNull(cancellableContinuation, "cont");
            this.this$0 = eventLoopImplBase;
            this.cont = cancellableContinuation;
        }

        public void run() {
            ((CancellableContinuationImpl) this.cont).resumeUndispatched(this.this$0, Unit.INSTANCE);
        }

        @Override // kotlinx.coroutines.EventLoopImplBase.DelayedTask
        public String toString() {
            return super.toString() + this.cont.toString();
        }
    }

    /* compiled from: EventLoop.common.kt */
    public final class DelayedRunnableTask extends DelayedTask {
        public final Runnable block;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public DelayedRunnableTask(long j, Runnable runnable) {
            super(j);
            Intrinsics.checkParameterIsNotNull(runnable, "block");
            this.block = runnable;
        }

        public void run() {
            this.block.run();
        }

        @Override // kotlinx.coroutines.EventLoopImplBase.DelayedTask
        public String toString() {
            return super.toString() + this.block.toString();
        }
    }

    /* compiled from: EventLoop.common.kt */
    public abstract class DelayedTask implements Runnable, Comparable<DelayedTask>, DisposableHandle {
        public Object _heap;
        public int index = -1;
        public long nanoTime;

        public DelayedTask(long j) {
            this.nanoTime = j;
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object] */
        @Override // java.lang.Comparable
        public int compareTo(DelayedTask delayedTask) {
            DelayedTask delayedTask2 = delayedTask;
            Intrinsics.checkParameterIsNotNull(delayedTask2, "other");
            int i = ((this.nanoTime - delayedTask2.nanoTime) > 0 ? 1 : ((this.nanoTime - delayedTask2.nanoTime) == 0 ? 0 : -1));
            if (i > 0) {
                return 1;
            }
            return i < 0 ? -1 : 0;
        }

        @Override // kotlinx.coroutines.DisposableHandle
        public final synchronized void dispose() {
            Object obj = this._heap;
            Symbol symbol = EventLoop_commonKt.DISPOSED_TASK;
            if (obj != symbol) {
                if (!(obj instanceof DelayedTaskQueue)) {
                    obj = null;
                }
                DelayedTaskQueue delayedTaskQueue = (DelayedTaskQueue) obj;
                if (delayedTaskQueue != null) {
                    Intrinsics.checkParameterIsNotNull(this, "node");
                    synchronized (delayedTaskQueue) {
                        if (getHeap() != null) {
                            int i = this.index;
                            boolean z = DebugKt.DEBUG;
                            delayedTaskQueue.removeAtImpl(i);
                        }
                    }
                }
                this._heap = symbol;
            }
        }

        public ThreadSafeHeap<?> getHeap() {
            Object obj = this._heap;
            if (!(obj instanceof ThreadSafeHeap)) {
                obj = null;
            }
            return (ThreadSafeHeap) obj;
        }

        public void setHeap(ThreadSafeHeap<?> threadSafeHeap) {
            if (this._heap != EventLoop_commonKt.DISPOSED_TASK) {
                this._heap = threadSafeHeap;
                return;
            }
            throw new IllegalArgumentException("Failed requirement.".toString());
        }

        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Delayed[nanos=");
            outline25.append(this.nanoTime);
            outline25.append(']');
            return outline25.toString();
        }
    }

    /* compiled from: EventLoop.common.kt */
    public final class DelayedTaskQueue extends ThreadSafeHeap<DelayedTask> {
        public long timeNow;

        public DelayedTaskQueue(long j) {
            this.timeNow = j;
        }
    }

    @Override // kotlinx.coroutines.CoroutineDispatcher
    public final void dispatch(CoroutineContext coroutineContext, Runnable runnable) {
        Intrinsics.checkParameterIsNotNull(coroutineContext, "context");
        Intrinsics.checkParameterIsNotNull(runnable, "block");
        enqueue(runnable);
    }

    public final void enqueue(Runnable runnable) {
        Intrinsics.checkParameterIsNotNull(runnable, "task");
        if (enqueueImpl(runnable)) {
            Thread thread = getThread();
            if (Thread.currentThread() != thread) {
                LockSupport.unpark(thread);
                return;
            }
            return;
        }
        DefaultExecutor.INSTANCE.enqueue(runnable);
    }

    public final boolean enqueueImpl(Runnable runnable) {
        while (true) {
            Object obj = this._queue;
            if (this._isCompleted != 0) {
                return false;
            }
            if (obj == null) {
                if (_queue$FU.compareAndSet(this, null, runnable)) {
                    return true;
                }
            } else if (obj instanceof LockFreeTaskQueueCore) {
                LockFreeTaskQueueCore lockFreeTaskQueueCore = (LockFreeTaskQueueCore) obj;
                int addLast = lockFreeTaskQueueCore.addLast(runnable);
                if (addLast == 0) {
                    return true;
                }
                if (addLast == 1) {
                    _queue$FU.compareAndSet(this, obj, lockFreeTaskQueueCore.next());
                } else if (addLast == 2) {
                    return false;
                }
            } else if (obj == EventLoop_commonKt.CLOSED_EMPTY) {
                return false;
            } else {
                LockFreeTaskQueueCore lockFreeTaskQueueCore2 = new LockFreeTaskQueueCore(8, true);
                lockFreeTaskQueueCore2.addLast((Runnable) obj);
                lockFreeTaskQueueCore2.addLast(runnable);
                if (_queue$FU.compareAndSet(this, obj, lockFreeTaskQueueCore2)) {
                    return true;
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x001e A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x001f  */
    public long getNextTime() {
        long j;
        DelayedTask firstImpl;
        ArrayQueue<DispatchedTask<?>> arrayQueue = this.unconfinedQueue;
        if (arrayQueue != null) {
            if (!(arrayQueue.head == arrayQueue.tail)) {
                j = 0;
                if (j != 0) {
                    return 0;
                }
                Object obj = this._queue;
                if (obj != null) {
                    if (!(obj instanceof LockFreeTaskQueueCore)) {
                        return obj == EventLoop_commonKt.CLOSED_EMPTY ? Long.MAX_VALUE : 0;
                    }
                    if (!((LockFreeTaskQueueCore) obj).isEmpty()) {
                        return 0;
                    }
                }
                DelayedTaskQueue delayedTaskQueue = (DelayedTaskQueue) this._delayed;
                if (delayedTaskQueue != null) {
                    synchronized (delayedTaskQueue) {
                        firstImpl = delayedTaskQueue.firstImpl();
                    }
                    if (firstImpl != null) {
                        long nanoTime = firstImpl.nanoTime - System.nanoTime();
                        if (nanoTime < 0) {
                            return 0;
                        }
                        return nanoTime;
                    }
                }
                return Long.MAX_VALUE;
            }
        }
        j = Long.MAX_VALUE;
        if (j != 0) {
        }
    }

    @Override // kotlinx.coroutines.Delay
    public DisposableHandle invokeOnTimeout(long j, Runnable runnable) {
        Intrinsics.checkParameterIsNotNull(runnable, "block");
        Intrinsics.checkParameterIsNotNull(runnable, "block");
        return DefaultExecutorKt.DefaultDelay.invokeOnTimeout(j, runnable);
    }

    public boolean isEmpty() {
        ArrayQueue<DispatchedTask<?>> arrayQueue = this.unconfinedQueue;
        if (!(arrayQueue == null || arrayQueue.head == arrayQueue.tail)) {
            return false;
        }
        DelayedTaskQueue delayedTaskQueue = (DelayedTaskQueue) this._delayed;
        if (delayedTaskQueue != null) {
            if (!(delayedTaskQueue._size == 0)) {
                return false;
            }
        }
        Object obj = this._queue;
        if (obj == null) {
            return true;
        }
        if (obj instanceof LockFreeTaskQueueCore) {
            return ((LockFreeTaskQueueCore) obj).isEmpty();
        }
        if (obj == EventLoop_commonKt.CLOSED_EMPTY) {
            return true;
        }
        return false;
    }

    @Override // kotlinx.coroutines.EventLoopImplPlatform
    public long processNextEvent() {
        DelayedTask delayedTask;
        if (processUnconfinedEvent()) {
            return getNextTime();
        }
        DelayedTaskQueue delayedTaskQueue = (DelayedTaskQueue) this._delayed;
        Runnable runnable = null;
        if (delayedTaskQueue != null) {
            if (!(delayedTaskQueue._size == 0)) {
                long nanoTime = System.nanoTime();
                do {
                    synchronized (delayedTaskQueue) {
                        DelayedTask firstImpl = delayedTaskQueue.firstImpl();
                        if (firstImpl != null) {
                            delayedTask = ((nanoTime - firstImpl.nanoTime) > 0 ? 1 : ((nanoTime - firstImpl.nanoTime) == 0 ? 0 : -1)) >= 0 ? enqueueImpl(firstImpl) : false ? delayedTaskQueue.removeAtImpl(0) : null;
                            continue;
                        } else {
                            delayedTask = null;
                            continue;
                        }
                    }
                } while (delayedTask != null);
            }
        }
        while (true) {
            Object obj = this._queue;
            if (obj != null) {
                if (!(obj instanceof LockFreeTaskQueueCore)) {
                    if (obj == EventLoop_commonKt.CLOSED_EMPTY) {
                        break;
                    } else if (_queue$FU.compareAndSet(this, obj, null)) {
                        runnable = (Runnable) obj;
                        break;
                    }
                } else {
                    LockFreeTaskQueueCore lockFreeTaskQueueCore = (LockFreeTaskQueueCore) obj;
                    Object removeFirstOrNull = lockFreeTaskQueueCore.removeFirstOrNull();
                    if (removeFirstOrNull != LockFreeTaskQueueCore.REMOVE_FROZEN) {
                        runnable = (Runnable) removeFirstOrNull;
                        break;
                    }
                    _queue$FU.compareAndSet(this, obj, lockFreeTaskQueueCore.next());
                }
            } else {
                break;
            }
        }
        if (runnable != null) {
            runnable.run();
        }
        return getNextTime();
    }

    /* JADX WARNING: Removed duplicated region for block: B:38:0x0073  */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x0088  */
    public final void schedule(long j, DelayedTask delayedTask) {
        char c;
        Thread thread;
        Intrinsics.checkParameterIsNotNull(delayedTask, "delayedTask");
        DelayedTask delayedTask2 = null;
        boolean z = false;
        if (this._isCompleted == 0) {
            DelayedTaskQueue delayedTaskQueue = (DelayedTaskQueue) this._delayed;
            if (delayedTaskQueue == null) {
                _delayed$FU.compareAndSet(this, null, new DelayedTaskQueue(j));
                Object obj = this._delayed;
                if (obj != null) {
                    delayedTaskQueue = (DelayedTaskQueue) obj;
                } else {
                    Intrinsics.throwNpe();
                    throw null;
                }
            }
            synchronized (delayedTask) {
                Intrinsics.checkParameterIsNotNull(delayedTaskQueue, "delayed");
                Intrinsics.checkParameterIsNotNull(this, "eventLoop");
                if (delayedTask._heap == EventLoop_commonKt.DISPOSED_TASK) {
                    c = 2;
                } else {
                    synchronized (delayedTaskQueue) {
                        DelayedTask firstImpl = delayedTaskQueue.firstImpl();
                        if (this._isCompleted == 0) {
                            if (firstImpl == null) {
                                delayedTaskQueue.timeNow = j;
                            } else {
                                long j2 = firstImpl.nanoTime;
                                if (j2 - j >= 0) {
                                    j2 = j;
                                }
                                if (j2 - delayedTaskQueue.timeNow > 0) {
                                    delayedTaskQueue.timeNow = j2;
                                }
                            }
                            long j3 = delayedTask.nanoTime;
                            long j4 = delayedTaskQueue.timeNow;
                            if (j3 - j4 < 0) {
                                delayedTask.nanoTime = j4;
                            }
                            delayedTaskQueue.addImpl(delayedTask);
                            c = 0;
                        }
                    }
                }
            }
            if (c != 0) {
                DelayedTaskQueue delayedTaskQueue2 = (DelayedTaskQueue) this._delayed;
                if (delayedTaskQueue2 != null) {
                    synchronized (delayedTaskQueue2) {
                        delayedTask2 = delayedTaskQueue2.firstImpl();
                    }
                }
                if (delayedTask2 == delayedTask) {
                    z = true;
                }
                if (z && Thread.currentThread() != (thread = getThread())) {
                    LockSupport.unpark(thread);
                    return;
                }
                return;
            } else if (c == 1) {
                reschedule(j, delayedTask);
                return;
            } else if (c != 2) {
                throw new IllegalStateException("unexpected result".toString());
            } else {
                return;
            }
        }
        c = 1;
        if (c != 0) {
        }
    }

    @Override // kotlinx.coroutines.Delay
    public void scheduleResumeAfterDelay(long j, CancellableContinuation<? super Unit> cancellableContinuation) {
        Intrinsics.checkParameterIsNotNull(cancellableContinuation, "continuation");
        long delayToNanos = EventLoop_commonKt.delayToNanos(j);
        if (delayToNanos < 4611686018427387903L) {
            long nanoTime = System.nanoTime();
            DelayedResumeTask delayedResumeTask = new DelayedResumeTask(this, delayToNanos + nanoTime, cancellableContinuation);
            ViewGroupUtilsApi14.disposeOnCancellation(cancellableContinuation, delayedResumeTask);
            schedule(nanoTime, delayedResumeTask);
        }
    }
}
