package kotlinx.coroutines.channels;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.ArrayList;
import java.util.Objects;
import java.util.concurrent.CancellationException;
import kotlin.Result;
import kotlin.TypeCastException;
import kotlin.Unit;
import kotlin.coroutines.Continuation;
import kotlin.coroutines.intrinsics.CoroutineSingletons;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;
import kotlin.jvm.internal.TypeIntrinsics;
import kotlinx.coroutines.CancelHandler;
import kotlinx.coroutines.CancellableContinuation;
import kotlinx.coroutines.CancellableContinuationImpl;
import kotlinx.coroutines.CancellableContinuationImplKt;
import kotlinx.coroutines.CompletedExceptionally;
import kotlinx.coroutines.DebugKt;
import kotlinx.coroutines.NotCompleted;
import kotlinx.coroutines.channels.ValueOrClosed;
import kotlinx.coroutines.internal.LockFreeLinkedListHead;
import kotlinx.coroutines.internal.LockFreeLinkedListNode;
import kotlinx.coroutines.internal.StackTraceRecoveryKt;
import kotlinx.coroutines.internal.Symbol;
import net.xfkefu.sdk.retrofit.Retrofit2;

/* compiled from: AbstractChannel.kt */
public abstract class AbstractChannel<E> extends AbstractSendChannel<E> implements Channel<E> {

    /* compiled from: AbstractChannel.kt */
    public final class Itr<E> {
        public final AbstractChannel<E> channel;
        public Object result = AbstractChannelKt.POLL_FAILED;

        public Itr(AbstractChannel<E> abstractChannel) {
            Intrinsics.checkParameterIsNotNull(abstractChannel, "channel");
            this.channel = abstractChannel;
        }

        public final boolean hasNextResult(Object obj) {
            if (!(obj instanceof Closed)) {
                return true;
            }
            Closed closed = (Closed) obj;
            if (closed.closeCause == null) {
                return false;
            }
            throw StackTraceRecoveryKt.recoverStackTrace(closed.getReceiveException());
        }
    }

    /* compiled from: AbstractChannel.kt */
    public final class ReceiveElement<E> extends Receive<E> {
        public final CancellableContinuation<Object> cont;
        public final int receiveMode;

        public ReceiveElement(CancellableContinuation<Object> cancellableContinuation, int i) {
            Intrinsics.checkParameterIsNotNull(cancellableContinuation, "cont");
            this.cont = cancellableContinuation;
            this.receiveMode = i;
        }

        @Override // kotlinx.coroutines.channels.ReceiveOrClosed
        public void completeResumeReceive(E e) {
            ((CancellableContinuationImpl) this.cont).completeResume(CancellableContinuationImplKt.RESUME_TOKEN);
        }

        @Override // kotlinx.coroutines.channels.Receive
        public void resumeReceiveClosed(Closed<?> closed) {
            Intrinsics.checkParameterIsNotNull(closed, "closed");
            int i = this.receiveMode;
            if (i == 1 && closed.closeCause == null) {
                ((CancellableContinuationImpl) this.cont).resumeWith(Result.m133constructorimpl(null));
            } else if (i == 2) {
                ((CancellableContinuationImpl) this.cont).resumeWith(Result.m133constructorimpl(new ValueOrClosed(new ValueOrClosed.Closed(closed.closeCause))));
            } else {
                ((CancellableContinuationImpl) this.cont).resumeWith(Result.m133constructorimpl(ViewGroupUtilsApi14.createFailure(closed.getReceiveException())));
            }
        }

        @Override // kotlinx.coroutines.internal.LockFreeLinkedListNode
        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("ReceiveElement@");
            outline25.append(ViewGroupUtilsApi14.getHexAddress(this));
            outline25.append("[receiveMode=");
            return GeneratedOutlineSupport.outline20(outline25, this.receiveMode, ']');
        }

        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Type inference failed for: r0v2, types: [kotlinx.coroutines.channels.ValueOrClosed] */
        /* JADX WARNING: Unknown variable types count: 1 */
        @Override // kotlinx.coroutines.channels.ReceiveOrClosed
        public Symbol tryResumeReceive(E e, LockFreeLinkedListNode.PrepareOp prepareOp) {
            CancellableContinuation<Object> cancellableContinuation = this.cont;
            if (this.receiveMode == 2) {
                e = new ValueOrClosed(e);
            }
            if (((CancellableContinuationImpl) cancellableContinuation).tryResume(e, null) == null) {
                return null;
            }
            boolean z = DebugKt.DEBUG;
            return CancellableContinuationImplKt.RESUME_TOKEN;
        }
    }

    /* compiled from: AbstractChannel.kt */
    public final class ReceiveHasNext<E> extends Receive<E> {
        public final CancellableContinuation<Boolean> cont;
        public final Itr<E> iterator;

        /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: kotlinx.coroutines.CancellableContinuation<? super java.lang.Boolean> */
        /* JADX WARN: Multi-variable type inference failed */
        public ReceiveHasNext(Itr<E> itr, CancellableContinuation<? super Boolean> cancellableContinuation) {
            Intrinsics.checkParameterIsNotNull(itr, "iterator");
            Intrinsics.checkParameterIsNotNull(cancellableContinuation, "cont");
            this.iterator = itr;
            this.cont = cancellableContinuation;
        }

        @Override // kotlinx.coroutines.channels.ReceiveOrClosed
        public void completeResumeReceive(E e) {
            this.iterator.result = e;
            ((CancellableContinuationImpl) this.cont).completeResume(CancellableContinuationImplKt.RESUME_TOKEN);
        }

        @Override // kotlinx.coroutines.channels.Receive
        public void resumeReceiveClosed(Closed<?> closed) {
            Object obj;
            Intrinsics.checkParameterIsNotNull(closed, "closed");
            Symbol symbol = null;
            if (closed.closeCause == null) {
                obj = ((CancellableContinuationImpl) this.cont).tryResume(Boolean.FALSE, null);
            } else {
                CancellableContinuation<Boolean> cancellableContinuation = this.cont;
                Throwable recoverStackTrace = StackTraceRecoveryKt.recoverStackTrace(closed.getReceiveException(), this.cont);
                CancellableContinuationImpl cancellableContinuationImpl = (CancellableContinuationImpl) cancellableContinuation;
                Objects.requireNonNull(cancellableContinuationImpl);
                Intrinsics.checkParameterIsNotNull(recoverStackTrace, Retrofit2.RESP_CODE_EXCEPTION);
                while (true) {
                    Object obj2 = cancellableContinuationImpl._state;
                    if (!(obj2 instanceof NotCompleted)) {
                        break;
                    }
                    if (CancellableContinuationImpl._state$FU.compareAndSet(cancellableContinuationImpl, obj2, new CompletedExceptionally(recoverStackTrace, false, 2))) {
                        cancellableContinuationImpl.detachChildIfNonResuable();
                        symbol = CancellableContinuationImplKt.RESUME_TOKEN;
                        break;
                    }
                }
                obj = symbol;
            }
            if (obj != null) {
                this.iterator.result = closed;
                ((CancellableContinuationImpl) this.cont).completeResume(obj);
            }
        }

        @Override // kotlinx.coroutines.internal.LockFreeLinkedListNode
        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("ReceiveHasNext@");
            outline25.append(ViewGroupUtilsApi14.getHexAddress(this));
            return outline25.toString();
        }

        @Override // kotlinx.coroutines.channels.ReceiveOrClosed
        public Symbol tryResumeReceive(E e, LockFreeLinkedListNode.PrepareOp prepareOp) {
            if (((CancellableContinuationImpl) this.cont).tryResume(Boolean.TRUE, null) == null) {
                return null;
            }
            boolean z = DebugKt.DEBUG;
            return CancellableContinuationImplKt.RESUME_TOKEN;
        }
    }

    public static final boolean access$enqueueReceive(AbstractChannel abstractChannel, Receive receive) {
        int tryCondAddNext;
        LockFreeLinkedListNode lockFreeLinkedListNode;
        if (abstractChannel.isBufferAlwaysEmpty()) {
            LockFreeLinkedListHead lockFreeLinkedListHead = abstractChannel.queue;
            do {
                Object prev = lockFreeLinkedListHead.getPrev();
                if (prev != null) {
                    lockFreeLinkedListNode = (LockFreeLinkedListNode) prev;
                    if (!(!(lockFreeLinkedListNode instanceof Send))) {
                    }
                } else {
                    throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
                }
            } while (!lockFreeLinkedListNode.addNext(receive, lockFreeLinkedListHead));
            return true;
        }
        LockFreeLinkedListHead lockFreeLinkedListHead2 = abstractChannel.queue;
        AbstractChannel$enqueueReceive$$inlined$addLastIfPrevAndIf$1 abstractChannel$enqueueReceive$$inlined$addLastIfPrevAndIf$1 = new AbstractChannel$enqueueReceive$$inlined$addLastIfPrevAndIf$1(receive, receive, abstractChannel);
        do {
            Object prev2 = lockFreeLinkedListHead2.getPrev();
            if (prev2 != null) {
                LockFreeLinkedListNode lockFreeLinkedListNode2 = (LockFreeLinkedListNode) prev2;
                if (!(!(lockFreeLinkedListNode2 instanceof Send))) {
                    break;
                }
                tryCondAddNext = lockFreeLinkedListNode2.tryCondAddNext(receive, lockFreeLinkedListHead2, abstractChannel$enqueueReceive$$inlined$addLastIfPrevAndIf$1);
                if (tryCondAddNext == 1) {
                    return true;
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
            }
        } while (tryCondAddNext != 2);
        return false;
    }

    @Override // kotlinx.coroutines.channels.ReceiveChannel
    public final void cancel(CancellationException cancellationException) {
        boolean z;
        Object obj;
        Object obj2;
        if (cancellationException == null) {
            cancellationException = new CancellationException(ViewGroupUtilsApi14.getClassSimpleName(this) + " was cancelled");
        }
        Closed<?> closed = new Closed<>(cancellationException);
        LockFreeLinkedListHead lockFreeLinkedListHead = this.queue;
        while (true) {
            Object prev = lockFreeLinkedListHead.getPrev();
            if (prev != null) {
                LockFreeLinkedListNode lockFreeLinkedListNode = (LockFreeLinkedListNode) prev;
                if (!(lockFreeLinkedListNode instanceof Closed)) {
                    if (lockFreeLinkedListNode.addNext(closed, lockFreeLinkedListHead)) {
                        z = true;
                        break;
                    }
                } else {
                    z = false;
                    break;
                }
            } else {
                throw new TypeCastException("null cannot be cast to non-null type kotlinx.coroutines.internal.Node /* = kotlinx.coroutines.internal.LockFreeLinkedListNode */");
            }
        }
        if (!z) {
            closed = (Closed) this.queue.getPrevNode();
        }
        helpClose(closed);
        if (z && (obj = this.onCloseHandler) != null && obj != (obj2 = AbstractChannelKt.HANDLER_INVOKED) && AbstractSendChannel.onCloseHandler$FU.compareAndSet(this, obj, obj2)) {
            TypeIntrinsics.beforeCheckcastToFunctionOfArity(obj, 1);
            ((Function1) obj).invoke(cancellationException);
        }
        onCancelIdempotent(z);
    }

    public abstract boolean isBufferAlwaysEmpty();

    public abstract boolean isBufferEmpty();

    @Override // kotlinx.coroutines.channels.ReceiveChannel
    public final Itr<E> iterator() {
        return new Itr<>(this);
    }

    public void onCancelIdempotent(boolean z) {
        Closed<?> closedForSend = getClosedForSend();
        if (closedForSend != null) {
            Object obj = null;
            while (true) {
                LockFreeLinkedListNode prevNode = closedForSend.getPrevNode();
                if (prevNode instanceof LockFreeLinkedListHead) {
                    break;
                }
                boolean z2 = DebugKt.DEBUG;
                if (!prevNode.remove()) {
                    prevNode.helpRemove();
                } else {
                    obj = ViewGroupUtilsApi14.m16plusimpl(obj, (Send) prevNode);
                }
            }
            if (obj != null) {
                if (!(obj instanceof ArrayList)) {
                    ((Send) obj).resumeSendClosed(closedForSend);
                    return;
                }
                ArrayList arrayList = (ArrayList) obj;
                int size = arrayList.size();
                while (true) {
                    size--;
                    if (size >= 0) {
                        ((Send) arrayList.get(size)).resumeSendClosed(closedForSend);
                    } else {
                        return;
                    }
                }
            }
        } else {
            throw new IllegalStateException("Cannot happen".toString());
        }
    }

    @Override // kotlinx.coroutines.channels.ReceiveChannel
    public final E poll() {
        E e = (E) pollInternal();
        if (e == AbstractChannelKt.POLL_FAILED) {
            return null;
        }
        if (e instanceof Closed) {
            Throwable th = e.closeCause;
            if (th == null) {
                e = null;
            } else {
                throw StackTraceRecoveryKt.recoverStackTrace(th);
            }
        }
        return e;
    }

    public Object pollInternal() {
        Send takeFirstSendOrPeekClosed;
        do {
            takeFirstSendOrPeekClosed = takeFirstSendOrPeekClosed();
            if (takeFirstSendOrPeekClosed == null) {
                return AbstractChannelKt.POLL_FAILED;
            }
        } while (takeFirstSendOrPeekClosed.tryResumeSend(null) == null);
        boolean z = DebugKt.DEBUG;
        takeFirstSendOrPeekClosed.completeResumeSend();
        return takeFirstSendOrPeekClosed.getPollResult();
    }

    @Override // kotlinx.coroutines.channels.ReceiveChannel
    public final Object receive(Continuation<? super E> continuation) {
        Object pollInternal = pollInternal();
        if (pollInternal != AbstractChannelKt.POLL_FAILED && !(pollInternal instanceof Closed)) {
            return pollInternal;
        }
        CancellableContinuationImpl orCreateCancellableContinuation = ViewGroupUtilsApi14.getOrCreateCancellableContinuation(ViewGroupUtilsApi14.intercepted(continuation));
        ReceiveElement receiveElement = new ReceiveElement(orCreateCancellableContinuation, 0);
        while (true) {
            if (access$enqueueReceive(this, receiveElement)) {
                orCreateCancellableContinuation.invokeOnCancellation(new RemoveReceiveOnCancel(this, receiveElement));
                break;
            }
            Object pollInternal2 = pollInternal();
            if (pollInternal2 instanceof Closed) {
                receiveElement.resumeReceiveClosed((Closed) pollInternal2);
                break;
            } else if (pollInternal2 != AbstractChannelKt.POLL_FAILED) {
                if (receiveElement.receiveMode == 2) {
                    pollInternal2 = new ValueOrClosed(pollInternal2);
                }
                orCreateCancellableContinuation.resumeWith(Result.m133constructorimpl(pollInternal2));
            }
        }
        Object result = orCreateCancellableContinuation.getResult();
        if (result == CoroutineSingletons.COROUTINE_SUSPENDED) {
            Intrinsics.checkNotNullParameter(continuation, "frame");
        }
        return result;
    }

    @Override // kotlinx.coroutines.channels.AbstractSendChannel
    public ReceiveOrClosed<E> takeFirstReceiveOrPeekClosed() {
        ReceiveOrClosed<E> takeFirstReceiveOrPeekClosed = super.takeFirstReceiveOrPeekClosed();
        if (takeFirstReceiveOrPeekClosed != null) {
            boolean z = takeFirstReceiveOrPeekClosed instanceof Closed;
        }
        return takeFirstReceiveOrPeekClosed;
    }

    /* compiled from: AbstractChannel.kt */
    public final class RemoveReceiveOnCancel extends CancelHandler {
        public final Receive<?> receive;
        public final /* synthetic */ AbstractChannel this$0;

        public RemoveReceiveOnCancel(AbstractChannel abstractChannel, Receive<?> receive2) {
            Intrinsics.checkParameterIsNotNull(receive2, "receive");
            this.this$0 = abstractChannel;
            this.receive = receive2;
        }

        @Override // kotlin.jvm.functions.Function1
        public Object invoke(Object obj) {
            Throwable th = (Throwable) obj;
            if (this.receive.remove()) {
                Objects.requireNonNull(this.this$0);
            }
            return Unit.INSTANCE;
        }

        public String toString() {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("RemoveReceiveOnCancel[");
            outline25.append(this.receive);
            outline25.append(']');
            return outline25.toString();
        }

        @Override // kotlinx.coroutines.CancelHandler
        public void invoke(Throwable th) {
            if (this.receive.remove()) {
                Objects.requireNonNull(this.this$0);
            }
        }
    }
}
