package okhttp3;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.io.IOException;
import java.security.cert.Certificate;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSession;
import kotlin.Lazy;
import kotlin.collections.EmptyList;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.internal.Util;

/* compiled from: Handshake.kt */
public final class Handshake {
    public final CipherSuite cipherSuite;
    public final List<Certificate> localCertificates;
    public final Lazy peerCertificates$delegate;
    public final TlsVersion tlsVersion;

    /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: java.util.List<? extends java.security.cert.Certificate> */
    /* JADX WARN: Multi-variable type inference failed */
    public Handshake(TlsVersion tlsVersion2, CipherSuite cipherSuite2, List<? extends Certificate> list, Function0<? extends List<? extends Certificate>> function0) {
        Intrinsics.checkNotNullParameter(tlsVersion2, "tlsVersion");
        Intrinsics.checkNotNullParameter(cipherSuite2, "cipherSuite");
        Intrinsics.checkNotNullParameter(list, "localCertificates");
        Intrinsics.checkNotNullParameter(function0, "peerCertificatesFn");
        this.tlsVersion = tlsVersion2;
        this.cipherSuite = cipherSuite2;
        this.localCertificates = list;
        this.peerCertificates$delegate = ViewGroupUtilsApi14.lazy(new Handshake$peerCertificates$2(function0));
    }

    public static final Handshake get(SSLSession sSLSession) {
        List list;
        List list2;
        Intrinsics.checkNotNullParameter(sSLSession, "$this$handshake");
        String cipherSuite2 = sSLSession.getCipherSuite();
        if (cipherSuite2 != null) {
            int hashCode = cipherSuite2.hashCode();
            if (hashCode == 1019404634 ? cipherSuite2.equals("TLS_NULL_WITH_NULL_NULL") : hashCode == 1208658923 && cipherSuite2.equals("SSL_NULL_WITH_NULL_NULL")) {
                throw new IOException(GeneratedOutlineSupport.outline18("cipherSuite == ", cipherSuite2));
            }
            CipherSuite forJavaName = CipherSuite.Companion.forJavaName(cipherSuite2);
            String protocol = sSLSession.getProtocol();
            if (protocol == null) {
                throw new IllegalStateException("tlsVersion == null".toString());
            } else if (!Intrinsics.areEqual("NONE", protocol)) {
                TlsVersion forJavaName2 = TlsVersion.Companion.forJavaName(protocol);
                try {
                    Certificate[] peerCertificates = sSLSession.getPeerCertificates();
                    if (peerCertificates != null) {
                        list = Util.immutableListOf((Certificate[]) Arrays.copyOf(peerCertificates, peerCertificates.length));
                    } else {
                        list = EmptyList.INSTANCE;
                    }
                } catch (SSLPeerUnverifiedException unused) {
                    list = EmptyList.INSTANCE;
                }
                Certificate[] localCertificates2 = sSLSession.getLocalCertificates();
                if (localCertificates2 != null) {
                    list2 = Util.immutableListOf((Certificate[]) Arrays.copyOf(localCertificates2, localCertificates2.length));
                } else {
                    list2 = EmptyList.INSTANCE;
                }
                return new Handshake(forJavaName2, forJavaName, list2, new Handshake$Companion$handshake$1(list));
            } else {
                throw new IOException("tlsVersion == NONE");
            }
        } else {
            throw new IllegalStateException("cipherSuite == null".toString());
        }
    }

    public boolean equals(Object obj) {
        if (obj instanceof Handshake) {
            Handshake handshake = (Handshake) obj;
            return handshake.tlsVersion == this.tlsVersion && Intrinsics.areEqual(handshake.cipherSuite, this.cipherSuite) && Intrinsics.areEqual(handshake.peerCertificates(), peerCertificates()) && Intrinsics.areEqual(handshake.localCertificates, this.localCertificates);
        }
    }

    public final String getName(Certificate certificate) {
        if (certificate instanceof X509Certificate) {
            return ((X509Certificate) certificate).getSubjectDN().toString();
        }
        String type = certificate.getType();
        Intrinsics.checkNotNullExpressionValue(type, "type");
        return type;
    }

    public int hashCode() {
        int hashCode = this.cipherSuite.hashCode();
        int hashCode2 = peerCertificates().hashCode();
        return this.localCertificates.hashCode() + ((hashCode2 + ((hashCode + ((this.tlsVersion.hashCode() + 527) * 31)) * 31)) * 31);
    }

    public final List<Certificate> peerCertificates() {
        return (List) this.peerCertificates$delegate.getValue();
    }

    public String toString() {
        List<Certificate> peerCertificates = peerCertificates();
        ArrayList arrayList = new ArrayList(ViewGroupUtilsApi14.collectionSizeOrDefault(peerCertificates, 10));
        Iterator<T> it = peerCertificates.iterator();
        while (it.hasNext()) {
            arrayList.add(getName(it.next()));
        }
        String obj = arrayList.toString();
        StringBuilder outline28 = GeneratedOutlineSupport.outline28("Handshake{", "tlsVersion=");
        outline28.append(this.tlsVersion);
        outline28.append(StringUtil.SPACE);
        outline28.append("cipherSuite=");
        outline28.append(this.cipherSuite);
        outline28.append(StringUtil.SPACE);
        outline28.append("peerCertificates=");
        outline28.append(obj);
        outline28.append(StringUtil.SPACE);
        outline28.append("localCertificates=");
        List<Certificate> list = this.localCertificates;
        ArrayList arrayList2 = new ArrayList(ViewGroupUtilsApi14.collectionSizeOrDefault(list, 10));
        Iterator<T> it2 = list.iterator();
        while (it2.hasNext()) {
            arrayList2.add(getName(it2.next()));
        }
        outline28.append(arrayList2);
        outline28.append('}');
        return outline28.toString();
    }
}
