package okhttp3.internal.connection;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.IOException;
import java.net.ProtocolException;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.EventListener$Companion$NONE$1;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http2.ConnectionShutdownException;
import okhttp3.internal.http2.ErrorCode;
import okhttp3.internal.http2.StreamResetException;
import okio.Buffer;
import okio.ForwardingSink;
import okio.ForwardingSource;
import okio.Sink;
import okio.Source;

/* compiled from: Exchange.kt */
public final class Exchange {
    public final RealCall call;
    public final ExchangeCodec codec;
    public final RealConnection connection;
    public final EventListener$Companion$NONE$1 eventListener;
    public final ExchangeFinder finder;
    public boolean isDuplex;

    /* compiled from: Exchange.kt */
    public final class RequestBodySink extends ForwardingSink {
        public long bytesReceived;
        public boolean closed;
        public boolean completed;
        public final long contentLength;
        public final /* synthetic */ Exchange this$0;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public RequestBodySink(Exchange exchange, Sink sink, long j) {
            super(sink);
            Intrinsics.checkNotNullParameter(sink, "delegate");
            this.this$0 = exchange;
            this.contentLength = j;
        }

        @Override // okio.ForwardingSink, java.io.Closeable, java.lang.AutoCloseable, okio.Sink
        public void close() {
            if (!this.closed) {
                this.closed = true;
                long j = this.contentLength;
                if (j == -1 || this.bytesReceived == j) {
                    try {
                        super.close();
                        complete(null);
                    } catch (IOException e) {
                        throw complete(e);
                    }
                } else {
                    throw new ProtocolException("unexpected end of stream");
                }
            }
        }

        public final <E extends IOException> E complete(E e) {
            if (this.completed) {
                return e;
            }
            this.completed = true;
            return (E) this.this$0.bodyComplete(this.bytesReceived, false, true, e);
        }

        @Override // okio.ForwardingSink, okio.Sink, java.io.Flushable
        public void flush() {
            try {
                super.flush();
            } catch (IOException e) {
                throw complete(e);
            }
        }

        @Override // okio.ForwardingSink, okio.Sink
        public void write(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "source");
            if (!this.closed) {
                long j2 = this.contentLength;
                if (j2 == -1 || this.bytesReceived + j <= j2) {
                    try {
                        super.write(buffer, j);
                        this.bytesReceived += j;
                    } catch (IOException e) {
                        throw complete(e);
                    }
                } else {
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("expected ");
                    outline25.append(this.contentLength);
                    outline25.append(" bytes but received ");
                    outline25.append(this.bytesReceived + j);
                    throw new ProtocolException(outline25.toString());
                }
            } else {
                throw new IllegalStateException("closed".toString());
            }
        }
    }

    /* compiled from: Exchange.kt */
    public final class ResponseBodySource extends ForwardingSource {
        public long bytesReceived;
        public boolean closed;
        public boolean completed;
        public final long contentLength;
        public boolean invokeStartEvent = true;
        public final /* synthetic */ Exchange this$0;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public ResponseBodySource(Exchange exchange, Source source, long j) {
            super(source);
            Intrinsics.checkNotNullParameter(source, "delegate");
            this.this$0 = exchange;
            this.contentLength = j;
            if (j == 0) {
                complete(null);
            }
        }

        @Override // okio.Source, okio.ForwardingSource, java.io.Closeable, java.lang.AutoCloseable
        public void close() {
            if (!this.closed) {
                this.closed = true;
                try {
                    super.close();
                    complete(null);
                } catch (IOException e) {
                    throw complete(e);
                }
            }
        }

        public final <E extends IOException> E complete(E e) {
            if (this.completed) {
                return e;
            }
            this.completed = true;
            if (e == null && this.invokeStartEvent) {
                this.invokeStartEvent = false;
                Exchange exchange = this.this$0;
                EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = exchange.eventListener;
                RealCall realCall = exchange.call;
                Objects.requireNonNull(eventListener$Companion$NONE$1);
                Intrinsics.checkNotNullParameter(realCall, "call");
            }
            return (E) this.this$0.bodyComplete(this.bytesReceived, true, false, e);
        }

        @Override // okio.Source, okio.ForwardingSource
        public long read(Buffer buffer, long j) {
            Intrinsics.checkNotNullParameter(buffer, "sink");
            if (!this.closed) {
                try {
                    long read = delegate().read(buffer, j);
                    if (this.invokeStartEvent) {
                        this.invokeStartEvent = false;
                        Exchange exchange = this.this$0;
                        EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = exchange.eventListener;
                        RealCall realCall = exchange.call;
                        Objects.requireNonNull(eventListener$Companion$NONE$1);
                        Intrinsics.checkNotNullParameter(realCall, "call");
                    }
                    if (read == -1) {
                        complete(null);
                        return -1;
                    }
                    long j2 = this.bytesReceived + read;
                    long j3 = this.contentLength;
                    if (j3 != -1) {
                        if (j2 > j3) {
                            throw new ProtocolException("expected " + this.contentLength + " bytes but received " + j2);
                        }
                    }
                    this.bytesReceived = j2;
                    if (j2 == j3) {
                        complete(null);
                    }
                    return read;
                } catch (IOException e) {
                    throw complete(e);
                }
            } else {
                throw new IllegalStateException("closed".toString());
            }
        }
    }

    public Exchange(RealCall realCall, EventListener$Companion$NONE$1 eventListener$Companion$NONE$1, ExchangeFinder exchangeFinder, ExchangeCodec exchangeCodec) {
        Intrinsics.checkNotNullParameter(realCall, "call");
        Intrinsics.checkNotNullParameter(eventListener$Companion$NONE$1, "eventListener");
        Intrinsics.checkNotNullParameter(exchangeFinder, "finder");
        Intrinsics.checkNotNullParameter(exchangeCodec, "codec");
        this.call = realCall;
        this.eventListener = eventListener$Companion$NONE$1;
        this.finder = exchangeFinder;
        this.codec = exchangeCodec;
        this.connection = exchangeCodec.getConnection();
    }

    public final <E extends IOException> E bodyComplete(long j, boolean z, boolean z2, E e) {
        if (e != null) {
            trackFailure(e);
        }
        if (z2) {
            if (e != null) {
                this.eventListener.requestFailed(this.call, e);
            } else {
                EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = this.eventListener;
                RealCall realCall = this.call;
                Objects.requireNonNull(eventListener$Companion$NONE$1);
                Intrinsics.checkNotNullParameter(realCall, "call");
            }
        }
        if (z) {
            if (e != null) {
                this.eventListener.responseFailed(this.call, e);
            } else {
                EventListener$Companion$NONE$1 eventListener$Companion$NONE$12 = this.eventListener;
                RealCall realCall2 = this.call;
                Objects.requireNonNull(eventListener$Companion$NONE$12);
                Intrinsics.checkNotNullParameter(realCall2, "call");
            }
        }
        return (E) this.call.messageDone$okhttp(this, z2, z, e);
    }

    public final Sink createRequestBody(Request request, boolean z) {
        Intrinsics.checkNotNullParameter(request, "request");
        this.isDuplex = z;
        RequestBody requestBody = request.body;
        Intrinsics.checkNotNull(requestBody);
        long contentLength = requestBody.contentLength();
        EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = this.eventListener;
        RealCall realCall = this.call;
        Objects.requireNonNull(eventListener$Companion$NONE$1);
        Intrinsics.checkNotNullParameter(realCall, "call");
        return new RequestBodySink(this, this.codec.createRequestBody(request, contentLength), contentLength);
    }

    public final Response.Builder readResponseHeaders(boolean z) {
        try {
            Response.Builder readResponseHeaders = this.codec.readResponseHeaders(z);
            if (readResponseHeaders != null) {
                Intrinsics.checkNotNullParameter(this, "deferredTrailers");
                readResponseHeaders.exchange = this;
            }
            return readResponseHeaders;
        } catch (IOException e) {
            this.eventListener.responseFailed(this.call, e);
            trackFailure(e);
            throw e;
        }
    }

    public final void responseHeadersStart() {
        EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = this.eventListener;
        RealCall realCall = this.call;
        Objects.requireNonNull(eventListener$Companion$NONE$1);
        Intrinsics.checkNotNullParameter(realCall, "call");
    }

    public final void trackFailure(IOException iOException) {
        this.finder.trackFailure(iOException);
        RealConnection connection2 = this.codec.getConnection();
        RealCall realCall = this.call;
        synchronized (connection2) {
            Intrinsics.checkNotNullParameter(realCall, "call");
            if (iOException instanceof StreamResetException) {
                if (((StreamResetException) iOException).errorCode == ErrorCode.REFUSED_STREAM) {
                    int i = connection2.refusedStreamCount + 1;
                    connection2.refusedStreamCount = i;
                    if (i > 1) {
                        connection2.noNewExchanges = true;
                        connection2.routeFailureCount++;
                    }
                } else if (((StreamResetException) iOException).errorCode != ErrorCode.CANCEL || !realCall.canceled) {
                    connection2.noNewExchanges = true;
                    connection2.routeFailureCount++;
                }
            } else if (!connection2.isMultiplexed$okhttp() || (iOException instanceof ConnectionShutdownException)) {
                connection2.noNewExchanges = true;
                if (connection2.successCount == 0) {
                    connection2.connectFailed$okhttp(realCall.client, connection2.route, iOException);
                    connection2.routeFailureCount++;
                }
            }
        }
    }
}
