package okhttp3.internal.connection;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Proxy;
import java.net.Socket;
import java.net.SocketAddress;
import java.net.SocketException;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.Objects;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.Address;
import okhttp3.Call;
import okhttp3.Dns$Companion$DnsSystem;
import okhttp3.EventListener$Companion$NONE$1;
import okhttp3.HttpUrl;
import okhttp3.Route;
import okhttp3.internal.Util;
import okhttp3.internal.connection.RouteSelector;
import okhttp3.internal.http2.ConnectionShutdownException;
import okhttp3.internal.http2.ErrorCode;
import okhttp3.internal.http2.StreamResetException;

/* compiled from: ExchangeFinder.kt */
public final class ExchangeFinder {
    public final Address address;
    public final RealCall call;
    public final RealConnectionPool connectionPool;
    public int connectionShutdownCount;
    public final EventListener$Companion$NONE$1 eventListener;
    public Route nextRouteToTry;
    public int otherFailureCount;
    public int refusedStreamCount;
    public RouteSelector.Selection routeSelection;
    public RouteSelector routeSelector;

    public ExchangeFinder(RealConnectionPool realConnectionPool, Address address2, RealCall realCall, EventListener$Companion$NONE$1 eventListener$Companion$NONE$1) {
        Intrinsics.checkNotNullParameter(realConnectionPool, "connectionPool");
        Intrinsics.checkNotNullParameter(address2, "address");
        Intrinsics.checkNotNullParameter(realCall, "call");
        Intrinsics.checkNotNullParameter(eventListener$Companion$NONE$1, "eventListener");
        this.connectionPool = realConnectionPool;
        this.address = address2;
        this.call = realCall;
        this.eventListener = eventListener$Companion$NONE$1;
    }

    /* JADX INFO: finally extract failed */
    /* JADX WARNING: Removed duplicated region for block: B:114:0x02b4  */
    /* JADX WARNING: Removed duplicated region for block: B:129:0x0318  */
    /* JADX WARNING: Removed duplicated region for block: B:159:0x0317 A[SYNTHETIC] */
    public final RealConnection findHealthyConnection(int i, int i2, int i3, int i4, boolean z, boolean z2) {
        boolean z3;
        List<Route> list;
        RouteDatabase routeDatabase;
        String str;
        int i5;
        boolean contains;
        Socket socket;
        while (!this.call.canceled) {
            RealConnection realConnection = this.call.connection;
            boolean z4 = false;
            boolean z5 = true;
            if (realConnection != null) {
                synchronized (realConnection) {
                    if (!realConnection.noNewExchanges) {
                        if (sameHostAndPort(realConnection.route.address.url)) {
                            socket = null;
                        }
                    }
                    socket = this.call.releaseConnectionNoEvents$okhttp();
                }
                if (this.call.connection != null) {
                    if (socket == null) {
                        z4 = true;
                    }
                    if (!z4) {
                        throw new IllegalStateException("Check failed.".toString());
                    }
                    z3 = z2;
                    if (realConnection.isHealthy(z3)) {
                        return realConnection;
                    }
                    realConnection.noNewExchanges$okhttp();
                    if (this.nextRouteToTry == null) {
                        RouteSelector.Selection selection = this.routeSelection;
                        if (!(selection != null ? selection.hasNext() : true)) {
                            RouteSelector routeSelector2 = this.routeSelector;
                            if (routeSelector2 != null) {
                                z5 = routeSelector2.hasNext();
                            }
                            if (!z5) {
                                throw new IOException("exhausted all routes");
                            }
                        } else {
                            continue;
                        }
                    }
                } else {
                    if (socket != null) {
                        Util.closeQuietly(socket);
                    }
                    EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = this.eventListener;
                    RealCall realCall = this.call;
                    Objects.requireNonNull(eventListener$Companion$NONE$1);
                    Intrinsics.checkNotNullParameter(realCall, "call");
                    Intrinsics.checkNotNullParameter(realConnection, "connection");
                }
            }
            this.refusedStreamCount = 0;
            this.connectionShutdownCount = 0;
            this.otherFailureCount = 0;
            if (this.connectionPool.callAcquirePooledConnection(this.address, this.call, null, false)) {
                realConnection = this.call.connection;
                Intrinsics.checkNotNull(realConnection);
                this.eventListener.connectionAcquired(this.call, realConnection);
            } else {
                Route route = this.nextRouteToTry;
                if (route != null) {
                    Intrinsics.checkNotNull(route);
                    this.nextRouteToTry = null;
                } else {
                    RouteSelector.Selection selection2 = this.routeSelection;
                    if (selection2 != null) {
                        Intrinsics.checkNotNull(selection2);
                        if (selection2.hasNext()) {
                            RouteSelector.Selection selection3 = this.routeSelection;
                            Intrinsics.checkNotNull(selection3);
                            route = selection3.next();
                        }
                    }
                    RouteSelector routeSelector3 = this.routeSelector;
                    if (routeSelector3 == null) {
                        Address address2 = this.address;
                        RealCall realCall2 = this.call;
                        routeSelector3 = new RouteSelector(address2, realCall2.client.routeDatabase, realCall2, this.eventListener);
                        this.routeSelector = routeSelector3;
                    }
                    if (routeSelector3.hasNext()) {
                        ArrayList arrayList = new ArrayList();
                        while (routeSelector3.hasNextProxy()) {
                            if (routeSelector3.hasNextProxy()) {
                                List<? extends Proxy> list2 = routeSelector3.proxies;
                                int i6 = routeSelector3.nextProxyIndex;
                                routeSelector3.nextProxyIndex = i6 + 1;
                                Proxy proxy = (Proxy) list2.get(i6);
                                ArrayList arrayList2 = new ArrayList();
                                routeSelector3.inetSocketAddresses = arrayList2;
                                if (proxy.type() == Proxy.Type.DIRECT || proxy.type() == Proxy.Type.SOCKS) {
                                    HttpUrl httpUrl = routeSelector3.address.url;
                                    str = httpUrl.host;
                                    i5 = httpUrl.port;
                                } else {
                                    SocketAddress address3 = proxy.address();
                                    if (address3 instanceof InetSocketAddress) {
                                        InetSocketAddress inetSocketAddress = (InetSocketAddress) address3;
                                        Intrinsics.checkNotNullParameter(inetSocketAddress, "$this$socketHost");
                                        InetAddress address4 = inetSocketAddress.getAddress();
                                        if (address4 != null) {
                                            str = address4.getHostAddress();
                                            Intrinsics.checkNotNullExpressionValue(str, "address.hostAddress");
                                        } else {
                                            str = inetSocketAddress.getHostName();
                                            Intrinsics.checkNotNullExpressionValue(str, "hostName");
                                        }
                                        i5 = inetSocketAddress.getPort();
                                    } else {
                                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Proxy.address() is not an InetSocketAddress: ");
                                        outline25.append(address3.getClass());
                                        throw new IllegalArgumentException(outline25.toString().toString());
                                    }
                                }
                                if (1 <= i5 && 65535 >= i5) {
                                    if (proxy.type() == Proxy.Type.SOCKS) {
                                        arrayList2.add(InetSocketAddress.createUnresolved(str, i5));
                                    } else {
                                        EventListener$Companion$NONE$1 eventListener$Companion$NONE$12 = routeSelector3.eventListener;
                                        Call call2 = routeSelector3.call;
                                        Objects.requireNonNull(eventListener$Companion$NONE$12);
                                        Intrinsics.checkNotNullParameter(call2, "call");
                                        Intrinsics.checkNotNullParameter(str, "domainName");
                                        List<InetAddress> lookup = ((Dns$Companion$DnsSystem) routeSelector3.address.dns).lookup(str);
                                        if (!lookup.isEmpty()) {
                                            EventListener$Companion$NONE$1 eventListener$Companion$NONE$13 = routeSelector3.eventListener;
                                            Call call3 = routeSelector3.call;
                                            Objects.requireNonNull(eventListener$Companion$NONE$13);
                                            Intrinsics.checkNotNullParameter(call3, "call");
                                            Intrinsics.checkNotNullParameter(str, "domainName");
                                            Intrinsics.checkNotNullParameter(lookup, "inetAddressList");
                                            for (InetAddress inetAddress : lookup) {
                                                arrayList2.add(new InetSocketAddress(inetAddress, i5));
                                            }
                                        } else {
                                            throw new UnknownHostException(routeSelector3.address.dns + " returned no addresses for " + str);
                                        }
                                    }
                                    for (InetSocketAddress inetSocketAddress2 : routeSelector3.inetSocketAddresses) {
                                        Route route2 = new Route(routeSelector3.address, proxy, inetSocketAddress2);
                                        RouteDatabase routeDatabase2 = routeSelector3.routeDatabase;
                                        synchronized (routeDatabase2) {
                                            Intrinsics.checkNotNullParameter(route2, "route");
                                            contains = routeDatabase2.failedRoutes.contains(route2);
                                        }
                                        if (contains) {
                                            routeSelector3.postponedRoutes.add(route2);
                                        } else {
                                            arrayList.add(route2);
                                        }
                                    }
                                    if (!arrayList.isEmpty()) {
                                        break;
                                    }
                                } else {
                                    throw new SocketException("No route to " + str + ':' + i5 + "; port is out of range");
                                }
                            } else {
                                StringBuilder outline252 = GeneratedOutlineSupport.outline25("No route to ");
                                outline252.append(routeSelector3.address.url.host);
                                outline252.append("; exhausted proxy configurations: ");
                                outline252.append(routeSelector3.proxies);
                                throw new SocketException(outline252.toString());
                            }
                        }
                        if (arrayList.isEmpty()) {
                            ViewGroupUtilsApi14.addAll(arrayList, routeSelector3.postponedRoutes);
                            routeSelector3.postponedRoutes.clear();
                        }
                        RouteSelector.Selection selection4 = new RouteSelector.Selection(arrayList);
                        this.routeSelection = selection4;
                        list = selection4.routes;
                        if (this.call.canceled) {
                            throw new IOException("Canceled");
                        } else if (this.connectionPool.callAcquirePooledConnection(this.address, this.call, list, false)) {
                            realConnection = this.call.connection;
                            Intrinsics.checkNotNull(realConnection);
                            this.eventListener.connectionAcquired(this.call, realConnection);
                        } else {
                            route = selection4.next();
                            RealConnection realConnection2 = new RealConnection(this.connectionPool, route);
                            this.call.connectionToCancel = realConnection2;
                            realConnection2.connect(i, i2, i3, i4, z, this.call, this.eventListener);
                            this.call.connectionToCancel = null;
                            routeDatabase = this.call.client.routeDatabase;
                            Route route3 = realConnection2.route;
                            synchronized (routeDatabase) {
                                Intrinsics.checkNotNullParameter(route3, "route");
                                routeDatabase.failedRoutes.remove(route3);
                            }
                            if (this.connectionPool.callAcquirePooledConnection(this.address, this.call, list, true)) {
                                RealConnection realConnection3 = this.call.connection;
                                Intrinsics.checkNotNull(realConnection3);
                                this.nextRouteToTry = route;
                                Socket socket2 = realConnection2.socket;
                                Intrinsics.checkNotNull(socket2);
                                Util.closeQuietly(socket2);
                                this.eventListener.connectionAcquired(this.call, realConnection3);
                                realConnection = realConnection3;
                            } else {
                                synchronized (realConnection2) {
                                    RealConnectionPool realConnectionPool = this.connectionPool;
                                    Objects.requireNonNull(realConnectionPool);
                                    Intrinsics.checkNotNullParameter(realConnection2, "connection");
                                    byte[] bArr = Util.EMPTY_BYTE_ARRAY;
                                    realConnectionPool.connections.add(realConnection2);
                                    realConnectionPool.cleanupQueue.schedule(realConnectionPool.cleanupTask, 0);
                                    this.call.acquireConnectionNoEvents(realConnection2);
                                }
                                this.eventListener.connectionAcquired(this.call, realConnection2);
                                z3 = z2;
                                realConnection = realConnection2;
                                if (realConnection.isHealthy(z3)) {
                                }
                            }
                        }
                    } else {
                        throw new NoSuchElementException();
                    }
                }
                list = null;
                RealConnection realConnection22 = new RealConnection(this.connectionPool, route);
                this.call.connectionToCancel = realConnection22;
                try {
                    realConnection22.connect(i, i2, i3, i4, z, this.call, this.eventListener);
                    this.call.connectionToCancel = null;
                    routeDatabase = this.call.client.routeDatabase;
                    Route route32 = realConnection22.route;
                    synchronized (routeDatabase) {
                    }
                } catch (Throwable th) {
                    this.call.connectionToCancel = null;
                    throw th;
                }
            }
            z3 = z2;
            if (realConnection.isHealthy(z3)) {
            }
        }
        throw new IOException("Canceled");
    }

    public final boolean sameHostAndPort(HttpUrl httpUrl) {
        Intrinsics.checkNotNullParameter(httpUrl, "url");
        HttpUrl httpUrl2 = this.address.url;
        return httpUrl.port == httpUrl2.port && Intrinsics.areEqual(httpUrl.host, httpUrl2.host);
    }

    public final void trackFailure(IOException iOException) {
        Intrinsics.checkNotNullParameter(iOException, "e");
        this.nextRouteToTry = null;
        if ((iOException instanceof StreamResetException) && ((StreamResetException) iOException).errorCode == ErrorCode.REFUSED_STREAM) {
            this.refusedStreamCount++;
        } else if (iOException instanceof ConnectionShutdownException) {
            this.connectionShutdownCount++;
        } else {
            this.otherFailureCount++;
        }
    }
}
