package okhttp3.internal.connection;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.lang.ref.Reference;
import java.lang.ref.WeakReference;
import java.net.Socket;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.Call;
import okhttp3.Callback;
import okhttp3.Dispatcher;
import okhttp3.EventListener$Companion$NONE$1;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.Util;
import okhttp3.internal.Util$asFactory$1;
import okhttp3.internal.cache.CacheInterceptor;
import okhttp3.internal.http.BridgeInterceptor;
import okhttp3.internal.http.CallServerInterceptor;
import okhttp3.internal.http.RealInterceptorChain;
import okhttp3.internal.http.RetryAndFollowUpInterceptor;
import okhttp3.internal.platform.Platform;

/* compiled from: RealCall.kt */
public final class RealCall implements Call {
    public Object callStackTrace;
    public volatile boolean canceled;
    public final OkHttpClient client;
    public RealConnection connection;
    public final RealConnectionPool connectionPool;
    public volatile RealConnection connectionToCancel;
    public final EventListener$Companion$NONE$1 eventListener;
    public volatile Exchange exchange;
    public ExchangeFinder exchangeFinder;
    public final AtomicBoolean executed = new AtomicBoolean();
    public boolean expectMoreExchanges = true;
    public final boolean forWebSocket;
    public Exchange interceptorScopedExchange;
    public final Request originalRequest;
    public boolean requestBodyOpen;
    public boolean responseBodyOpen;
    public final RealCall$timeout$1 timeout;
    public boolean timeoutEarlyExit;

    /* compiled from: RealCall.kt */
    public final class AsyncCall implements Runnable {
        public volatile AtomicInteger callsPerHost = new AtomicInteger(0);
        public final Callback responseCallback;
        public final /* synthetic */ RealCall this$0;

        public AsyncCall(RealCall realCall, Callback callback) {
            Intrinsics.checkNotNullParameter(callback, "responseCallback");
            this.this$0 = realCall;
            this.responseCallback = callback;
        }

        public final String getHost() {
            return this.this$0.originalRequest.url.host;
        }

        /* JADX WARNING: Removed duplicated region for block: B:18:0x0053 A[Catch:{ IOException -> 0x0076, all -> 0x004b, all -> 0x0074 }] */
        /* JADX WARNING: Removed duplicated region for block: B:24:0x0079 A[Catch:{ IOException -> 0x0076, all -> 0x004b, all -> 0x0074 }] */
        /* JADX WARNING: Removed duplicated region for block: B:25:0x0099 A[Catch:{ IOException -> 0x0076, all -> 0x004b, all -> 0x0074 }] */
        public void run() {
            IOException e;
            RealCall realCall;
            Throwable th;
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("OkHttp ");
            outline25.append(this.this$0.originalRequest.url.redact());
            String sb = outline25.toString();
            Thread currentThread = Thread.currentThread();
            Intrinsics.checkNotNullExpressionValue(currentThread, "currentThread");
            String name = currentThread.getName();
            currentThread.setName(sb);
            try {
                this.this$0.timeout.enter();
                boolean z = false;
                try {
                    try {
                        this.responseCallback.onResponse(this.this$0, this.this$0.getResponseWithInterceptorChain$okhttp());
                        realCall = this.this$0;
                    } catch (IOException e2) {
                        e = e2;
                        z = true;
                        if (!z) {
                        }
                        realCall = this.this$0;
                        realCall.client.dispatcher.finished$okhttp(this);
                    } catch (Throwable th2) {
                        th = th2;
                        z = true;
                        this.this$0.cancel();
                        if (!z) {
                        }
                        throw th;
                    }
                } catch (IOException e3) {
                    e = e3;
                    if (!z) {
                        Platform.Companion companion = Platform.Companion;
                        Platform platform = Platform.platform;
                        platform.log("Callback failure for " + RealCall.access$toLoggableString(this.this$0), 4, e);
                    } else {
                        this.responseCallback.onFailure(this.this$0, e);
                    }
                    realCall = this.this$0;
                    realCall.client.dispatcher.finished$okhttp(this);
                } catch (Throwable th3) {
                    this.this$0.client.dispatcher.finished$okhttp(this);
                    throw th3;
                }
                realCall.client.dispatcher.finished$okhttp(this);
            } finally {
                currentThread.setName(name);
            }
        }
    }

    /* compiled from: RealCall.kt */
    public final class CallReference extends WeakReference<RealCall> {
        public final Object callStackTrace;

        /* JADX INFO: super call moved to the top of the method (can break code semantics) */
        public CallReference(RealCall realCall, Object obj) {
            super(realCall);
            Intrinsics.checkNotNullParameter(realCall, "referent");
            this.callStackTrace = obj;
        }
    }

    public RealCall(OkHttpClient okHttpClient, Request request, boolean z) {
        Intrinsics.checkNotNullParameter(okHttpClient, "client");
        Intrinsics.checkNotNullParameter(request, "originalRequest");
        this.client = okHttpClient;
        this.originalRequest = request;
        this.forWebSocket = z;
        this.connectionPool = okHttpClient.connectionPool.delegate;
        Util$asFactory$1 util$asFactory$1 = okHttpClient.eventListenerFactory;
        Objects.requireNonNull(util$asFactory$1);
        Intrinsics.checkNotNullParameter(this, "it");
        this.eventListener = util$asFactory$1.$this_asFactory;
        RealCall$timeout$1 realCall$timeout$1 = new RealCall$timeout$1(this);
        realCall$timeout$1.timeout((long) 0, TimeUnit.MILLISECONDS);
        this.timeout = realCall$timeout$1;
    }

    public static final String access$toLoggableString(RealCall realCall) {
        StringBuilder sb = new StringBuilder();
        sb.append(realCall.canceled ? "canceled " : "");
        sb.append(realCall.forWebSocket ? "web socket" : "call");
        sb.append(" to ");
        sb.append(realCall.originalRequest.url.redact());
        return sb.toString();
    }

    public final void acquireConnectionNoEvents(RealConnection realConnection) {
        Intrinsics.checkNotNullParameter(realConnection, "connection");
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        if (this.connection == null) {
            this.connection = realConnection;
            realConnection.calls.add(new CallReference(this, this.callStackTrace));
            return;
        }
        throw new IllegalStateException("Check failed.".toString());
    }

    public final <E extends IOException> E callDone(E e) {
        InterruptedIOException interruptedIOException;
        Socket releaseConnectionNoEvents$okhttp;
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        RealConnection realConnection = this.connection;
        if (realConnection != null) {
            synchronized (realConnection) {
                releaseConnectionNoEvents$okhttp = releaseConnectionNoEvents$okhttp();
            }
            if (this.connection == null) {
                if (releaseConnectionNoEvents$okhttp != null) {
                    Util.closeQuietly(releaseConnectionNoEvents$okhttp);
                }
                Objects.requireNonNull(this.eventListener);
                Intrinsics.checkNotNullParameter(this, "call");
                Intrinsics.checkNotNullParameter(realConnection, "connection");
            } else {
                if (!(releaseConnectionNoEvents$okhttp == null)) {
                    throw new IllegalStateException("Check failed.".toString());
                }
            }
        }
        if (!this.timeoutEarlyExit && this.timeout.exit()) {
            InterruptedIOException interruptedIOException2 = new InterruptedIOException("timeout");
            interruptedIOException = interruptedIOException2;
            if (e != null) {
                interruptedIOException2.initCause(e);
                interruptedIOException = interruptedIOException2;
            }
        } else {
            interruptedIOException = e;
        }
        if (e != null) {
            EventListener$Companion$NONE$1 eventListener$Companion$NONE$1 = this.eventListener;
            Intrinsics.checkNotNull(interruptedIOException);
            Objects.requireNonNull(eventListener$Companion$NONE$1);
            Intrinsics.checkNotNullParameter(this, "call");
            Intrinsics.checkNotNullParameter(interruptedIOException, "ioe");
        } else {
            Objects.requireNonNull(this.eventListener);
            Intrinsics.checkNotNullParameter(this, "call");
        }
        return interruptedIOException;
    }

    public final void callStart() {
        Platform.Companion companion = Platform.Companion;
        this.callStackTrace = Platform.platform.getStackTraceForCloseable("response.body().close()");
        Objects.requireNonNull(this.eventListener);
        Intrinsics.checkNotNullParameter(this, "call");
    }

    public void cancel() {
        Socket socket;
        if (!this.canceled) {
            this.canceled = true;
            Exchange exchange2 = this.exchange;
            if (exchange2 != null) {
                exchange2.codec.cancel();
            }
            RealConnection realConnection = this.connectionToCancel;
            if (!(realConnection == null || (socket = realConnection.rawSocket) == null)) {
                Util.closeQuietly(socket);
            }
            Objects.requireNonNull(this.eventListener);
            Intrinsics.checkNotNullParameter(this, "call");
        }
    }

    @Override // java.lang.Object
    public Object clone() {
        return new RealCall(this.client, this.originalRequest, this.forWebSocket);
    }

    public void enqueue(Callback callback) {
        AsyncCall asyncCall;
        Intrinsics.checkNotNullParameter(callback, "responseCallback");
        if (this.executed.compareAndSet(false, true)) {
            callStart();
            Dispatcher dispatcher = this.client.dispatcher;
            AsyncCall asyncCall2 = new AsyncCall(this, callback);
            Objects.requireNonNull(dispatcher);
            Intrinsics.checkNotNullParameter(asyncCall2, "call");
            synchronized (dispatcher) {
                dispatcher.readyAsyncCalls.add(asyncCall2);
                if (!asyncCall2.this$0.forWebSocket) {
                    String host = asyncCall2.getHost();
                    Iterator<AsyncCall> it = dispatcher.runningAsyncCalls.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            Iterator<AsyncCall> it2 = dispatcher.readyAsyncCalls.iterator();
                            while (true) {
                                if (!it2.hasNext()) {
                                    asyncCall = null;
                                    break;
                                }
                                asyncCall = it2.next();
                                if (Intrinsics.areEqual(asyncCall.getHost(), host)) {
                                    break;
                                }
                            }
                        } else {
                            asyncCall = it.next();
                            if (Intrinsics.areEqual(asyncCall.getHost(), host)) {
                                break;
                            }
                        }
                    }
                    if (asyncCall != null) {
                        Intrinsics.checkNotNullParameter(asyncCall, "other");
                        asyncCall2.callsPerHost = asyncCall.callsPerHost;
                    }
                }
            }
            dispatcher.promoteAndExecute();
            return;
        }
        throw new IllegalStateException("Already Executed".toString());
    }

    public Response execute() {
        Dispatcher dispatcher;
        if (this.executed.compareAndSet(false, true)) {
            this.timeout.enter();
            callStart();
            try {
                Dispatcher dispatcher2 = this.client.dispatcher;
                synchronized (dispatcher2) {
                    Intrinsics.checkNotNullParameter(this, "call");
                    dispatcher2.runningSyncCalls.add(this);
                }
                return getResponseWithInterceptorChain$okhttp();
            } finally {
                dispatcher = this.client.dispatcher;
                Objects.requireNonNull(dispatcher);
                Intrinsics.checkNotNullParameter(this, "call");
                dispatcher.finished(dispatcher.runningSyncCalls, this);
            }
        } else {
            throw new IllegalStateException("Already Executed".toString());
        }
    }

    public final void exitNetworkInterceptorExchange$okhttp(boolean z) {
        Exchange exchange2;
        synchronized (this) {
            if (!this.expectMoreExchanges) {
                throw new IllegalStateException("released".toString());
            }
        }
        if (z && (exchange2 = this.exchange) != null) {
            exchange2.codec.cancel();
            exchange2.call.messageDone$okhttp(exchange2, true, true, null);
        }
        this.interceptorScopedExchange = null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x008e  */
    public final Response getResponseWithInterceptorChain$okhttp() {
        Throwable th;
        ArrayList arrayList = new ArrayList();
        ViewGroupUtilsApi14.addAll(arrayList, this.client.interceptors);
        arrayList.add(new RetryAndFollowUpInterceptor(this.client));
        arrayList.add(new BridgeInterceptor(this.client.cookieJar));
        Objects.requireNonNull(this.client);
        arrayList.add(new CacheInterceptor());
        arrayList.add(ConnectInterceptor.INSTANCE);
        if (!this.forWebSocket) {
            ViewGroupUtilsApi14.addAll(arrayList, this.client.networkInterceptors);
        }
        arrayList.add(new CallServerInterceptor(this.forWebSocket));
        Request request = this.originalRequest;
        OkHttpClient okHttpClient = this.client;
        RealInterceptorChain realInterceptorChain = new RealInterceptorChain(this, arrayList, 0, null, request, okHttpClient.connectTimeoutMillis, okHttpClient.readTimeoutMillis, okHttpClient.writeTimeoutMillis);
        boolean z = false;
        try {
            Response proceed = realInterceptorChain.proceed(this.originalRequest);
            if (!this.canceled) {
                noMoreExchanges$okhttp(null);
                return proceed;
            }
            Util.closeQuietly(proceed);
            throw new IOException("Canceled");
        } catch (IOException e) {
            IOException noMoreExchanges$okhttp = noMoreExchanges$okhttp(e);
            if (noMoreExchanges$okhttp == null) {
                throw new NullPointerException("null cannot be cast to non-null type kotlin.Throwable");
            }
            throw noMoreExchanges$okhttp;
        } catch (Throwable th2) {
            th = th2;
            z = true;
            if (!z) {
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0023 A[Catch:{ all -> 0x0019 }] */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0027 A[Catch:{ all -> 0x0019 }] */
    public final <E extends IOException> E messageDone$okhttp(Exchange exchange2, boolean z, boolean z2, E e) {
        boolean z3;
        boolean z4;
        Intrinsics.checkNotNullParameter(exchange2, "exchange");
        if (!Intrinsics.areEqual(exchange2, this.exchange)) {
            return e;
        }
        synchronized (this) {
            z3 = false;
            if (z) {
                try {
                    if (!this.requestBodyOpen) {
                    }
                    if (z) {
                        this.requestBodyOpen = false;
                    }
                    if (z2) {
                        this.responseBodyOpen = false;
                    }
                    boolean z5 = this.requestBodyOpen;
                    boolean z6 = z5 && !this.responseBodyOpen;
                    if (!z5 && !this.responseBodyOpen && !this.expectMoreExchanges) {
                        z3 = true;
                    }
                    z4 = z3;
                    z3 = z6;
                } catch (Throwable th) {
                    throw th;
                }
            }
            if (!z2 || !this.responseBodyOpen) {
                z4 = false;
            }
            if (z) {
            }
            if (z2) {
            }
            boolean z52 = this.requestBodyOpen;
            if (z52) {
            }
            z3 = true;
            z4 = z3;
            z3 = z6;
        }
        if (z3) {
            this.exchange = null;
            RealConnection realConnection = this.connection;
            if (realConnection != null) {
                synchronized (realConnection) {
                    realConnection.successCount++;
                }
            }
        }
        return z4 ? (E) callDone(e) : e;
    }

    public final IOException noMoreExchanges$okhttp(IOException iOException) {
        boolean z;
        synchronized (this) {
            z = false;
            if (this.expectMoreExchanges) {
                this.expectMoreExchanges = false;
                if (!this.requestBodyOpen && !this.responseBodyOpen) {
                    z = true;
                }
            }
        }
        return z ? callDone(iOException) : iOException;
    }

    public final Socket releaseConnectionNoEvents$okhttp() {
        RealConnection realConnection = this.connection;
        Intrinsics.checkNotNull(realConnection);
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        List<Reference<RealCall>> list = realConnection.calls;
        Iterator<Reference<RealCall>> it = list.iterator();
        boolean z = false;
        int i = 0;
        while (true) {
            if (!it.hasNext()) {
                i = -1;
                break;
            } else if (Intrinsics.areEqual(it.next().get(), this)) {
                break;
            } else {
                i++;
            }
        }
        if (i != -1) {
            list.remove(i);
            this.connection = null;
            if (list.isEmpty()) {
                realConnection.idleAtNs = System.nanoTime();
                RealConnectionPool realConnectionPool = this.connectionPool;
                Objects.requireNonNull(realConnectionPool);
                Intrinsics.checkNotNullParameter(realConnection, "connection");
                byte[] bArr2 = Util.EMPTY_BYTE_ARRAY;
                if (realConnection.noNewExchanges || realConnectionPool.maxIdleConnections == 0) {
                    realConnection.noNewExchanges = true;
                    realConnectionPool.connections.remove(realConnection);
                    if (realConnectionPool.connections.isEmpty()) {
                        realConnectionPool.cleanupQueue.cancelAll();
                    }
                    z = true;
                } else {
                    realConnectionPool.cleanupQueue.schedule(realConnectionPool.cleanupTask, 0);
                }
                if (z) {
                    Socket socket = realConnection.socket;
                    Intrinsics.checkNotNull(socket);
                    return socket;
                }
            }
            return null;
        }
        throw new IllegalStateException("Check failed.".toString());
    }
}
