package okhttp3.internal.connection;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import io.netty.handler.codec.compression.FastLz;
import io.netty.util.internal.StringUtil;
import java.io.IOException;
import java.io.InterruptedIOException;
import java.lang.ref.Reference;
import java.net.ConnectException;
import java.net.InetSocketAddress;
import java.net.ProtocolException;
import java.net.Proxy;
import java.net.Socket;
import java.net.SocketTimeoutException;
import java.net.UnknownServiceException;
import java.security.Principal;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLHandshakeException;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSession;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.Address;
import okhttp3.Call;
import okhttp3.CertificatePinner;
import okhttp3.CertificatePinner$check$1;
import okhttp3.Connection;
import okhttp3.ConnectionSpec;
import okhttp3.EventListener$Companion$NONE$1;
import okhttp3.Handshake;
import okhttp3.Headers;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.Route;
import okhttp3.internal.Util;
import okhttp3.internal.concurrent.TaskQueue;
import okhttp3.internal.concurrent.TaskQueue$execute$1;
import okhttp3.internal.concurrent.TaskRunner;
import okhttp3.internal.http.ExchangeCodec;
import okhttp3.internal.http.RealInterceptorChain;
import okhttp3.internal.http1.Http1ExchangeCodec;
import okhttp3.internal.http2.ErrorCode;
import okhttp3.internal.http2.Http2;
import okhttp3.internal.http2.Http2Connection;
import okhttp3.internal.http2.Http2ExchangeCodec;
import okhttp3.internal.http2.Http2Stream;
import okhttp3.internal.http2.Http2Writer;
import okhttp3.internal.http2.Settings;
import okhttp3.internal.platform.Platform;
import okhttp3.internal.tls.OkHostnameVerifier;
import okio.BufferedSink;
import okio.BufferedSource;
import okio.Source;

/* compiled from: RealConnection.kt */
public final class RealConnection extends Http2Connection.Listener implements Connection {
    public int allocationLimit = 1;
    public final List<Reference<RealCall>> calls = new ArrayList();
    public Handshake handshake;
    public Http2Connection http2Connection;
    public long idleAtNs = Long.MAX_VALUE;
    public boolean noCoalescedConnections;
    public boolean noNewExchanges;
    public Protocol protocol;
    public Socket rawSocket;
    public int refusedStreamCount;
    public final Route route;
    public int routeFailureCount;
    public BufferedSink sink;
    public Socket socket;
    public BufferedSource source;
    public int successCount;

    public abstract /* synthetic */ class WhenMappings {
        public static final /* synthetic */ int[] $EnumSwitchMapping$0;

        static {
            int[] iArr = new int[Proxy.Type.values().length];
            $EnumSwitchMapping$0 = iArr;
            iArr[Proxy.Type.DIRECT.ordinal()] = 1;
            iArr[Proxy.Type.HTTP.ordinal()] = 2;
        }
    }

    public RealConnection(RealConnectionPool realConnectionPool, Route route2) {
        Intrinsics.checkNotNullParameter(realConnectionPool, "connectionPool");
        Intrinsics.checkNotNullParameter(route2, "route");
        this.route = route2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:45:0x00e5  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x00ec  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x0116  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x011c  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x0121  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x0155 A[EDGE_INSN: B:79:0x0155->B:71:0x0155 ?: BREAK  , SYNTHETIC] */
    public final void connect(int i, int i2, int i3, int i4, boolean z, Call call, EventListener$Companion$NONE$1 eventListener$Companion$NONE$1) {
        IOException e;
        Socket socket2;
        Socket socket3;
        boolean z2;
        Intrinsics.checkNotNullParameter(call, "call");
        Intrinsics.checkNotNullParameter(eventListener$Companion$NONE$1, "eventListener");
        if (this.protocol == null) {
            List<ConnectionSpec> list = this.route.address.connectionSpecs;
            ConnectionSpecSelector connectionSpecSelector = new ConnectionSpecSelector(list);
            Address address = this.route.address;
            if (address.sslSocketFactory == null) {
                if (list.contains(ConnectionSpec.CLEARTEXT)) {
                    String str = this.route.address.url.host;
                    Platform.Companion companion = Platform.Companion;
                    if (!Platform.platform.isCleartextTrafficPermitted(str)) {
                        throw new RouteException(new UnknownServiceException(GeneratedOutlineSupport.outline19("CLEARTEXT communication to ", str, " not permitted by network security policy")));
                    }
                } else {
                    throw new RouteException(new UnknownServiceException("CLEARTEXT communication not enabled for client"));
                }
            } else if (address.protocols.contains(Protocol.H2_PRIOR_KNOWLEDGE)) {
                throw new RouteException(new UnknownServiceException("H2_PRIOR_KNOWLEDGE cannot be used with HTTPS"));
            }
            RouteException routeException = null;
            do {
                try {
                    if (this.route.requiresTunnel()) {
                        connectTunnel(i, i2, i3, call, eventListener$Companion$NONE$1);
                        if (this.rawSocket == null) {
                            if (this.route.requiresTunnel() || this.rawSocket != null) {
                                this.idleAtNs = System.nanoTime();
                                return;
                            }
                            throw new RouteException(new ProtocolException("Too many tunnel connections attempted: 21"));
                        }
                    } else {
                        try {
                            connectSocket(i, i2, call, eventListener$Companion$NONE$1);
                        } catch (IOException e2) {
                            e = e2;
                            socket2 = this.socket;
                            if (socket2 != null) {
                                Util.closeQuietly(socket2);
                            }
                            socket3 = this.rawSocket;
                            if (socket3 != null) {
                                Util.closeQuietly(socket3);
                            }
                            this.socket = null;
                            this.rawSocket = null;
                            this.source = null;
                            this.sink = null;
                            this.handshake = null;
                            this.protocol = null;
                            this.http2Connection = null;
                            this.allocationLimit = 1;
                            Route route2 = this.route;
                            InetSocketAddress inetSocketAddress = route2.socketAddress;
                            Proxy proxy = route2.proxy;
                            Intrinsics.checkNotNullParameter(call, "call");
                            Intrinsics.checkNotNullParameter(inetSocketAddress, "inetSocketAddress");
                            Intrinsics.checkNotNullParameter(proxy, "proxy");
                            Intrinsics.checkNotNullParameter(e, "ioe");
                            if (routeException != null) {
                                routeException = new RouteException(e);
                            } else {
                                routeException.addConnectException(e);
                            }
                            if (z) {
                                break;
                            }
                            Intrinsics.checkNotNullParameter(e, "e");
                            connectionSpecSelector.isFallback = true;
                            if (connectionSpecSelector.isFallbackPossible && !(e instanceof ProtocolException) && !(e instanceof InterruptedIOException) && ((!(e instanceof SSLHandshakeException) || !(e.getCause() instanceof CertificateException)) && !(e instanceof SSLPeerUnverifiedException) && (e instanceof SSLException))) {
                                z2 = true;
                                continue;
                            } else {
                                z2 = false;
                                continue;
                            }
                            if (!z2) {
                            }
                            throw routeException;
                        }
                    }
                    try {
                        establishProtocol(connectionSpecSelector, i4, call, eventListener$Companion$NONE$1);
                        Route route3 = this.route;
                        InetSocketAddress inetSocketAddress2 = route3.socketAddress;
                        Proxy proxy2 = route3.proxy;
                        Intrinsics.checkNotNullParameter(call, "call");
                        Intrinsics.checkNotNullParameter(inetSocketAddress2, "inetSocketAddress");
                        Intrinsics.checkNotNullParameter(proxy2, "proxy");
                        if (this.route.requiresTunnel()) {
                        }
                        this.idleAtNs = System.nanoTime();
                        return;
                    } catch (IOException e3) {
                        e = e3;
                    }
                } catch (IOException e4) {
                    e = e4;
                    socket2 = this.socket;
                    if (socket2 != null) {
                    }
                    socket3 = this.rawSocket;
                    if (socket3 != null) {
                    }
                    this.socket = null;
                    this.rawSocket = null;
                    this.source = null;
                    this.sink = null;
                    this.handshake = null;
                    this.protocol = null;
                    this.http2Connection = null;
                    this.allocationLimit = 1;
                    Route route22 = this.route;
                    InetSocketAddress inetSocketAddress3 = route22.socketAddress;
                    Proxy proxy3 = route22.proxy;
                    Intrinsics.checkNotNullParameter(call, "call");
                    Intrinsics.checkNotNullParameter(inetSocketAddress3, "inetSocketAddress");
                    Intrinsics.checkNotNullParameter(proxy3, "proxy");
                    Intrinsics.checkNotNullParameter(e, "ioe");
                    if (routeException != null) {
                    }
                    if (z) {
                    }
                    throw routeException;
                }
            } while (!z2);
            throw routeException;
        }
        throw new IllegalStateException("already connected".toString());
    }

    public final void connectFailed$okhttp(OkHttpClient okHttpClient, Route route2, IOException iOException) {
        Intrinsics.checkNotNullParameter(okHttpClient, "client");
        Intrinsics.checkNotNullParameter(route2, "failedRoute");
        Intrinsics.checkNotNullParameter(iOException, "failure");
        if (route2.proxy.type() != Proxy.Type.DIRECT) {
            Address address = route2.address;
            address.proxySelector.connectFailed(address.url.uri(), route2.proxy.address(), iOException);
        }
        RouteDatabase routeDatabase = okHttpClient.routeDatabase;
        synchronized (routeDatabase) {
            Intrinsics.checkNotNullParameter(route2, "failedRoute");
            routeDatabase.failedRoutes.add(route2);
        }
    }

    public final void connectSocket(int i, int i2, Call call, EventListener$Companion$NONE$1 eventListener$Companion$NONE$1) {
        Socket socket2;
        int i3;
        Route route2 = this.route;
        Proxy proxy = route2.proxy;
        Address address = route2.address;
        Proxy.Type type = proxy.type();
        if (type != null && ((i3 = WhenMappings.$EnumSwitchMapping$0[type.ordinal()]) == 1 || i3 == 2)) {
            socket2 = address.socketFactory.createSocket();
            Intrinsics.checkNotNull(socket2);
        } else {
            socket2 = new Socket(proxy);
        }
        this.rawSocket = socket2;
        InetSocketAddress inetSocketAddress = this.route.socketAddress;
        Objects.requireNonNull(eventListener$Companion$NONE$1);
        Intrinsics.checkNotNullParameter(call, "call");
        Intrinsics.checkNotNullParameter(inetSocketAddress, "inetSocketAddress");
        Intrinsics.checkNotNullParameter(proxy, "proxy");
        socket2.setSoTimeout(i2);
        try {
            Platform.Companion companion = Platform.Companion;
            Platform.platform.connectSocket(socket2, this.route.socketAddress, i);
            try {
                this.source = SystemPropsKt.buffer(SystemPropsKt.source(socket2));
                this.sink = SystemPropsKt.buffer(SystemPropsKt.sink(socket2));
            } catch (NullPointerException e) {
                if (Intrinsics.areEqual(e.getMessage(), "throw with null exception")) {
                    throw new IOException(e);
                }
            }
        } catch (ConnectException e2) {
            StringBuilder outline25 = GeneratedOutlineSupport.outline25("Failed to connect to ");
            outline25.append(this.route.socketAddress);
            ConnectException connectException = new ConnectException(outline25.toString());
            connectException.initCause(e2);
            throw connectException;
        }
    }

    public final void connectTunnel(int i, int i2, int i3, Call call, EventListener$Companion$NONE$1 eventListener$Companion$NONE$1) {
        Request.Builder builder = new Request.Builder();
        builder.url(this.route.address.url);
        OkHttpClient okHttpClient = null;
        builder.method("CONNECT", null);
        boolean z = true;
        builder.header("Host", Util.toHostHeader(this.route.address.url, true));
        builder.header("Proxy-Connection", "Keep-Alive");
        builder.header("User-Agent", "okhttp/4.9.1");
        Request build = builder.build();
        Response.Builder builder2 = new Response.Builder();
        builder2.request(build);
        builder2.protocol(Protocol.HTTP_1_1);
        builder2.code = 407;
        builder2.message("Preemptive Authenticate");
        builder2.body = Util.EMPTY_RESPONSE;
        builder2.sentRequestAtMillis = -1;
        builder2.receivedResponseAtMillis = -1;
        Intrinsics.checkNotNullParameter("Proxy-Authenticate", VpnProfileDataSource.KEY_NAME);
        Intrinsics.checkNotNullParameter("OkHttp-Preemptive", "value");
        Headers.Builder builder3 = builder2.headers;
        Objects.requireNonNull(builder3);
        Intrinsics.checkNotNullParameter("Proxy-Authenticate", VpnProfileDataSource.KEY_NAME);
        Intrinsics.checkNotNullParameter("OkHttp-Preemptive", "value");
        Headers.Companion companion = Headers.Companion;
        companion.checkName("Proxy-Authenticate");
        companion.checkValue("OkHttp-Preemptive", "Proxy-Authenticate");
        builder3.removeAll("Proxy-Authenticate");
        builder3.addLenient$okhttp("Proxy-Authenticate", "OkHttp-Preemptive");
        Response build2 = builder2.build();
        Route route2 = this.route;
        Request authenticate = route2.address.proxyAuthenticator.authenticate(route2, build2);
        if (authenticate != null) {
            build = authenticate;
        }
        HttpUrl httpUrl = build.url;
        int i4 = 0;
        while (i4 < 21) {
            connectSocket(i, i2, call, eventListener$Companion$NONE$1);
            String str = "CONNECT " + Util.toHostHeader(httpUrl, z) + " HTTP/1.1";
            while (true) {
                BufferedSource bufferedSource = this.source;
                Intrinsics.checkNotNull(bufferedSource);
                BufferedSink bufferedSink = this.sink;
                Intrinsics.checkNotNull(bufferedSink);
                Http1ExchangeCodec http1ExchangeCodec = new Http1ExchangeCodec(okHttpClient, this, bufferedSource, bufferedSink);
                TimeUnit timeUnit = TimeUnit.MILLISECONDS;
                bufferedSource.timeout().timeout((long) i2, timeUnit);
                bufferedSink.timeout().timeout((long) i3, timeUnit);
                http1ExchangeCodec.writeRequest(build.headers, str);
                http1ExchangeCodec.sink.flush();
                Response.Builder readResponseHeaders = http1ExchangeCodec.readResponseHeaders(false);
                Intrinsics.checkNotNull(readResponseHeaders);
                readResponseHeaders.request(build);
                Response build3 = readResponseHeaders.build();
                Intrinsics.checkNotNullParameter(build3, "response");
                long headersContentLength = Util.headersContentLength(build3);
                if (headersContentLength != -1) {
                    Source newFixedLengthSource = http1ExchangeCodec.newFixedLengthSource(headersContentLength);
                    Util.skipAll(newFixedLengthSource, Integer.MAX_VALUE, timeUnit);
                    ((Http1ExchangeCodec.FixedLengthSource) newFixedLengthSource).close();
                }
                int i5 = build3.code;
                if (i5 != 200) {
                    if (i5 == 407) {
                        Route route3 = this.route;
                        Request authenticate2 = route3.address.proxyAuthenticator.authenticate(route3, build3);
                        if (authenticate2 == null) {
                            throw new IOException("Failed to authenticate with proxy");
                        } else if (StringsKt__IndentKt.equals("close", Response.header$default(build3, "Connection", null, 2), true)) {
                            build = authenticate2;
                            break;
                        } else {
                            okHttpClient = null;
                            build = authenticate2;
                        }
                    } else {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Unexpected response code for CONNECT: ");
                        outline25.append(build3.code);
                        throw new IOException(outline25.toString());
                    }
                } else if (!bufferedSource.getBuffer().exhausted() || !bufferedSink.getBuffer().exhausted()) {
                    throw new IOException("TLS tunnel buffered too many bytes!");
                } else {
                    build = null;
                }
            }
            if (build != null) {
                Socket socket2 = this.rawSocket;
                if (socket2 != null) {
                    Util.closeQuietly(socket2);
                }
                okHttpClient = null;
                this.rawSocket = null;
                this.sink = null;
                this.source = null;
                Route route4 = this.route;
                InetSocketAddress inetSocketAddress = route4.socketAddress;
                Proxy proxy = route4.proxy;
                Intrinsics.checkNotNullParameter(call, "call");
                Intrinsics.checkNotNullParameter(inetSocketAddress, "inetSocketAddress");
                Intrinsics.checkNotNullParameter(proxy, "proxy");
                i4++;
                z = true;
            } else {
                return;
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:46:0x01a7  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x01b0  */
    public final void establishProtocol(ConnectionSpecSelector connectionSpecSelector, int i, Call call, EventListener$Companion$NONE$1 eventListener$Companion$NONE$1) {
        Throwable th;
        Address address = this.route.address;
        if (address.sslSocketFactory == null) {
            List<Protocol> list = address.protocols;
            Protocol protocol2 = Protocol.H2_PRIOR_KNOWLEDGE;
            if (list.contains(protocol2)) {
                this.socket = this.rawSocket;
                this.protocol = protocol2;
                startHttp2(i);
                return;
            }
            this.socket = this.rawSocket;
            this.protocol = Protocol.HTTP_1_1;
            return;
        }
        Intrinsics.checkNotNullParameter(call, "call");
        Address address2 = this.route.address;
        SSLSocketFactory sSLSocketFactory = address2.sslSocketFactory;
        SSLSocket sSLSocket = null;
        String str = null;
        try {
            Intrinsics.checkNotNull(sSLSocketFactory);
            Socket socket2 = this.rawSocket;
            HttpUrl httpUrl = address2.url;
            Socket createSocket = sSLSocketFactory.createSocket(socket2, httpUrl.host, httpUrl.port, true);
            if (createSocket != null) {
                SSLSocket sSLSocket2 = (SSLSocket) createSocket;
                try {
                    ConnectionSpec configureSecureSocket = connectionSpecSelector.configureSecureSocket(sSLSocket2);
                    if (configureSecureSocket.supportsTlsExtensions) {
                        Platform.Companion companion = Platform.Companion;
                        Platform.platform.configureTlsExtensions(sSLSocket2, address2.url.host, address2.protocols);
                    }
                    sSLSocket2.startHandshake();
                    SSLSession session = sSLSocket2.getSession();
                    Intrinsics.checkNotNullExpressionValue(session, "sslSocketSession");
                    Handshake handshake2 = Handshake.get(session);
                    HostnameVerifier hostnameVerifier = address2.hostnameVerifier;
                    Intrinsics.checkNotNull(hostnameVerifier);
                    if (!hostnameVerifier.verify(address2.url.host, session)) {
                        List<Certificate> peerCertificates = handshake2.peerCertificates();
                        if (!peerCertificates.isEmpty()) {
                            Certificate certificate = peerCertificates.get(0);
                            if (certificate == null) {
                                throw new NullPointerException("null cannot be cast to non-null type java.security.cert.X509Certificate");
                            }
                            X509Certificate x509Certificate = (X509Certificate) certificate;
                            StringBuilder sb = new StringBuilder();
                            sb.append("\n              |Hostname ");
                            sb.append(address2.url.host);
                            sb.append(" not verified:\n              |    certificate: ");
                            sb.append(CertificatePinner.Companion.pin(x509Certificate));
                            sb.append("\n              |    DN: ");
                            Principal subjectDN = x509Certificate.getSubjectDN();
                            Intrinsics.checkNotNullExpressionValue(subjectDN, "cert.subjectDN");
                            sb.append(subjectDN.getName());
                            sb.append("\n              |    subjectAltNames: ");
                            OkHostnameVerifier okHostnameVerifier = OkHostnameVerifier.INSTANCE;
                            Intrinsics.checkNotNullParameter(x509Certificate, VpnProfileDataSource.KEY_CERTIFICATE);
                            List<String> subjectAltNames = okHostnameVerifier.getSubjectAltNames(x509Certificate, 7);
                            List<String> subjectAltNames2 = okHostnameVerifier.getSubjectAltNames(x509Certificate, 2);
                            Intrinsics.checkNotNullParameter(subjectAltNames, "$this$plus");
                            Intrinsics.checkNotNullParameter(subjectAltNames2, "elements");
                            ArrayList arrayList = new ArrayList(subjectAltNames2.size() + subjectAltNames.size());
                            arrayList.addAll(subjectAltNames);
                            arrayList.addAll(subjectAltNames2);
                            sb.append(arrayList);
                            sb.append("\n              ");
                            throw new SSLPeerUnverifiedException(StringsKt__IndentKt.trimMargin$default(sb.toString(), null, 1));
                        }
                        throw new SSLPeerUnverifiedException("Hostname " + address2.url.host + " not verified (no certificates)");
                    }
                    CertificatePinner certificatePinner = address2.certificatePinner;
                    Intrinsics.checkNotNull(certificatePinner);
                    this.handshake = new Handshake(handshake2.tlsVersion, handshake2.cipherSuite, handshake2.localCertificates, new RealConnection$connectTls$1(certificatePinner, handshake2, address2));
                    certificatePinner.check$okhttp(address2.url.host, new RealConnection$connectTls$2(this));
                    if (configureSecureSocket.supportsTlsExtensions) {
                        Platform.Companion companion2 = Platform.Companion;
                        str = Platform.platform.getSelectedProtocol(sSLSocket2);
                    }
                    this.socket = sSLSocket2;
                    this.source = SystemPropsKt.buffer(SystemPropsKt.source(sSLSocket2));
                    this.sink = SystemPropsKt.buffer(SystemPropsKt.sink(sSLSocket2));
                    this.protocol = str != null ? Protocol.Companion.get(str) : Protocol.HTTP_1_1;
                    Platform.Companion companion3 = Platform.Companion;
                    Platform.platform.afterHandshake(sSLSocket2);
                    Intrinsics.checkNotNullParameter(call, "call");
                    if (this.protocol == Protocol.HTTP_2) {
                        startHttp2(i);
                    }
                } catch (Throwable th2) {
                    th = th2;
                    sSLSocket = sSLSocket2;
                    if (sSLSocket != null) {
                    }
                    if (sSLSocket != null) {
                    }
                    throw th;
                }
            } else {
                throw new NullPointerException("null cannot be cast to non-null type javax.net.ssl.SSLSocket");
            }
        } catch (Throwable th3) {
            th = th3;
            if (sSLSocket != null) {
                Platform.Companion companion4 = Platform.Companion;
                Platform.platform.afterHandshake(sSLSocket);
            }
            if (sSLSocket != null) {
                Util.closeQuietly((Socket) sSLSocket);
            }
            throw th;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:48:0x00d2, code lost:
        if (r8 == false) goto L_0x00d6;
     */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x009b  */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x00d9 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x00da A[SYNTHETIC, Splitter:B:53:0x00da] */
    public final boolean isEligible$okhttp(Address address, List<Route> list) {
        boolean z;
        OkHostnameVerifier okHostnameVerifier;
        HttpUrl httpUrl;
        HttpUrl httpUrl2;
        boolean z2;
        Handshake handshake2;
        boolean z3;
        boolean z4;
        Intrinsics.checkNotNullParameter(address, "address");
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        if (this.calls.size() >= this.allocationLimit || this.noNewExchanges || !this.route.address.equalsNonHost$okhttp(address)) {
            return false;
        }
        if (Intrinsics.areEqual(address.url.host, this.route.address.url.host)) {
            return true;
        }
        if (!(this.http2Connection == null || list == null)) {
            if (!list.isEmpty()) {
                Iterator<T> it = list.iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    T next = it.next();
                    if (next.proxy.type() == Proxy.Type.DIRECT && this.route.proxy.type() == Proxy.Type.DIRECT && Intrinsics.areEqual(this.route.socketAddress, next.socketAddress)) {
                        z4 = true;
                        continue;
                    } else {
                        z4 = false;
                        continue;
                    }
                    if (z4) {
                        z = true;
                        break;
                    }
                }
                if (!z || address.hostnameVerifier != (okHostnameVerifier = OkHostnameVerifier.INSTANCE)) {
                    return false;
                }
                httpUrl = address.url;
                byte[] bArr2 = Util.EMPTY_BYTE_ARRAY;
                httpUrl2 = this.route.address.url;
                if (httpUrl.port == httpUrl2.port) {
                    if (!Intrinsics.areEqual(httpUrl.host, httpUrl2.host)) {
                        if (!this.noCoalescedConnections && (handshake2 = this.handshake) != null) {
                            Intrinsics.checkNotNull(handshake2);
                            List<Certificate> peerCertificates = handshake2.peerCertificates();
                            if (!peerCertificates.isEmpty()) {
                                String str = httpUrl.host;
                                Certificate certificate = peerCertificates.get(0);
                                Objects.requireNonNull(certificate, "null cannot be cast to non-null type java.security.cert.X509Certificate");
                                if (okHostnameVerifier.verify(str, (X509Certificate) certificate)) {
                                    z3 = true;
                                }
                            }
                            z3 = false;
                        }
                    }
                    z2 = true;
                    if (!z2) {
                        return false;
                    }
                    try {
                        CertificatePinner certificatePinner = address.certificatePinner;
                        Intrinsics.checkNotNull(certificatePinner);
                        String str2 = address.url.host;
                        Handshake handshake3 = this.handshake;
                        Intrinsics.checkNotNull(handshake3);
                        List<Certificate> peerCertificates2 = handshake3.peerCertificates();
                        Intrinsics.checkNotNullParameter(str2, "hostname");
                        Intrinsics.checkNotNullParameter(peerCertificates2, "peerCertificates");
                        certificatePinner.check$okhttp(str2, new CertificatePinner$check$1(certificatePinner, peerCertificates2, str2));
                        return true;
                    } catch (SSLPeerUnverifiedException unused) {
                    }
                }
                z2 = false;
                if (!z2) {
                }
            }
            z = false;
            if (!z) {
                httpUrl = address.url;
                byte[] bArr22 = Util.EMPTY_BYTE_ARRAY;
                httpUrl2 = this.route.address.url;
                if (httpUrl.port == httpUrl2.port) {
                }
                z2 = false;
                if (!z2) {
                }
            }
        }
        return false;
    }

    /* JADX INFO: finally extract failed */
    public final boolean isHealthy(boolean z) {
        long j;
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        long nanoTime = System.nanoTime();
        Socket socket2 = this.rawSocket;
        Intrinsics.checkNotNull(socket2);
        Socket socket3 = this.socket;
        Intrinsics.checkNotNull(socket3);
        BufferedSource bufferedSource = this.source;
        Intrinsics.checkNotNull(bufferedSource);
        if (socket2.isClosed() || socket3.isClosed() || socket3.isInputShutdown() || socket3.isOutputShutdown()) {
            return false;
        }
        Http2Connection http2Connection2 = this.http2Connection;
        if (http2Connection2 != null) {
            synchronized (http2Connection2) {
                if (http2Connection2.isShutdown) {
                    return false;
                }
                if (http2Connection2.degradedPongsReceived >= http2Connection2.degradedPingsSent || nanoTime < http2Connection2.degradedPongDeadlineNs) {
                    return true;
                }
                return false;
            }
        }
        synchronized (this) {
            j = nanoTime - this.idleAtNs;
        }
        if (j < 10000000000L || !z) {
            return true;
        }
        Intrinsics.checkNotNullParameter(socket3, "$this$isHealthy");
        Intrinsics.checkNotNullParameter(bufferedSource, "source");
        try {
            int soTimeout = socket3.getSoTimeout();
            try {
                socket3.setSoTimeout(1);
                boolean z2 = !bufferedSource.exhausted();
                socket3.setSoTimeout(soTimeout);
                return z2;
            } catch (Throwable th) {
                socket3.setSoTimeout(soTimeout);
                throw th;
            }
        } catch (SocketTimeoutException unused) {
            return true;
        } catch (IOException unused2) {
            return false;
        }
    }

    public final boolean isMultiplexed$okhttp() {
        return this.http2Connection != null;
    }

    public final ExchangeCodec newCodec$okhttp(OkHttpClient okHttpClient, RealInterceptorChain realInterceptorChain) {
        Intrinsics.checkNotNullParameter(okHttpClient, "client");
        Intrinsics.checkNotNullParameter(realInterceptorChain, "chain");
        Socket socket2 = this.socket;
        Intrinsics.checkNotNull(socket2);
        BufferedSource bufferedSource = this.source;
        Intrinsics.checkNotNull(bufferedSource);
        BufferedSink bufferedSink = this.sink;
        Intrinsics.checkNotNull(bufferedSink);
        Http2Connection http2Connection2 = this.http2Connection;
        if (http2Connection2 != null) {
            return new Http2ExchangeCodec(okHttpClient, this, realInterceptorChain, http2Connection2);
        }
        socket2.setSoTimeout(realInterceptorChain.readTimeoutMillis);
        TimeUnit timeUnit = TimeUnit.MILLISECONDS;
        bufferedSource.timeout().timeout((long) realInterceptorChain.readTimeoutMillis, timeUnit);
        bufferedSink.timeout().timeout((long) realInterceptorChain.writeTimeoutMillis, timeUnit);
        return new Http1ExchangeCodec(okHttpClient, this, bufferedSource, bufferedSink);
    }

    public final synchronized void noNewExchanges$okhttp() {
        this.noNewExchanges = true;
    }

    @Override // okhttp3.internal.http2.Http2Connection.Listener
    public synchronized void onSettings(Http2Connection http2Connection2, Settings settings) {
        Intrinsics.checkNotNullParameter(http2Connection2, "connection");
        Intrinsics.checkNotNullParameter(settings, "settings");
        this.allocationLimit = (settings.set & 16) != 0 ? settings.values[4] : Integer.MAX_VALUE;
    }

    @Override // okhttp3.internal.http2.Http2Connection.Listener
    public void onStream(Http2Stream http2Stream) {
        Intrinsics.checkNotNullParameter(http2Stream, "stream");
        http2Stream.close(ErrorCode.REFUSED_STREAM, null);
    }

    public final void startHttp2(int i) {
        String str;
        Socket socket2 = this.socket;
        Intrinsics.checkNotNull(socket2);
        BufferedSource bufferedSource = this.source;
        Intrinsics.checkNotNull(bufferedSource);
        BufferedSink bufferedSink = this.sink;
        Intrinsics.checkNotNull(bufferedSink);
        socket2.setSoTimeout(0);
        TaskRunner taskRunner = TaskRunner.INSTANCE;
        Http2Connection.Builder builder = new Http2Connection.Builder(true, taskRunner);
        String str2 = this.route.address.url.host;
        Intrinsics.checkNotNullParameter(socket2, "socket");
        Intrinsics.checkNotNullParameter(str2, "peerName");
        Intrinsics.checkNotNullParameter(bufferedSource, "source");
        Intrinsics.checkNotNullParameter(bufferedSink, "sink");
        builder.socket = socket2;
        if (builder.client) {
            str = Util.okHttpName + StringUtil.SPACE + str2;
        } else {
            str = GeneratedOutlineSupport.outline18("MockWebServer ", str2);
        }
        builder.connectionName = str;
        builder.source = bufferedSource;
        builder.sink = bufferedSink;
        Intrinsics.checkNotNullParameter(this, "listener");
        builder.listener = this;
        builder.pingIntervalMillis = i;
        Http2Connection http2Connection2 = new Http2Connection(builder);
        this.http2Connection = http2Connection2;
        Http2Connection http2Connection3 = Http2Connection.Companion;
        Settings settings = Http2Connection.DEFAULT_SETTINGS;
        this.allocationLimit = (settings.set & 16) != 0 ? settings.values[4] : Integer.MAX_VALUE;
        Intrinsics.checkNotNullParameter(taskRunner, "taskRunner");
        Http2Writer http2Writer = http2Connection2.writer;
        synchronized (http2Writer) {
            if (http2Writer.closed) {
                throw new IOException("closed");
            } else if (http2Writer.client) {
                Logger logger = Http2Writer.logger;
                if (logger.isLoggable(Level.FINE)) {
                    logger.fine(Util.format(">> CONNECTION " + Http2.CONNECTION_PREFACE.hex(), new Object[0]));
                }
                http2Writer.sink.write(Http2.CONNECTION_PREFACE);
                http2Writer.sink.flush();
            }
        }
        Http2Writer http2Writer2 = http2Connection2.writer;
        Settings settings2 = http2Connection2.okHttpSettings;
        synchronized (http2Writer2) {
            Intrinsics.checkNotNullParameter(settings2, "settings");
            if (!http2Writer2.closed) {
                http2Writer2.frameHeader(0, Integer.bitCount(settings2.set) * 6, 4, 0);
                int i2 = 0;
                while (i2 < 10) {
                    if (((1 << i2) & settings2.set) != 0) {
                        http2Writer2.sink.writeShort(i2 != 4 ? i2 != 7 ? i2 : 4 : 3);
                        http2Writer2.sink.writeInt(settings2.values[i2]);
                    }
                    i2++;
                }
                http2Writer2.sink.flush();
            } else {
                throw new IOException("closed");
            }
        }
        int initialWindowSize = http2Connection2.okHttpSettings.getInitialWindowSize();
        if (initialWindowSize != 65535) {
            http2Connection2.writer.windowUpdate(0, (long) (initialWindowSize - FastLz.MAX_CHUNK_LENGTH));
        }
        TaskQueue newQueue = taskRunner.newQueue();
        String str3 = http2Connection2.connectionName;
        newQueue.schedule(new TaskQueue$execute$1(http2Connection2.readerRunnable, str3, true, str3, true), 0);
    }

    public String toString() {
        Object obj;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("Connection{");
        outline25.append(this.route.address.url.host);
        outline25.append(':');
        outline25.append(this.route.address.url.port);
        outline25.append(StringUtil.COMMA);
        outline25.append(" proxy=");
        outline25.append(this.route.proxy);
        outline25.append(" hostAddress=");
        outline25.append(this.route.socketAddress);
        outline25.append(" cipherSuite=");
        Handshake handshake2 = this.handshake;
        if (handshake2 == null || (obj = handshake2.cipherSuite) == null) {
            obj = "none";
        }
        outline25.append(obj);
        outline25.append(" protocol=");
        outline25.append(this.protocol);
        outline25.append('}');
        return outline25.toString();
    }
}
