package okhttp3.internal.http;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.util.List;
import kotlin.jvm.internal.Intrinsics;
import okhttp3.Interceptor;
import okhttp3.Request;
import okhttp3.Response;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.connection.RealCall;

/* compiled from: RealInterceptorChain.kt */
public final class RealInterceptorChain implements Interceptor.Chain {
    public final RealCall call;
    public int calls;
    public final int connectTimeoutMillis;
    public final Exchange exchange;
    public final int index;
    public final List<Interceptor> interceptors;
    public final int readTimeoutMillis;
    public final Request request;
    public final int writeTimeoutMillis;

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: java.util.List<? extends okhttp3.Interceptor> */
    /* JADX WARN: Multi-variable type inference failed */
    public RealInterceptorChain(RealCall realCall, List<? extends Interceptor> list, int i, Exchange exchange2, Request request2, int i2, int i3, int i4) {
        Intrinsics.checkNotNullParameter(realCall, "call");
        Intrinsics.checkNotNullParameter(list, "interceptors");
        Intrinsics.checkNotNullParameter(request2, "request");
        this.call = realCall;
        this.interceptors = list;
        this.index = i;
        this.exchange = exchange2;
        this.request = request2;
        this.connectTimeoutMillis = i2;
        this.readTimeoutMillis = i3;
        this.writeTimeoutMillis = i4;
    }

    public static RealInterceptorChain copy$okhttp$default(RealInterceptorChain realInterceptorChain, int i, Exchange exchange2, Request request2, int i2, int i3, int i4, int i5) {
        int i6 = (i5 & 1) != 0 ? realInterceptorChain.index : i;
        Exchange exchange3 = (i5 & 2) != 0 ? realInterceptorChain.exchange : exchange2;
        Request request3 = (i5 & 4) != 0 ? realInterceptorChain.request : request2;
        int i7 = (i5 & 8) != 0 ? realInterceptorChain.connectTimeoutMillis : i2;
        int i8 = (i5 & 16) != 0 ? realInterceptorChain.readTimeoutMillis : i3;
        int i9 = (i5 & 32) != 0 ? realInterceptorChain.writeTimeoutMillis : i4;
        Intrinsics.checkNotNullParameter(request3, "request");
        return new RealInterceptorChain(realInterceptorChain.call, realInterceptorChain.interceptors, i6, exchange3, request3, i7, i8, i9);
    }

    public Response proceed(Request request2) {
        Intrinsics.checkNotNullParameter(request2, "request");
        boolean z = false;
        if (this.index < this.interceptors.size()) {
            this.calls++;
            Exchange exchange2 = this.exchange;
            if (exchange2 != null) {
                if (exchange2.finder.sameHostAndPort(request2.url)) {
                    if (!(this.calls == 1)) {
                        StringBuilder outline25 = GeneratedOutlineSupport.outline25("network interceptor ");
                        outline25.append(this.interceptors.get(this.index - 1));
                        outline25.append(" must call proceed() exactly once");
                        throw new IllegalStateException(outline25.toString().toString());
                    }
                } else {
                    StringBuilder outline252 = GeneratedOutlineSupport.outline25("network interceptor ");
                    outline252.append(this.interceptors.get(this.index - 1));
                    outline252.append(" must retain the same host and port");
                    throw new IllegalStateException(outline252.toString().toString());
                }
            }
            RealInterceptorChain copy$okhttp$default = copy$okhttp$default(this, this.index + 1, null, request2, 0, 0, 0, 58);
            Interceptor interceptor = this.interceptors.get(this.index);
            Response intercept = interceptor.intercept(copy$okhttp$default);
            if (intercept != null) {
                if (this.exchange != null) {
                    if (!(this.index + 1 >= this.interceptors.size() || copy$okhttp$default.calls == 1)) {
                        throw new IllegalStateException(("network interceptor " + interceptor + " must call proceed() exactly once").toString());
                    }
                }
                if (intercept.body != null) {
                    z = true;
                }
                if (z) {
                    return intercept;
                }
                throw new IllegalStateException(("interceptor " + interceptor + " returned a response with no body").toString());
            }
            throw new NullPointerException("interceptor " + interceptor + " returned null");
        }
        throw new IllegalStateException("Check failed.".toString());
    }
}
