package okhttp3.internal.http2;

import com.allpayx.sdk.util.HttpUtil;
import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.internal.Util;
import okhttp3.internal.http2.Huffman;
import okio.Buffer;
import okio.BufferedSource;
import okio.ByteString;
import okio.Source;
import org.xbill.DNS.KEYRecord;

/* compiled from: Hpack.kt */
public final class Hpack {
    public static final Hpack INSTANCE = new Hpack();
    public static final Map<ByteString, Integer> NAME_TO_FIRST_INDEX;
    public static final Header[] STATIC_HEADER_TABLE;

    /* compiled from: Hpack.kt */
    public final class Reader {
        public Header[] dynamicTable;
        public int dynamicTableByteCount;
        public int headerCount;
        public final List<Header> headerList;
        public final int headerTableSizeSetting;
        public int maxDynamicTableByteCount;
        public int nextHeaderIndex;
        public final BufferedSource source;

        public Reader(Source source2, int i, int i2, int i3) {
            i2 = (i3 & 4) != 0 ? i : i2;
            Intrinsics.checkNotNullParameter(source2, "source");
            this.headerTableSizeSetting = i;
            this.maxDynamicTableByteCount = i2;
            this.headerList = new ArrayList();
            this.source = SystemPropsKt.buffer(source2);
            this.dynamicTable = new Header[8];
            this.nextHeaderIndex = 7;
        }

        public final void clearDynamicTable() {
            Header[] headerArr = this.dynamicTable;
            int length = headerArr.length;
            Intrinsics.checkNotNullParameter(headerArr, "$this$fill");
            Arrays.fill(headerArr, 0, length, (Object) null);
            this.nextHeaderIndex = this.dynamicTable.length - 1;
            this.headerCount = 0;
            this.dynamicTableByteCount = 0;
        }

        public final int dynamicTableIndex(int i) {
            return this.nextHeaderIndex + 1 + i;
        }

        public final int evictToRecoverBytes(int i) {
            int i2;
            int i3 = 0;
            if (i > 0) {
                int length = this.dynamicTable.length;
                while (true) {
                    length--;
                    i2 = this.nextHeaderIndex;
                    if (length < i2 || i <= 0) {
                        Header[] headerArr = this.dynamicTable;
                        System.arraycopy(headerArr, i2 + 1, headerArr, i2 + 1 + i3, this.headerCount);
                        this.nextHeaderIndex += i3;
                    } else {
                        Header header = this.dynamicTable[length];
                        Intrinsics.checkNotNull(header);
                        int i4 = header.hpackSize;
                        i -= i4;
                        this.dynamicTableByteCount -= i4;
                        this.headerCount--;
                        i3++;
                    }
                }
                Header[] headerArr2 = this.dynamicTable;
                System.arraycopy(headerArr2, i2 + 1, headerArr2, i2 + 1 + i3, this.headerCount);
                this.nextHeaderIndex += i3;
            }
            return i3;
        }

        /* JADX WARNING: Removed duplicated region for block: B:6:0x0010  */
        /* JADX WARNING: Removed duplicated region for block: B:7:0x0019  */
        public final ByteString getName(int i) {
            boolean z;
            if (i >= 0) {
                Hpack hpack = Hpack.INSTANCE;
                if (i <= Hpack.STATIC_HEADER_TABLE.length - 1) {
                    z = true;
                    if (!z) {
                        Hpack hpack2 = Hpack.INSTANCE;
                        return Hpack.STATIC_HEADER_TABLE[i].name;
                    }
                    Hpack hpack3 = Hpack.INSTANCE;
                    int dynamicTableIndex = dynamicTableIndex(i - Hpack.STATIC_HEADER_TABLE.length);
                    if (dynamicTableIndex >= 0) {
                        Header[] headerArr = this.dynamicTable;
                        if (dynamicTableIndex < headerArr.length) {
                            Header header = headerArr[dynamicTableIndex];
                            Intrinsics.checkNotNull(header);
                            return header.name;
                        }
                    }
                    StringBuilder outline25 = GeneratedOutlineSupport.outline25("Header index too large ");
                    outline25.append(i + 1);
                    throw new IOException(outline25.toString());
                }
            }
            z = false;
            if (!z) {
            }
        }

        public final void insertIntoDynamicTable(int i, Header header) {
            this.headerList.add(header);
            int i2 = header.hpackSize;
            if (i != -1) {
                Header header2 = this.dynamicTable[this.nextHeaderIndex + 1 + i];
                Intrinsics.checkNotNull(header2);
                i2 -= header2.hpackSize;
            }
            int i3 = this.maxDynamicTableByteCount;
            if (i2 > i3) {
                clearDynamicTable();
                return;
            }
            int evictToRecoverBytes = evictToRecoverBytes((this.dynamicTableByteCount + i2) - i3);
            if (i == -1) {
                int i4 = this.headerCount + 1;
                Header[] headerArr = this.dynamicTable;
                if (i4 > headerArr.length) {
                    Header[] headerArr2 = new Header[(headerArr.length * 2)];
                    System.arraycopy(headerArr, 0, headerArr2, headerArr.length, headerArr.length);
                    this.nextHeaderIndex = this.dynamicTable.length - 1;
                    this.dynamicTable = headerArr2;
                }
                int i5 = this.nextHeaderIndex;
                this.nextHeaderIndex = i5 - 1;
                this.dynamicTable[i5] = header;
                this.headerCount++;
            } else {
                this.dynamicTable[this.nextHeaderIndex + 1 + i + evictToRecoverBytes + i] = header;
            }
            this.dynamicTableByteCount += i2;
        }

        public final ByteString readByteString() {
            byte readByte = this.source.readByte();
            byte[] bArr = Util.EMPTY_BYTE_ARRAY;
            int i = readByte & 255;
            int i2 = 0;
            boolean z = (i & 128) == 128;
            long readInt = (long) readInt(i, 127);
            if (!z) {
                return this.source.readByteString(readInt);
            }
            Buffer buffer = new Buffer();
            Huffman huffman = Huffman.INSTANCE;
            BufferedSource bufferedSource = this.source;
            Intrinsics.checkNotNullParameter(bufferedSource, "source");
            Intrinsics.checkNotNullParameter(buffer, "sink");
            Huffman.Node node = Huffman.root;
            int i3 = 0;
            for (long j = 0; j < readInt; j++) {
                byte readByte2 = bufferedSource.readByte();
                byte[] bArr2 = Util.EMPTY_BYTE_ARRAY;
                i2 = (i2 << 8) | (readByte2 & 255);
                i3 += 8;
                while (i3 >= 8) {
                    int i4 = i3 - 8;
                    int i5 = (i2 >>> i4) & KEYRecord.PROTOCOL_ANY;
                    Huffman.Node[] nodeArr = node.children;
                    Intrinsics.checkNotNull(nodeArr);
                    node = nodeArr[i5];
                    Intrinsics.checkNotNull(node);
                    if (node.children == null) {
                        buffer.writeByte(node.symbol);
                        i3 -= node.terminalBitCount;
                        node = Huffman.root;
                    } else {
                        i3 = i4;
                    }
                }
            }
            while (i3 > 0) {
                int i6 = (i2 << (8 - i3)) & KEYRecord.PROTOCOL_ANY;
                Huffman.Node[] nodeArr2 = node.children;
                Intrinsics.checkNotNull(nodeArr2);
                Huffman.Node node2 = nodeArr2[i6];
                Intrinsics.checkNotNull(node2);
                if (node2.children != null || node2.terminalBitCount > i3) {
                    break;
                }
                buffer.writeByte(node2.symbol);
                i3 -= node2.terminalBitCount;
                node = Huffman.root;
            }
            return buffer.readByteString();
        }

        public final int readInt(int i, int i2) {
            int i3 = i & i2;
            if (i3 < i2) {
                return i3;
            }
            int i4 = 0;
            while (true) {
                byte readByte = this.source.readByte();
                byte[] bArr = Util.EMPTY_BYTE_ARRAY;
                int i5 = readByte & 255;
                if ((i5 & 128) == 0) {
                    return i2 + (i5 << i4);
                }
                i2 += (i5 & 127) << i4;
                i4 += 7;
            }
        }
    }

    /* compiled from: Hpack.kt */
    public final class Writer {
        public Header[] dynamicTable;
        public int dynamicTableByteCount;
        public boolean emitDynamicTableSizeUpdate;
        public int headerCount;
        public int headerTableSizeSetting;
        public int maxDynamicTableByteCount;
        public int nextHeaderIndex;
        public final Buffer out;
        public int smallestHeaderTableSizeSetting;
        public final boolean useCompression;

        public Writer(int i, boolean z, Buffer buffer, int i2) {
            i = (i2 & 1) != 0 ? 4096 : i;
            z = (i2 & 2) != 0 ? true : z;
            Intrinsics.checkNotNullParameter(buffer, "out");
            this.headerTableSizeSetting = i;
            this.useCompression = z;
            this.out = buffer;
            this.smallestHeaderTableSizeSetting = Integer.MAX_VALUE;
            this.maxDynamicTableByteCount = i;
            this.dynamicTable = new Header[8];
            this.nextHeaderIndex = 7;
        }

        public final void clearDynamicTable() {
            Header[] headerArr = this.dynamicTable;
            int length = headerArr.length;
            Intrinsics.checkNotNullParameter(headerArr, "$this$fill");
            Arrays.fill(headerArr, 0, length, (Object) null);
            this.nextHeaderIndex = this.dynamicTable.length - 1;
            this.headerCount = 0;
            this.dynamicTableByteCount = 0;
        }

        public final int evictToRecoverBytes(int i) {
            int i2;
            int i3 = 0;
            if (i > 0) {
                int length = this.dynamicTable.length;
                while (true) {
                    length--;
                    i2 = this.nextHeaderIndex;
                    if (length < i2 || i <= 0) {
                        Header[] headerArr = this.dynamicTable;
                        System.arraycopy(headerArr, i2 + 1, headerArr, i2 + 1 + i3, this.headerCount);
                        Header[] headerArr2 = this.dynamicTable;
                        int i4 = this.nextHeaderIndex;
                        Arrays.fill(headerArr2, i4 + 1, i4 + 1 + i3, (Object) null);
                        this.nextHeaderIndex += i3;
                    } else {
                        Header header = this.dynamicTable[length];
                        Intrinsics.checkNotNull(header);
                        i -= header.hpackSize;
                        int i5 = this.dynamicTableByteCount;
                        Header header2 = this.dynamicTable[length];
                        Intrinsics.checkNotNull(header2);
                        this.dynamicTableByteCount = i5 - header2.hpackSize;
                        this.headerCount--;
                        i3++;
                    }
                }
                Header[] headerArr3 = this.dynamicTable;
                System.arraycopy(headerArr3, i2 + 1, headerArr3, i2 + 1 + i3, this.headerCount);
                Header[] headerArr22 = this.dynamicTable;
                int i42 = this.nextHeaderIndex;
                Arrays.fill(headerArr22, i42 + 1, i42 + 1 + i3, (Object) null);
                this.nextHeaderIndex += i3;
            }
            return i3;
        }

        public final void insertIntoDynamicTable(Header header) {
            int i = header.hpackSize;
            int i2 = this.maxDynamicTableByteCount;
            if (i > i2) {
                clearDynamicTable();
                return;
            }
            evictToRecoverBytes((this.dynamicTableByteCount + i) - i2);
            int i3 = this.headerCount + 1;
            Header[] headerArr = this.dynamicTable;
            if (i3 > headerArr.length) {
                Header[] headerArr2 = new Header[(headerArr.length * 2)];
                System.arraycopy(headerArr, 0, headerArr2, headerArr.length, headerArr.length);
                this.nextHeaderIndex = this.dynamicTable.length - 1;
                this.dynamicTable = headerArr2;
            }
            int i4 = this.nextHeaderIndex;
            this.nextHeaderIndex = i4 - 1;
            this.dynamicTable[i4] = header;
            this.headerCount++;
            this.dynamicTableByteCount += i;
        }

        public final void writeByteString(ByteString byteString) {
            Intrinsics.checkNotNullParameter(byteString, "data");
            int i = 0;
            if (this.useCompression) {
                Huffman huffman = Huffman.INSTANCE;
                Intrinsics.checkNotNullParameter(byteString, "bytes");
                int size = byteString.size();
                long j = 0;
                for (int i2 = 0; i2 < size; i2++) {
                    byte b = byteString.getByte(i2);
                    byte[] bArr = Util.EMPTY_BYTE_ARRAY;
                    j += (long) Huffman.CODE_BIT_COUNTS[b & 255];
                }
                if (((int) ((j + ((long) 7)) >> 3)) < byteString.size()) {
                    Buffer buffer = new Buffer();
                    Huffman huffman2 = Huffman.INSTANCE;
                    Intrinsics.checkNotNullParameter(byteString, "source");
                    Intrinsics.checkNotNullParameter(buffer, "sink");
                    int size2 = byteString.size();
                    long j2 = 0;
                    byte b2 = 0;
                    while (i < size2) {
                        byte b3 = byteString.getByte(i);
                        byte[] bArr2 = Util.EMPTY_BYTE_ARRAY;
                        int i3 = b3 & 255;
                        int i4 = Huffman.CODES[i3];
                        byte b4 = Huffman.CODE_BIT_COUNTS[i3];
                        j2 = (j2 << b4) | ((long) i4);
                        int i5 = b2 + b4;
                        while (i5 >= 8) {
                            i5 = (i5 == 1 ? 1 : 0) - 8;
                            buffer.writeByte((int) (j2 >> i5));
                        }
                        i++;
                        b2 = i5;
                    }
                    if (b2 > 0) {
                        buffer.writeByte((int) ((255 >>> (b2 == 1 ? 1 : 0)) | (j2 << (8 - b2))));
                    }
                    ByteString readByteString = buffer.readByteString();
                    writeInt(readByteString.size(), 127, 128);
                    this.out.write(readByteString);
                    return;
                }
            }
            writeInt(byteString.size(), 127, 0);
            this.out.write(byteString);
        }

        public final void writeHeaders(List<Header> list) {
            int i;
            int i2;
            Intrinsics.checkNotNullParameter(list, "headerBlock");
            if (this.emitDynamicTableSizeUpdate) {
                int i3 = this.smallestHeaderTableSizeSetting;
                if (i3 < this.maxDynamicTableByteCount) {
                    writeInt(i3, 31, 32);
                }
                this.emitDynamicTableSizeUpdate = false;
                this.smallestHeaderTableSizeSetting = Integer.MAX_VALUE;
                writeInt(this.maxDynamicTableByteCount, 31, 32);
            }
            int size = list.size();
            for (int i4 = 0; i4 < size; i4++) {
                Header header = list.get(i4);
                ByteString asciiLowercase = header.name.toAsciiLowercase();
                ByteString byteString = header.value;
                Hpack hpack = Hpack.INSTANCE;
                Integer num = Hpack.NAME_TO_FIRST_INDEX.get(asciiLowercase);
                if (num != null) {
                    i2 = num.intValue() + 1;
                    if (2 <= i2 && 7 >= i2) {
                        Header[] headerArr = Hpack.STATIC_HEADER_TABLE;
                        if (Intrinsics.areEqual(headerArr[i2 - 1].value, byteString)) {
                            i = i2;
                        } else if (Intrinsics.areEqual(headerArr[i2].value, byteString)) {
                            i = i2;
                            i2++;
                        }
                    }
                    i = i2;
                    i2 = -1;
                } else {
                    i2 = -1;
                    i = -1;
                }
                if (i2 == -1) {
                    int i5 = this.nextHeaderIndex + 1;
                    int length = this.dynamicTable.length;
                    while (true) {
                        if (i5 >= length) {
                            break;
                        }
                        Header header2 = this.dynamicTable[i5];
                        Intrinsics.checkNotNull(header2);
                        if (Intrinsics.areEqual(header2.name, asciiLowercase)) {
                            Header header3 = this.dynamicTable[i5];
                            Intrinsics.checkNotNull(header3);
                            if (Intrinsics.areEqual(header3.value, byteString)) {
                                int i6 = i5 - this.nextHeaderIndex;
                                Hpack hpack2 = Hpack.INSTANCE;
                                i2 = Hpack.STATIC_HEADER_TABLE.length + i6;
                                break;
                            } else if (i == -1) {
                                Hpack hpack3 = Hpack.INSTANCE;
                                i = (i5 - this.nextHeaderIndex) + Hpack.STATIC_HEADER_TABLE.length;
                            }
                        }
                        i5++;
                    }
                }
                if (i2 != -1) {
                    writeInt(i2, 127, 128);
                } else if (i == -1) {
                    this.out.writeByte(64);
                    writeByteString(asciiLowercase);
                    writeByteString(byteString);
                    insertIntoDynamicTable(header);
                } else if (!asciiLowercase.startsWith(Header.PSEUDO_PREFIX) || !(!Intrinsics.areEqual(Header.TARGET_AUTHORITY, asciiLowercase))) {
                    writeInt(i, 63, 64);
                    writeByteString(byteString);
                    insertIntoDynamicTable(header);
                } else {
                    writeInt(i, 15, 0);
                    writeByteString(byteString);
                }
            }
        }

        public final void writeInt(int i, int i2, int i3) {
            if (i < i2) {
                this.out.writeByte(i | i3);
                return;
            }
            this.out.writeByte(i3 | i2);
            int i4 = i - i2;
            while (i4 >= 128) {
                this.out.writeByte(128 | (i4 & 127));
                i4 >>>= 7;
            }
            this.out.writeByte(i4);
        }
    }

    static {
        Header header = new Header(Header.TARGET_AUTHORITY, "");
        ByteString byteString = Header.TARGET_METHOD;
        ByteString byteString2 = Header.TARGET_PATH;
        ByteString byteString3 = Header.TARGET_SCHEME;
        ByteString byteString4 = Header.RESPONSE_STATUS;
        Header[] headerArr = {header, new Header(byteString, HttpUtil.METHOD_GET), new Header(byteString, HttpUtil.METHOD_POST), new Header(byteString2, "/"), new Header(byteString2, "/index.html"), new Header(byteString3, "http"), new Header(byteString3, "https"), new Header(byteString4, "200"), new Header(byteString4, "204"), new Header(byteString4, "206"), new Header(byteString4, "304"), new Header(byteString4, "400"), new Header(byteString4, "404"), new Header(byteString4, "500"), new Header("accept-charset", ""), new Header("accept-encoding", "gzip, deflate"), new Header("accept-language", ""), new Header("accept-ranges", ""), new Header("accept", ""), new Header("access-control-allow-origin", ""), new Header("age", ""), new Header("allow", ""), new Header("authorization", ""), new Header("cache-control", ""), new Header("content-disposition", ""), new Header("content-encoding", ""), new Header("content-language", ""), new Header("content-length", ""), new Header("content-location", ""), new Header("content-range", ""), new Header("content-type", ""), new Header("cookie", ""), new Header("date", ""), new Header("etag", ""), new Header("expect", ""), new Header("expires", ""), new Header("from", ""), new Header("host", ""), new Header("if-match", ""), new Header("if-modified-since", ""), new Header("if-none-match", ""), new Header("if-range", ""), new Header("if-unmodified-since", ""), new Header("last-modified", ""), new Header("link", ""), new Header("location", ""), new Header("max-forwards", ""), new Header("proxy-authenticate", ""), new Header("proxy-authorization", ""), new Header("range", ""), new Header("referer", ""), new Header("refresh", ""), new Header("retry-after", ""), new Header("server", ""), new Header("set-cookie", ""), new Header("strict-transport-security", ""), new Header("transfer-encoding", ""), new Header("user-agent", ""), new Header("vary", ""), new Header("via", ""), new Header("www-authenticate", "")};
        STATIC_HEADER_TABLE = headerArr;
        LinkedHashMap linkedHashMap = new LinkedHashMap(headerArr.length);
        int length = headerArr.length;
        for (int i = 0; i < length; i++) {
            Header[] headerArr2 = STATIC_HEADER_TABLE;
            if (!linkedHashMap.containsKey(headerArr2[i].name)) {
                linkedHashMap.put(headerArr2[i].name, Integer.valueOf(i));
            }
        }
        Map<ByteString, Integer> unmodifiableMap = Collections.unmodifiableMap(linkedHashMap);
        Intrinsics.checkNotNullExpressionValue(unmodifiableMap, "Collections.unmodifiableMap(result)");
        NAME_TO_FIRST_INDEX = unmodifiableMap;
    }

    public final ByteString checkLowercase(ByteString byteString) {
        Intrinsics.checkNotNullParameter(byteString, VpnProfileDataSource.KEY_NAME);
        int size = byteString.size();
        for (int i = 0; i < size; i++) {
            byte b = (byte) 65;
            byte b2 = (byte) 90;
            byte b3 = byteString.getByte(i);
            if (b <= b3 && b2 >= b3) {
                StringBuilder outline25 = GeneratedOutlineSupport.outline25("PROTOCOL_ERROR response malformed: mixed case name: ");
                outline25.append(byteString.utf8());
                throw new IOException(outline25.toString());
            }
        }
        return byteString;
    }
}
