package okhttp3.internal.tls;

import com.android.tools.r8.GeneratedOutlineSupport;
import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import java.security.cert.Certificate;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Objects;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.SSLException;
import javax.net.ssl.SSLSession;
import kotlin.collections.EmptyList;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.internal.Util;

/* compiled from: OkHostnameVerifier.kt */
public final class OkHostnameVerifier implements HostnameVerifier {
    public static final OkHostnameVerifier INSTANCE = new OkHostnameVerifier();

    public final List<String> getSubjectAltNames(X509Certificate x509Certificate, int i) {
        try {
            Collection<List<?>> subjectAlternativeNames = x509Certificate.getSubjectAlternativeNames();
            if (subjectAlternativeNames == null) {
                return EmptyList.INSTANCE;
            }
            ArrayList arrayList = new ArrayList();
            for (List<?> list : subjectAlternativeNames) {
                if (list != null) {
                    if (list.size() >= 2) {
                        if (!(!Intrinsics.areEqual(list.get(0), Integer.valueOf(i)))) {
                            Object obj = list.get(1);
                            if (obj != null) {
                                arrayList.add((String) obj);
                            }
                        }
                    }
                }
            }
            return arrayList;
        } catch (CertificateParsingException unused) {
            return EmptyList.INSTANCE;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:68:0x013c A[SYNTHETIC] */
    public final boolean verify(String str, X509Certificate x509Certificate) {
        boolean z;
        int length;
        Intrinsics.checkNotNullParameter(str, "host");
        Intrinsics.checkNotNullParameter(x509Certificate, VpnProfileDataSource.KEY_CERTIFICATE);
        byte[] bArr = Util.EMPTY_BYTE_ARRAY;
        Intrinsics.checkNotNullParameter(str, "$this$canParseAsIpAddress");
        if (Util.VERIFY_AS_IP_ADDRESS.matches(str)) {
            String canonicalHost = SystemPropsKt.toCanonicalHost(str);
            List<String> subjectAltNames = getSubjectAltNames(x509Certificate, 7);
            if (!(subjectAltNames instanceof Collection) || !subjectAltNames.isEmpty()) {
                Iterator<T> it = subjectAltNames.iterator();
                while (it.hasNext()) {
                    if (Intrinsics.areEqual(canonicalHost, SystemPropsKt.toCanonicalHost(it.next()))) {
                        return true;
                    }
                }
            }
        } else {
            Locale locale = Locale.US;
            Intrinsics.checkNotNullExpressionValue(locale, "Locale.US");
            String lowerCase = str.toLowerCase(locale);
            Intrinsics.checkNotNullExpressionValue(lowerCase, "(this as java.lang.String).toLowerCase(locale)");
            List<String> subjectAltNames2 = getSubjectAltNames(x509Certificate, 2);
            if (!(subjectAltNames2 instanceof Collection) || !subjectAltNames2.isEmpty()) {
                Iterator<T> it2 = subjectAltNames2.iterator();
                while (it2.hasNext()) {
                    T next = it2.next();
                    if (!(lowerCase.length() == 0) && !StringsKt__IndentKt.startsWith$default(lowerCase, ".", false, 2) && !StringsKt__IndentKt.endsWith$default(lowerCase, "..", false, 2)) {
                        if (!(next == null || next.length() == 0) && !StringsKt__IndentKt.startsWith$default(next, ".", false, 2) && !StringsKt__IndentKt.endsWith$default((String) next, "..", false, 2)) {
                            String outline18 = !StringsKt__IndentKt.endsWith$default(lowerCase, ".", false, 2) ? GeneratedOutlineSupport.outline18(lowerCase, ".") : lowerCase;
                            if (!StringsKt__IndentKt.endsWith$default((String) next, ".", false, 2)) {
                                next = GeneratedOutlineSupport.outline18(next, ".");
                            }
                            Locale locale2 = Locale.US;
                            Intrinsics.checkNotNullExpressionValue(locale2, "Locale.US");
                            Objects.requireNonNull(next, "null cannot be cast to non-null type java.lang.String");
                            String lowerCase2 = next.toLowerCase(locale2);
                            Intrinsics.checkNotNullExpressionValue(lowerCase2, "(this as java.lang.String).toLowerCase(locale)");
                            if (!StringsKt__IndentKt.contains$default((CharSequence) lowerCase2, (CharSequence) "*", false, 2)) {
                                z = Intrinsics.areEqual(outline18, lowerCase2);
                                continue;
                            } else if (StringsKt__IndentKt.startsWith$default(lowerCase2, "*.", false, 2) && StringsKt__IndentKt.indexOf$default((CharSequence) lowerCase2, '*', 1, false, 4) == -1 && outline18.length() >= lowerCase2.length() && !Intrinsics.areEqual("*.", lowerCase2)) {
                                String substring = lowerCase2.substring(1);
                                Intrinsics.checkNotNullExpressionValue(substring, "(this as java.lang.String).substring(startIndex)");
                                if (StringsKt__IndentKt.endsWith$default(outline18, substring, false, 2) && ((length = outline18.length() - substring.length()) <= 0 || StringsKt__IndentKt.lastIndexOf$default((CharSequence) outline18, '.', length - 1, false, 4) == -1)) {
                                    z = true;
                                    continue;
                                }
                            }
                            if (z) {
                                return true;
                            }
                        }
                    }
                    z = false;
                    continue;
                    if (z) {
                    }
                }
            }
        }
        return false;
    }

    public boolean verify(String str, SSLSession sSLSession) {
        Intrinsics.checkNotNullParameter(str, "host");
        Intrinsics.checkNotNullParameter(sSLSession, "session");
        try {
            Certificate certificate = sSLSession.getPeerCertificates()[0];
            if (certificate != null) {
                return verify(str, (X509Certificate) certificate);
            }
            throw new NullPointerException("null cannot be cast to non-null type java.security.cert.X509Certificate");
        } catch (SSLException unused) {
            return false;
        }
    }
}
