package okhttp3.logging;

import androidx.transition.ViewGroupUtilsApi14;
import com.android.tools.r8.GeneratedOutlineSupport;
import io.netty.util.internal.StringUtil;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.Set;
import java.util.concurrent.TimeUnit;
import kotlin.collections.EmptySet;
import kotlin.jvm.internal.Intrinsics;
import kotlin.text.StringsKt__IndentKt;
import kotlinx.coroutines.internal.SystemPropsKt;
import okhttp3.Headers;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.Protocol;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.connection.Exchange;
import okhttp3.internal.connection.RealConnection;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.http.RealInterceptorChain;
import okio.Buffer;
import okio.BufferedSource;
import okio.GzipSource;

/* compiled from: HttpLoggingInterceptor.kt */
public final class HttpLoggingInterceptor implements Interceptor {
    public volatile Set<String> headersToRedact = EmptySet.INSTANCE;
    public volatile Level level = Level.NONE;
    public final Logger logger;

    /* compiled from: HttpLoggingInterceptor.kt */
    public enum Level {
        NONE,
        BASIC,
        HEADERS,
        BODY
    }

    /* compiled from: HttpLoggingInterceptor.kt */
    public interface Logger {
        public static final Logger DEFAULT = new HttpLoggingInterceptor$Logger$Companion$DefaultLogger();
    }

    public HttpLoggingInterceptor() {
        Logger logger2 = Logger.DEFAULT;
        Intrinsics.checkNotNullParameter(logger2, "logger");
        this.logger = logger2;
    }

    public final boolean bodyHasUnknownEncoding(Headers headers) {
        String str = headers.get("Content-Encoding");
        if (str == null || StringsKt__IndentKt.equals(str, "identity", true) || StringsKt__IndentKt.equals(str, "gzip", true)) {
            return false;
        }
        return true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:97:0x02b9, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:98:0x02ba, code lost:
        androidx.transition.ViewGroupUtilsApi14.closeFinally(r5, r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:99:0x02be, code lost:
        throw r0;
     */
    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) {
        String str;
        String str2;
        String str3;
        String str4;
        Long l;
        Charset charset;
        Charset charset2;
        Intrinsics.checkNotNullParameter(chain, "chain");
        Level level2 = this.level;
        RealInterceptorChain realInterceptorChain = (RealInterceptorChain) chain;
        Request request = realInterceptorChain.request;
        if (level2 == Level.NONE) {
            return realInterceptorChain.proceed(request);
        }
        boolean z = level2 == Level.BODY;
        boolean z2 = z || level2 == Level.HEADERS;
        RequestBody requestBody = request.body;
        Exchange exchange = realInterceptorChain.exchange;
        RealConnection realConnection = exchange != null ? exchange.connection : null;
        StringBuilder outline25 = GeneratedOutlineSupport.outline25("--> ");
        outline25.append(request.method);
        outline25.append(StringUtil.SPACE);
        outline25.append(request.url);
        if (realConnection != null) {
            StringBuilder outline252 = GeneratedOutlineSupport.outline25(" ");
            Protocol protocol = realConnection.protocol;
            Intrinsics.checkNotNull(protocol);
            outline252.append(protocol);
            str = outline252.toString();
        } else {
            str = "";
        }
        outline25.append(str);
        String sb = outline25.toString();
        if (!z2 && requestBody != null) {
            StringBuilder outline28 = GeneratedOutlineSupport.outline28(sb, " (");
            outline28.append(requestBody.contentLength());
            outline28.append("-byte body)");
            sb = outline28.toString();
        }
        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log(sb);
        if (z2) {
            Headers headers = request.headers;
            if (requestBody != null) {
                MediaType contentType = requestBody.contentType();
                if (contentType != null && headers.get("Content-Type") == null) {
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("Content-Type: " + contentType);
                }
                if (requestBody.contentLength() != -1 && headers.get("Content-Length") == null) {
                    Logger logger2 = this.logger;
                    StringBuilder outline253 = GeneratedOutlineSupport.outline25("Content-Length: ");
                    outline253.append(requestBody.contentLength());
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger2).log(outline253.toString());
                }
            }
            int size = headers.size();
            for (int i = 0; i < size; i++) {
                logHeader(headers, i);
            }
            if (!z || requestBody == null) {
                Logger logger3 = this.logger;
                StringBuilder outline254 = GeneratedOutlineSupport.outline25("--> END ");
                outline254.append(request.method);
                ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger3).log(outline254.toString());
            } else if (bodyHasUnknownEncoding(request.headers)) {
                ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log(GeneratedOutlineSupport.outline22(GeneratedOutlineSupport.outline25("--> END "), request.method, " (encoded body omitted)"));
            } else {
                Buffer buffer = new Buffer();
                requestBody.writeTo(buffer);
                MediaType contentType2 = requestBody.contentType();
                if (contentType2 == null || (charset2 = contentType2.charset(StandardCharsets.UTF_8)) == null) {
                    charset2 = StandardCharsets.UTF_8;
                    Intrinsics.checkNotNullExpressionValue(charset2, "UTF_8");
                }
                ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("");
                if (SystemPropsKt.isProbablyUtf8(buffer)) {
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log(buffer.readString(charset2));
                    Logger logger4 = this.logger;
                    StringBuilder outline255 = GeneratedOutlineSupport.outline25("--> END ");
                    outline255.append(request.method);
                    outline255.append(" (");
                    outline255.append(requestBody.contentLength());
                    outline255.append("-byte body)");
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger4).log(outline255.toString());
                } else {
                    Logger logger5 = this.logger;
                    StringBuilder outline256 = GeneratedOutlineSupport.outline25("--> END ");
                    outline256.append(request.method);
                    outline256.append(" (binary ");
                    outline256.append(requestBody.contentLength());
                    outline256.append("-byte body omitted)");
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger5).log(outline256.toString());
                }
            }
        }
        long nanoTime = System.nanoTime();
        try {
            Response proceed = ((RealInterceptorChain) chain).proceed(request);
            long millis = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - nanoTime);
            ResponseBody responseBody = proceed.body;
            Intrinsics.checkNotNull(responseBody);
            long contentLength = responseBody.contentLength();
            String str5 = contentLength != -1 ? contentLength + "-byte" : "unknown-length";
            Logger logger6 = this.logger;
            StringBuilder outline257 = GeneratedOutlineSupport.outline25("<-- ");
            outline257.append(proceed.code);
            if (proceed.message.length() == 0) {
                str2 = "-byte body omitted)";
                str3 = "";
            } else {
                String str6 = proceed.message;
                StringBuilder sb2 = new StringBuilder();
                str2 = "-byte body omitted)";
                sb2.append(String.valueOf((char) StringUtil.SPACE));
                sb2.append(str6);
                str3 = sb2.toString();
            }
            outline257.append(str3);
            outline257.append(StringUtil.SPACE);
            outline257.append(proceed.request.url);
            outline257.append(" (");
            outline257.append(millis);
            outline257.append("ms");
            if (!z2) {
                str4 = GeneratedOutlineSupport.outline19(", ", str5, " body");
            } else {
                str4 = "";
            }
            outline257.append(str4);
            outline257.append(')');
            ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger6).log(outline257.toString());
            if (z2) {
                Headers headers2 = proceed.headers;
                int size2 = headers2.size();
                for (int i2 = 0; i2 < size2; i2++) {
                    logHeader(headers2, i2);
                }
                if (!z || !HttpHeaders.promisesBody(proceed)) {
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("<-- END HTTP");
                } else if (bodyHasUnknownEncoding(proceed.headers)) {
                    ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("<-- END HTTP (encoded body omitted)");
                } else {
                    BufferedSource source = responseBody.source();
                    source.request(Long.MAX_VALUE);
                    Buffer buffer2 = source.getBuffer();
                    if (StringsKt__IndentKt.equals("gzip", headers2.get("Content-Encoding"), true)) {
                        l = Long.valueOf(buffer2.size);
                        GzipSource gzipSource = new GzipSource(buffer2.clone());
                        buffer2 = new Buffer();
                        buffer2.writeAll(gzipSource);
                        ViewGroupUtilsApi14.closeFinally(gzipSource, null);
                    } else {
                        l = null;
                    }
                    MediaType contentType3 = responseBody.contentType();
                    if (contentType3 == null || (charset = contentType3.charset(StandardCharsets.UTF_8)) == null) {
                        charset = StandardCharsets.UTF_8;
                        Intrinsics.checkNotNullExpressionValue(charset, "UTF_8");
                    }
                    if (!SystemPropsKt.isProbablyUtf8(buffer2)) {
                        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("");
                        Logger logger7 = this.logger;
                        StringBuilder outline258 = GeneratedOutlineSupport.outline25("<-- END HTTP (binary ");
                        outline258.append(buffer2.size);
                        outline258.append(str2);
                        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger7).log(outline258.toString());
                        return proceed;
                    }
                    if (contentLength != 0) {
                        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("");
                        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log(buffer2.clone().readString(charset));
                    }
                    if (l != null) {
                        Logger logger8 = this.logger;
                        StringBuilder outline259 = GeneratedOutlineSupport.outline25("<-- END HTTP (");
                        outline259.append(buffer2.size);
                        outline259.append("-byte, ");
                        outline259.append(l);
                        outline259.append("-gzipped-byte body)");
                        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger8).log(outline259.toString());
                    } else {
                        Logger logger9 = this.logger;
                        StringBuilder outline2510 = GeneratedOutlineSupport.outline25("<-- END HTTP (");
                        outline2510.append(buffer2.size);
                        outline2510.append("-byte body)");
                        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger9).log(outline2510.toString());
                    }
                }
            }
            return proceed;
        } catch (Exception e) {
            ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) this.logger).log("<-- HTTP FAILED: " + e);
            throw e;
        }
    }

    public final void logHeader(Headers headers, int i) {
        String str;
        int i2 = i * 2;
        if (this.headersToRedact.contains(headers.namesAndValues[i2])) {
            str = "██";
        } else {
            str = headers.namesAndValues[i2 + 1];
        }
        Logger logger2 = this.logger;
        ((HttpLoggingInterceptor$Logger$Companion$DefaultLogger) logger2).log(headers.namesAndValues[i2] + ": " + str);
    }
}
