package okio;

import com.android.tools.r8.GeneratedOutlineSupport;
import java.io.EOFException;
import java.io.IOException;
import java.util.zip.DataFormatException;
import java.util.zip.Inflater;
import kotlin.jvm.internal.Intrinsics;
import kotlinx.coroutines.internal.SystemPropsKt;

/* compiled from: InflaterSource.kt */
public final class InflaterSource implements Source {
    public int bufferBytesHeldByInflater;
    public boolean closed;
    public final Inflater inflater;
    public final BufferedSource source;

    public InflaterSource(BufferedSource bufferedSource, Inflater inflater2) {
        Intrinsics.checkNotNullParameter(bufferedSource, "source");
        Intrinsics.checkNotNullParameter(inflater2, "inflater");
        this.source = bufferedSource;
        this.inflater = inflater2;
    }

    @Override // okio.Source, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        if (!this.closed) {
            this.inflater.end();
            this.closed = true;
            this.source.close();
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0071  */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x0070 A[SYNTHETIC] */
    @Override // okio.Source
    public long read(Buffer buffer, long j) {
        long j2;
        Intrinsics.checkNotNullParameter(buffer, "sink");
        do {
            Intrinsics.checkNotNullParameter(buffer, "sink");
            int i = (j > 0 ? 1 : (j == 0 ? 0 : -1));
            if (!(i >= 0)) {
                throw new IllegalArgumentException(GeneratedOutlineSupport.outline14("byteCount < 0: ", j).toString());
            } else if (!this.closed) {
                if (i != 0) {
                    try {
                        Segment writableSegment$okio = buffer.writableSegment$okio(1);
                        int min = (int) Math.min(j, (long) (8192 - writableSegment$okio.limit));
                        refill();
                        int inflate = this.inflater.inflate(writableSegment$okio.data, writableSegment$okio.limit, min);
                        int i2 = this.bufferBytesHeldByInflater;
                        if (i2 != 0) {
                            int remaining = i2 - this.inflater.getRemaining();
                            this.bufferBytesHeldByInflater -= remaining;
                            this.source.skip((long) remaining);
                        }
                        if (inflate > 0) {
                            writableSegment$okio.limit += inflate;
                            j2 = (long) inflate;
                            buffer.size += j2;
                            if (j2 <= 0) {
                                return j2;
                            }
                            if (this.inflater.finished() || this.inflater.needsDictionary()) {
                                return -1;
                            }
                        } else if (writableSegment$okio.pos == writableSegment$okio.limit) {
                            buffer.head = writableSegment$okio.pop();
                            SegmentPool.recycle(writableSegment$okio);
                        }
                    } catch (DataFormatException e) {
                        throw new IOException(e);
                    }
                }
                j2 = 0;
                if (j2 <= 0) {
                }
            } else {
                throw new IllegalStateException("closed".toString());
            }
        } while (!this.source.exhausted());
        throw new EOFException("source exhausted prematurely");
    }

    public final boolean refill() {
        if (!this.inflater.needsInput()) {
            return false;
        }
        if (this.source.exhausted()) {
            return true;
        }
        Segment segment = this.source.getBuffer().head;
        Intrinsics.checkNotNull(segment);
        int i = segment.limit;
        int i2 = segment.pos;
        int i3 = i - i2;
        this.bufferBytesHeldByInflater = i3;
        this.inflater.setInput(segment.data, i2, i3);
        return false;
    }

    @Override // okio.Source
    public Timeout timeout() {
        return this.source.timeout();
    }

    public InflaterSource(Source source2, Inflater inflater2) {
        Intrinsics.checkNotNullParameter(source2, "source");
        Intrinsics.checkNotNullParameter(inflater2, "inflater");
        BufferedSource buffer = SystemPropsKt.buffer(source2);
        Intrinsics.checkNotNullParameter(buffer, "source");
        Intrinsics.checkNotNullParameter(inflater2, "inflater");
        this.source = buffer;
        this.inflater = inflater2;
    }
}
