package org.xbill.DNS;

import com.faster.cheetah.sdk.strongswan.data.VpnProfileDataSource;
import io.netty.util.internal.StringUtil;
import java.io.ByteArrayOutputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import kotlinx.coroutines.internal.SystemPropsKt;
import org.xbill.DNS.utils.base32;

public class NSEC3Record extends Record {
    public static final int SHA1_DIGEST_ID = 1;
    public static final base32 b32 = new base32("0123456789ABCDEFGHIJKLMNOPQRSTUV=", false, false);
    private static final long serialVersionUID = -7123504635968932855L;
    private int flags;
    private int hashAlg;
    private int iterations;
    private byte[] next;
    private byte[] salt;
    private TypeBitmap types;

    public NSEC3Record() {
    }

    public static byte[] hashName(Name name, int i, int i2, byte[] bArr) {
        if (i == 1) {
            MessageDigest instance = MessageDigest.getInstance("sha-1");
            byte[] bArr2 = null;
            for (int i3 = 0; i3 <= i2; i3++) {
                instance.reset();
                if (i3 == 0) {
                    instance.update(name.toWireCanonical());
                } else {
                    instance.update(bArr2);
                }
                if (bArr != null) {
                    instance.update(bArr);
                }
                bArr2 = instance.digest();
            }
            return bArr2;
        }
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append("Unknown NSEC3 algorithmidentifier: ");
        stringBuffer.append(i);
        throw new NoSuchAlgorithmException(stringBuffer.toString());
    }

    public int getFlags() {
        return this.flags;
    }

    public int getHashAlgorithm() {
        return this.hashAlg;
    }

    public int getIterations() {
        return this.iterations;
    }

    public byte[] getNext() {
        return this.next;
    }

    @Override // org.xbill.DNS.Record
    public Record getObject() {
        return new NSEC3Record();
    }

    public byte[] getSalt() {
        return this.salt;
    }

    public int[] getTypes() {
        return this.types.toArray();
    }

    public boolean hasType(int i) {
        return this.types.contains(i);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:38:0x00c4, code lost:
        r3 = null;
     */
    @Override // org.xbill.DNS.Record
    public void rdataFromString(Tokenizer tokenizer, Name name) {
        byte[] bytes;
        int i;
        char c;
        byte[] byteArray;
        this.hashAlg = tokenizer.getUInt8();
        this.flags = tokenizer.getUInt8();
        this.iterations = tokenizer.getUInt16();
        if (tokenizer.getString().equals("-")) {
            this.salt = null;
        } else {
            tokenizer.unget();
            byte[] hexString = tokenizer.getHexString();
            this.salt = hexString;
            if (hexString.length > 255) {
                throw tokenizer.exception("salt value too long");
            }
        }
        String _getIdentifier = tokenizer._getIdentifier("a base32 string");
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        for (byte b : _getIdentifier.getBytes()) {
            char c2 = (char) b;
            if (!Character.isWhitespace(c2)) {
                byteArrayOutputStream.write((byte) Character.toUpperCase(c2));
            }
        }
        while (true) {
            i = 8;
            c = '=';
            if (byteArrayOutputStream.size() % 8 == 0) {
                break;
            }
            byteArrayOutputStream.write(61);
        }
        byte[] byteArray2 = byteArrayOutputStream.toByteArray();
        byteArrayOutputStream.reset();
        DataOutputStream dataOutputStream = new DataOutputStream(byteArrayOutputStream);
        int i2 = 0;
        loop2:
        while (true) {
            if (i2 >= byteArray2.length / i) {
                byteArray = byteArrayOutputStream.toByteArray();
                break;
            }
            short[] sArr = new short[i];
            int[] iArr = new int[5];
            int i3 = 0;
            int i4 = 8;
            while (true) {
                if (i3 >= i) {
                    break;
                }
                int i5 = (i2 * 8) + i3;
                if (((char) byteArray2[i5]) == c) {
                    break;
                }
                sArr[i3] = (short) "0123456789ABCDEFGHIJKLMNOPQRSTUV=".indexOf(byteArray2[i5]);
                if (sArr[i3] < 0) {
                    break loop2;
                }
                i4--;
                i3++;
                i = 8;
            }
            int i6 = i4 != 0 ? i4 != 1 ? i4 != 3 ? i4 != 4 ? i4 != 6 ? -1 : 1 : 2 : 3 : 4 : 5;
            if (i6 < 0) {
                break;
            }
            iArr[0] = (sArr[0] << 3) | (sArr[1] >> 2);
            iArr[1] = ((sArr[1] & 3) << 6) | (sArr[2] << 1) | (sArr[3] >> 4);
            iArr[2] = ((sArr[3] & 15) << 4) | ((sArr[4] >> 1) & 15);
            iArr[3] = (sArr[4] << 7) | (sArr[5] << 2) | (sArr[6] >> 3);
            iArr[4] = ((sArr[6] & 7) << 5) | sArr[7];
            for (int i7 = 0; i7 < i6; i7++) {
                try {
                    try {
                        dataOutputStream.writeByte((byte) (iArr[i7] & KEYRecord.PROTOCOL_ANY));
                    } catch (IOException unused) {
                    }
                } catch (IOException unused2) {
                }
            }
            i2++;
            i = 8;
            c = '=';
        }
        if (byteArray != null) {
            this.next = byteArray;
            this.types = new TypeBitmap(tokenizer);
            return;
        }
        throw tokenizer.exception("invalid base32 encoding");
    }

    @Override // org.xbill.DNS.Record
    public void rrFromWire(DNSInput dNSInput) {
        this.hashAlg = dNSInput.readU8();
        this.flags = dNSInput.readU8();
        this.iterations = dNSInput.readU16();
        int readU8 = dNSInput.readU8();
        if (readU8 > 0) {
            this.salt = dNSInput.readByteArray(readU8);
        } else {
            this.salt = null;
        }
        this.next = dNSInput.readByteArray(dNSInput.readU8());
        this.types = new TypeBitmap(dNSInput);
    }

    @Override // org.xbill.DNS.Record
    public String rrToString() {
        StringBuffer stringBuffer = new StringBuffer();
        stringBuffer.append(this.hashAlg);
        stringBuffer.append(StringUtil.SPACE);
        stringBuffer.append(this.flags);
        stringBuffer.append(StringUtil.SPACE);
        stringBuffer.append(this.iterations);
        stringBuffer.append(StringUtil.SPACE);
        byte[] bArr = this.salt;
        if (bArr == null) {
            stringBuffer.append('-');
        } else {
            stringBuffer.append(SystemPropsKt.toString(bArr));
        }
        stringBuffer.append(StringUtil.SPACE);
        byte[] bArr2 = this.next;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        for (int i = 0; i < (bArr2.length + 4) / 5; i++) {
            short[] sArr = new short[5];
            int[] iArr = new int[8];
            int i2 = 5;
            for (int i3 = 0; i3 < 5; i3++) {
                int i4 = (i * 5) + i3;
                if (i4 < bArr2.length) {
                    sArr[i3] = (short) (bArr2[i4] & 255);
                } else {
                    sArr[i3] = 0;
                    i2--;
                }
            }
            int i5 = i2 != 1 ? i2 != 2 ? i2 != 3 ? i2 != 4 ? i2 != 5 ? -1 : 0 : 1 : 3 : 4 : 6;
            iArr[0] = (byte) ((sArr[0] >> 3) & 31);
            iArr[1] = (byte) (((sArr[0] & 7) << 2) | ((sArr[1] >> 6) & 3));
            iArr[2] = (byte) ((sArr[1] >> 1) & 31);
            iArr[3] = (byte) (((sArr[1] & 1) << 4) | ((sArr[2] >> 4) & 15));
            iArr[4] = (byte) (((sArr[3] >> 7) & 1) | ((sArr[2] & 15) << 1));
            iArr[5] = (byte) ((sArr[3] >> 2) & 31);
            iArr[6] = (byte) (((sArr[3] & 3) << 3) | ((sArr[4] >> 5) & 7));
            iArr[7] = (byte) (sArr[4] & 31);
            for (int i6 = 0; i6 < 8 - i5; i6++) {
                byteArrayOutputStream.write("0123456789ABCDEFGHIJKLMNOPQRSTUV=".charAt(iArr[i6]));
            }
        }
        stringBuffer.append(new String(byteArrayOutputStream.toByteArray()));
        if (!this.types.empty()) {
            stringBuffer.append(StringUtil.SPACE);
            stringBuffer.append(this.types.toString());
        }
        return stringBuffer.toString();
    }

    @Override // org.xbill.DNS.Record
    public void rrToWire(DNSOutput dNSOutput, Compression compression, boolean z) {
        dNSOutput.writeU8(this.hashAlg);
        dNSOutput.writeU8(this.flags);
        dNSOutput.writeU16(this.iterations);
        byte[] bArr = this.salt;
        if (bArr != null) {
            dNSOutput.writeU8(bArr.length);
            dNSOutput.writeByteArray(this.salt);
        } else {
            dNSOutput.writeU8(0);
        }
        dNSOutput.writeU8(this.next.length);
        dNSOutput.writeByteArray(this.next);
        this.types.toWire(dNSOutput);
    }

    public NSEC3Record(Name name, int i, long j, int i2, int i3, int i4, byte[] bArr, byte[] bArr2, int[] iArr) {
        super(name, 50, i, j);
        this.hashAlg = Record.checkU8("hashAlg", i2);
        this.flags = Record.checkU8(VpnProfileDataSource.KEY_FLAGS, i3);
        this.iterations = Record.checkU16("iterations", i4);
        if (bArr != null) {
            if (bArr.length > 255) {
                throw new IllegalArgumentException("Invalid salt");
            } else if (bArr.length > 0) {
                byte[] bArr3 = new byte[bArr.length];
                this.salt = bArr3;
                System.arraycopy(bArr, 0, bArr3, 0, bArr.length);
            }
        }
        if (bArr2.length <= 255) {
            byte[] bArr4 = new byte[bArr2.length];
            this.next = bArr4;
            System.arraycopy(bArr2, 0, bArr4, 0, bArr2.length);
            this.types = new TypeBitmap(iArr);
            return;
        }
        throw new IllegalArgumentException("Invalid next hash");
    }

    public byte[] hashName(Name name) {
        return hashName(name, this.hashAlg, this.iterations, this.salt);
    }
}
